const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-03-31";
pub const sdk_id: []const u8 = "LakeFormation";
pub const arn_namespace: ?[]const u8 = "lakeformation";
pub const endpoint_prefix: []const u8 = "lakeformation";
pub const sigv4_name: []const u8 = "lakeformation";
pub const name: []const u8 = "AWSLakeFormation";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-03-31",
    sdk_id: []const u8 = "LakeFormation",
    arn_namespace: ?[]const u8 = "lakeformation",
    endpoint_prefix: []const u8 = "lakeformation",
    sigv4_name: []const u8 = "lakeformation",
    name: []const u8 = "AWSLakeFormation",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const add_lf_tags_to_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/AddLFTagsToResource",
        .success_code = 200,
    };

    action_name: []const u8 = "AddLFTagsToResource",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        resource: Resource,
        lf_tags: []LFTagPair,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .resource = "Resource",
                .lf_tags = "LFTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_lf_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_lf_tags_to_resource };
        }
    },
    Response: type = struct {
        failures: ?[]LFTagError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failures = "Failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const assume_decorated_role_with_saml: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/AssumeDecoratedRoleWithSAML",
        .success_code = 200,
    };

    action_name: []const u8 = "AssumeDecoratedRoleWithSAML",
    Request: type = struct {
        saml_assertion: []const u8,
        role_arn: []const u8,
        principal_arn: []const u8,
        duration_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .saml_assertion = "SAMLAssertion",
                .role_arn = "RoleArn",
                .principal_arn = "PrincipalArn",
                .duration_seconds = "DurationSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(assume_decorated_role_with_saml) } {
            return .{ .service_metadata = service_metadata, .action = assume_decorated_role_with_saml };
        }
    },
    Response: type = struct {
        access_key_id: ?[]const u8 = null,
        secret_access_key: ?[]const u8 = null,
        session_token: ?[]const u8 = null,
        expiration: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_key_id = "AccessKeyId",
                .secret_access_key = "SecretAccessKey",
                .session_token = "SessionToken",
                .expiration = "Expiration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_grant_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/BatchGrantPermissions",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGrantPermissions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        entries: []BatchPermissionsRequestEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_grant_permissions) } {
            return .{ .service_metadata = service_metadata, .action = batch_grant_permissions };
        }
    },
    Response: type = struct {
        failures: ?[]BatchPermissionsFailureEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failures = "Failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_revoke_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/BatchRevokePermissions",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchRevokePermissions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        entries: []BatchPermissionsRequestEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_revoke_permissions) } {
            return .{ .service_metadata = service_metadata, .action = batch_revoke_permissions };
        }
    },
    Response: type = struct {
        failures: ?[]BatchPermissionsFailureEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failures = "Failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const cancel_transaction: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CancelTransaction",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelTransaction",
    Request: type = struct {
        transaction_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_id = "TransactionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_transaction) } {
            return .{ .service_metadata = service_metadata, .action = cancel_transaction };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        TransactionCommitInProgress,
        TransactionCommitted,
    },
} = .{};
pub const commit_transaction: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CommitTransaction",
        .success_code = 200,
    };

    action_name: []const u8 = "CommitTransaction",
    Request: type = struct {
        transaction_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_id = "TransactionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(commit_transaction) } {
            return .{ .service_metadata = service_metadata, .action = commit_transaction };
        }
    },
    Response: type = struct {
        transaction_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_status = "TransactionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        TransactionCanceled,
    },
} = .{};
pub const create_data_cells_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateDataCellsFilter",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataCellsFilter",
    Request: type = struct {
        table_data: DataCellsFilter,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_data = "TableData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_cells_filter) } {
            return .{ .service_metadata = service_metadata, .action = create_data_cells_filter };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_lake_formation_identity_center_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateLakeFormationIdentityCenterConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLakeFormationIdentityCenterConfiguration",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        instance_arn: ?[]const u8 = null,
        external_filtering: ?ExternalFilteringConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .instance_arn = "InstanceArn",
                .external_filtering = "ExternalFiltering",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lake_formation_identity_center_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_lake_formation_identity_center_configuration };
        }
    },
    Response: type = struct {
        application_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        ConcurrentModification,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const create_lake_formation_opt_in: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateLakeFormationOptIn",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLakeFormationOptIn",
    Request: type = struct {
        principal: DataLakePrincipal,
        resource: Resource,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal = "Principal",
                .resource = "Resource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lake_formation_opt_in) } {
            return .{ .service_metadata = service_metadata, .action = create_lake_formation_opt_in };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const create_lf_tag: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateLFTag",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLFTag",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        tag_key: []const u8,
        tag_values: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .tag_key = "TagKey",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lf_tag) } {
            return .{ .service_metadata = service_metadata, .action = create_lf_tag };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const delete_data_cells_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteDataCellsFilter",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataCellsFilter",
    Request: type = struct {
        table_catalog_id: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        table_name: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_catalog_id = "TableCatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_cells_filter) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_cells_filter };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_lake_formation_identity_center_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteLakeFormationIdentityCenterConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLakeFormationIdentityCenterConfiguration",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lake_formation_identity_center_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_lake_formation_identity_center_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_lake_formation_opt_in: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteLakeFormationOptIn",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLakeFormationOptIn",
    Request: type = struct {
        principal: DataLakePrincipal,
        resource: Resource,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal = "Principal",
                .resource = "Resource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lake_formation_opt_in) } {
            return .{ .service_metadata = service_metadata, .action = delete_lake_formation_opt_in };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_lf_tag: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteLFTag",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLFTag",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        tag_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .tag_key = "TagKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lf_tag) } {
            return .{ .service_metadata = service_metadata, .action = delete_lf_tag };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_objects_on_cancel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteObjectsOnCancel",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteObjectsOnCancel",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        transaction_id: []const u8,
        objects: []struct {
            uri: []const u8,
            e_tag: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .uri = "Uri",
                    .e_tag = "ETag",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .transaction_id = "TransactionId",
                .objects = "Objects",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_objects_on_cancel) } {
            return .{ .service_metadata = service_metadata, .action = delete_objects_on_cancel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNotReady,
        TransactionCanceled,
        TransactionCommitted,
    },
} = .{};
pub const deregister_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeregisterResource",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_resource) } {
            return .{ .service_metadata = service_metadata, .action = deregister_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const describe_lake_formation_identity_center_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeLakeFormationIdentityCenterConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeLakeFormationIdentityCenterConfiguration",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_lake_formation_identity_center_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_lake_formation_identity_center_configuration };
        }
    },
    Response: type = struct {
        catalog_id: ?[]const u8 = null,
        instance_arn: ?[]const u8 = null,
        application_arn: ?[]const u8 = null,
        external_filtering: ?ExternalFilteringConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .instance_arn = "InstanceArn",
                .application_arn = "ApplicationArn",
                .external_filtering = "ExternalFiltering",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const describe_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeResource",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource };
        }
    },
    Response: type = struct {
        resource_info: ?ResourceInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_info = "ResourceInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const describe_transaction: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeTransaction",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTransaction",
    Request: type = struct {
        transaction_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_id = "TransactionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transaction) } {
            return .{ .service_metadata = service_metadata, .action = describe_transaction };
        }
    },
    Response: type = struct {
        transaction_description: ?TransactionDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_description = "TransactionDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const extend_transaction: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ExtendTransaction",
        .success_code = 200,
    };

    action_name: []const u8 = "ExtendTransaction",
    Request: type = struct {
        transaction_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_id = "TransactionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(extend_transaction) } {
            return .{ .service_metadata = service_metadata, .action = extend_transaction };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        TransactionCanceled,
        TransactionCommitInProgress,
        TransactionCommitted,
    },
} = .{};
pub const get_data_cells_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetDataCellsFilter",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataCellsFilter",
    Request: type = struct {
        table_catalog_id: []const u8,
        database_name: []const u8,
        table_name: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_catalog_id = "TableCatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_cells_filter) } {
            return .{ .service_metadata = service_metadata, .action = get_data_cells_filter };
        }
    },
    Response: type = struct {
        data_cells_filter: ?DataCellsFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_cells_filter = "DataCellsFilter",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_data_lake_settings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetDataLakeSettings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataLakeSettings",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_lake_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_data_lake_settings };
        }
    },
    Response: type = struct {
        data_lake_settings: ?DataLakeSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_lake_settings = "DataLakeSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_effective_permissions_for_path: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetEffectivePermissionsForPath",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEffectivePermissionsForPath",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_effective_permissions_for_path) } {
            return .{ .service_metadata = service_metadata, .action = get_effective_permissions_for_path };
        }
    },
    Response: type = struct {
        permissions: ?[]PrincipalResourcePermissions = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "Permissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_lf_tag: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetLFTag",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLFTag",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        tag_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .tag_key = "TagKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lf_tag) } {
            return .{ .service_metadata = service_metadata, .action = get_lf_tag };
        }
    },
    Response: type = struct {
        catalog_id: ?[]const u8 = null,
        tag_key: ?[]const u8 = null,
        tag_values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .tag_key = "TagKey",
                .tag_values = "TagValues",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_query_state: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetQueryState",
        .success_code = 200,
    };

    action_name: []const u8 = "GetQueryState",
    Request: type = struct {
        query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query_state) } {
            return .{ .service_metadata = service_metadata, .action = get_query_state };
        }
    },
    Response: type = struct {
        @"error": ?[]const u8 = null,
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"error" = "Error",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_query_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetQueryStatistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetQueryStatistics",
    Request: type = struct {
        query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_query_statistics };
        }
    },
    Response: type = struct {
        execution_statistics: ?struct {
            average_execution_time_millis: ?i64 = null,
            data_scanned_bytes: ?i64 = null,
            work_units_executed_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .average_execution_time_millis = "AverageExecutionTimeMillis",
                    .data_scanned_bytes = "DataScannedBytes",
                    .work_units_executed_count = "WorkUnitsExecutedCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        planning_statistics: ?struct {
            estimated_data_to_scan_bytes: ?i64 = null,
            planning_time_millis: ?i64 = null,
            queue_time_millis: ?i64 = null,
            work_units_generated_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .estimated_data_to_scan_bytes = "EstimatedDataToScanBytes",
                    .planning_time_millis = "PlanningTimeMillis",
                    .queue_time_millis = "QueueTimeMillis",
                    .work_units_generated_count = "WorkUnitsGeneratedCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        query_submission_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_statistics = "ExecutionStatistics",
                .planning_statistics = "PlanningStatistics",
                .query_submission_time = "QuerySubmissionTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Expired,
        InternalService,
        InvalidInput,
        StatisticsNotReadyYet,
        Throttled,
    },
} = .{};
pub const get_resource_lf_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetResourceLFTags",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceLFTags",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        resource: Resource,
        show_assigned_lf_tags: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .resource = "Resource",
                .show_assigned_lf_tags = "ShowAssignedLFTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_lf_tags) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_lf_tags };
        }
    },
    Response: type = struct {
        lf_tag_on_database: ?[]LFTagPair = null,
        lf_tags_on_table: ?[]LFTagPair = null,
        lf_tags_on_columns: ?[]ColumnLFTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lf_tag_on_database = "LFTagOnDatabase",
                .lf_tags_on_table = "LFTagsOnTable",
                .lf_tags_on_columns = "LFTagsOnColumns",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_table_objects: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetTableObjects",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTableObjects",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        transaction_id: ?[]const u8 = null,
        query_as_of_time: ?i64 = null,
        partition_predicate: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .transaction_id = "TransactionId",
                .query_as_of_time = "QueryAsOfTime",
                .partition_predicate = "PartitionPredicate",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table_objects) } {
            return .{ .service_metadata = service_metadata, .action = get_table_objects };
        }
    },
    Response: type = struct {
        objects: ?[]struct {
            partition_values: ?[][]const u8 = null,
            objects: ?[]struct {
                uri: ?[]const u8 = null,
                e_tag: ?[]const u8 = null,
                size: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .uri = "Uri",
                        .e_tag = "ETag",
                        .size = "Size",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .partition_values = "PartitionValues",
                    .objects = "Objects",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .objects = "Objects",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNotReady,
        TransactionCanceled,
        TransactionCommitted,
    },
} = .{};
pub const get_temporary_glue_partition_credentials: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetTemporaryGluePartitionCredentials",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTemporaryGluePartitionCredentials",
    Request: type = struct {
        table_arn: []const u8,
        partition: struct {
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        },
        permissions: ?[][]const u8 = null,
        duration_seconds: ?i64 = null,
        audit_context: ?AuditContext = null,
        supported_permission_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_arn = "TableArn",
                .partition = "Partition",
                .permissions = "Permissions",
                .duration_seconds = "DurationSeconds",
                .audit_context = "AuditContext",
                .supported_permission_types = "SupportedPermissionTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_temporary_glue_partition_credentials) } {
            return .{ .service_metadata = service_metadata, .action = get_temporary_glue_partition_credentials };
        }
    },
    Response: type = struct {
        access_key_id: ?[]const u8 = null,
        secret_access_key: ?[]const u8 = null,
        session_token: ?[]const u8 = null,
        expiration: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_key_id = "AccessKeyId",
                .secret_access_key = "SecretAccessKey",
                .session_token = "SessionToken",
                .expiration = "Expiration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        PermissionTypeMismatch,
    },
} = .{};
pub const get_temporary_glue_table_credentials: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetTemporaryGlueTableCredentials",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTemporaryGlueTableCredentials",
    Request: type = struct {
        table_arn: []const u8,
        permissions: ?[][]const u8 = null,
        duration_seconds: ?i64 = null,
        audit_context: ?AuditContext = null,
        supported_permission_types: ?[][]const u8 = null,
        s3_path: ?[]const u8 = null,
        query_session_context: ?struct {
            query_id: ?[]const u8 = null,
            query_start_time: ?i64 = null,
            cluster_id: ?[]const u8 = null,
            query_authorization_id: ?[]const u8 = null,
            additional_context: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .query_id = "QueryId",
                    .query_start_time = "QueryStartTime",
                    .cluster_id = "ClusterId",
                    .query_authorization_id = "QueryAuthorizationId",
                    .additional_context = "AdditionalContext",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "additional_context", field_name))
                    return try serializeMap(self.additional_context, self.fieldNameFor("additional_context"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_arn = "TableArn",
                .permissions = "Permissions",
                .duration_seconds = "DurationSeconds",
                .audit_context = "AuditContext",
                .supported_permission_types = "SupportedPermissionTypes",
                .s3_path = "S3Path",
                .query_session_context = "QuerySessionContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_temporary_glue_table_credentials) } {
            return .{ .service_metadata = service_metadata, .action = get_temporary_glue_table_credentials };
        }
    },
    Response: type = struct {
        access_key_id: ?[]const u8 = null,
        secret_access_key: ?[]const u8 = null,
        session_token: ?[]const u8 = null,
        expiration: ?i64 = null,
        vended_s3_path: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_key_id = "AccessKeyId",
                .secret_access_key = "SecretAccessKey",
                .session_token = "SessionToken",
                .expiration = "Expiration",
                .vended_s3_path = "VendedS3Path",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        PermissionTypeMismatch,
    },
} = .{};
pub const get_work_unit_results: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetWorkUnitResults",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkUnitResults",
    Request: type = struct {
        query_id: []const u8,
        work_unit_id: i64,
        work_unit_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
                .work_unit_id = "WorkUnitId",
                .work_unit_token = "WorkUnitToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_work_unit_results) } {
            return .{ .service_metadata = service_metadata, .action = get_work_unit_results };
        }
    },
    Response: type = struct {
        result_stream: ?[]const u8 = null,

        pub const http_payload: []const u8 = "result_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result_stream = "ResultStream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Expired,
        InternalService,
        InvalidInput,
        Throttled,
    },
} = .{};
pub const get_work_units: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetWorkUnits",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkUnits",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,
        query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
                .query_id = "QueryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_work_units) } {
            return .{ .service_metadata = service_metadata, .action = get_work_units };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        query_id: []const u8,
        work_unit_ranges: []struct {
            work_unit_id_max: i64,
            work_unit_id_min: i64,
            work_unit_token: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .work_unit_id_max = "WorkUnitIdMax",
                    .work_unit_id_min = "WorkUnitIdMin",
                    .work_unit_token = "WorkUnitToken",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .query_id = "QueryId",
                .work_unit_ranges = "WorkUnitRanges",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Expired,
        InternalService,
        InvalidInput,
        WorkUnitsNotReadyYet,
    },
} = .{};
pub const grant_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GrantPermissions",
        .success_code = 200,
    };

    action_name: []const u8 = "GrantPermissions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        principal: DataLakePrincipal,
        resource: Resource,
        permissions: [][]const u8,
        permissions_with_grant_option: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .principal = "Principal",
                .resource = "Resource",
                .permissions = "Permissions",
                .permissions_with_grant_option = "PermissionsWithGrantOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(grant_permissions) } {
            return .{ .service_metadata = service_metadata, .action = grant_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const list_data_cells_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListDataCellsFilter",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataCellsFilter",
    Request: type = struct {
        table: ?TableResource = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table = "Table",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_cells_filter) } {
            return .{ .service_metadata = service_metadata, .action = list_data_cells_filter };
        }
    },
    Response: type = struct {
        data_cells_filters: ?[]DataCellsFilter = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_cells_filters = "DataCellsFilters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_lake_formation_opt_ins: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListLakeFormationOptIns",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLakeFormationOptIns",
    Request: type = struct {
        principal: ?DataLakePrincipal = null,
        resource: ?Resource = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal = "Principal",
                .resource = "Resource",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lake_formation_opt_ins) } {
            return .{ .service_metadata = service_metadata, .action = list_lake_formation_opt_ins };
        }
    },
    Response: type = struct {
        lake_formation_opt_ins_info_list: ?[]struct {
            resource: ?Resource = null,
            principal: ?DataLakePrincipal = null,
            last_modified: ?i64 = null,
            last_updated_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource = "Resource",
                    .principal = "Principal",
                    .last_modified = "LastModified",
                    .last_updated_by = "LastUpdatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lake_formation_opt_ins_info_list = "LakeFormationOptInsInfoList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_lf_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListLFTags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLFTags",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        resource_share_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .resource_share_type = "ResourceShareType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lf_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_lf_tags };
        }
    },
    Response: type = struct {
        lf_tags: ?[]LFTagPair = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lf_tags = "LFTags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListPermissions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPermissions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        principal: ?DataLakePrincipal = null,
        resource_type: ?[]const u8 = null,
        resource: ?Resource = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        include_related: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .principal = "Principal",
                .resource_type = "ResourceType",
                .resource = "Resource",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .include_related = "IncludeRelated",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permissions) } {
            return .{ .service_metadata = service_metadata, .action = list_permissions };
        }
    },
    Response: type = struct {
        principal_resource_permissions: ?[]PrincipalResourcePermissions = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal_resource_permissions = "PrincipalResourcePermissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListResources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResources",
    Request: type = struct {
        filter_condition_list: ?[]struct {
            field: ?[]const u8 = null,
            comparison_operator: ?[]const u8 = null,
            string_value_list: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field = "Field",
                    .comparison_operator = "ComparisonOperator",
                    .string_value_list = "StringValueList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_condition_list = "FilterConditionList",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_resources };
        }
    },
    Response: type = struct {
        resource_info_list: ?[]ResourceInfo = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_info_list = "ResourceInfoList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_table_storage_optimizers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListTableStorageOptimizers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTableStorageOptimizers",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        storage_optimizer_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .storage_optimizer_type = "StorageOptimizerType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_table_storage_optimizers) } {
            return .{ .service_metadata = service_metadata, .action = list_table_storage_optimizers };
        }
    },
    Response: type = struct {
        storage_optimizer_list: ?[]struct {
            storage_optimizer_type: ?[]const u8 = null,
            config: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            error_message: ?[]const u8 = null,
            warnings: ?[]const u8 = null,
            last_run_details: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .storage_optimizer_type = "StorageOptimizerType",
                    .config = "Config",
                    .error_message = "ErrorMessage",
                    .warnings = "Warnings",
                    .last_run_details = "LastRunDetails",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "config", field_name))
                    return try serializeMap(self.config, self.fieldNameFor("config"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_optimizer_list = "StorageOptimizerList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const list_transactions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListTransactions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTransactions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        status_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .status_filter = "StatusFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_transactions) } {
            return .{ .service_metadata = service_metadata, .action = list_transactions };
        }
    },
    Response: type = struct {
        transactions: ?[]TransactionDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transactions = "Transactions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const put_data_lake_settings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/PutDataLakeSettings",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDataLakeSettings",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        data_lake_settings: DataLakeSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .data_lake_settings = "DataLakeSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_data_lake_settings) } {
            return .{ .service_metadata = service_metadata, .action = put_data_lake_settings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
    },
} = .{};
pub const register_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/RegisterResource",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterResource",
    Request: type = struct {
        resource_arn: []const u8,
        use_service_linked_role: ?bool = null,
        role_arn: ?[]const u8 = null,
        with_federation: ?bool = null,
        hybrid_access_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .use_service_linked_role = "UseServiceLinkedRole",
                .role_arn = "RoleArn",
                .with_federation = "WithFederation",
                .hybrid_access_enabled = "HybridAccessEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_resource) } {
            return .{ .service_metadata = service_metadata, .action = register_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const remove_lf_tags_from_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/RemoveLFTagsFromResource",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveLFTagsFromResource",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        resource: Resource,
        lf_tags: []LFTagPair,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .resource = "Resource",
                .lf_tags = "LFTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_lf_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_lf_tags_from_resource };
        }
    },
    Response: type = struct {
        failures: ?[]LFTagError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failures = "Failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const revoke_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/RevokePermissions",
        .success_code = 200,
    };

    action_name: []const u8 = "RevokePermissions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        principal: DataLakePrincipal,
        resource: Resource,
        permissions: [][]const u8,
        permissions_with_grant_option: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .principal = "Principal",
                .resource = "Resource",
                .permissions = "Permissions",
                .permissions_with_grant_option = "PermissionsWithGrantOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_permissions) } {
            return .{ .service_metadata = service_metadata, .action = revoke_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const search_databases_by_lf_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/SearchDatabasesByLFTags",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchDatabasesByLFTags",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        catalog_id: ?[]const u8 = null,
        expression: []LFTag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .catalog_id = "CatalogId",
                .expression = "Expression",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_databases_by_lf_tags) } {
            return .{ .service_metadata = service_metadata, .action = search_databases_by_lf_tags };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        database_list: ?[]struct {
            database: ?DatabaseResource = null,
            lf_tags: ?[]LFTagPair = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database = "Database",
                    .lf_tags = "LFTags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .database_list = "DatabaseList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const search_tables_by_lf_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/SearchTablesByLFTags",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchTablesByLFTags",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        catalog_id: ?[]const u8 = null,
        expression: []LFTag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .catalog_id = "CatalogId",
                .expression = "Expression",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_tables_by_lf_tags) } {
            return .{ .service_metadata = service_metadata, .action = search_tables_by_lf_tags };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        table_list: ?[]struct {
            table: ?TableResource = null,
            lf_tag_on_database: ?[]LFTagPair = null,
            lf_tags_on_table: ?[]LFTagPair = null,
            lf_tags_on_columns: ?[]ColumnLFTag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table = "Table",
                    .lf_tag_on_database = "LFTagOnDatabase",
                    .lf_tags_on_table = "LFTagsOnTable",
                    .lf_tags_on_columns = "LFTagsOnColumns",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .table_list = "TableList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const start_query_planning: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/StartQueryPlanning",
        .success_code = 200,
    };

    action_name: []const u8 = "StartQueryPlanning",
    Request: type = struct {
        query_planning_context: struct {
            catalog_id: ?[]const u8 = null,
            database_name: []const u8,
            query_as_of_time: ?i64 = null,
            query_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            transaction_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .catalog_id = "CatalogId",
                    .database_name = "DatabaseName",
                    .query_as_of_time = "QueryAsOfTime",
                    .query_parameters = "QueryParameters",
                    .transaction_id = "TransactionId",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "query_parameters", field_name))
                    return try serializeMap(self.query_parameters, self.fieldNameFor("query_parameters"), options, out_stream);
                return false;
            }
        },
        query_string: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_planning_context = "QueryPlanningContext",
                .query_string = "QueryString",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_query_planning) } {
            return .{ .service_metadata = service_metadata, .action = start_query_planning };
        }
    },
    Response: type = struct {
        query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
        Throttled,
    },
} = .{};
pub const start_transaction: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/StartTransaction",
        .success_code = 200,
    };

    action_name: []const u8 = "StartTransaction",
    Request: type = struct {
        transaction_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_type = "TransactionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_transaction) } {
            return .{ .service_metadata = service_metadata, .action = start_transaction };
        }
    },
    Response: type = struct {
        transaction_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_id = "TransactionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        OperationTimeout,
    },
} = .{};
pub const update_data_cells_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateDataCellsFilter",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataCellsFilter",
    Request: type = struct {
        table_data: DataCellsFilter,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_data = "TableData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_cells_filter) } {
            return .{ .service_metadata = service_metadata, .action = update_data_cells_filter };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_lake_formation_identity_center_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateLakeFormationIdentityCenterConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLakeFormationIdentityCenterConfiguration",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        application_status: ?[]const u8 = null,
        external_filtering: ?ExternalFilteringConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .application_status = "ApplicationStatus",
                .external_filtering = "ExternalFiltering",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_lake_formation_identity_center_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_lake_formation_identity_center_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_lf_tag: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateLFTag",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLFTag",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        tag_key: []const u8,
        tag_values_to_delete: ?[][]const u8 = null,
        tag_values_to_add: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .tag_key = "TagKey",
                .tag_values_to_delete = "TagValuesToDelete",
                .tag_values_to_add = "TagValuesToAdd",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_lf_tag) } {
            return .{ .service_metadata = service_metadata, .action = update_lf_tag };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateResource",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResource",
    Request: type = struct {
        role_arn: []const u8,
        resource_arn: []const u8,
        with_federation: ?bool = null,
        hybrid_access_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "RoleArn",
                .resource_arn = "ResourceArn",
                .with_federation = "WithFederation",
                .hybrid_access_enabled = "HybridAccessEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource) } {
            return .{ .service_metadata = service_metadata, .action = update_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_table_objects: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateTableObjects",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTableObjects",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        transaction_id: ?[]const u8 = null,
        write_operations: []struct {
            add_object: ?struct {
                uri: []const u8,
                e_tag: []const u8,
                size: i64,
                partition_values: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .uri = "Uri",
                        .e_tag = "ETag",
                        .size = "Size",
                        .partition_values = "PartitionValues",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            delete_object: ?struct {
                uri: []const u8,
                e_tag: ?[]const u8 = null,
                partition_values: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .uri = "Uri",
                        .e_tag = "ETag",
                        .partition_values = "PartitionValues",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add_object = "AddObject",
                    .delete_object = "DeleteObject",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .transaction_id = "TransactionId",
                .write_operations = "WriteOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_table_objects) } {
            return .{ .service_metadata = service_metadata, .action = update_table_objects };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNotReady,
        TransactionCanceled,
        TransactionCommitInProgress,
        TransactionCommitted,
    },
} = .{};
pub const update_table_storage_optimizer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateTableStorageOptimizer",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTableStorageOptimizer",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        storage_optimizer_config: []struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .storage_optimizer_config = "StorageOptimizerConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "storage_optimizer_config", field_name))
                return try serializeMap(self.storage_optimizer_config, self.fieldNameFor("storage_optimizer_config"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_table_storage_optimizer) } {
            return .{ .service_metadata = service_metadata, .action = update_table_storage_optimizer };
        }
    },
    Response: type = struct {
        result: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "Result",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};

pub const ExternalFilteringConfiguration = struct {
    status: []const u8,
    authorized_targets: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .authorized_targets = "AuthorizedTargets",
        };
        return @field(mappings, field_name);
    }
};

pub const DataCellsFilter = struct {
    table_catalog_id: []const u8,
    database_name: []const u8,
    table_name: []const u8,
    name: []const u8,
    row_filter: ?RowFilter = null,
    column_names: ?[][]const u8 = null,
    column_wildcard: ?ColumnWildcard = null,
    version_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_catalog_id = "TableCatalogId",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .name = "Name",
            .row_filter = "RowFilter",
            .column_names = "ColumnNames",
            .column_wildcard = "ColumnWildcard",
            .version_id = "VersionId",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnWildcard = struct {
    excluded_column_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .excluded_column_names = "ExcludedColumnNames",
        };
        return @field(mappings, field_name);
    }
};

pub const RowFilter = struct {
    filter_expression: ?[]const u8 = null,
    all_rows_wildcard: ?AllRowsWildcard = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_expression = "FilterExpression",
            .all_rows_wildcard = "AllRowsWildcard",
        };
        return @field(mappings, field_name);
    }
};

pub const AllRowsWildcard = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const ColumnLFTag = struct {
    name: ?[]const u8 = null,
    lf_tags: ?[]LFTagPair = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .lf_tags = "LFTags",
        };
        return @field(mappings, field_name);
    }
};

pub const LFTagPair = struct {
    catalog_id: ?[]const u8 = null,
    tag_key: []const u8,
    tag_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .tag_key = "TagKey",
            .tag_values = "TagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const TableResource = struct {
    catalog_id: ?[]const u8 = null,
    database_name: []const u8,
    name: ?[]const u8 = null,
    table_wildcard: ?TableWildcard = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database_name = "DatabaseName",
            .name = "Name",
            .table_wildcard = "TableWildcard",
        };
        return @field(mappings, field_name);
    }
};

pub const TableWildcard = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const LFTag = struct {
    tag_key: []const u8,
    tag_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_key = "TagKey",
            .tag_values = "TagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseResource = struct {
    catalog_id: ?[]const u8 = null,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    catalog: ?CatalogResource = null,
    database: ?DatabaseResource = null,
    table: ?TableResource = null,
    table_with_columns: ?TableWithColumnsResource = null,
    data_location: ?DataLocationResource = null,
    data_cells_filter: ?DataCellsFilterResource = null,
    lf_tag: ?LFTagKeyResource = null,
    lf_tag_policy: ?LFTagPolicyResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog = "Catalog",
            .database = "Database",
            .table = "Table",
            .table_with_columns = "TableWithColumns",
            .data_location = "DataLocation",
            .data_cells_filter = "DataCellsFilter",
            .lf_tag = "LFTag",
            .lf_tag_policy = "LFTagPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const LFTagPolicyResource = struct {
    catalog_id: ?[]const u8 = null,
    resource_type: []const u8,
    expression: []LFTag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .resource_type = "ResourceType",
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const LFTagKeyResource = struct {
    catalog_id: ?[]const u8 = null,
    tag_key: []const u8,
    tag_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .tag_key = "TagKey",
            .tag_values = "TagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DataCellsFilterResource = struct {
    table_catalog_id: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_catalog_id = "TableCatalogId",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const DataLocationResource = struct {
    catalog_id: ?[]const u8 = null,
    resource_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .resource_arn = "ResourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const TableWithColumnsResource = struct {
    catalog_id: ?[]const u8 = null,
    database_name: []const u8,
    name: []const u8,
    column_names: ?[][]const u8 = null,
    column_wildcard: ?ColumnWildcard = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database_name = "DatabaseName",
            .name = "Name",
            .column_names = "ColumnNames",
            .column_wildcard = "ColumnWildcard",
        };
        return @field(mappings, field_name);
    }
};

pub const CatalogResource = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const DataLakePrincipal = struct {
    data_lake_principal_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_lake_principal_identifier = "DataLakePrincipalIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const LFTagError = struct {
    lf_tag: ?LFTagPair = null,
    @"error": ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lf_tag = "LFTag",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetail = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const DataLakeSettings = struct {
    data_lake_admins: ?[]DataLakePrincipal = null,
    read_only_admins: ?[]DataLakePrincipal = null,
    create_database_default_permissions: ?[]PrincipalPermissions = null,
    create_table_default_permissions: ?[]PrincipalPermissions = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    trusted_resource_owners: ?[][]const u8 = null,
    allow_external_data_filtering: ?bool = null,
    allow_full_table_external_data_access: ?bool = null,
    external_data_filtering_allow_list: ?[]DataLakePrincipal = null,
    authorized_session_tag_value_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_lake_admins = "DataLakeAdmins",
            .read_only_admins = "ReadOnlyAdmins",
            .create_database_default_permissions = "CreateDatabaseDefaultPermissions",
            .create_table_default_permissions = "CreateTableDefaultPermissions",
            .parameters = "Parameters",
            .trusted_resource_owners = "TrustedResourceOwners",
            .allow_external_data_filtering = "AllowExternalDataFiltering",
            .allow_full_table_external_data_access = "AllowFullTableExternalDataAccess",
            .external_data_filtering_allow_list = "ExternalDataFilteringAllowList",
            .authorized_session_tag_value_list = "AuthorizedSessionTagValueList",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const PrincipalPermissions = struct {
    principal: ?DataLakePrincipal = null,
    permissions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal = "Principal",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const TransactionDescription = struct {
    transaction_id: ?[]const u8 = null,
    transaction_status: ?[]const u8 = null,
    transaction_start_time: ?i64 = null,
    transaction_end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transaction_id = "TransactionId",
            .transaction_status = "TransactionStatus",
            .transaction_start_time = "TransactionStartTime",
            .transaction_end_time = "TransactionEndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceInfo = struct {
    resource_arn: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    last_modified: ?i64 = null,
    with_federation: ?bool = null,
    hybrid_access_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .role_arn = "RoleArn",
            .last_modified = "LastModified",
            .with_federation = "WithFederation",
            .hybrid_access_enabled = "HybridAccessEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const PrincipalResourcePermissions = struct {
    principal: ?DataLakePrincipal = null,
    resource: ?Resource = null,
    permissions: ?[][]const u8 = null,
    permissions_with_grant_option: ?[][]const u8 = null,
    additional_details: ?DetailsMap = null,
    last_updated: ?i64 = null,
    last_updated_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal = "Principal",
            .resource = "Resource",
            .permissions = "Permissions",
            .permissions_with_grant_option = "PermissionsWithGrantOption",
            .additional_details = "AdditionalDetails",
            .last_updated = "LastUpdated",
            .last_updated_by = "LastUpdatedBy",
        };
        return @field(mappings, field_name);
    }
};

pub const DetailsMap = struct {
    resource_share: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_share = "ResourceShare",
        };
        return @field(mappings, field_name);
    }
};

pub const AuditContext = struct {
    additional_audit_context: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_audit_context = "AdditionalAuditContext",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchPermissionsFailureEntry = struct {
    request_entry: ?BatchPermissionsRequestEntry = null,
    @"error": ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .request_entry = "RequestEntry",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchPermissionsRequestEntry = struct {
    id: []const u8,
    principal: ?DataLakePrincipal = null,
    resource: ?Resource = null,
    permissions: ?[][]const u8 = null,
    permissions_with_grant_option: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .principal = "Principal",
            .resource = "Resource",
            .permissions = "Permissions",
            .permissions_with_grant_option = "PermissionsWithGrantOption",
        };
        return @field(mappings, field_name);
    }
};
