const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-03-31";
pub const sdk_id: []const u8 = "Lambda";
pub const arn_namespace: ?[]const u8 = "lambda";
pub const endpoint_prefix: []const u8 = "lambda";
pub const sigv4_name: []const u8 = "lambda";
pub const name: []const u8 = "AWSGirApiService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-03-31",
    sdk_id: []const u8 = "Lambda",
    arn_namespace: ?[]const u8 = "lambda",
    endpoint_prefix: []const u8 = "lambda",
    sigv4_name: []const u8 = "lambda",
    name: []const u8 = "AWSGirApiService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const add_layer_version_permission: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2018-10-31/layers/{LayerName}/versions/{VersionNumber}/policy",
        .success_code = 201,
    };

    action_name: []const u8 = "AddLayerVersionPermission",
    Request: type = struct {
        layer_name: []const u8,
        version_number: i64,
        statement_id: []const u8,
        action: []const u8,
        principal: []const u8,
        organization_id: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .revision_id = "RevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .layer_name = "LayerName",
                .version_number = "VersionNumber",
                .statement_id = "StatementId",
                .action = "Action",
                .principal = "Principal",
                .organization_id = "OrganizationId",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_layer_version_permission) } {
            return .{ .service_metadata = service_metadata, .action = add_layer_version_permission };
        }
    },
    Response: type = struct {
        statement: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement = "Statement",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        PolicyLengthExceeded,
        PreconditionFailed,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const add_permission: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-03-31/functions/{FunctionName}/policy",
        .success_code = 201,
    };

    action_name: []const u8 = "AddPermission",
    Request: type = struct {
        function_name: []const u8,
        statement_id: []const u8,
        action: []const u8,
        principal: []const u8,
        source_arn: ?[]const u8 = null,
        source_account: ?[]const u8 = null,
        event_source_token: ?[]const u8 = null,
        qualifier: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,
        principal_org_id: ?[]const u8 = null,
        function_url_auth_type: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .statement_id = "StatementId",
                .action = "Action",
                .principal = "Principal",
                .source_arn = "SourceArn",
                .source_account = "SourceAccount",
                .event_source_token = "EventSourceToken",
                .qualifier = "Qualifier",
                .revision_id = "RevisionId",
                .principal_org_id = "PrincipalOrgID",
                .function_url_auth_type = "FunctionUrlAuthType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_permission) } {
            return .{ .service_metadata = service_metadata, .action = add_permission };
        }
    },
    Response: type = struct {
        statement: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement = "Statement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        PolicyLengthExceeded,
        PreconditionFailed,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const create_alias: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-03-31/functions/{FunctionName}/aliases",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAlias",
    Request: type = struct {
        function_name: []const u8,
        name: []const u8,
        function_version: []const u8,
        description: ?[]const u8 = null,
        routing_config: ?AliasRoutingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .name = "Name",
                .function_version = "FunctionVersion",
                .description = "Description",
                .routing_config = "RoutingConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_alias };
        }
    },
    Response: type = struct {
        alias_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        function_version: ?[]const u8 = null,
        description: ?[]const u8 = null,
        routing_config: ?AliasRoutingConfiguration = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_arn = "AliasArn",
                .name = "Name",
                .function_version = "FunctionVersion",
                .description = "Description",
                .routing_config = "RoutingConfig",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const create_code_signing_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-04-22/code-signing-configs",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateCodeSigningConfig",
    Request: type = struct {
        description: ?[]const u8 = null,
        allowed_publishers: AllowedPublishers,
        code_signing_policies: ?CodeSigningPolicies = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .allowed_publishers = "AllowedPublishers",
                .code_signing_policies = "CodeSigningPolicies",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_code_signing_config) } {
            return .{ .service_metadata = service_metadata, .action = create_code_signing_config };
        }
    },
    Response: type = struct {
        code_signing_config: CodeSigningConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_signing_config = "CodeSigningConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        Service,
    },
} = .{};
pub const create_event_source_mapping: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-03-31/event-source-mappings",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateEventSourceMapping",
    Request: type = struct {
        event_source_arn: ?[]const u8 = null,
        function_name: []const u8,
        enabled: ?bool = null,
        batch_size: ?i64 = null,
        filter_criteria: ?FilterCriteria = null,
        maximum_batching_window_in_seconds: ?i64 = null,
        parallelization_factor: ?i64 = null,
        starting_position: ?[]const u8 = null,
        starting_position_timestamp: ?i64 = null,
        destination_config: ?DestinationConfig = null,
        maximum_record_age_in_seconds: ?i64 = null,
        bisect_batch_on_function_error: ?bool = null,
        maximum_retry_attempts: ?i64 = null,
        tumbling_window_in_seconds: ?i64 = null,
        topics: ?[][]const u8 = null,
        queues: ?[][]const u8 = null,
        source_access_configurations: ?[]SourceAccessConfiguration = null,
        self_managed_event_source: ?SelfManagedEventSource = null,
        function_response_types: ?[][]const u8 = null,
        amazon_managed_kafka_event_source_config: ?AmazonManagedKafkaEventSourceConfig = null,
        self_managed_kafka_event_source_config: ?SelfManagedKafkaEventSourceConfig = null,
        scaling_config: ?ScalingConfig = null,
        document_db_event_source_config: ?DocumentDBEventSourceConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_source_arn = "EventSourceArn",
                .function_name = "FunctionName",
                .enabled = "Enabled",
                .batch_size = "BatchSize",
                .filter_criteria = "FilterCriteria",
                .maximum_batching_window_in_seconds = "MaximumBatchingWindowInSeconds",
                .parallelization_factor = "ParallelizationFactor",
                .starting_position = "StartingPosition",
                .starting_position_timestamp = "StartingPositionTimestamp",
                .destination_config = "DestinationConfig",
                .maximum_record_age_in_seconds = "MaximumRecordAgeInSeconds",
                .bisect_batch_on_function_error = "BisectBatchOnFunctionError",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .tumbling_window_in_seconds = "TumblingWindowInSeconds",
                .topics = "Topics",
                .queues = "Queues",
                .source_access_configurations = "SourceAccessConfigurations",
                .self_managed_event_source = "SelfManagedEventSource",
                .function_response_types = "FunctionResponseTypes",
                .amazon_managed_kafka_event_source_config = "AmazonManagedKafkaEventSourceConfig",
                .self_managed_kafka_event_source_config = "SelfManagedKafkaEventSourceConfig",
                .scaling_config = "ScalingConfig",
                .document_db_event_source_config = "DocumentDBEventSourceConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_source_mapping) } {
            return .{ .service_metadata = service_metadata, .action = create_event_source_mapping };
        }
    },
    Response: type = struct {
        uuid: ?[]const u8 = null,
        starting_position: ?[]const u8 = null,
        starting_position_timestamp: ?i64 = null,
        batch_size: ?i64 = null,
        maximum_batching_window_in_seconds: ?i64 = null,
        parallelization_factor: ?i64 = null,
        event_source_arn: ?[]const u8 = null,
        filter_criteria: ?FilterCriteria = null,
        function_arn: ?[]const u8 = null,
        last_modified: ?i64 = null,
        last_processing_result: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_transition_reason: ?[]const u8 = null,
        destination_config: ?DestinationConfig = null,
        topics: ?[][]const u8 = null,
        queues: ?[][]const u8 = null,
        source_access_configurations: ?[]SourceAccessConfiguration = null,
        self_managed_event_source: ?SelfManagedEventSource = null,
        maximum_record_age_in_seconds: ?i64 = null,
        bisect_batch_on_function_error: ?bool = null,
        maximum_retry_attempts: ?i64 = null,
        tumbling_window_in_seconds: ?i64 = null,
        function_response_types: ?[][]const u8 = null,
        amazon_managed_kafka_event_source_config: ?AmazonManagedKafkaEventSourceConfig = null,
        self_managed_kafka_event_source_config: ?SelfManagedKafkaEventSourceConfig = null,
        scaling_config: ?ScalingConfig = null,
        document_db_event_source_config: ?DocumentDBEventSourceConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uuid = "UUID",
                .starting_position = "StartingPosition",
                .starting_position_timestamp = "StartingPositionTimestamp",
                .batch_size = "BatchSize",
                .maximum_batching_window_in_seconds = "MaximumBatchingWindowInSeconds",
                .parallelization_factor = "ParallelizationFactor",
                .event_source_arn = "EventSourceArn",
                .filter_criteria = "FilterCriteria",
                .function_arn = "FunctionArn",
                .last_modified = "LastModified",
                .last_processing_result = "LastProcessingResult",
                .state = "State",
                .state_transition_reason = "StateTransitionReason",
                .destination_config = "DestinationConfig",
                .topics = "Topics",
                .queues = "Queues",
                .source_access_configurations = "SourceAccessConfigurations",
                .self_managed_event_source = "SelfManagedEventSource",
                .maximum_record_age_in_seconds = "MaximumRecordAgeInSeconds",
                .bisect_batch_on_function_error = "BisectBatchOnFunctionError",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .tumbling_window_in_seconds = "TumblingWindowInSeconds",
                .function_response_types = "FunctionResponseTypes",
                .amazon_managed_kafka_event_source_config = "AmazonManagedKafkaEventSourceConfig",
                .self_managed_kafka_event_source_config = "SelfManagedKafkaEventSourceConfig",
                .scaling_config = "ScalingConfig",
                .document_db_event_source_config = "DocumentDBEventSourceConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const create_function: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-03-31/functions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateFunction",
    Request: type = struct {
        function_name: []const u8,
        runtime: ?[]const u8 = null,
        role: []const u8,
        handler: ?[]const u8 = null,
        code: struct {
            zip_file: ?[]const u8 = null,
            s3_bucket: ?[]const u8 = null,
            s3_key: ?[]const u8 = null,
            s3_object_version: ?[]const u8 = null,
            image_uri: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .zip_file = "ZipFile",
                    .s3_bucket = "S3Bucket",
                    .s3_key = "S3Key",
                    .s3_object_version = "S3ObjectVersion",
                    .image_uri = "ImageUri",
                };
                return @field(mappings, field_name);
            }
        },
        description: ?[]const u8 = null,
        timeout: ?i64 = null,
        memory_size: ?i64 = null,
        publish: ?bool = null,
        vpc_config: ?VpcConfig = null,
        package_type: ?[]const u8 = null,
        dead_letter_config: ?DeadLetterConfig = null,
        environment: ?Environment = null,
        kms_key_arn: ?[]const u8 = null,
        tracing_config: ?TracingConfig = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        layers: ?[][]const u8 = null,
        file_system_configs: ?[]FileSystemConfig = null,
        image_config: ?ImageConfig = null,
        code_signing_config_arn: ?[]const u8 = null,
        architectures: ?[][]const u8 = null,
        ephemeral_storage: ?EphemeralStorage = null,
        snap_start: ?SnapStart = null,
        logging_config: ?LoggingConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .runtime = "Runtime",
                .role = "Role",
                .handler = "Handler",
                .code = "Code",
                .description = "Description",
                .timeout = "Timeout",
                .memory_size = "MemorySize",
                .publish = "Publish",
                .vpc_config = "VpcConfig",
                .package_type = "PackageType",
                .dead_letter_config = "DeadLetterConfig",
                .environment = "Environment",
                .kms_key_arn = "KMSKeyArn",
                .tracing_config = "TracingConfig",
                .tags = "Tags",
                .layers = "Layers",
                .file_system_configs = "FileSystemConfigs",
                .image_config = "ImageConfig",
                .code_signing_config_arn = "CodeSigningConfigArn",
                .architectures = "Architectures",
                .ephemeral_storage = "EphemeralStorage",
                .snap_start = "SnapStart",
                .logging_config = "LoggingConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_function) } {
            return .{ .service_metadata = service_metadata, .action = create_function };
        }
    },
    Response: type = struct {
        function_name: ?[]const u8 = null,
        function_arn: ?[]const u8 = null,
        runtime: ?[]const u8 = null,
        role: ?[]const u8 = null,
        handler: ?[]const u8 = null,
        code_size: ?i64 = null,
        description: ?[]const u8 = null,
        timeout: ?i64 = null,
        memory_size: ?i64 = null,
        last_modified: ?[]const u8 = null,
        code_sha256: ?[]const u8 = null,
        version: ?[]const u8 = null,
        vpc_config: ?VpcConfigResponse = null,
        dead_letter_config: ?DeadLetterConfig = null,
        environment: ?EnvironmentResponse = null,
        kms_key_arn: ?[]const u8 = null,
        tracing_config: ?TracingConfigResponse = null,
        master_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,
        layers: ?[]Layer = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        state_reason_code: ?[]const u8 = null,
        last_update_status: ?[]const u8 = null,
        last_update_status_reason: ?[]const u8 = null,
        last_update_status_reason_code: ?[]const u8 = null,
        file_system_configs: ?[]FileSystemConfig = null,
        package_type: ?[]const u8 = null,
        image_config_response: ?ImageConfigResponse = null,
        signing_profile_version_arn: ?[]const u8 = null,
        signing_job_arn: ?[]const u8 = null,
        architectures: ?[][]const u8 = null,
        ephemeral_storage: ?EphemeralStorage = null,
        snap_start: ?SnapStartResponse = null,
        runtime_version_config: ?RuntimeVersionConfig = null,
        logging_config: ?LoggingConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .function_arn = "FunctionArn",
                .runtime = "Runtime",
                .role = "Role",
                .handler = "Handler",
                .code_size = "CodeSize",
                .description = "Description",
                .timeout = "Timeout",
                .memory_size = "MemorySize",
                .last_modified = "LastModified",
                .code_sha256 = "CodeSha256",
                .version = "Version",
                .vpc_config = "VpcConfig",
                .dead_letter_config = "DeadLetterConfig",
                .environment = "Environment",
                .kms_key_arn = "KMSKeyArn",
                .tracing_config = "TracingConfig",
                .master_arn = "MasterArn",
                .revision_id = "RevisionId",
                .layers = "Layers",
                .state = "State",
                .state_reason = "StateReason",
                .state_reason_code = "StateReasonCode",
                .last_update_status = "LastUpdateStatus",
                .last_update_status_reason = "LastUpdateStatusReason",
                .last_update_status_reason_code = "LastUpdateStatusReasonCode",
                .file_system_configs = "FileSystemConfigs",
                .package_type = "PackageType",
                .image_config_response = "ImageConfigResponse",
                .signing_profile_version_arn = "SigningProfileVersionArn",
                .signing_job_arn = "SigningJobArn",
                .architectures = "Architectures",
                .ephemeral_storage = "EphemeralStorage",
                .snap_start = "SnapStart",
                .runtime_version_config = "RuntimeVersionConfig",
                .logging_config = "LoggingConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeSigningConfigNotFound,
        CodeStorageExceeded,
        CodeVerificationFailed,
        InvalidCodeSignature,
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const create_function_url_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-10-31/functions/{FunctionName}/url",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateFunctionUrlConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,
        auth_type: []const u8,
        cors: ?Cors = null,
        invoke_mode: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
                .auth_type = "AuthType",
                .cors = "Cors",
                .invoke_mode = "InvokeMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_function_url_config) } {
            return .{ .service_metadata = service_metadata, .action = create_function_url_config };
        }
    },
    Response: type = struct {
        function_url: []const u8,
        function_arn: []const u8,
        auth_type: []const u8,
        cors: ?Cors = null,
        creation_time: []const u8,
        invoke_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_url = "FunctionUrl",
                .function_arn = "FunctionArn",
                .auth_type = "AuthType",
                .cors = "Cors",
                .creation_time = "CreationTime",
                .invoke_mode = "InvokeMode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_alias: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-03-31/functions/{FunctionName}/aliases/{Name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAlias",
    Request: type = struct {
        function_name: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_alias };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_code_signing_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-04-22/code-signing-configs/{CodeSigningConfigArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteCodeSigningConfig",
    Request: type = struct {
        code_signing_config_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_signing_config_arn = "CodeSigningConfigArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_code_signing_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_code_signing_config };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const delete_event_source_mapping: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-03-31/event-source-mappings/{UUID}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteEventSourceMapping",
    Request: type = struct {
        uuid: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uuid = "UUID",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_source_mapping) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_source_mapping };
        }
    },
    Response: type = struct {
        uuid: ?[]const u8 = null,
        starting_position: ?[]const u8 = null,
        starting_position_timestamp: ?i64 = null,
        batch_size: ?i64 = null,
        maximum_batching_window_in_seconds: ?i64 = null,
        parallelization_factor: ?i64 = null,
        event_source_arn: ?[]const u8 = null,
        filter_criteria: ?FilterCriteria = null,
        function_arn: ?[]const u8 = null,
        last_modified: ?i64 = null,
        last_processing_result: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_transition_reason: ?[]const u8 = null,
        destination_config: ?DestinationConfig = null,
        topics: ?[][]const u8 = null,
        queues: ?[][]const u8 = null,
        source_access_configurations: ?[]SourceAccessConfiguration = null,
        self_managed_event_source: ?SelfManagedEventSource = null,
        maximum_record_age_in_seconds: ?i64 = null,
        bisect_batch_on_function_error: ?bool = null,
        maximum_retry_attempts: ?i64 = null,
        tumbling_window_in_seconds: ?i64 = null,
        function_response_types: ?[][]const u8 = null,
        amazon_managed_kafka_event_source_config: ?AmazonManagedKafkaEventSourceConfig = null,
        self_managed_kafka_event_source_config: ?SelfManagedKafkaEventSourceConfig = null,
        scaling_config: ?ScalingConfig = null,
        document_db_event_source_config: ?DocumentDBEventSourceConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uuid = "UUID",
                .starting_position = "StartingPosition",
                .starting_position_timestamp = "StartingPositionTimestamp",
                .batch_size = "BatchSize",
                .maximum_batching_window_in_seconds = "MaximumBatchingWindowInSeconds",
                .parallelization_factor = "ParallelizationFactor",
                .event_source_arn = "EventSourceArn",
                .filter_criteria = "FilterCriteria",
                .function_arn = "FunctionArn",
                .last_modified = "LastModified",
                .last_processing_result = "LastProcessingResult",
                .state = "State",
                .state_transition_reason = "StateTransitionReason",
                .destination_config = "DestinationConfig",
                .topics = "Topics",
                .queues = "Queues",
                .source_access_configurations = "SourceAccessConfigurations",
                .self_managed_event_source = "SelfManagedEventSource",
                .maximum_record_age_in_seconds = "MaximumRecordAgeInSeconds",
                .bisect_batch_on_function_error = "BisectBatchOnFunctionError",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .tumbling_window_in_seconds = "TumblingWindowInSeconds",
                .function_response_types = "FunctionResponseTypes",
                .amazon_managed_kafka_event_source_config = "AmazonManagedKafkaEventSourceConfig",
                .self_managed_kafka_event_source_config = "SelfManagedKafkaEventSourceConfig",
                .scaling_config = "ScalingConfig",
                .document_db_event_source_config = "DocumentDBEventSourceConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceInUse,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_function: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-03-31/functions/{FunctionName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFunction",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_function) } {
            return .{ .service_metadata = service_metadata, .action = delete_function };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_function_code_signing_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-06-30/functions/{FunctionName}/code-signing-config",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFunctionCodeSigningConfig",
    Request: type = struct {
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_function_code_signing_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_function_code_signing_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CodeSigningConfigNotFound,
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_function_concurrency: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2017-10-31/functions/{FunctionName}/concurrency",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFunctionConcurrency",
    Request: type = struct {
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_function_concurrency) } {
            return .{ .service_metadata = service_metadata, .action = delete_function_concurrency };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_function_event_invoke_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2019-09-25/functions/{FunctionName}/event-invoke-config",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFunctionEventInvokeConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_function_event_invoke_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_function_event_invoke_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_function_url_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2021-10-31/functions/{FunctionName}/url",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFunctionUrlConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_function_url_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_function_url_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_layer_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2018-10-31/layers/{LayerName}/versions/{VersionNumber}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteLayerVersion",
    Request: type = struct {
        layer_name: []const u8,
        version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .layer_name = "LayerName",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_layer_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_layer_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_provisioned_concurrency_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2019-09-30/functions/{FunctionName}/provisioned-concurrency",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteProvisionedConcurrencyConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: []const u8,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_provisioned_concurrency_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_provisioned_concurrency_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_account_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2016-08-19/account-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccountSettings",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_account_settings };
        }
    },
    Response: type = struct {
        account_limit: ?struct {
            total_code_size: ?i64 = null,
            code_size_unzipped: ?i64 = null,
            code_size_zipped: ?i64 = null,
            concurrent_executions: ?i64 = null,
            unreserved_concurrent_executions: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .total_code_size = "TotalCodeSize",
                    .code_size_unzipped = "CodeSizeUnzipped",
                    .code_size_zipped = "CodeSizeZipped",
                    .concurrent_executions = "ConcurrentExecutions",
                    .unreserved_concurrent_executions = "UnreservedConcurrentExecutions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        account_usage: ?struct {
            total_code_size: ?i64 = null,
            function_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .total_code_size = "TotalCodeSize",
                    .function_count = "FunctionCount",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_limit = "AccountLimit",
                .account_usage = "AccountUsage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_alias: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-03-31/functions/{FunctionName}/aliases/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAlias",
    Request: type = struct {
        function_name: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_alias) } {
            return .{ .service_metadata = service_metadata, .action = get_alias };
        }
    },
    Response: type = struct {
        alias_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        function_version: ?[]const u8 = null,
        description: ?[]const u8 = null,
        routing_config: ?AliasRoutingConfiguration = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_arn = "AliasArn",
                .name = "Name",
                .function_version = "FunctionVersion",
                .description = "Description",
                .routing_config = "RoutingConfig",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_code_signing_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-04-22/code-signing-configs/{CodeSigningConfigArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCodeSigningConfig",
    Request: type = struct {
        code_signing_config_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_signing_config_arn = "CodeSigningConfigArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_code_signing_config) } {
            return .{ .service_metadata = service_metadata, .action = get_code_signing_config };
        }
    },
    Response: type = struct {
        code_signing_config: CodeSigningConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_signing_config = "CodeSigningConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const get_event_source_mapping: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-03-31/event-source-mappings/{UUID}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEventSourceMapping",
    Request: type = struct {
        uuid: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uuid = "UUID",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_event_source_mapping) } {
            return .{ .service_metadata = service_metadata, .action = get_event_source_mapping };
        }
    },
    Response: type = struct {
        uuid: ?[]const u8 = null,
        starting_position: ?[]const u8 = null,
        starting_position_timestamp: ?i64 = null,
        batch_size: ?i64 = null,
        maximum_batching_window_in_seconds: ?i64 = null,
        parallelization_factor: ?i64 = null,
        event_source_arn: ?[]const u8 = null,
        filter_criteria: ?FilterCriteria = null,
        function_arn: ?[]const u8 = null,
        last_modified: ?i64 = null,
        last_processing_result: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_transition_reason: ?[]const u8 = null,
        destination_config: ?DestinationConfig = null,
        topics: ?[][]const u8 = null,
        queues: ?[][]const u8 = null,
        source_access_configurations: ?[]SourceAccessConfiguration = null,
        self_managed_event_source: ?SelfManagedEventSource = null,
        maximum_record_age_in_seconds: ?i64 = null,
        bisect_batch_on_function_error: ?bool = null,
        maximum_retry_attempts: ?i64 = null,
        tumbling_window_in_seconds: ?i64 = null,
        function_response_types: ?[][]const u8 = null,
        amazon_managed_kafka_event_source_config: ?AmazonManagedKafkaEventSourceConfig = null,
        self_managed_kafka_event_source_config: ?SelfManagedKafkaEventSourceConfig = null,
        scaling_config: ?ScalingConfig = null,
        document_db_event_source_config: ?DocumentDBEventSourceConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uuid = "UUID",
                .starting_position = "StartingPosition",
                .starting_position_timestamp = "StartingPositionTimestamp",
                .batch_size = "BatchSize",
                .maximum_batching_window_in_seconds = "MaximumBatchingWindowInSeconds",
                .parallelization_factor = "ParallelizationFactor",
                .event_source_arn = "EventSourceArn",
                .filter_criteria = "FilterCriteria",
                .function_arn = "FunctionArn",
                .last_modified = "LastModified",
                .last_processing_result = "LastProcessingResult",
                .state = "State",
                .state_transition_reason = "StateTransitionReason",
                .destination_config = "DestinationConfig",
                .topics = "Topics",
                .queues = "Queues",
                .source_access_configurations = "SourceAccessConfigurations",
                .self_managed_event_source = "SelfManagedEventSource",
                .maximum_record_age_in_seconds = "MaximumRecordAgeInSeconds",
                .bisect_batch_on_function_error = "BisectBatchOnFunctionError",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .tumbling_window_in_seconds = "TumblingWindowInSeconds",
                .function_response_types = "FunctionResponseTypes",
                .amazon_managed_kafka_event_source_config = "AmazonManagedKafkaEventSourceConfig",
                .self_managed_kafka_event_source_config = "SelfManagedKafkaEventSourceConfig",
                .scaling_config = "ScalingConfig",
                .document_db_event_source_config = "DocumentDBEventSourceConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_function: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-03-31/functions/{FunctionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFunction",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_function) } {
            return .{ .service_metadata = service_metadata, .action = get_function };
        }
    },
    Response: type = struct {
        configuration: ?FunctionConfiguration = null,
        code: ?struct {
            repository_type: ?[]const u8 = null,
            location: ?[]const u8 = null,
            image_uri: ?[]const u8 = null,
            resolved_image_uri: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .repository_type = "RepositoryType",
                    .location = "Location",
                    .image_uri = "ImageUri",
                    .resolved_image_uri = "ResolvedImageUri",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        concurrency: ?Concurrency = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "Configuration",
                .code = "Code",
                .tags = "Tags",
                .concurrency = "Concurrency",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_function_code_signing_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-06-30/functions/{FunctionName}/code-signing-config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFunctionCodeSigningConfig",
    Request: type = struct {
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_function_code_signing_config) } {
            return .{ .service_metadata = service_metadata, .action = get_function_code_signing_config };
        }
    },
    Response: type = struct {
        code_signing_config_arn: []const u8,
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_signing_config_arn = "CodeSigningConfigArn",
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_function_concurrency: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2019-09-30/functions/{FunctionName}/concurrency",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFunctionConcurrency",
    Request: type = struct {
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_function_concurrency) } {
            return .{ .service_metadata = service_metadata, .action = get_function_concurrency };
        }
    },
    Response: type = struct {
        reserved_concurrent_executions: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_concurrent_executions = "ReservedConcurrentExecutions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_function_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-03-31/functions/{FunctionName}/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFunctionConfiguration",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_function_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_function_configuration };
        }
    },
    Response: type = struct {
        function_name: ?[]const u8 = null,
        function_arn: ?[]const u8 = null,
        runtime: ?[]const u8 = null,
        role: ?[]const u8 = null,
        handler: ?[]const u8 = null,
        code_size: ?i64 = null,
        description: ?[]const u8 = null,
        timeout: ?i64 = null,
        memory_size: ?i64 = null,
        last_modified: ?[]const u8 = null,
        code_sha256: ?[]const u8 = null,
        version: ?[]const u8 = null,
        vpc_config: ?VpcConfigResponse = null,
        dead_letter_config: ?DeadLetterConfig = null,
        environment: ?EnvironmentResponse = null,
        kms_key_arn: ?[]const u8 = null,
        tracing_config: ?TracingConfigResponse = null,
        master_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,
        layers: ?[]Layer = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        state_reason_code: ?[]const u8 = null,
        last_update_status: ?[]const u8 = null,
        last_update_status_reason: ?[]const u8 = null,
        last_update_status_reason_code: ?[]const u8 = null,
        file_system_configs: ?[]FileSystemConfig = null,
        package_type: ?[]const u8 = null,
        image_config_response: ?ImageConfigResponse = null,
        signing_profile_version_arn: ?[]const u8 = null,
        signing_job_arn: ?[]const u8 = null,
        architectures: ?[][]const u8 = null,
        ephemeral_storage: ?EphemeralStorage = null,
        snap_start: ?SnapStartResponse = null,
        runtime_version_config: ?RuntimeVersionConfig = null,
        logging_config: ?LoggingConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .function_arn = "FunctionArn",
                .runtime = "Runtime",
                .role = "Role",
                .handler = "Handler",
                .code_size = "CodeSize",
                .description = "Description",
                .timeout = "Timeout",
                .memory_size = "MemorySize",
                .last_modified = "LastModified",
                .code_sha256 = "CodeSha256",
                .version = "Version",
                .vpc_config = "VpcConfig",
                .dead_letter_config = "DeadLetterConfig",
                .environment = "Environment",
                .kms_key_arn = "KMSKeyArn",
                .tracing_config = "TracingConfig",
                .master_arn = "MasterArn",
                .revision_id = "RevisionId",
                .layers = "Layers",
                .state = "State",
                .state_reason = "StateReason",
                .state_reason_code = "StateReasonCode",
                .last_update_status = "LastUpdateStatus",
                .last_update_status_reason = "LastUpdateStatusReason",
                .last_update_status_reason_code = "LastUpdateStatusReasonCode",
                .file_system_configs = "FileSystemConfigs",
                .package_type = "PackageType",
                .image_config_response = "ImageConfigResponse",
                .signing_profile_version_arn = "SigningProfileVersionArn",
                .signing_job_arn = "SigningJobArn",
                .architectures = "Architectures",
                .ephemeral_storage = "EphemeralStorage",
                .snap_start = "SnapStart",
                .runtime_version_config = "RuntimeVersionConfig",
                .logging_config = "LoggingConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_function_event_invoke_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2019-09-25/functions/{FunctionName}/event-invoke-config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFunctionEventInvokeConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_function_event_invoke_config) } {
            return .{ .service_metadata = service_metadata, .action = get_function_event_invoke_config };
        }
    },
    Response: type = struct {
        last_modified: ?i64 = null,
        function_arn: ?[]const u8 = null,
        maximum_retry_attempts: ?i64 = null,
        maximum_event_age_in_seconds: ?i64 = null,
        destination_config: ?DestinationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .last_modified = "LastModified",
                .function_arn = "FunctionArn",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .maximum_event_age_in_seconds = "MaximumEventAgeInSeconds",
                .destination_config = "DestinationConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_function_url_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-10-31/functions/{FunctionName}/url",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFunctionUrlConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_function_url_config) } {
            return .{ .service_metadata = service_metadata, .action = get_function_url_config };
        }
    },
    Response: type = struct {
        function_url: []const u8,
        function_arn: []const u8,
        auth_type: []const u8,
        cors: ?Cors = null,
        creation_time: []const u8,
        last_modified_time: []const u8,
        invoke_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_url = "FunctionUrl",
                .function_arn = "FunctionArn",
                .auth_type = "AuthType",
                .cors = "Cors",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .invoke_mode = "InvokeMode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_layer_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2018-10-31/layers/{LayerName}/versions/{VersionNumber}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLayerVersion",
    Request: type = struct {
        layer_name: []const u8,
        version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .layer_name = "LayerName",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_layer_version) } {
            return .{ .service_metadata = service_metadata, .action = get_layer_version };
        }
    },
    Response: type = struct {
        content: ?LayerVersionContentOutput = null,
        layer_arn: ?[]const u8 = null,
        layer_version_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?[]const u8 = null,
        version: ?i64 = null,
        compatible_runtimes: ?[][]const u8 = null,
        license_info: ?[]const u8 = null,
        compatible_architectures: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .layer_arn = "LayerArn",
                .layer_version_arn = "LayerVersionArn",
                .description = "Description",
                .created_date = "CreatedDate",
                .version = "Version",
                .compatible_runtimes = "CompatibleRuntimes",
                .license_info = "LicenseInfo",
                .compatible_architectures = "CompatibleArchitectures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_layer_version_by_arn: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2018-10-31/layers?find=LayerVersion",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLayerVersionByArn",
    Request: type = struct {
        arn: []const u8,

        pub const http_query = .{
            .arn = "Arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_layer_version_by_arn) } {
            return .{ .service_metadata = service_metadata, .action = get_layer_version_by_arn };
        }
    },
    Response: type = struct {
        content: ?LayerVersionContentOutput = null,
        layer_arn: ?[]const u8 = null,
        layer_version_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?[]const u8 = null,
        version: ?i64 = null,
        compatible_runtimes: ?[][]const u8 = null,
        license_info: ?[]const u8 = null,
        compatible_architectures: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .layer_arn = "LayerArn",
                .layer_version_arn = "LayerVersionArn",
                .description = "Description",
                .created_date = "CreatedDate",
                .version = "Version",
                .compatible_runtimes = "CompatibleRuntimes",
                .license_info = "LicenseInfo",
                .compatible_architectures = "CompatibleArchitectures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_layer_version_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2018-10-31/layers/{LayerName}/versions/{VersionNumber}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLayerVersionPolicy",
    Request: type = struct {
        layer_name: []const u8,
        version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .layer_name = "LayerName",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_layer_version_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_layer_version_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-03-31/functions/{FunctionName}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPolicy",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_provisioned_concurrency_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2019-09-30/functions/{FunctionName}/provisioned-concurrency",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProvisionedConcurrencyConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: []const u8,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_provisioned_concurrency_config) } {
            return .{ .service_metadata = service_metadata, .action = get_provisioned_concurrency_config };
        }
    },
    Response: type = struct {
        requested_provisioned_concurrent_executions: ?i64 = null,
        available_provisioned_concurrent_executions: ?i64 = null,
        allocated_provisioned_concurrent_executions: ?i64 = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        last_modified: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .requested_provisioned_concurrent_executions = "RequestedProvisionedConcurrentExecutions",
                .available_provisioned_concurrent_executions = "AvailableProvisionedConcurrentExecutions",
                .allocated_provisioned_concurrent_executions = "AllocatedProvisionedConcurrentExecutions",
                .status = "Status",
                .status_reason = "StatusReason",
                .last_modified = "LastModified",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ProvisionedConcurrencyConfigNotFound,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const get_runtime_management_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-07-20/functions/{FunctionName}/runtime-management-config",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRuntimeManagementConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_runtime_management_config) } {
            return .{ .service_metadata = service_metadata, .action = get_runtime_management_config };
        }
    },
    Response: type = struct {
        update_runtime_on: ?[]const u8 = null,
        runtime_version_arn: ?[]const u8 = null,
        function_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_runtime_on = "UpdateRuntimeOn",
                .runtime_version_arn = "RuntimeVersionArn",
                .function_arn = "FunctionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const invoke: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-03-31/functions/{FunctionName}/invocations",
        .success_code = 200,
    };

    action_name: []const u8 = "Invoke",
    Request: type = struct {
        function_name: []const u8,
        invocation_type: ?[]const u8 = null,
        log_type: ?[]const u8 = null,
        client_context: ?[]const u8 = null,
        payload: ?[]const u8 = null,
        qualifier: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub const http_header = .{
            .invocation_type = "X-Amz-Invocation-Type",
            .log_type = "X-Amz-Log-Type",
            .client_context = "X-Amz-Client-Context",
        };

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .invocation_type = "InvocationType",
                .log_type = "LogType",
                .client_context = "ClientContext",
                .payload = "Payload",
                .qualifier = "Qualifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invoke) } {
            return .{ .service_metadata = service_metadata, .action = invoke };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,
        function_error: ?[]const u8 = null,
        log_result: ?[]const u8 = null,
        payload: ?[]const u8 = null,
        executed_version: ?[]const u8 = null,
        pub const http_header = .{
            .function_error = "X-Amz-Function-Error",
            .log_result = "X-Amz-Log-Result",
            .executed_version = "X-Amz-Executed-Version",
        };

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "StatusCode",
                .function_error = "FunctionError",
                .log_result = "LogResult",
                .payload = "Payload",
                .executed_version = "ExecutedVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EC2AccessDenied,
        EC2Throttled,
        EC2Unexpected,
        EFSIO,
        EFSMountConnectivity,
        EFSMountFailure,
        EFSMountTimeout,
        ENILimitReached,
        InvalidParameterValue,
        InvalidRequestContent,
        InvalidRuntime,
        InvalidSecurityGroupID,
        InvalidSubnetID,
        InvalidZipFile,
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        RecursiveInvocation,
        RequestTooLarge,
        ResourceConflict,
        ResourceNotFound,
        ResourceNotReady,
        Service,
        SnapStart,
        SnapStartNotReady,
        SnapStartTimeout,
        SubnetIPAddressLimitReached,
        TooManyRequests,
        UnsupportedMediaType,
    },
} = .{};
pub const invoke_async: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2014-11-13/functions/{FunctionName}/invoke-async",
        .success_code = 202,
    };

    action_name: []const u8 = "InvokeAsync",
    Request: type = struct {
        function_name: []const u8,
        invoke_args: []const u8,

        pub const http_payload: []const u8 = "invoke_args";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .invoke_args = "InvokeArgs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invoke_async) } {
            return .{ .service_metadata = service_metadata, .action = invoke_async };
        }
    },
    Response: type = struct {
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequestContent,
        InvalidRuntime,
        ResourceConflict,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const invoke_with_response_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-11-15/functions/{FunctionName}/response-streaming-invocations",
        .success_code = 200,
    };

    action_name: []const u8 = "InvokeWithResponseStream",
    Request: type = struct {
        function_name: []const u8,
        invocation_type: ?[]const u8 = null,
        log_type: ?[]const u8 = null,
        client_context: ?[]const u8 = null,
        qualifier: ?[]const u8 = null,
        payload: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub const http_header = .{
            .invocation_type = "X-Amz-Invocation-Type",
            .log_type = "X-Amz-Log-Type",
            .client_context = "X-Amz-Client-Context",
        };

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .invocation_type = "InvocationType",
                .log_type = "LogType",
                .client_context = "ClientContext",
                .qualifier = "Qualifier",
                .payload = "Payload",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invoke_with_response_stream) } {
            return .{ .service_metadata = service_metadata, .action = invoke_with_response_stream };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,
        executed_version: ?[]const u8 = null,
        event_stream: ?union {
            payload_chunk: ?struct {
                payload: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .payload = "Payload",
                    };
                    return @field(mappings, field_name);
                }
            },
            invoke_complete: ?struct {
                error_code: ?[]const u8 = null,
                error_details: ?[]const u8 = null,
                log_result: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "ErrorCode",
                        .error_details = "ErrorDetails",
                        .log_result = "LogResult",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .payload_chunk = "PayloadChunk",
                    .invoke_complete = "InvokeComplete",
                };
                return @field(mappings, field_name);
            }
        } = null,
        response_stream_content_type: ?[]const u8 = null,
        pub const http_header = .{
            .executed_version = "X-Amz-Executed-Version",
            .response_stream_content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "event_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "StatusCode",
                .executed_version = "ExecutedVersion",
                .event_stream = "EventStream",
                .response_stream_content_type = "ResponseStreamContentType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EC2AccessDenied,
        EC2Throttled,
        EC2Unexpected,
        EFSIO,
        EFSMountConnectivity,
        EFSMountFailure,
        EFSMountTimeout,
        ENILimitReached,
        InvalidParameterValue,
        InvalidRequestContent,
        InvalidRuntime,
        InvalidSecurityGroupID,
        InvalidSubnetID,
        InvalidZipFile,
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        RecursiveInvocation,
        RequestTooLarge,
        ResourceConflict,
        ResourceNotFound,
        ResourceNotReady,
        Service,
        SnapStart,
        SnapStartNotReady,
        SnapStartTimeout,
        SubnetIPAddressLimitReached,
        TooManyRequests,
        UnsupportedMediaType,
    },
} = .{};
pub const list_aliases: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-03-31/functions/{FunctionName}/aliases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAliases",
    Request: type = struct {
        function_name: []const u8,
        function_version: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .function_version = "FunctionVersion",
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .function_version = "FunctionVersion",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_aliases };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        aliases: ?[]AliasConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .aliases = "Aliases",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_code_signing_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-04-22/code-signing-configs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCodeSigningConfigs",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_code_signing_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_code_signing_configs };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        code_signing_configs: ?[]CodeSigningConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .code_signing_configs = "CodeSigningConfigs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        Service,
    },
} = .{};
pub const list_event_source_mappings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-03-31/event-source-mappings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEventSourceMappings",
    Request: type = struct {
        event_source_arn: ?[]const u8 = null,
        function_name: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .event_source_arn = "EventSourceArn",
            .function_name = "FunctionName",
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_source_arn = "EventSourceArn",
                .function_name = "FunctionName",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_source_mappings) } {
            return .{ .service_metadata = service_metadata, .action = list_event_source_mappings };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        event_source_mappings: ?[]EventSourceMappingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .event_source_mappings = "EventSourceMappings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_function_event_invoke_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2019-09-25/functions/{FunctionName}/event-invoke-config/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFunctionEventInvokeConfigs",
    Request: type = struct {
        function_name: []const u8,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_function_event_invoke_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_function_event_invoke_configs };
        }
    },
    Response: type = struct {
        function_event_invoke_configs: ?[]FunctionEventInvokeConfig = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_event_invoke_configs = "FunctionEventInvokeConfigs",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_functions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-03-31/functions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFunctions",
    Request: type = struct {
        master_region: ?[]const u8 = null,
        function_version: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .master_region = "MasterRegion",
            .function_version = "FunctionVersion",
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .master_region = "MasterRegion",
                .function_version = "FunctionVersion",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_functions) } {
            return .{ .service_metadata = service_metadata, .action = list_functions };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        functions: ?[]FunctionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .functions = "Functions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_functions_by_code_signing_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-04-22/code-signing-configs/{CodeSigningConfigArn}/functions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFunctionsByCodeSigningConfig",
    Request: type = struct {
        code_signing_config_arn: []const u8,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_signing_config_arn = "CodeSigningConfigArn",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_functions_by_code_signing_config) } {
            return .{ .service_metadata = service_metadata, .action = list_functions_by_code_signing_config };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        function_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .function_arns = "FunctionArns",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const list_function_url_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-10-31/functions/{FunctionName}/urls",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFunctionUrlConfigs",
    Request: type = struct {
        function_name: []const u8,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_function_url_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_function_url_configs };
        }
    },
    Response: type = struct {
        function_url_configs: []struct {
            function_url: []const u8,
            function_arn: []const u8,
            creation_time: []const u8,
            last_modified_time: []const u8,
            cors: ?Cors = null,
            auth_type: []const u8,
            invoke_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .function_url = "FunctionUrl",
                    .function_arn = "FunctionArn",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .cors = "Cors",
                    .auth_type = "AuthType",
                    .invoke_mode = "InvokeMode",
                };
                return @field(mappings, field_name);
            }
        },
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_url_configs = "FunctionUrlConfigs",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_layers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2018-10-31/layers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLayers",
    Request: type = struct {
        compatible_runtime: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,
        compatible_architecture: ?[]const u8 = null,

        pub const http_query = .{
            .compatible_runtime = "CompatibleRuntime",
            .marker = "Marker",
            .max_items = "MaxItems",
            .compatible_architecture = "CompatibleArchitecture",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compatible_runtime = "CompatibleRuntime",
                .marker = "Marker",
                .max_items = "MaxItems",
                .compatible_architecture = "CompatibleArchitecture",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_layers) } {
            return .{ .service_metadata = service_metadata, .action = list_layers };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        layers: ?[]struct {
            layer_name: ?[]const u8 = null,
            layer_arn: ?[]const u8 = null,
            latest_matching_version: ?LayerVersionsListItem = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .layer_name = "LayerName",
                    .layer_arn = "LayerArn",
                    .latest_matching_version = "LatestMatchingVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .layers = "Layers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_layer_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2018-10-31/layers/{LayerName}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLayerVersions",
    Request: type = struct {
        compatible_runtime: ?[]const u8 = null,
        layer_name: []const u8,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,
        compatible_architecture: ?[]const u8 = null,

        pub const http_query = .{
            .compatible_runtime = "CompatibleRuntime",
            .marker = "Marker",
            .max_items = "MaxItems",
            .compatible_architecture = "CompatibleArchitecture",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compatible_runtime = "CompatibleRuntime",
                .layer_name = "LayerName",
                .marker = "Marker",
                .max_items = "MaxItems",
                .compatible_architecture = "CompatibleArchitecture",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_layer_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_layer_versions };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        layer_versions: ?[]LayerVersionsListItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .layer_versions = "LayerVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_provisioned_concurrency_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2019-09-30/functions/{FunctionName}/provisioned-concurrency?List=ALL",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProvisionedConcurrencyConfigs",
    Request: type = struct {
        function_name: []const u8,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_provisioned_concurrency_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_provisioned_concurrency_configs };
        }
    },
    Response: type = struct {
        provisioned_concurrency_configs: ?[]struct {
            function_arn: ?[]const u8 = null,
            requested_provisioned_concurrent_executions: ?i64 = null,
            available_provisioned_concurrent_executions: ?i64 = null,
            allocated_provisioned_concurrent_executions: ?i64 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            last_modified: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .function_arn = "FunctionArn",
                    .requested_provisioned_concurrent_executions = "RequestedProvisionedConcurrentExecutions",
                    .available_provisioned_concurrent_executions = "AvailableProvisionedConcurrentExecutions",
                    .allocated_provisioned_concurrent_executions = "AllocatedProvisionedConcurrentExecutions",
                    .status = "Status",
                    .status_reason = "StatusReason",
                    .last_modified = "LastModified",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_concurrency_configs = "ProvisionedConcurrencyConfigs",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-03-31/tags/{Resource}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTags",
    Request: type = struct {
        resource: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "Resource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_versions_by_function: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2015-03-31/functions/{FunctionName}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVersionsByFunction",
    Request: type = struct {
        function_name: []const u8,
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "Marker",
            .max_items = "MaxItems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_versions_by_function) } {
            return .{ .service_metadata = service_metadata, .action = list_versions_by_function };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        versions: ?[]FunctionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const publish_layer_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2018-10-31/layers/{LayerName}/versions",
        .success_code = 201,
    };

    action_name: []const u8 = "PublishLayerVersion",
    Request: type = struct {
        layer_name: []const u8,
        description: ?[]const u8 = null,
        content: struct {
            s3_bucket: ?[]const u8 = null,
            s3_key: ?[]const u8 = null,
            s3_object_version: ?[]const u8 = null,
            zip_file: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_bucket = "S3Bucket",
                    .s3_key = "S3Key",
                    .s3_object_version = "S3ObjectVersion",
                    .zip_file = "ZipFile",
                };
                return @field(mappings, field_name);
            }
        },
        compatible_runtimes: ?[][]const u8 = null,
        license_info: ?[]const u8 = null,
        compatible_architectures: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .layer_name = "LayerName",
                .description = "Description",
                .content = "Content",
                .compatible_runtimes = "CompatibleRuntimes",
                .license_info = "LicenseInfo",
                .compatible_architectures = "CompatibleArchitectures",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish_layer_version) } {
            return .{ .service_metadata = service_metadata, .action = publish_layer_version };
        }
    },
    Response: type = struct {
        content: ?LayerVersionContentOutput = null,
        layer_arn: ?[]const u8 = null,
        layer_version_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?[]const u8 = null,
        version: ?i64 = null,
        compatible_runtimes: ?[][]const u8 = null,
        license_info: ?[]const u8 = null,
        compatible_architectures: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .layer_arn = "LayerArn",
                .layer_version_arn = "LayerVersionArn",
                .description = "Description",
                .created_date = "CreatedDate",
                .version = "Version",
                .compatible_runtimes = "CompatibleRuntimes",
                .license_info = "LicenseInfo",
                .compatible_architectures = "CompatibleArchitectures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeStorageExceeded,
        InvalidParameterValue,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const publish_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2015-03-31/functions/{FunctionName}/versions",
        .success_code = 201,
    };

    action_name: []const u8 = "PublishVersion",
    Request: type = struct {
        function_name: []const u8,
        code_sha256: ?[]const u8 = null,
        description: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .code_sha256 = "CodeSha256",
                .description = "Description",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish_version) } {
            return .{ .service_metadata = service_metadata, .action = publish_version };
        }
    },
    Response: type = struct {
        function_name: ?[]const u8 = null,
        function_arn: ?[]const u8 = null,
        runtime: ?[]const u8 = null,
        role: ?[]const u8 = null,
        handler: ?[]const u8 = null,
        code_size: ?i64 = null,
        description: ?[]const u8 = null,
        timeout: ?i64 = null,
        memory_size: ?i64 = null,
        last_modified: ?[]const u8 = null,
        code_sha256: ?[]const u8 = null,
        version: ?[]const u8 = null,
        vpc_config: ?VpcConfigResponse = null,
        dead_letter_config: ?DeadLetterConfig = null,
        environment: ?EnvironmentResponse = null,
        kms_key_arn: ?[]const u8 = null,
        tracing_config: ?TracingConfigResponse = null,
        master_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,
        layers: ?[]Layer = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        state_reason_code: ?[]const u8 = null,
        last_update_status: ?[]const u8 = null,
        last_update_status_reason: ?[]const u8 = null,
        last_update_status_reason_code: ?[]const u8 = null,
        file_system_configs: ?[]FileSystemConfig = null,
        package_type: ?[]const u8 = null,
        image_config_response: ?ImageConfigResponse = null,
        signing_profile_version_arn: ?[]const u8 = null,
        signing_job_arn: ?[]const u8 = null,
        architectures: ?[][]const u8 = null,
        ephemeral_storage: ?EphemeralStorage = null,
        snap_start: ?SnapStartResponse = null,
        runtime_version_config: ?RuntimeVersionConfig = null,
        logging_config: ?LoggingConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .function_arn = "FunctionArn",
                .runtime = "Runtime",
                .role = "Role",
                .handler = "Handler",
                .code_size = "CodeSize",
                .description = "Description",
                .timeout = "Timeout",
                .memory_size = "MemorySize",
                .last_modified = "LastModified",
                .code_sha256 = "CodeSha256",
                .version = "Version",
                .vpc_config = "VpcConfig",
                .dead_letter_config = "DeadLetterConfig",
                .environment = "Environment",
                .kms_key_arn = "KMSKeyArn",
                .tracing_config = "TracingConfig",
                .master_arn = "MasterArn",
                .revision_id = "RevisionId",
                .layers = "Layers",
                .state = "State",
                .state_reason = "StateReason",
                .state_reason_code = "StateReasonCode",
                .last_update_status = "LastUpdateStatus",
                .last_update_status_reason = "LastUpdateStatusReason",
                .last_update_status_reason_code = "LastUpdateStatusReasonCode",
                .file_system_configs = "FileSystemConfigs",
                .package_type = "PackageType",
                .image_config_response = "ImageConfigResponse",
                .signing_profile_version_arn = "SigningProfileVersionArn",
                .signing_job_arn = "SigningJobArn",
                .architectures = "Architectures",
                .ephemeral_storage = "EphemeralStorage",
                .snap_start = "SnapStart",
                .runtime_version_config = "RuntimeVersionConfig",
                .logging_config = "LoggingConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeStorageExceeded,
        InvalidParameterValue,
        PreconditionFailed,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const put_function_code_signing_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-06-30/functions/{FunctionName}/code-signing-config",
        .success_code = 200,
    };

    action_name: []const u8 = "PutFunctionCodeSigningConfig",
    Request: type = struct {
        code_signing_config_arn: []const u8,
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_signing_config_arn = "CodeSigningConfigArn",
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_function_code_signing_config) } {
            return .{ .service_metadata = service_metadata, .action = put_function_code_signing_config };
        }
    },
    Response: type = struct {
        code_signing_config_arn: []const u8,
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_signing_config_arn = "CodeSigningConfigArn",
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeSigningConfigNotFound,
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const put_function_concurrency: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2017-10-31/functions/{FunctionName}/concurrency",
        .success_code = 200,
    };

    action_name: []const u8 = "PutFunctionConcurrency",
    Request: type = struct {
        function_name: []const u8,
        reserved_concurrent_executions: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .reserved_concurrent_executions = "ReservedConcurrentExecutions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_function_concurrency) } {
            return .{ .service_metadata = service_metadata, .action = put_function_concurrency };
        }
    },
    Response: type = struct {
        reserved_concurrent_executions: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_concurrent_executions = "ReservedConcurrentExecutions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const put_function_event_invoke_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2019-09-25/functions/{FunctionName}/event-invoke-config",
        .success_code = 200,
    };

    action_name: []const u8 = "PutFunctionEventInvokeConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,
        maximum_retry_attempts: ?i64 = null,
        maximum_event_age_in_seconds: ?i64 = null,
        destination_config: ?DestinationConfig = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .maximum_event_age_in_seconds = "MaximumEventAgeInSeconds",
                .destination_config = "DestinationConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_function_event_invoke_config) } {
            return .{ .service_metadata = service_metadata, .action = put_function_event_invoke_config };
        }
    },
    Response: type = struct {
        last_modified: ?i64 = null,
        function_arn: ?[]const u8 = null,
        maximum_retry_attempts: ?i64 = null,
        maximum_event_age_in_seconds: ?i64 = null,
        destination_config: ?DestinationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .last_modified = "LastModified",
                .function_arn = "FunctionArn",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .maximum_event_age_in_seconds = "MaximumEventAgeInSeconds",
                .destination_config = "DestinationConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const put_provisioned_concurrency_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2019-09-30/functions/{FunctionName}/provisioned-concurrency",
        .success_code = 202,
    };

    action_name: []const u8 = "PutProvisionedConcurrencyConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: []const u8,
        provisioned_concurrent_executions: i64,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
                .provisioned_concurrent_executions = "ProvisionedConcurrentExecutions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_provisioned_concurrency_config) } {
            return .{ .service_metadata = service_metadata, .action = put_provisioned_concurrency_config };
        }
    },
    Response: type = struct {
        requested_provisioned_concurrent_executions: ?i64 = null,
        available_provisioned_concurrent_executions: ?i64 = null,
        allocated_provisioned_concurrent_executions: ?i64 = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        last_modified: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .requested_provisioned_concurrent_executions = "RequestedProvisionedConcurrentExecutions",
                .available_provisioned_concurrent_executions = "AvailableProvisionedConcurrentExecutions",
                .allocated_provisioned_concurrent_executions = "AllocatedProvisionedConcurrentExecutions",
                .status = "Status",
                .status_reason = "StatusReason",
                .last_modified = "LastModified",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const put_runtime_management_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2021-07-20/functions/{FunctionName}/runtime-management-config",
        .success_code = 200,
    };

    action_name: []const u8 = "PutRuntimeManagementConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,
        update_runtime_on: []const u8,
        runtime_version_arn: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
                .update_runtime_on = "UpdateRuntimeOn",
                .runtime_version_arn = "RuntimeVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_runtime_management_config) } {
            return .{ .service_metadata = service_metadata, .action = put_runtime_management_config };
        }
    },
    Response: type = struct {
        update_runtime_on: []const u8,
        function_arn: []const u8,
        runtime_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_runtime_on = "UpdateRuntimeOn",
                .function_arn = "FunctionArn",
                .runtime_version_arn = "RuntimeVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const remove_layer_version_permission: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2018-10-31/layers/{LayerName}/versions/{VersionNumber}/policy/{StatementId}",
        .success_code = 204,
    };

    action_name: []const u8 = "RemoveLayerVersionPermission",
    Request: type = struct {
        layer_name: []const u8,
        version_number: i64,
        statement_id: []const u8,
        revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .revision_id = "RevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .layer_name = "LayerName",
                .version_number = "VersionNumber",
                .statement_id = "StatementId",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_layer_version_permission) } {
            return .{ .service_metadata = service_metadata, .action = remove_layer_version_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        PreconditionFailed,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const remove_permission: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2015-03-31/functions/{FunctionName}/policy/{StatementId}",
        .success_code = 204,
    };

    action_name: []const u8 = "RemovePermission",
    Request: type = struct {
        function_name: []const u8,
        statement_id: []const u8,
        qualifier: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
            .revision_id = "RevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .statement_id = "StatementId",
                .qualifier = "Qualifier",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_permission) } {
            return .{ .service_metadata = service_metadata, .action = remove_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        PreconditionFailed,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2017-03-31/tags/{Resource}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "Resource",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2017-03-31/tags/{Resource}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "Resource",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const update_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-03-31/functions/{FunctionName}/aliases/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAlias",
    Request: type = struct {
        function_name: []const u8,
        name: []const u8,
        function_version: ?[]const u8 = null,
        description: ?[]const u8 = null,
        routing_config: ?AliasRoutingConfiguration = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .name = "Name",
                .function_version = "FunctionVersion",
                .description = "Description",
                .routing_config = "RoutingConfig",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_alias) } {
            return .{ .service_metadata = service_metadata, .action = update_alias };
        }
    },
    Response: type = struct {
        alias_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        function_version: ?[]const u8 = null,
        description: ?[]const u8 = null,
        routing_config: ?AliasRoutingConfiguration = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_arn = "AliasArn",
                .name = "Name",
                .function_version = "FunctionVersion",
                .description = "Description",
                .routing_config = "RoutingConfig",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        PreconditionFailed,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const update_code_signing_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-04-22/code-signing-configs/{CodeSigningConfigArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCodeSigningConfig",
    Request: type = struct {
        code_signing_config_arn: []const u8,
        description: ?[]const u8 = null,
        allowed_publishers: ?AllowedPublishers = null,
        code_signing_policies: ?CodeSigningPolicies = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_signing_config_arn = "CodeSigningConfigArn",
                .description = "Description",
                .allowed_publishers = "AllowedPublishers",
                .code_signing_policies = "CodeSigningPolicies",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_code_signing_config) } {
            return .{ .service_metadata = service_metadata, .action = update_code_signing_config };
        }
    },
    Response: type = struct {
        code_signing_config: CodeSigningConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_signing_config = "CodeSigningConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const update_event_source_mapping: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-03-31/event-source-mappings/{UUID}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateEventSourceMapping",
    Request: type = struct {
        uuid: []const u8,
        function_name: ?[]const u8 = null,
        enabled: ?bool = null,
        batch_size: ?i64 = null,
        filter_criteria: ?FilterCriteria = null,
        maximum_batching_window_in_seconds: ?i64 = null,
        destination_config: ?DestinationConfig = null,
        maximum_record_age_in_seconds: ?i64 = null,
        bisect_batch_on_function_error: ?bool = null,
        maximum_retry_attempts: ?i64 = null,
        parallelization_factor: ?i64 = null,
        source_access_configurations: ?[]SourceAccessConfiguration = null,
        tumbling_window_in_seconds: ?i64 = null,
        function_response_types: ?[][]const u8 = null,
        scaling_config: ?ScalingConfig = null,
        document_db_event_source_config: ?DocumentDBEventSourceConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uuid = "UUID",
                .function_name = "FunctionName",
                .enabled = "Enabled",
                .batch_size = "BatchSize",
                .filter_criteria = "FilterCriteria",
                .maximum_batching_window_in_seconds = "MaximumBatchingWindowInSeconds",
                .destination_config = "DestinationConfig",
                .maximum_record_age_in_seconds = "MaximumRecordAgeInSeconds",
                .bisect_batch_on_function_error = "BisectBatchOnFunctionError",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .parallelization_factor = "ParallelizationFactor",
                .source_access_configurations = "SourceAccessConfigurations",
                .tumbling_window_in_seconds = "TumblingWindowInSeconds",
                .function_response_types = "FunctionResponseTypes",
                .scaling_config = "ScalingConfig",
                .document_db_event_source_config = "DocumentDBEventSourceConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_event_source_mapping) } {
            return .{ .service_metadata = service_metadata, .action = update_event_source_mapping };
        }
    },
    Response: type = struct {
        uuid: ?[]const u8 = null,
        starting_position: ?[]const u8 = null,
        starting_position_timestamp: ?i64 = null,
        batch_size: ?i64 = null,
        maximum_batching_window_in_seconds: ?i64 = null,
        parallelization_factor: ?i64 = null,
        event_source_arn: ?[]const u8 = null,
        filter_criteria: ?FilterCriteria = null,
        function_arn: ?[]const u8 = null,
        last_modified: ?i64 = null,
        last_processing_result: ?[]const u8 = null,
        state: ?[]const u8 = null,
        state_transition_reason: ?[]const u8 = null,
        destination_config: ?DestinationConfig = null,
        topics: ?[][]const u8 = null,
        queues: ?[][]const u8 = null,
        source_access_configurations: ?[]SourceAccessConfiguration = null,
        self_managed_event_source: ?SelfManagedEventSource = null,
        maximum_record_age_in_seconds: ?i64 = null,
        bisect_batch_on_function_error: ?bool = null,
        maximum_retry_attempts: ?i64 = null,
        tumbling_window_in_seconds: ?i64 = null,
        function_response_types: ?[][]const u8 = null,
        amazon_managed_kafka_event_source_config: ?AmazonManagedKafkaEventSourceConfig = null,
        self_managed_kafka_event_source_config: ?SelfManagedKafkaEventSourceConfig = null,
        scaling_config: ?ScalingConfig = null,
        document_db_event_source_config: ?DocumentDBEventSourceConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uuid = "UUID",
                .starting_position = "StartingPosition",
                .starting_position_timestamp = "StartingPositionTimestamp",
                .batch_size = "BatchSize",
                .maximum_batching_window_in_seconds = "MaximumBatchingWindowInSeconds",
                .parallelization_factor = "ParallelizationFactor",
                .event_source_arn = "EventSourceArn",
                .filter_criteria = "FilterCriteria",
                .function_arn = "FunctionArn",
                .last_modified = "LastModified",
                .last_processing_result = "LastProcessingResult",
                .state = "State",
                .state_transition_reason = "StateTransitionReason",
                .destination_config = "DestinationConfig",
                .topics = "Topics",
                .queues = "Queues",
                .source_access_configurations = "SourceAccessConfigurations",
                .self_managed_event_source = "SelfManagedEventSource",
                .maximum_record_age_in_seconds = "MaximumRecordAgeInSeconds",
                .bisect_batch_on_function_error = "BisectBatchOnFunctionError",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .tumbling_window_in_seconds = "TumblingWindowInSeconds",
                .function_response_types = "FunctionResponseTypes",
                .amazon_managed_kafka_event_source_config = "AmazonManagedKafkaEventSourceConfig",
                .self_managed_kafka_event_source_config = "SelfManagedKafkaEventSourceConfig",
                .scaling_config = "ScalingConfig",
                .document_db_event_source_config = "DocumentDBEventSourceConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceInUse,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const update_function_code: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-03-31/functions/{FunctionName}/code",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFunctionCode",
    Request: type = struct {
        function_name: []const u8,
        zip_file: ?[]const u8 = null,
        s3_bucket: ?[]const u8 = null,
        s3_key: ?[]const u8 = null,
        s3_object_version: ?[]const u8 = null,
        image_uri: ?[]const u8 = null,
        publish: ?bool = null,
        dry_run: ?bool = null,
        revision_id: ?[]const u8 = null,
        architectures: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .zip_file = "ZipFile",
                .s3_bucket = "S3Bucket",
                .s3_key = "S3Key",
                .s3_object_version = "S3ObjectVersion",
                .image_uri = "ImageUri",
                .publish = "Publish",
                .dry_run = "DryRun",
                .revision_id = "RevisionId",
                .architectures = "Architectures",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_function_code) } {
            return .{ .service_metadata = service_metadata, .action = update_function_code };
        }
    },
    Response: type = struct {
        function_name: ?[]const u8 = null,
        function_arn: ?[]const u8 = null,
        runtime: ?[]const u8 = null,
        role: ?[]const u8 = null,
        handler: ?[]const u8 = null,
        code_size: ?i64 = null,
        description: ?[]const u8 = null,
        timeout: ?i64 = null,
        memory_size: ?i64 = null,
        last_modified: ?[]const u8 = null,
        code_sha256: ?[]const u8 = null,
        version: ?[]const u8 = null,
        vpc_config: ?VpcConfigResponse = null,
        dead_letter_config: ?DeadLetterConfig = null,
        environment: ?EnvironmentResponse = null,
        kms_key_arn: ?[]const u8 = null,
        tracing_config: ?TracingConfigResponse = null,
        master_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,
        layers: ?[]Layer = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        state_reason_code: ?[]const u8 = null,
        last_update_status: ?[]const u8 = null,
        last_update_status_reason: ?[]const u8 = null,
        last_update_status_reason_code: ?[]const u8 = null,
        file_system_configs: ?[]FileSystemConfig = null,
        package_type: ?[]const u8 = null,
        image_config_response: ?ImageConfigResponse = null,
        signing_profile_version_arn: ?[]const u8 = null,
        signing_job_arn: ?[]const u8 = null,
        architectures: ?[][]const u8 = null,
        ephemeral_storage: ?EphemeralStorage = null,
        snap_start: ?SnapStartResponse = null,
        runtime_version_config: ?RuntimeVersionConfig = null,
        logging_config: ?LoggingConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .function_arn = "FunctionArn",
                .runtime = "Runtime",
                .role = "Role",
                .handler = "Handler",
                .code_size = "CodeSize",
                .description = "Description",
                .timeout = "Timeout",
                .memory_size = "MemorySize",
                .last_modified = "LastModified",
                .code_sha256 = "CodeSha256",
                .version = "Version",
                .vpc_config = "VpcConfig",
                .dead_letter_config = "DeadLetterConfig",
                .environment = "Environment",
                .kms_key_arn = "KMSKeyArn",
                .tracing_config = "TracingConfig",
                .master_arn = "MasterArn",
                .revision_id = "RevisionId",
                .layers = "Layers",
                .state = "State",
                .state_reason = "StateReason",
                .state_reason_code = "StateReasonCode",
                .last_update_status = "LastUpdateStatus",
                .last_update_status_reason = "LastUpdateStatusReason",
                .last_update_status_reason_code = "LastUpdateStatusReasonCode",
                .file_system_configs = "FileSystemConfigs",
                .package_type = "PackageType",
                .image_config_response = "ImageConfigResponse",
                .signing_profile_version_arn = "SigningProfileVersionArn",
                .signing_job_arn = "SigningJobArn",
                .architectures = "Architectures",
                .ephemeral_storage = "EphemeralStorage",
                .snap_start = "SnapStart",
                .runtime_version_config = "RuntimeVersionConfig",
                .logging_config = "LoggingConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeSigningConfigNotFound,
        CodeStorageExceeded,
        CodeVerificationFailed,
        InvalidCodeSignature,
        InvalidParameterValue,
        PreconditionFailed,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const update_function_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2015-03-31/functions/{FunctionName}/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFunctionConfiguration",
    Request: type = struct {
        function_name: []const u8,
        role: ?[]const u8 = null,
        handler: ?[]const u8 = null,
        description: ?[]const u8 = null,
        timeout: ?i64 = null,
        memory_size: ?i64 = null,
        vpc_config: ?VpcConfig = null,
        environment: ?Environment = null,
        runtime: ?[]const u8 = null,
        dead_letter_config: ?DeadLetterConfig = null,
        kms_key_arn: ?[]const u8 = null,
        tracing_config: ?TracingConfig = null,
        revision_id: ?[]const u8 = null,
        layers: ?[][]const u8 = null,
        file_system_configs: ?[]FileSystemConfig = null,
        image_config: ?ImageConfig = null,
        ephemeral_storage: ?EphemeralStorage = null,
        snap_start: ?SnapStart = null,
        logging_config: ?LoggingConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .role = "Role",
                .handler = "Handler",
                .description = "Description",
                .timeout = "Timeout",
                .memory_size = "MemorySize",
                .vpc_config = "VpcConfig",
                .environment = "Environment",
                .runtime = "Runtime",
                .dead_letter_config = "DeadLetterConfig",
                .kms_key_arn = "KMSKeyArn",
                .tracing_config = "TracingConfig",
                .revision_id = "RevisionId",
                .layers = "Layers",
                .file_system_configs = "FileSystemConfigs",
                .image_config = "ImageConfig",
                .ephemeral_storage = "EphemeralStorage",
                .snap_start = "SnapStart",
                .logging_config = "LoggingConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_function_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_function_configuration };
        }
    },
    Response: type = struct {
        function_name: ?[]const u8 = null,
        function_arn: ?[]const u8 = null,
        runtime: ?[]const u8 = null,
        role: ?[]const u8 = null,
        handler: ?[]const u8 = null,
        code_size: ?i64 = null,
        description: ?[]const u8 = null,
        timeout: ?i64 = null,
        memory_size: ?i64 = null,
        last_modified: ?[]const u8 = null,
        code_sha256: ?[]const u8 = null,
        version: ?[]const u8 = null,
        vpc_config: ?VpcConfigResponse = null,
        dead_letter_config: ?DeadLetterConfig = null,
        environment: ?EnvironmentResponse = null,
        kms_key_arn: ?[]const u8 = null,
        tracing_config: ?TracingConfigResponse = null,
        master_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,
        layers: ?[]Layer = null,
        state: ?[]const u8 = null,
        state_reason: ?[]const u8 = null,
        state_reason_code: ?[]const u8 = null,
        last_update_status: ?[]const u8 = null,
        last_update_status_reason: ?[]const u8 = null,
        last_update_status_reason_code: ?[]const u8 = null,
        file_system_configs: ?[]FileSystemConfig = null,
        package_type: ?[]const u8 = null,
        image_config_response: ?ImageConfigResponse = null,
        signing_profile_version_arn: ?[]const u8 = null,
        signing_job_arn: ?[]const u8 = null,
        architectures: ?[][]const u8 = null,
        ephemeral_storage: ?EphemeralStorage = null,
        snap_start: ?SnapStartResponse = null,
        runtime_version_config: ?RuntimeVersionConfig = null,
        logging_config: ?LoggingConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .function_arn = "FunctionArn",
                .runtime = "Runtime",
                .role = "Role",
                .handler = "Handler",
                .code_size = "CodeSize",
                .description = "Description",
                .timeout = "Timeout",
                .memory_size = "MemorySize",
                .last_modified = "LastModified",
                .code_sha256 = "CodeSha256",
                .version = "Version",
                .vpc_config = "VpcConfig",
                .dead_letter_config = "DeadLetterConfig",
                .environment = "Environment",
                .kms_key_arn = "KMSKeyArn",
                .tracing_config = "TracingConfig",
                .master_arn = "MasterArn",
                .revision_id = "RevisionId",
                .layers = "Layers",
                .state = "State",
                .state_reason = "StateReason",
                .state_reason_code = "StateReasonCode",
                .last_update_status = "LastUpdateStatus",
                .last_update_status_reason = "LastUpdateStatusReason",
                .last_update_status_reason_code = "LastUpdateStatusReasonCode",
                .file_system_configs = "FileSystemConfigs",
                .package_type = "PackageType",
                .image_config_response = "ImageConfigResponse",
                .signing_profile_version_arn = "SigningProfileVersionArn",
                .signing_job_arn = "SigningJobArn",
                .architectures = "Architectures",
                .ephemeral_storage = "EphemeralStorage",
                .snap_start = "SnapStart",
                .runtime_version_config = "RuntimeVersionConfig",
                .logging_config = "LoggingConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CodeSigningConfigNotFound,
        CodeVerificationFailed,
        InvalidCodeSignature,
        InvalidParameterValue,
        PreconditionFailed,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const update_function_event_invoke_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2019-09-25/functions/{FunctionName}/event-invoke-config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFunctionEventInvokeConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,
        maximum_retry_attempts: ?i64 = null,
        maximum_event_age_in_seconds: ?i64 = null,
        destination_config: ?DestinationConfig = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .maximum_event_age_in_seconds = "MaximumEventAgeInSeconds",
                .destination_config = "DestinationConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_function_event_invoke_config) } {
            return .{ .service_metadata = service_metadata, .action = update_function_event_invoke_config };
        }
    },
    Response: type = struct {
        last_modified: ?i64 = null,
        function_arn: ?[]const u8 = null,
        maximum_retry_attempts: ?i64 = null,
        maximum_event_age_in_seconds: ?i64 = null,
        destination_config: ?DestinationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .last_modified = "LastModified",
                .function_arn = "FunctionArn",
                .maximum_retry_attempts = "MaximumRetryAttempts",
                .maximum_event_age_in_seconds = "MaximumEventAgeInSeconds",
                .destination_config = "DestinationConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const update_function_url_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2021-10-31/functions/{FunctionName}/url",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFunctionUrlConfig",
    Request: type = struct {
        function_name: []const u8,
        qualifier: ?[]const u8 = null,
        auth_type: ?[]const u8 = null,
        cors: ?Cors = null,
        invoke_mode: ?[]const u8 = null,

        pub const http_query = .{
            .qualifier = "Qualifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_name = "FunctionName",
                .qualifier = "Qualifier",
                .auth_type = "AuthType",
                .cors = "Cors",
                .invoke_mode = "InvokeMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_function_url_config) } {
            return .{ .service_metadata = service_metadata, .action = update_function_url_config };
        }
    },
    Response: type = struct {
        function_url: []const u8,
        function_arn: []const u8,
        auth_type: []const u8,
        cors: ?Cors = null,
        creation_time: []const u8,
        last_modified_time: []const u8,
        invoke_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_url = "FunctionUrl",
                .function_arn = "FunctionArn",
                .auth_type = "AuthType",
                .cors = "Cors",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .invoke_mode = "InvokeMode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceConflict,
        ResourceNotFound,
        Service,
        TooManyRequests,
    },
} = .{};

pub const Cors = struct {
    allow_credentials: ?bool = null,
    allow_headers: ?[][]const u8 = null,
    allow_methods: ?[][]const u8 = null,
    allow_origins: ?[][]const u8 = null,
    expose_headers: ?[][]const u8 = null,
    max_age: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_credentials = "AllowCredentials",
            .allow_headers = "AllowHeaders",
            .allow_methods = "AllowMethods",
            .allow_origins = "AllowOrigins",
            .expose_headers = "ExposeHeaders",
            .max_age = "MaxAge",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationConfig = struct {
    on_success: ?OnSuccess = null,
    on_failure: ?OnFailure = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .on_success = "OnSuccess",
            .on_failure = "OnFailure",
        };
        return @field(mappings, field_name);
    }
};

pub const OnFailure = struct {
    destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "Destination",
        };
        return @field(mappings, field_name);
    }
};

pub const OnSuccess = struct {
    destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "Destination",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingConfig = struct {
    log_format: ?[]const u8 = null,
    application_log_level: ?[]const u8 = null,
    system_log_level: ?[]const u8 = null,
    log_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_format = "LogFormat",
            .application_log_level = "ApplicationLogLevel",
            .system_log_level = "SystemLogLevel",
            .log_group = "LogGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const RuntimeVersionConfig = struct {
    runtime_version_arn: ?[]const u8 = null,
    @"error": ?RuntimeVersionError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .runtime_version_arn = "RuntimeVersionArn",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const RuntimeVersionError = struct {
    error_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapStartResponse = struct {
    apply_on: ?[]const u8 = null,
    optimization_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .apply_on = "ApplyOn",
            .optimization_status = "OptimizationStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const EphemeralStorage = struct {
    size: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .size = "Size",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageConfigResponse = struct {
    image_config: ?ImageConfig = null,
    @"error": ?ImageConfigError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_config = "ImageConfig",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageConfigError = struct {
    error_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageConfig = struct {
    entry_point: ?[][]const u8 = null,
    command: ?[][]const u8 = null,
    working_directory: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entry_point = "EntryPoint",
            .command = "Command",
            .working_directory = "WorkingDirectory",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSystemConfig = struct {
    arn: []const u8,
    local_mount_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .local_mount_path = "LocalMountPath",
        };
        return @field(mappings, field_name);
    }
};

pub const Layer = struct {
    arn: ?[]const u8 = null,
    code_size: ?i64 = null,
    signing_profile_version_arn: ?[]const u8 = null,
    signing_job_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .code_size = "CodeSize",
            .signing_profile_version_arn = "SigningProfileVersionArn",
            .signing_job_arn = "SigningJobArn",
        };
        return @field(mappings, field_name);
    }
};

pub const TracingConfigResponse = struct {
    mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
        };
        return @field(mappings, field_name);
    }
};

pub const EnvironmentResponse = struct {
    variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    @"error": ?EnvironmentError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .variables = "Variables",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "variables", field_name))
            return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
        return false;
    }
};

pub const EnvironmentError = struct {
    error_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const DeadLetterConfig = struct {
    target_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_arn = "TargetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfigResponse = struct {
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,
    ipv6_allowed_for_dual_stack: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
            .vpc_id = "VpcId",
            .ipv6_allowed_for_dual_stack = "Ipv6AllowedForDualStack",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapStart = struct {
    apply_on: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .apply_on = "ApplyOn",
        };
        return @field(mappings, field_name);
    }
};

pub const TracingConfig = struct {
    mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
        };
        return @field(mappings, field_name);
    }
};

pub const Environment = struct {
    variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .variables = "Variables",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "variables", field_name))
            return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
        return false;
    }
};

pub const VpcConfig = struct {
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    ipv6_allowed_for_dual_stack: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
            .ipv6_allowed_for_dual_stack = "Ipv6AllowedForDualStack",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentDBEventSourceConfig = struct {
    database_name: ?[]const u8 = null,
    collection_name: ?[]const u8 = null,
    full_document: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .collection_name = "CollectionName",
            .full_document = "FullDocument",
        };
        return @field(mappings, field_name);
    }
};

pub const ScalingConfig = struct {
    maximum_concurrency: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_concurrency = "MaximumConcurrency",
        };
        return @field(mappings, field_name);
    }
};

pub const SelfManagedKafkaEventSourceConfig = struct {
    consumer_group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .consumer_group_id = "ConsumerGroupId",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonManagedKafkaEventSourceConfig = struct {
    consumer_group_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .consumer_group_id = "ConsumerGroupId",
        };
        return @field(mappings, field_name);
    }
};

pub const SelfManagedEventSource = struct {
    endpoints: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoints = "Endpoints",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "endpoints", field_name))
            return try serializeMap(self.endpoints, self.fieldNameFor("endpoints"), options, out_stream);
        return false;
    }
};

pub const SourceAccessConfiguration = struct {
    type: ?[]const u8 = null,
    uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .uri = "URI",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterCriteria = struct {
    filters: ?[]Filter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filters = "Filters",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    pattern: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pattern = "Pattern",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeSigningConfig = struct {
    code_signing_config_id: []const u8,
    code_signing_config_arn: []const u8,
    description: ?[]const u8 = null,
    allowed_publishers: AllowedPublishers,
    code_signing_policies: CodeSigningPolicies,
    last_modified: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code_signing_config_id = "CodeSigningConfigId",
            .code_signing_config_arn = "CodeSigningConfigArn",
            .description = "Description",
            .allowed_publishers = "AllowedPublishers",
            .code_signing_policies = "CodeSigningPolicies",
            .last_modified = "LastModified",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeSigningPolicies = struct {
    untrusted_artifact_on_deployment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .untrusted_artifact_on_deployment = "UntrustedArtifactOnDeployment",
        };
        return @field(mappings, field_name);
    }
};

pub const AllowedPublishers = struct {
    signing_profile_version_arns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signing_profile_version_arns = "SigningProfileVersionArns",
        };
        return @field(mappings, field_name);
    }
};

pub const AliasRoutingConfiguration = struct {
    additional_version_weights: ?[]struct {
        key: ?[]const u8 = null,
        value: ?f64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_version_weights = "AdditionalVersionWeights",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_version_weights", field_name))
            return try serializeMap(self.additional_version_weights, self.fieldNameFor("additional_version_weights"), options, out_stream);
        return false;
    }
};

pub const LayerVersionContentOutput = struct {
    location: ?[]const u8 = null,
    code_sha256: ?[]const u8 = null,
    code_size: ?i64 = null,
    signing_profile_version_arn: ?[]const u8 = null,
    signing_job_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .location = "Location",
            .code_sha256 = "CodeSha256",
            .code_size = "CodeSize",
            .signing_profile_version_arn = "SigningProfileVersionArn",
            .signing_job_arn = "SigningJobArn",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionConfiguration = struct {
    function_name: ?[]const u8 = null,
    function_arn: ?[]const u8 = null,
    runtime: ?[]const u8 = null,
    role: ?[]const u8 = null,
    handler: ?[]const u8 = null,
    code_size: ?i64 = null,
    description: ?[]const u8 = null,
    timeout: ?i64 = null,
    memory_size: ?i64 = null,
    last_modified: ?[]const u8 = null,
    code_sha256: ?[]const u8 = null,
    version: ?[]const u8 = null,
    vpc_config: ?VpcConfigResponse = null,
    dead_letter_config: ?DeadLetterConfig = null,
    environment: ?EnvironmentResponse = null,
    kms_key_arn: ?[]const u8 = null,
    tracing_config: ?TracingConfigResponse = null,
    master_arn: ?[]const u8 = null,
    revision_id: ?[]const u8 = null,
    layers: ?[]Layer = null,
    state: ?[]const u8 = null,
    state_reason: ?[]const u8 = null,
    state_reason_code: ?[]const u8 = null,
    last_update_status: ?[]const u8 = null,
    last_update_status_reason: ?[]const u8 = null,
    last_update_status_reason_code: ?[]const u8 = null,
    file_system_configs: ?[]FileSystemConfig = null,
    package_type: ?[]const u8 = null,
    image_config_response: ?ImageConfigResponse = null,
    signing_profile_version_arn: ?[]const u8 = null,
    signing_job_arn: ?[]const u8 = null,
    architectures: ?[][]const u8 = null,
    ephemeral_storage: ?EphemeralStorage = null,
    snap_start: ?SnapStartResponse = null,
    runtime_version_config: ?RuntimeVersionConfig = null,
    logging_config: ?LoggingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_name = "FunctionName",
            .function_arn = "FunctionArn",
            .runtime = "Runtime",
            .role = "Role",
            .handler = "Handler",
            .code_size = "CodeSize",
            .description = "Description",
            .timeout = "Timeout",
            .memory_size = "MemorySize",
            .last_modified = "LastModified",
            .code_sha256 = "CodeSha256",
            .version = "Version",
            .vpc_config = "VpcConfig",
            .dead_letter_config = "DeadLetterConfig",
            .environment = "Environment",
            .kms_key_arn = "KMSKeyArn",
            .tracing_config = "TracingConfig",
            .master_arn = "MasterArn",
            .revision_id = "RevisionId",
            .layers = "Layers",
            .state = "State",
            .state_reason = "StateReason",
            .state_reason_code = "StateReasonCode",
            .last_update_status = "LastUpdateStatus",
            .last_update_status_reason = "LastUpdateStatusReason",
            .last_update_status_reason_code = "LastUpdateStatusReasonCode",
            .file_system_configs = "FileSystemConfigs",
            .package_type = "PackageType",
            .image_config_response = "ImageConfigResponse",
            .signing_profile_version_arn = "SigningProfileVersionArn",
            .signing_job_arn = "SigningJobArn",
            .architectures = "Architectures",
            .ephemeral_storage = "EphemeralStorage",
            .snap_start = "SnapStart",
            .runtime_version_config = "RuntimeVersionConfig",
            .logging_config = "LoggingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const LayerVersionsListItem = struct {
    layer_version_arn: ?[]const u8 = null,
    version: ?i64 = null,
    description: ?[]const u8 = null,
    created_date: ?[]const u8 = null,
    compatible_runtimes: ?[][]const u8 = null,
    license_info: ?[]const u8 = null,
    compatible_architectures: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .layer_version_arn = "LayerVersionArn",
            .version = "Version",
            .description = "Description",
            .created_date = "CreatedDate",
            .compatible_runtimes = "CompatibleRuntimes",
            .license_info = "LicenseInfo",
            .compatible_architectures = "CompatibleArchitectures",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionEventInvokeConfig = struct {
    last_modified: ?i64 = null,
    function_arn: ?[]const u8 = null,
    maximum_retry_attempts: ?i64 = null,
    maximum_event_age_in_seconds: ?i64 = null,
    destination_config: ?DestinationConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_modified = "LastModified",
            .function_arn = "FunctionArn",
            .maximum_retry_attempts = "MaximumRetryAttempts",
            .maximum_event_age_in_seconds = "MaximumEventAgeInSeconds",
            .destination_config = "DestinationConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const EventSourceMappingConfiguration = struct {
    uuid: ?[]const u8 = null,
    starting_position: ?[]const u8 = null,
    starting_position_timestamp: ?i64 = null,
    batch_size: ?i64 = null,
    maximum_batching_window_in_seconds: ?i64 = null,
    parallelization_factor: ?i64 = null,
    event_source_arn: ?[]const u8 = null,
    filter_criteria: ?FilterCriteria = null,
    function_arn: ?[]const u8 = null,
    last_modified: ?i64 = null,
    last_processing_result: ?[]const u8 = null,
    state: ?[]const u8 = null,
    state_transition_reason: ?[]const u8 = null,
    destination_config: ?DestinationConfig = null,
    topics: ?[][]const u8 = null,
    queues: ?[][]const u8 = null,
    source_access_configurations: ?[]SourceAccessConfiguration = null,
    self_managed_event_source: ?SelfManagedEventSource = null,
    maximum_record_age_in_seconds: ?i64 = null,
    bisect_batch_on_function_error: ?bool = null,
    maximum_retry_attempts: ?i64 = null,
    tumbling_window_in_seconds: ?i64 = null,
    function_response_types: ?[][]const u8 = null,
    amazon_managed_kafka_event_source_config: ?AmazonManagedKafkaEventSourceConfig = null,
    self_managed_kafka_event_source_config: ?SelfManagedKafkaEventSourceConfig = null,
    scaling_config: ?ScalingConfig = null,
    document_db_event_source_config: ?DocumentDBEventSourceConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .uuid = "UUID",
            .starting_position = "StartingPosition",
            .starting_position_timestamp = "StartingPositionTimestamp",
            .batch_size = "BatchSize",
            .maximum_batching_window_in_seconds = "MaximumBatchingWindowInSeconds",
            .parallelization_factor = "ParallelizationFactor",
            .event_source_arn = "EventSourceArn",
            .filter_criteria = "FilterCriteria",
            .function_arn = "FunctionArn",
            .last_modified = "LastModified",
            .last_processing_result = "LastProcessingResult",
            .state = "State",
            .state_transition_reason = "StateTransitionReason",
            .destination_config = "DestinationConfig",
            .topics = "Topics",
            .queues = "Queues",
            .source_access_configurations = "SourceAccessConfigurations",
            .self_managed_event_source = "SelfManagedEventSource",
            .maximum_record_age_in_seconds = "MaximumRecordAgeInSeconds",
            .bisect_batch_on_function_error = "BisectBatchOnFunctionError",
            .maximum_retry_attempts = "MaximumRetryAttempts",
            .tumbling_window_in_seconds = "TumblingWindowInSeconds",
            .function_response_types = "FunctionResponseTypes",
            .amazon_managed_kafka_event_source_config = "AmazonManagedKafkaEventSourceConfig",
            .self_managed_kafka_event_source_config = "SelfManagedKafkaEventSourceConfig",
            .scaling_config = "ScalingConfig",
            .document_db_event_source_config = "DocumentDBEventSourceConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AliasConfiguration = struct {
    alias_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    function_version: ?[]const u8 = null,
    description: ?[]const u8 = null,
    routing_config: ?AliasRoutingConfiguration = null,
    revision_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alias_arn = "AliasArn",
            .name = "Name",
            .function_version = "FunctionVersion",
            .description = "Description",
            .routing_config = "RoutingConfig",
            .revision_id = "RevisionId",
        };
        return @field(mappings, field_name);
    }
};

pub const Concurrency = struct {
    reserved_concurrent_executions: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reserved_concurrent_executions = "ReservedConcurrentExecutions",
        };
        return @field(mappings, field_name);
    }
};
