const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-04-19";
pub const sdk_id: []const u8 = "Lex Model Building Service";
pub const arn_namespace: ?[]const u8 = "lex";
pub const endpoint_prefix: []const u8 = "models.lex";
pub const sigv4_name: []const u8 = "lex";
pub const name: []const u8 = "AWSDeepSenseModelBuildingService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-04-19",
    sdk_id: []const u8 = "Lex Model Building Service",
    arn_namespace: ?[]const u8 = "lex",
    endpoint_prefix: []const u8 = "models.lex",
    sigv4_name: []const u8 = "lex",
    name: []const u8 = "AWSDeepSenseModelBuildingService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_bot_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{name}/versions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateBotVersion",
    Request: type = struct {
        name: []const u8,
        checksum: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .checksum = "checksum",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot_version) } {
            return .{ .service_metadata = service_metadata, .action = create_bot_version };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        intents: ?[]Intent = null,
        clarification_prompt: ?Prompt = null,
        abort_statement: ?Statement = null,
        status: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        voice_id: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        version: ?[]const u8 = null,
        locale: ?[]const u8 = null,
        child_directed: ?bool = null,
        enable_model_improvements: ?bool = null,
        detect_sentiment: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .intents = "intents",
                .clarification_prompt = "clarificationPrompt",
                .abort_statement = "abortStatement",
                .status = "status",
                .failure_reason = "failureReason",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .voice_id = "voiceId",
                .checksum = "checksum",
                .version = "version",
                .locale = "locale",
                .child_directed = "childDirected",
                .enable_model_improvements = "enableModelImprovements",
                .detect_sentiment = "detectSentiment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
        PreconditionFailed,
    },
} = .{};
pub const create_intent_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/intents/{name}/versions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateIntentVersion",
    Request: type = struct {
        name: []const u8,
        checksum: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .checksum = "checksum",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_intent_version) } {
            return .{ .service_metadata = service_metadata, .action = create_intent_version };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slots: ?[]Slot = null,
        sample_utterances: ?[][]const u8 = null,
        confirmation_prompt: ?Prompt = null,
        rejection_statement: ?Statement = null,
        follow_up_prompt: ?FollowUpPrompt = null,
        conclusion_statement: ?Statement = null,
        dialog_code_hook: ?CodeHook = null,
        fulfillment_activity: ?FulfillmentActivity = null,
        parent_intent_signature: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        kendra_configuration: ?KendraConfiguration = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .slots = "slots",
                .sample_utterances = "sampleUtterances",
                .confirmation_prompt = "confirmationPrompt",
                .rejection_statement = "rejectionStatement",
                .follow_up_prompt = "followUpPrompt",
                .conclusion_statement = "conclusionStatement",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_activity = "fulfillmentActivity",
                .parent_intent_signature = "parentIntentSignature",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .version = "version",
                .checksum = "checksum",
                .kendra_configuration = "kendraConfiguration",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
        PreconditionFailed,
    },
} = .{};
pub const create_slot_type_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/slottypes/{name}/versions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSlotTypeVersion",
    Request: type = struct {
        name: []const u8,
        checksum: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .checksum = "checksum",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_slot_type_version) } {
            return .{ .service_metadata = service_metadata, .action = create_slot_type_version };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        enumeration_values: ?[]EnumerationValue = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        value_selection_strategy: ?[]const u8 = null,
        parent_slot_type_signature: ?[]const u8 = null,
        slot_type_configurations: ?[]SlotTypeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .enumeration_values = "enumerationValues",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .version = "version",
                .checksum = "checksum",
                .value_selection_strategy = "valueSelectionStrategy",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .slot_type_configurations = "slotTypeConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
        PreconditionFailed,
    },
} = .{};
pub const delete_bot: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBot",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
        ResourceInUse,
    },
} = .{};
pub const delete_bot_alias: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botName}/aliases/{name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBotAlias",
    Request: type = struct {
        name: []const u8,
        bot_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .bot_name = "botName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot_alias };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
        ResourceInUse,
    },
} = .{};
pub const delete_bot_channel_association: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botName}/aliases/{botAlias}/channels/{name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBotChannelAssociation",
    Request: type = struct {
        name: []const u8,
        bot_name: []const u8,
        bot_alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .bot_name = "botName",
                .bot_alias = "botAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot_channel_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot_channel_association };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const delete_bot_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{name}/versions/{version}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBotVersion",
    Request: type = struct {
        name: []const u8,
        version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
        ResourceInUse,
    },
} = .{};
pub const delete_intent: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/intents/{name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIntent",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_intent) } {
            return .{ .service_metadata = service_metadata, .action = delete_intent };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
        ResourceInUse,
    },
} = .{};
pub const delete_intent_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/intents/{name}/versions/{version}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIntentVersion",
    Request: type = struct {
        name: []const u8,
        version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_intent_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_intent_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
        ResourceInUse,
    },
} = .{};
pub const delete_slot_type: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/slottypes/{name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSlotType",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_slot_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
        ResourceInUse,
    },
} = .{};
pub const delete_slot_type_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/slottypes/{name}/version/{version}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSlotTypeVersion",
    Request: type = struct {
        name: []const u8,
        version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_slot_type_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_slot_type_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
        ResourceInUse,
    },
} = .{};
pub const delete_utterances: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botName}/utterances/{userId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteUtterances",
    Request: type = struct {
        bot_name: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .user_id = "userId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_utterances) } {
            return .{ .service_metadata = service_metadata, .action = delete_utterances };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_bot: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{name}/versions/{versionOrAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBot",
    Request: type = struct {
        name: []const u8,
        version_or_alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version_or_alias = "versionOrAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bot) } {
            return .{ .service_metadata = service_metadata, .action = get_bot };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        intents: ?[]Intent = null,
        enable_model_improvements: ?bool = null,
        nlu_intent_confidence_threshold: ?f64 = null,
        clarification_prompt: ?Prompt = null,
        abort_statement: ?Statement = null,
        status: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        voice_id: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        version: ?[]const u8 = null,
        locale: ?[]const u8 = null,
        child_directed: ?bool = null,
        detect_sentiment: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .intents = "intents",
                .enable_model_improvements = "enableModelImprovements",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .clarification_prompt = "clarificationPrompt",
                .abort_statement = "abortStatement",
                .status = "status",
                .failure_reason = "failureReason",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .voice_id = "voiceId",
                .checksum = "checksum",
                .version = "version",
                .locale = "locale",
                .child_directed = "childDirected",
                .detect_sentiment = "detectSentiment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_bot_alias: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botName}/aliases/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBotAlias",
    Request: type = struct {
        name: []const u8,
        bot_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .bot_name = "botName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = get_bot_alias };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        checksum: ?[]const u8 = null,
        conversation_logs: ?ConversationLogsResponse = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .bot_version = "botVersion",
                .bot_name = "botName",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .checksum = "checksum",
                .conversation_logs = "conversationLogs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_bot_aliases: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botName}/aliases",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBotAliases",
    Request: type = struct {
        bot_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .name_contains = "nameContains",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .name_contains = "nameContains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bot_aliases) } {
            return .{ .service_metadata = service_metadata, .action = get_bot_aliases };
        }
    },
    Response: type = struct {
        bot_aliases: ?[]struct {
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            bot_version: ?[]const u8 = null,
            bot_name: ?[]const u8 = null,
            last_updated_date: ?i64 = null,
            created_date: ?i64 = null,
            checksum: ?[]const u8 = null,
            conversation_logs: ?ConversationLogsResponse = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .description = "description",
                    .bot_version = "botVersion",
                    .bot_name = "botName",
                    .last_updated_date = "lastUpdatedDate",
                    .created_date = "createdDate",
                    .checksum = "checksum",
                    .conversation_logs = "conversationLogs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_aliases = "BotAliases",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const get_bot_channel_association: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botName}/aliases/{botAlias}/channels/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBotChannelAssociation",
    Request: type = struct {
        name: []const u8,
        bot_name: []const u8,
        bot_alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .bot_name = "botName",
                .bot_alias = "botAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bot_channel_association) } {
            return .{ .service_metadata = service_metadata, .action = get_bot_channel_association };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_alias: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        created_date: ?i64 = null,
        type: ?[]const u8 = null,
        bot_configuration: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        status: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .bot_alias = "botAlias",
                .bot_name = "botName",
                .created_date = "createdDate",
                .type = "type",
                .bot_configuration = "botConfiguration",
                .status = "status",
                .failure_reason = "failureReason",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_configuration", field_name))
                return try serializeMap(self.bot_configuration, self.fieldNameFor("bot_configuration"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_bot_channel_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botName}/aliases/{botAlias}/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBotChannelAssociations",
    Request: type = struct {
        bot_name: []const u8,
        bot_alias: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .name_contains = "nameContains",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .bot_alias = "botAlias",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .name_contains = "nameContains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bot_channel_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_bot_channel_associations };
        }
    },
    Response: type = struct {
        bot_channel_associations: ?[]struct {
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            bot_alias: ?[]const u8 = null,
            bot_name: ?[]const u8 = null,
            created_date: ?i64 = null,
            type: ?[]const u8 = null,
            bot_configuration: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            status: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .description = "description",
                    .bot_alias = "botAlias",
                    .bot_name = "botName",
                    .created_date = "createdDate",
                    .type = "type",
                    .bot_configuration = "botConfiguration",
                    .status = "status",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "bot_configuration", field_name))
                    return try serializeMap(self.bot_configuration, self.fieldNameFor("bot_configuration"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_channel_associations = "botChannelAssociations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const get_bots: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBots",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .name_contains = "nameContains",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .name_contains = "nameContains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bots) } {
            return .{ .service_metadata = service_metadata, .action = get_bots };
        }
    },
    Response: type = struct {
        bots: ?[]BotMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bots = "bots",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_bot_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{name}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBotVersions",
    Request: type = struct {
        name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bot_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_bot_versions };
        }
    },
    Response: type = struct {
        bots: ?[]BotMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bots = "bots",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_builtin_intent: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/builtins/intents/{signature}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBuiltinIntent",
    Request: type = struct {
        signature: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .signature = "signature",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_builtin_intent) } {
            return .{ .service_metadata = service_metadata, .action = get_builtin_intent };
        }
    },
    Response: type = struct {
        signature: ?[]const u8 = null,
        supported_locales: ?[][]const u8 = null,
        slots: ?[]struct {
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .signature = "signature",
                .supported_locales = "supportedLocales",
                .slots = "slots",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_builtin_intents: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/builtins/intents",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBuiltinIntents",
    Request: type = struct {
        locale: ?[]const u8 = null,
        signature_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .locale = "locale",
            .signature_contains = "signatureContains",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locale = "locale",
                .signature_contains = "signatureContains",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_builtin_intents) } {
            return .{ .service_metadata = service_metadata, .action = get_builtin_intents };
        }
    },
    Response: type = struct {
        intents: ?[]struct {
            signature: ?[]const u8 = null,
            supported_locales: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .signature = "signature",
                    .supported_locales = "supportedLocales",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intents = "intents",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const get_builtin_slot_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/builtins/slottypes",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBuiltinSlotTypes",
    Request: type = struct {
        locale: ?[]const u8 = null,
        signature_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .locale = "locale",
            .signature_contains = "signatureContains",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locale = "locale",
                .signature_contains = "signatureContains",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_builtin_slot_types) } {
            return .{ .service_metadata = service_metadata, .action = get_builtin_slot_types };
        }
    },
    Response: type = struct {
        slot_types: ?[]struct {
            signature: ?[]const u8 = null,
            supported_locales: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .signature = "signature",
                    .supported_locales = "supportedLocales",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_types = "slotTypes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const get_export: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/exports",
        .success_code = 200,
    };

    action_name: []const u8 = "GetExport",
    Request: type = struct {
        name: []const u8,
        version: []const u8,
        resource_type: []const u8,
        export_type: []const u8,

        pub const http_query = .{
            .name = "name",
            .version = "version",
            .resource_type = "resourceType",
            .export_type = "exportType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version = "version",
                .resource_type = "resourceType",
                .export_type = "exportType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_export) } {
            return .{ .service_metadata = service_metadata, .action = get_export };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        export_type: ?[]const u8 = null,
        export_status: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version = "version",
                .resource_type = "resourceType",
                .export_type = "exportType",
                .export_status = "exportStatus",
                .failure_reason = "failureReason",
                .url = "url",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_import: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/imports/{importId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImport",
    Request: type = struct {
        import_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_import) } {
            return .{ .service_metadata = service_metadata, .action = get_import };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        merge_strategy: ?[]const u8 = null,
        import_id: ?[]const u8 = null,
        import_status: ?[]const u8 = null,
        failure_reason: ?[][]const u8 = null,
        created_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .resource_type = "resourceType",
                .merge_strategy = "mergeStrategy",
                .import_id = "importId",
                .import_status = "importStatus",
                .failure_reason = "failureReason",
                .created_date = "createdDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_intent: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/intents/{name}/versions/{version}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntent",
    Request: type = struct {
        name: []const u8,
        version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_intent) } {
            return .{ .service_metadata = service_metadata, .action = get_intent };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slots: ?[]Slot = null,
        sample_utterances: ?[][]const u8 = null,
        confirmation_prompt: ?Prompt = null,
        rejection_statement: ?Statement = null,
        follow_up_prompt: ?FollowUpPrompt = null,
        conclusion_statement: ?Statement = null,
        dialog_code_hook: ?CodeHook = null,
        fulfillment_activity: ?FulfillmentActivity = null,
        parent_intent_signature: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        kendra_configuration: ?KendraConfiguration = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .slots = "slots",
                .sample_utterances = "sampleUtterances",
                .confirmation_prompt = "confirmationPrompt",
                .rejection_statement = "rejectionStatement",
                .follow_up_prompt = "followUpPrompt",
                .conclusion_statement = "conclusionStatement",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_activity = "fulfillmentActivity",
                .parent_intent_signature = "parentIntentSignature",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .version = "version",
                .checksum = "checksum",
                .kendra_configuration = "kendraConfiguration",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_intents: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/intents",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntents",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .name_contains = "nameContains",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .name_contains = "nameContains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_intents) } {
            return .{ .service_metadata = service_metadata, .action = get_intents };
        }
    },
    Response: type = struct {
        intents: ?[]IntentMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intents = "intents",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_intent_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/intents/{name}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntentVersions",
    Request: type = struct {
        name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_intent_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_intent_versions };
        }
    },
    Response: type = struct {
        intents: ?[]IntentMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intents = "intents",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_migration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/migrations/{migrationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMigration",
    Request: type = struct {
        migration_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_id = "migrationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_migration) } {
            return .{ .service_metadata = service_metadata, .action = get_migration };
        }
    },
    Response: type = struct {
        migration_id: ?[]const u8 = null,
        v1_bot_name: ?[]const u8 = null,
        v1_bot_version: ?[]const u8 = null,
        v1_bot_locale: ?[]const u8 = null,
        v2_bot_id: ?[]const u8 = null,
        v2_bot_role: ?[]const u8 = null,
        migration_status: ?[]const u8 = null,
        migration_strategy: ?[]const u8 = null,
        migration_timestamp: ?i64 = null,
        alerts: ?[]struct {
            type: ?[]const u8 = null,
            message: ?[]const u8 = null,
            details: ?[][]const u8 = null,
            reference_ur_ls: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "type",
                    .message = "message",
                    .details = "details",
                    .reference_ur_ls = "referenceURLs",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_id = "migrationId",
                .v1_bot_name = "v1BotName",
                .v1_bot_version = "v1BotVersion",
                .v1_bot_locale = "v1BotLocale",
                .v2_bot_id = "v2BotId",
                .v2_bot_role = "v2BotRole",
                .migration_status = "migrationStatus",
                .migration_strategy = "migrationStrategy",
                .migration_timestamp = "migrationTimestamp",
                .alerts = "alerts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_migrations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/migrations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMigrations",
    Request: type = struct {
        sort_by_attribute: ?[]const u8 = null,
        sort_by_order: ?[]const u8 = null,
        v1_bot_name_contains: ?[]const u8 = null,
        migration_status_equals: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .sort_by_attribute = "sortByAttribute",
            .sort_by_order = "sortByOrder",
            .v1_bot_name_contains = "v1BotNameContains",
            .migration_status_equals = "migrationStatusEquals",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort_by_attribute = "sortByAttribute",
                .sort_by_order = "sortByOrder",
                .v1_bot_name_contains = "v1BotNameContains",
                .migration_status_equals = "migrationStatusEquals",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_migrations) } {
            return .{ .service_metadata = service_metadata, .action = get_migrations };
        }
    },
    Response: type = struct {
        migration_summaries: ?[]struct {
            migration_id: ?[]const u8 = null,
            v1_bot_name: ?[]const u8 = null,
            v1_bot_version: ?[]const u8 = null,
            v1_bot_locale: ?[]const u8 = null,
            v2_bot_id: ?[]const u8 = null,
            v2_bot_role: ?[]const u8 = null,
            migration_status: ?[]const u8 = null,
            migration_strategy: ?[]const u8 = null,
            migration_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .migration_id = "migrationId",
                    .v1_bot_name = "v1BotName",
                    .v1_bot_version = "v1BotVersion",
                    .v1_bot_locale = "v1BotLocale",
                    .v2_bot_id = "v2BotId",
                    .v2_bot_role = "v2BotRole",
                    .migration_status = "migrationStatus",
                    .migration_strategy = "migrationStrategy",
                    .migration_timestamp = "migrationTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_summaries = "migrationSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const get_slot_type: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/slottypes/{name}/versions/{version}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSlotType",
    Request: type = struct {
        name: []const u8,
        version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = get_slot_type };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        enumeration_values: ?[]EnumerationValue = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        value_selection_strategy: ?[]const u8 = null,
        parent_slot_type_signature: ?[]const u8 = null,
        slot_type_configurations: ?[]SlotTypeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .enumeration_values = "enumerationValues",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .version = "version",
                .checksum = "checksum",
                .value_selection_strategy = "valueSelectionStrategy",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .slot_type_configurations = "slotTypeConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_slot_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/slottypes",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSlotTypes",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .name_contains = "nameContains",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .name_contains = "nameContains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_slot_types) } {
            return .{ .service_metadata = service_metadata, .action = get_slot_types };
        }
    },
    Response: type = struct {
        slot_types: ?[]SlotTypeMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_types = "slotTypes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_slot_type_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/slottypes/{name}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSlotTypeVersions",
    Request: type = struct {
        name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_slot_type_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_slot_type_versions };
        }
    },
    Response: type = struct {
        slot_types: ?[]SlotTypeMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_types = "slotTypes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_utterances_view: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botName}/utterances?view=aggregation",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUtterancesView",
    Request: type = struct {
        bot_name: []const u8,
        bot_versions: [][]const u8,
        status_type: []const u8,

        pub const http_query = .{
            .bot_versions = "bot_versions",
            .status_type = "status_type",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .bot_versions = "botVersions",
                .status_type = "statusType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_utterances_view) } {
            return .{ .service_metadata = service_metadata, .action = get_utterances_view };
        }
    },
    Response: type = struct {
        bot_name: ?[]const u8 = null,
        utterances: ?[]struct {
            bot_version: ?[]const u8 = null,
            utterances: ?[]struct {
                utterance_string: ?[]const u8 = null,
                count: ?i64 = null,
                distinct_users: ?i64 = null,
                first_uttered_date: ?i64 = null,
                last_uttered_date: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .utterance_string = "utteranceString",
                        .count = "count",
                        .distinct_users = "distinctUsers",
                        .first_uttered_date = "firstUtteredDate",
                        .last_uttered_date = "lastUtteredDate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_version = "botVersion",
                    .utterances = "utterances",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .utterances = "utterances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const put_bot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{name}/versions/$LATEST",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBot",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        intents: ?[]Intent = null,
        enable_model_improvements: ?bool = null,
        nlu_intent_confidence_threshold: ?f64 = null,
        clarification_prompt: ?Prompt = null,
        abort_statement: ?Statement = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        voice_id: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        process_behavior: ?[]const u8 = null,
        locale: []const u8,
        child_directed: bool,
        detect_sentiment: ?bool = null,
        create_version: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .intents = "intents",
                .enable_model_improvements = "enableModelImprovements",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .clarification_prompt = "clarificationPrompt",
                .abort_statement = "abortStatement",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .voice_id = "voiceId",
                .checksum = "checksum",
                .process_behavior = "processBehavior",
                .locale = "locale",
                .child_directed = "childDirected",
                .detect_sentiment = "detectSentiment",
                .create_version = "createVersion",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bot) } {
            return .{ .service_metadata = service_metadata, .action = put_bot };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        intents: ?[]Intent = null,
        enable_model_improvements: ?bool = null,
        nlu_intent_confidence_threshold: ?f64 = null,
        clarification_prompt: ?Prompt = null,
        abort_statement: ?Statement = null,
        status: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        voice_id: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        version: ?[]const u8 = null,
        locale: ?[]const u8 = null,
        child_directed: ?bool = null,
        create_version: ?bool = null,
        detect_sentiment: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .intents = "intents",
                .enable_model_improvements = "enableModelImprovements",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .clarification_prompt = "clarificationPrompt",
                .abort_statement = "abortStatement",
                .status = "status",
                .failure_reason = "failureReason",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .voice_id = "voiceId",
                .checksum = "checksum",
                .version = "version",
                .locale = "locale",
                .child_directed = "childDirected",
                .create_version = "createVersion",
                .detect_sentiment = "detectSentiment",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        PreconditionFailed,
    },
} = .{};
pub const put_bot_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botName}/aliases/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBotAlias",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        bot_version: []const u8,
        bot_name: []const u8,
        checksum: ?[]const u8 = null,
        conversation_logs: ?struct {
            log_settings: []struct {
                log_type: []const u8,
                destination: []const u8,
                kms_key_arn: ?[]const u8 = null,
                resource_arn: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .log_type = "logType",
                        .destination = "destination",
                        .kms_key_arn = "kmsKeyArn",
                        .resource_arn = "resourceArn",
                    };
                    return @field(mappings, field_name);
                }
            },
            iam_role_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .log_settings = "logSettings",
                    .iam_role_arn = "iamRoleArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .bot_version = "botVersion",
                .bot_name = "botName",
                .checksum = "checksum",
                .conversation_logs = "conversationLogs",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = put_bot_alias };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        checksum: ?[]const u8 = null,
        conversation_logs: ?ConversationLogsResponse = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .bot_version = "botVersion",
                .bot_name = "botName",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .checksum = "checksum",
                .conversation_logs = "conversationLogs",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        PreconditionFailed,
    },
} = .{};
pub const put_intent: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/intents/{name}/versions/$LATEST",
        .success_code = 200,
    };

    action_name: []const u8 = "PutIntent",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        slots: ?[]Slot = null,
        sample_utterances: ?[][]const u8 = null,
        confirmation_prompt: ?Prompt = null,
        rejection_statement: ?Statement = null,
        follow_up_prompt: ?FollowUpPrompt = null,
        conclusion_statement: ?Statement = null,
        dialog_code_hook: ?CodeHook = null,
        fulfillment_activity: ?FulfillmentActivity = null,
        parent_intent_signature: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        create_version: ?bool = null,
        kendra_configuration: ?KendraConfiguration = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .slots = "slots",
                .sample_utterances = "sampleUtterances",
                .confirmation_prompt = "confirmationPrompt",
                .rejection_statement = "rejectionStatement",
                .follow_up_prompt = "followUpPrompt",
                .conclusion_statement = "conclusionStatement",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_activity = "fulfillmentActivity",
                .parent_intent_signature = "parentIntentSignature",
                .checksum = "checksum",
                .create_version = "createVersion",
                .kendra_configuration = "kendraConfiguration",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_intent) } {
            return .{ .service_metadata = service_metadata, .action = put_intent };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slots: ?[]Slot = null,
        sample_utterances: ?[][]const u8 = null,
        confirmation_prompt: ?Prompt = null,
        rejection_statement: ?Statement = null,
        follow_up_prompt: ?FollowUpPrompt = null,
        conclusion_statement: ?Statement = null,
        dialog_code_hook: ?CodeHook = null,
        fulfillment_activity: ?FulfillmentActivity = null,
        parent_intent_signature: ?[]const u8 = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        create_version: ?bool = null,
        kendra_configuration: ?KendraConfiguration = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .slots = "slots",
                .sample_utterances = "sampleUtterances",
                .confirmation_prompt = "confirmationPrompt",
                .rejection_statement = "rejectionStatement",
                .follow_up_prompt = "followUpPrompt",
                .conclusion_statement = "conclusionStatement",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_activity = "fulfillmentActivity",
                .parent_intent_signature = "parentIntentSignature",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .version = "version",
                .checksum = "checksum",
                .create_version = "createVersion",
                .kendra_configuration = "kendraConfiguration",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        PreconditionFailed,
    },
} = .{};
pub const put_slot_type: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/slottypes/{name}/versions/$LATEST",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSlotType",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        enumeration_values: ?[]EnumerationValue = null,
        checksum: ?[]const u8 = null,
        value_selection_strategy: ?[]const u8 = null,
        create_version: ?bool = null,
        parent_slot_type_signature: ?[]const u8 = null,
        slot_type_configurations: ?[]SlotTypeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .enumeration_values = "enumerationValues",
                .checksum = "checksum",
                .value_selection_strategy = "valueSelectionStrategy",
                .create_version = "createVersion",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .slot_type_configurations = "slotTypeConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = put_slot_type };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        enumeration_values: ?[]EnumerationValue = null,
        last_updated_date: ?i64 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        checksum: ?[]const u8 = null,
        value_selection_strategy: ?[]const u8 = null,
        create_version: ?bool = null,
        parent_slot_type_signature: ?[]const u8 = null,
        slot_type_configurations: ?[]SlotTypeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .enumeration_values = "enumerationValues",
                .last_updated_date = "lastUpdatedDate",
                .created_date = "createdDate",
                .version = "version",
                .checksum = "checksum",
                .value_selection_strategy = "valueSelectionStrategy",
                .create_version = "createVersion",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .slot_type_configurations = "slotTypeConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        PreconditionFailed,
    },
} = .{};
pub const start_import: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/imports",
        .success_code = 201,
    };

    action_name: []const u8 = "StartImport",
    Request: type = struct {
        payload: []const u8,
        resource_type: []const u8,
        merge_strategy: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .payload = "payload",
                .resource_type = "resourceType",
                .merge_strategy = "mergeStrategy",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_import) } {
            return .{ .service_metadata = service_metadata, .action = start_import };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        merge_strategy: ?[]const u8 = null,
        import_id: ?[]const u8 = null,
        import_status: ?[]const u8 = null,
        tags: ?[]Tag = null,
        created_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .resource_type = "resourceType",
                .merge_strategy = "mergeStrategy",
                .import_id = "importId",
                .import_status = "importStatus",
                .tags = "tags",
                .created_date = "createdDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const start_migration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/migrations",
        .success_code = 202,
    };

    action_name: []const u8 = "StartMigration",
    Request: type = struct {
        v1_bot_name: []const u8,
        v1_bot_version: []const u8,
        v2_bot_name: []const u8,
        v2_bot_role: []const u8,
        migration_strategy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .v1_bot_name = "v1BotName",
                .v1_bot_version = "v1BotVersion",
                .v2_bot_name = "v2BotName",
                .v2_bot_role = "v2BotRole",
                .migration_strategy = "migrationStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_migration) } {
            return .{ .service_metadata = service_metadata, .action = start_migration };
        }
    },
    Response: type = struct {
        v1_bot_name: ?[]const u8 = null,
        v1_bot_version: ?[]const u8 = null,
        v1_bot_locale: ?[]const u8 = null,
        v2_bot_id: ?[]const u8 = null,
        v2_bot_role: ?[]const u8 = null,
        migration_id: ?[]const u8 = null,
        migration_strategy: ?[]const u8 = null,
        migration_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .v1_bot_name = "v1BotName",
                .v1_bot_version = "v1BotVersion",
                .v1_bot_locale = "v1BotLocale",
                .v2_bot_id = "v2BotId",
                .v2_bot_role = "v2BotRole",
                .migration_id = "migrationId",
                .migration_strategy = "migrationStrategy",
                .migration_timestamp = "migrationTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotTypeConfiguration = struct {
    regex_configuration: ?SlotTypeRegexConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .regex_configuration = "regexConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotTypeRegexConfiguration = struct {
    pattern: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pattern = "pattern",
        };
        return @field(mappings, field_name);
    }
};

pub const EnumerationValue = struct {
    value: []const u8,
    synonyms: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .synonyms = "synonyms",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputContext = struct {
    name: []const u8,
    time_to_live_in_seconds: i64,
    turns_to_live: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .time_to_live_in_seconds = "timeToLiveInSeconds",
            .turns_to_live = "turnsToLive",
        };
        return @field(mappings, field_name);
    }
};

pub const InputContext = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const KendraConfiguration = struct {
    kendra_index: []const u8,
    query_filter_string: ?[]const u8 = null,
    role: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kendra_index = "kendraIndex",
            .query_filter_string = "queryFilterString",
            .role = "role",
        };
        return @field(mappings, field_name);
    }
};

pub const FulfillmentActivity = struct {
    type: []const u8,
    code_hook: ?CodeHook = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .code_hook = "codeHook",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeHook = struct {
    uri: []const u8,
    message_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .uri = "uri",
            .message_version = "messageVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const Statement = struct {
    messages: []Message,
    response_card: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .messages = "messages",
            .response_card = "responseCard",
        };
        return @field(mappings, field_name);
    }
};

pub const Message = struct {
    content_type: []const u8,
    content: []const u8,
    group_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_type = "contentType",
            .content = "content",
            .group_number = "groupNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const FollowUpPrompt = struct {
    prompt: Prompt,
    rejection_statement: Statement,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prompt = "prompt",
            .rejection_statement = "rejectionStatement",
        };
        return @field(mappings, field_name);
    }
};

pub const Prompt = struct {
    messages: []Message,
    max_attempts: i64,
    response_card: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .messages = "messages",
            .max_attempts = "maxAttempts",
            .response_card = "responseCard",
        };
        return @field(mappings, field_name);
    }
};

pub const Slot = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    slot_constraint: []const u8,
    slot_type: ?[]const u8 = null,
    slot_type_version: ?[]const u8 = null,
    value_elicitation_prompt: ?Prompt = null,
    priority: ?i64 = null,
    sample_utterances: ?[][]const u8 = null,
    response_card: ?[]const u8 = null,
    obfuscation_setting: ?[]const u8 = null,
    default_value_spec: ?SlotDefaultValueSpec = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .slot_constraint = "slotConstraint",
            .slot_type = "slotType",
            .slot_type_version = "slotTypeVersion",
            .value_elicitation_prompt = "valueElicitationPrompt",
            .priority = "priority",
            .sample_utterances = "sampleUtterances",
            .response_card = "responseCard",
            .obfuscation_setting = "obfuscationSetting",
            .default_value_spec = "defaultValueSpec",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotDefaultValueSpec = struct {
    default_value_list: []SlotDefaultValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value_list = "defaultValueList",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotDefaultValue = struct {
    default_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "defaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ConversationLogsResponse = struct {
    log_settings: ?[]LogSettingsResponse = null,
    iam_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_settings = "logSettings",
            .iam_role_arn = "iamRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LogSettingsResponse = struct {
    log_type: ?[]const u8 = null,
    destination: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    resource_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_type = "logType",
            .destination = "destination",
            .kms_key_arn = "kmsKeyArn",
            .resource_arn = "resourceArn",
            .resource_prefix = "resourcePrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Intent = struct {
    intent_name: []const u8,
    intent_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .intent_name = "intentName",
            .intent_version = "intentVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotTypeMetadata = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    last_updated_date: ?i64 = null,
    created_date: ?i64 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .last_updated_date = "lastUpdatedDate",
            .created_date = "createdDate",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const IntentMetadata = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    last_updated_date: ?i64 = null,
    created_date: ?i64 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .last_updated_date = "lastUpdatedDate",
            .created_date = "createdDate",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const BotMetadata = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    status: ?[]const u8 = null,
    last_updated_date: ?i64 = null,
    created_date: ?i64 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .status = "status",
            .last_updated_date = "lastUpdatedDate",
            .created_date = "createdDate",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};
