const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-11-28";
pub const sdk_id: []const u8 = "Lex Runtime Service";
pub const arn_namespace: ?[]const u8 = "lex";
pub const endpoint_prefix: []const u8 = "runtime.lex";
pub const sigv4_name: []const u8 = "lex";
pub const name: []const u8 = "AWSDeepSenseRunTimeService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-11-28",
    sdk_id: []const u8 = "Lex Runtime Service",
    arn_namespace: ?[]const u8 = "lex",
    endpoint_prefix: []const u8 = "runtime.lex",
    sigv4_name: []const u8 = "lex",
    name: []const u8 = "AWSDeepSenseRunTimeService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_session: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bot/{botName}/alias/{botAlias}/user/{userId}/session",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSession",
    Request: type = struct {
        bot_name: []const u8,
        bot_alias: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .bot_alias = "botAlias",
                .user_id = "userId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_session) } {
            return .{ .service_metadata = service_metadata, .action = delete_session };
        }
    },
    Response: type = struct {
        bot_name: ?[]const u8 = null,
        bot_alias: ?[]const u8 = null,
        user_id: ?[]const u8 = null,
        session_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .bot_alias = "botAlias",
                .user_id = "userId",
                .session_id = "sessionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_session: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bot/{botName}/alias/{botAlias}/user/{userId}/session",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSession",
    Request: type = struct {
        bot_name: []const u8,
        bot_alias: []const u8,
        user_id: []const u8,
        checkpoint_label_filter: ?[]const u8 = null,

        pub const http_query = .{
            .checkpoint_label_filter = "checkpointLabelFilter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .bot_alias = "botAlias",
                .user_id = "userId",
                .checkpoint_label_filter = "checkpointLabelFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_session) } {
            return .{ .service_metadata = service_metadata, .action = get_session };
        }
    },
    Response: type = struct {
        recent_intent_summary_view: ?[]IntentSummary = null,
        session_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        session_id: ?[]const u8 = null,
        dialog_action: ?DialogAction = null,
        active_contexts: ?[]ActiveContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recent_intent_summary_view = "recentIntentSummaryView",
                .session_attributes = "sessionAttributes",
                .session_id = "sessionId",
                .dialog_action = "dialogAction",
                .active_contexts = "activeContexts",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "session_attributes", field_name))
                return try serializeMap(self.session_attributes, self.fieldNameFor("session_attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const post_content: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bot/{botName}/alias/{botAlias}/user/{userId}/content",
        .success_code = 200,
    };

    action_name: []const u8 = "PostContent",
    Request: type = struct {
        bot_name: []const u8,
        bot_alias: []const u8,
        user_id: []const u8,
        session_attributes: ?[]const u8 = null,
        request_attributes: ?[]const u8 = null,
        content_type: []const u8,
        accept: ?[]const u8 = null,
        input_stream: []const u8,
        active_contexts: ?[]const u8 = null,
        pub const http_header = .{
            .session_attributes = "x-amz-lex-session-attributes",
            .request_attributes = "x-amz-lex-request-attributes",
            .content_type = "Content-Type",
            .accept = "Accept",
            .active_contexts = "x-amz-lex-active-contexts",
        };

        pub const http_payload: []const u8 = "input_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .bot_alias = "botAlias",
                .user_id = "userId",
                .session_attributes = "sessionAttributes",
                .request_attributes = "requestAttributes",
                .content_type = "contentType",
                .accept = "accept",
                .input_stream = "inputStream",
                .active_contexts = "activeContexts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(post_content) } {
            return .{ .service_metadata = service_metadata, .action = post_content };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        intent_name: ?[]const u8 = null,
        nlu_intent_confidence: ?[]const u8 = null,
        alternative_intents: ?[]const u8 = null,
        slots: ?[]const u8 = null,
        session_attributes: ?[]const u8 = null,
        sentiment_response: ?[]const u8 = null,
        message: ?[]const u8 = null,
        encoded_message: ?[]const u8 = null,
        message_format: ?[]const u8 = null,
        dialog_state: ?[]const u8 = null,
        slot_to_elicit: ?[]const u8 = null,
        input_transcript: ?[]const u8 = null,
        encoded_input_transcript: ?[]const u8 = null,
        audio_stream: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        active_contexts: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .intent_name = "x-amz-lex-intent-name",
            .nlu_intent_confidence = "x-amz-lex-nlu-intent-confidence",
            .alternative_intents = "x-amz-lex-alternative-intents",
            .slots = "x-amz-lex-slots",
            .session_attributes = "x-amz-lex-session-attributes",
            .sentiment_response = "x-amz-lex-sentiment",
            .message = "x-amz-lex-message",
            .encoded_message = "x-amz-lex-encoded-message",
            .message_format = "x-amz-lex-message-format",
            .dialog_state = "x-amz-lex-dialog-state",
            .slot_to_elicit = "x-amz-lex-slot-to-elicit",
            .input_transcript = "x-amz-lex-input-transcript",
            .encoded_input_transcript = "x-amz-lex-encoded-input-transcript",
            .bot_version = "x-amz-lex-bot-version",
            .session_id = "x-amz-lex-session-id",
            .active_contexts = "x-amz-lex-active-contexts",
        };

        pub const http_payload: []const u8 = "audio_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .intent_name = "intentName",
                .nlu_intent_confidence = "nluIntentConfidence",
                .alternative_intents = "alternativeIntents",
                .slots = "slots",
                .session_attributes = "sessionAttributes",
                .sentiment_response = "sentimentResponse",
                .message = "message",
                .encoded_message = "encodedMessage",
                .message_format = "messageFormat",
                .dialog_state = "dialogState",
                .slot_to_elicit = "slotToElicit",
                .input_transcript = "inputTranscript",
                .encoded_input_transcript = "encodedInputTranscript",
                .audio_stream = "audioStream",
                .bot_version = "botVersion",
                .session_id = "sessionId",
                .active_contexts = "activeContexts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        DependencyFailed,
        InternalFailure,
        LimitExceeded,
        LoopDetected,
        NotAcceptable,
        NotFound,
        RequestTimeout,
        UnsupportedMediaType,
    },
} = .{};
pub const post_text: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bot/{botName}/alias/{botAlias}/user/{userId}/text",
        .success_code = 200,
    };

    action_name: []const u8 = "PostText",
    Request: type = struct {
        bot_name: []const u8,
        bot_alias: []const u8,
        user_id: []const u8,
        session_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        input_text: []const u8,
        active_contexts: ?[]ActiveContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .bot_alias = "botAlias",
                .user_id = "userId",
                .session_attributes = "sessionAttributes",
                .request_attributes = "requestAttributes",
                .input_text = "inputText",
                .active_contexts = "activeContexts",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "session_attributes", field_name))
                return try serializeMap(self.session_attributes, self.fieldNameFor("session_attributes"), options, out_stream);
            if (std.mem.eql(u8, "request_attributes", field_name))
                return try serializeMap(self.request_attributes, self.fieldNameFor("request_attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(post_text) } {
            return .{ .service_metadata = service_metadata, .action = post_text };
        }
    },
    Response: type = struct {
        intent_name: ?[]const u8 = null,
        nlu_intent_confidence: ?IntentConfidence = null,
        alternative_intents: ?[]struct {
            intent_name: ?[]const u8 = null,
            nlu_intent_confidence: ?IntentConfidence = null,
            slots: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .intent_name = "intentName",
                    .nlu_intent_confidence = "nluIntentConfidence",
                    .slots = "slots",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "slots", field_name))
                    return try serializeMap(self.slots, self.fieldNameFor("slots"), options, out_stream);
                return false;
            }
        } = null,
        slots: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        session_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        message: ?[]const u8 = null,
        sentiment_response: ?struct {
            sentiment_label: ?[]const u8 = null,
            sentiment_score: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sentiment_label = "sentimentLabel",
                    .sentiment_score = "sentimentScore",
                };
                return @field(mappings, field_name);
            }
        } = null,
        message_format: ?[]const u8 = null,
        dialog_state: ?[]const u8 = null,
        slot_to_elicit: ?[]const u8 = null,
        response_card: ?struct {
            version: ?[]const u8 = null,
            content_type: ?[]const u8 = null,
            generic_attachments: ?[]struct {
                title: ?[]const u8 = null,
                sub_title: ?[]const u8 = null,
                attachment_link_url: ?[]const u8 = null,
                image_url: ?[]const u8 = null,
                buttons: ?[]struct {
                    text: []const u8,
                    value: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .text = "text",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .title = "title",
                        .sub_title = "subTitle",
                        .attachment_link_url = "attachmentLinkUrl",
                        .image_url = "imageUrl",
                        .buttons = "buttons",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version = "version",
                    .content_type = "contentType",
                    .generic_attachments = "genericAttachments",
                };
                return @field(mappings, field_name);
            }
        } = null,
        session_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        active_contexts: ?[]ActiveContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_name = "intentName",
                .nlu_intent_confidence = "nluIntentConfidence",
                .alternative_intents = "alternativeIntents",
                .slots = "slots",
                .session_attributes = "sessionAttributes",
                .message = "message",
                .sentiment_response = "sentimentResponse",
                .message_format = "messageFormat",
                .dialog_state = "dialogState",
                .slot_to_elicit = "slotToElicit",
                .response_card = "responseCard",
                .session_id = "sessionId",
                .bot_version = "botVersion",
                .active_contexts = "activeContexts",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "slots", field_name))
                return try serializeMap(self.slots, self.fieldNameFor("slots"), options, out_stream);
            if (std.mem.eql(u8, "session_attributes", field_name))
                return try serializeMap(self.session_attributes, self.fieldNameFor("session_attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        DependencyFailed,
        InternalFailure,
        LimitExceeded,
        LoopDetected,
        NotFound,
    },
} = .{};
pub const put_session: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bot/{botName}/alias/{botAlias}/user/{userId}/session",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSession",
    Request: type = struct {
        bot_name: []const u8,
        bot_alias: []const u8,
        user_id: []const u8,
        session_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        dialog_action: ?DialogAction = null,
        recent_intent_summary_view: ?[]IntentSummary = null,
        accept: ?[]const u8 = null,
        active_contexts: ?[]ActiveContext = null,
        pub const http_header = .{
            .accept = "Accept",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .bot_alias = "botAlias",
                .user_id = "userId",
                .session_attributes = "sessionAttributes",
                .dialog_action = "dialogAction",
                .recent_intent_summary_view = "recentIntentSummaryView",
                .accept = "accept",
                .active_contexts = "activeContexts",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "session_attributes", field_name))
                return try serializeMap(self.session_attributes, self.fieldNameFor("session_attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_session) } {
            return .{ .service_metadata = service_metadata, .action = put_session };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        intent_name: ?[]const u8 = null,
        slots: ?[]const u8 = null,
        session_attributes: ?[]const u8 = null,
        message: ?[]const u8 = null,
        encoded_message: ?[]const u8 = null,
        message_format: ?[]const u8 = null,
        dialog_state: ?[]const u8 = null,
        slot_to_elicit: ?[]const u8 = null,
        audio_stream: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        active_contexts: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .intent_name = "x-amz-lex-intent-name",
            .slots = "x-amz-lex-slots",
            .session_attributes = "x-amz-lex-session-attributes",
            .message = "x-amz-lex-message",
            .encoded_message = "x-amz-lex-encoded-message",
            .message_format = "x-amz-lex-message-format",
            .dialog_state = "x-amz-lex-dialog-state",
            .slot_to_elicit = "x-amz-lex-slot-to-elicit",
            .session_id = "x-amz-lex-session-id",
            .active_contexts = "x-amz-lex-active-contexts",
        };

        pub const http_payload: []const u8 = "audio_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .intent_name = "intentName",
                .slots = "slots",
                .session_attributes = "sessionAttributes",
                .message = "message",
                .encoded_message = "encodedMessage",
                .message_format = "messageFormat",
                .dialog_state = "dialogState",
                .slot_to_elicit = "slotToElicit",
                .audio_stream = "audioStream",
                .session_id = "sessionId",
                .active_contexts = "activeContexts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadGateway,
        BadRequest,
        Conflict,
        DependencyFailed,
        InternalFailure,
        LimitExceeded,
        NotAcceptable,
        NotFound,
    },
} = .{};

pub const ActiveContext = struct {
    name: []const u8,
    time_to_live: ActiveContextTimeToLive,
    parameters: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .time_to_live = "timeToLive",
            .parameters = "parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const ActiveContextTimeToLive = struct {
    time_to_live_in_seconds: ?i64 = null,
    turns_to_live: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_to_live_in_seconds = "timeToLiveInSeconds",
            .turns_to_live = "turnsToLive",
        };
        return @field(mappings, field_name);
    }
};

pub const IntentSummary = struct {
    intent_name: ?[]const u8 = null,
    checkpoint_label: ?[]const u8 = null,
    slots: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    confirmation_status: ?[]const u8 = null,
    dialog_action_type: []const u8,
    fulfillment_state: ?[]const u8 = null,
    slot_to_elicit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .intent_name = "intentName",
            .checkpoint_label = "checkpointLabel",
            .slots = "slots",
            .confirmation_status = "confirmationStatus",
            .dialog_action_type = "dialogActionType",
            .fulfillment_state = "fulfillmentState",
            .slot_to_elicit = "slotToElicit",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "slots", field_name))
            return try serializeMap(self.slots, self.fieldNameFor("slots"), options, out_stream);
        return false;
    }
};

pub const DialogAction = struct {
    type: []const u8,
    intent_name: ?[]const u8 = null,
    slots: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    slot_to_elicit: ?[]const u8 = null,
    fulfillment_state: ?[]const u8 = null,
    message: ?[]const u8 = null,
    message_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .intent_name = "intentName",
            .slots = "slots",
            .slot_to_elicit = "slotToElicit",
            .fulfillment_state = "fulfillmentState",
            .message = "message",
            .message_format = "messageFormat",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "slots", field_name))
            return try serializeMap(self.slots, self.fieldNameFor("slots"), options, out_stream);
        return false;
    }
};

pub const IntentConfidence = struct {
    score: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .score = "score",
        };
        return @field(mappings, field_name);
    }
};
