const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-08-07";
pub const sdk_id: []const u8 = "Lex Runtime V2";
pub const arn_namespace: ?[]const u8 = "lex";
pub const endpoint_prefix: []const u8 = "runtime-v2-lex";
pub const sigv4_name: []const u8 = "lex";
pub const name: []const u8 = "AWSDeepSenseRunTimeServiceApi2_0";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-08-07",
    sdk_id: []const u8 = "Lex Runtime V2",
    arn_namespace: ?[]const u8 = "lex",
    endpoint_prefix: []const u8 = "runtime-v2-lex",
    sigv4_name: []const u8 = "lex",
    name: []const u8 = "AWSDeepSenseRunTimeServiceApi2_0",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_session: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botAliases/{botAliasId}/botLocales/{localeId}/sessions/{sessionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSession",
    Request: type = struct {
        bot_id: []const u8,
        bot_alias_id: []const u8,
        locale_id: []const u8,
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_alias_id = "botAliasId",
                .locale_id = "localeId",
                .session_id = "sessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_session) } {
            return .{ .service_metadata = service_metadata, .action = delete_session };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_alias_id: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        session_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_alias_id = "botAliasId",
                .locale_id = "localeId",
                .session_id = "sessionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_session: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botAliases/{botAliasId}/botLocales/{localeId}/sessions/{sessionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSession",
    Request: type = struct {
        bot_id: []const u8,
        bot_alias_id: []const u8,
        locale_id: []const u8,
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_alias_id = "botAliasId",
                .locale_id = "localeId",
                .session_id = "sessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_session) } {
            return .{ .service_metadata = service_metadata, .action = get_session };
        }
    },
    Response: type = struct {
        session_id: ?[]const u8 = null,
        messages: ?[]Message = null,
        interpretations: ?[]Interpretation = null,
        session_state: ?SessionState = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "sessionId",
                .messages = "messages",
                .interpretations = "interpretations",
                .session_state = "sessionState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_session: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botAliases/{botAliasId}/botLocales/{localeId}/sessions/{sessionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSession",
    Request: type = struct {
        bot_id: []const u8,
        bot_alias_id: []const u8,
        locale_id: []const u8,
        session_id: []const u8,
        messages: ?[]Message = null,
        session_state: SessionState,
        request_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_content_type: ?[]const u8 = null,
        pub const http_header = .{
            .response_content_type = "ResponseContentType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_alias_id = "botAliasId",
                .locale_id = "localeId",
                .session_id = "sessionId",
                .messages = "messages",
                .session_state = "sessionState",
                .request_attributes = "requestAttributes",
                .response_content_type = "responseContentType",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_attributes", field_name))
                return try serializeMap(self.request_attributes, self.fieldNameFor("request_attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_session) } {
            return .{ .service_metadata = service_metadata, .action = put_session };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        messages: ?[]const u8 = null,
        session_state: ?[]const u8 = null,
        request_attributes: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        audio_stream: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .messages = "x-amz-lex-messages",
            .session_state = "x-amz-lex-session-state",
            .request_attributes = "x-amz-lex-request-attributes",
            .session_id = "x-amz-lex-session-id",
        };

        pub const http_payload: []const u8 = "audio_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .messages = "messages",
                .session_state = "sessionState",
                .request_attributes = "requestAttributes",
                .session_id = "sessionId",
                .audio_stream = "audioStream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadGateway,
        Conflict,
        DependencyFailed,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const recognize_text: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botAliases/{botAliasId}/botLocales/{localeId}/sessions/{sessionId}/text",
        .success_code = 200,
    };

    action_name: []const u8 = "RecognizeText",
    Request: type = struct {
        bot_id: []const u8,
        bot_alias_id: []const u8,
        locale_id: []const u8,
        session_id: []const u8,
        text: []const u8,
        session_state: ?SessionState = null,
        request_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_alias_id = "botAliasId",
                .locale_id = "localeId",
                .session_id = "sessionId",
                .text = "text",
                .session_state = "sessionState",
                .request_attributes = "requestAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_attributes", field_name))
                return try serializeMap(self.request_attributes, self.fieldNameFor("request_attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(recognize_text) } {
            return .{ .service_metadata = service_metadata, .action = recognize_text };
        }
    },
    Response: type = struct {
        messages: ?[]Message = null,
        session_state: ?SessionState = null,
        interpretations: ?[]Interpretation = null,
        request_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        session_id: ?[]const u8 = null,
        recognized_bot_member: ?RecognizedBotMember = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .messages = "messages",
                .session_state = "sessionState",
                .interpretations = "interpretations",
                .request_attributes = "requestAttributes",
                .session_id = "sessionId",
                .recognized_bot_member = "recognizedBotMember",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_attributes", field_name))
                return try serializeMap(self.request_attributes, self.fieldNameFor("request_attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadGateway,
        Conflict,
        DependencyFailed,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const recognize_utterance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botAliases/{botAliasId}/botLocales/{localeId}/sessions/{sessionId}/utterance",
        .success_code = 200,
    };

    action_name: []const u8 = "RecognizeUtterance",
    Request: type = struct {
        bot_id: []const u8,
        bot_alias_id: []const u8,
        locale_id: []const u8,
        session_id: []const u8,
        session_state: ?[]const u8 = null,
        request_attributes: ?[]const u8 = null,
        request_content_type: []const u8,
        response_content_type: ?[]const u8 = null,
        input_stream: ?[]const u8 = null,
        pub const http_header = .{
            .session_state = "x-amz-lex-session-state",
            .request_attributes = "x-amz-lex-request-attributes",
            .request_content_type = "Content-Type",
            .response_content_type = "Response-Content-Type",
        };

        pub const http_payload: []const u8 = "input_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_alias_id = "botAliasId",
                .locale_id = "localeId",
                .session_id = "sessionId",
                .session_state = "sessionState",
                .request_attributes = "requestAttributes",
                .request_content_type = "requestContentType",
                .response_content_type = "responseContentType",
                .input_stream = "inputStream",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(recognize_utterance) } {
            return .{ .service_metadata = service_metadata, .action = recognize_utterance };
        }
    },
    Response: type = struct {
        input_mode: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        messages: ?[]const u8 = null,
        interpretations: ?[]const u8 = null,
        session_state: ?[]const u8 = null,
        request_attributes: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        input_transcript: ?[]const u8 = null,
        audio_stream: ?[]const u8 = null,
        recognized_bot_member: ?[]const u8 = null,
        pub const http_header = .{
            .input_mode = "x-amz-lex-input-mode",
            .content_type = "Content-Type",
            .messages = "x-amz-lex-messages",
            .interpretations = "x-amz-lex-interpretations",
            .session_state = "x-amz-lex-session-state",
            .request_attributes = "x-amz-lex-request-attributes",
            .session_id = "x-amz-lex-session-id",
            .input_transcript = "x-amz-lex-input-transcript",
            .recognized_bot_member = "x-amz-lex-recognized-bot-member",
        };

        pub const http_payload: []const u8 = "audio_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input_mode = "inputMode",
                .content_type = "contentType",
                .messages = "messages",
                .interpretations = "interpretations",
                .session_state = "sessionState",
                .request_attributes = "requestAttributes",
                .session_id = "sessionId",
                .input_transcript = "inputTranscript",
                .audio_stream = "audioStream",
                .recognized_bot_member = "recognizedBotMember",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadGateway,
        Conflict,
        DependencyFailed,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_conversation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botAliases/{botAliasId}/botLocales/{localeId}/sessions/{sessionId}/conversation",
        .success_code = 200,
    };

    action_name: []const u8 = "StartConversation",
    Request: type = struct {
        bot_id: []const u8,
        bot_alias_id: []const u8,
        locale_id: []const u8,
        session_id: []const u8,
        conversation_mode: ?[]const u8 = null,
        request_event_stream: union {
            configuration_event: ?struct {
                request_attributes: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                response_content_type: []const u8,
                session_state: ?SessionState = null,
                welcome_messages: ?[]Message = null,
                disable_playback: ?bool = null,
                event_id: ?[]const u8 = null,
                client_timestamp_millis: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .request_attributes = "requestAttributes",
                        .response_content_type = "responseContentType",
                        .session_state = "sessionState",
                        .welcome_messages = "welcomeMessages",
                        .disable_playback = "disablePlayback",
                        .event_id = "eventId",
                        .client_timestamp_millis = "clientTimestampMillis",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "request_attributes", field_name))
                        return try serializeMap(self.request_attributes, self.fieldNameFor("request_attributes"), options, out_stream);
                    return false;
                }
            },
            audio_input_event: ?struct {
                audio_chunk: ?[]const u8 = null,
                content_type: []const u8,
                event_id: ?[]const u8 = null,
                client_timestamp_millis: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .audio_chunk = "audioChunk",
                        .content_type = "contentType",
                        .event_id = "eventId",
                        .client_timestamp_millis = "clientTimestampMillis",
                    };
                    return @field(mappings, field_name);
                }
            },
            dtmf_input_event: ?struct {
                input_character: []const u8,
                event_id: ?[]const u8 = null,
                client_timestamp_millis: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input_character = "inputCharacter",
                        .event_id = "eventId",
                        .client_timestamp_millis = "clientTimestampMillis",
                    };
                    return @field(mappings, field_name);
                }
            },
            text_input_event: ?struct {
                text: []const u8,
                event_id: ?[]const u8 = null,
                client_timestamp_millis: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .text = "text",
                        .event_id = "eventId",
                        .client_timestamp_millis = "clientTimestampMillis",
                    };
                    return @field(mappings, field_name);
                }
            },
            playback_completion_event: ?struct {
                event_id: ?[]const u8 = null,
                client_timestamp_millis: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .event_id = "eventId",
                        .client_timestamp_millis = "clientTimestampMillis",
                    };
                    return @field(mappings, field_name);
                }
            },
            disconnection_event: ?struct {
                event_id: ?[]const u8 = null,
                client_timestamp_millis: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .event_id = "eventId",
                        .client_timestamp_millis = "clientTimestampMillis",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .configuration_event = "ConfigurationEvent",
                    .audio_input_event = "AudioInputEvent",
                    .dtmf_input_event = "DTMFInputEvent",
                    .text_input_event = "TextInputEvent",
                    .playback_completion_event = "PlaybackCompletionEvent",
                    .disconnection_event = "DisconnectionEvent",
                };
                return @field(mappings, field_name);
            }
        },
        pub const http_header = .{
            .conversation_mode = "x-amz-lex-conversation-mode",
        };

        pub const http_payload: []const u8 = "request_event_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_alias_id = "botAliasId",
                .locale_id = "localeId",
                .session_id = "sessionId",
                .conversation_mode = "conversationMode",
                .request_event_stream = "requestEventStream",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_conversation) } {
            return .{ .service_metadata = service_metadata, .action = start_conversation };
        }
    },
    Response: type = struct {
        response_event_stream: ?union {
            playback_interruption_event: ?struct {
                event_reason: ?[]const u8 = null,
                caused_by_event_id: ?[]const u8 = null,
                event_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .event_reason = "eventReason",
                        .caused_by_event_id = "causedByEventId",
                        .event_id = "eventId",
                    };
                    return @field(mappings, field_name);
                }
            },
            transcript_event: ?struct {
                transcript: ?[]const u8 = null,
                event_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .transcript = "transcript",
                        .event_id = "eventId",
                    };
                    return @field(mappings, field_name);
                }
            },
            intent_result_event: ?struct {
                input_mode: ?[]const u8 = null,
                interpretations: ?[]Interpretation = null,
                session_state: ?SessionState = null,
                request_attributes: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                session_id: ?[]const u8 = null,
                event_id: ?[]const u8 = null,
                recognized_bot_member: ?RecognizedBotMember = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input_mode = "inputMode",
                        .interpretations = "interpretations",
                        .session_state = "sessionState",
                        .request_attributes = "requestAttributes",
                        .session_id = "sessionId",
                        .event_id = "eventId",
                        .recognized_bot_member = "recognizedBotMember",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "request_attributes", field_name))
                        return try serializeMap(self.request_attributes, self.fieldNameFor("request_attributes"), options, out_stream);
                    return false;
                }
            },
            text_response_event: ?struct {
                messages: ?[]Message = null,
                event_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .messages = "messages",
                        .event_id = "eventId",
                    };
                    return @field(mappings, field_name);
                }
            },
            audio_response_event: ?struct {
                audio_chunk: ?[]const u8 = null,
                content_type: ?[]const u8 = null,
                event_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .audio_chunk = "audioChunk",
                        .content_type = "contentType",
                        .event_id = "eventId",
                    };
                    return @field(mappings, field_name);
                }
            },
            heartbeat_event: ?struct {
                event_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .event_id = "eventId",
                    };
                    return @field(mappings, field_name);
                }
            },
            access_denied_exception: ?AccessDeniedException,
            resource_not_found_exception: ?ResourceNotFoundException,
            validation_exception: ?ValidationException,
            throttling_exception: ?ThrottlingException,
            internal_server_exception: ?InternalServerException,
            conflict_exception: ?ConflictException,
            dependency_failed_exception: ?DependencyFailedException,
            bad_gateway_exception: ?BadGatewayException,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .playback_interruption_event = "PlaybackInterruptionEvent",
                    .transcript_event = "TranscriptEvent",
                    .intent_result_event = "IntentResultEvent",
                    .text_response_event = "TextResponseEvent",
                    .audio_response_event = "AudioResponseEvent",
                    .heartbeat_event = "HeartbeatEvent",
                    .access_denied_exception = "AccessDeniedException",
                    .resource_not_found_exception = "ResourceNotFoundException",
                    .validation_exception = "ValidationException",
                    .throttling_exception = "ThrottlingException",
                    .internal_server_exception = "InternalServerException",
                    .conflict_exception = "ConflictException",
                    .dependency_failed_exception = "DependencyFailedException",
                    .bad_gateway_exception = "BadGatewayException",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_payload: []const u8 = "response_event_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .response_event_stream = "responseEventStream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const BadGatewayException = struct {
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const DependencyFailedException = struct {
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ConflictException = struct {
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const InternalServerException = struct {
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ThrottlingException = struct {
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ValidationException = struct {
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceNotFoundException = struct {
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessDeniedException = struct {
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const Message = struct {
    content: ?[]const u8 = null,
    content_type: []const u8,
    image_response_card: ?ImageResponseCard = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content = "content",
            .content_type = "contentType",
            .image_response_card = "imageResponseCard",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageResponseCard = struct {
    title: []const u8,
    subtitle: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    buttons: ?[]Button = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title = "title",
            .subtitle = "subtitle",
            .image_url = "imageUrl",
            .buttons = "buttons",
        };
        return @field(mappings, field_name);
    }
};

pub const Button = struct {
    text: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "text",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const RecognizedBotMember = struct {
    bot_id: []const u8,
    bot_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_name = "botName",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionState = struct {
    dialog_action: ?DialogAction = null,
    intent: ?Intent = null,
    active_contexts: ?[]ActiveContext = null,
    session_attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    originating_request_id: ?[]const u8 = null,
    runtime_hints: ?RuntimeHints = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dialog_action = "dialogAction",
            .intent = "intent",
            .active_contexts = "activeContexts",
            .session_attributes = "sessionAttributes",
            .originating_request_id = "originatingRequestId",
            .runtime_hints = "runtimeHints",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "session_attributes", field_name))
            return try serializeMap(self.session_attributes, self.fieldNameFor("session_attributes"), options, out_stream);
        return false;
    }
};

pub const RuntimeHints = struct {
    slot_hints: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]struct {
            key: ?[]const u8 = null,
            value: ?RuntimeHintDetails = null,
        } = null,


    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "value", field_name))
            return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
        return false;
    }
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .slot_hints = "slotHints",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "slot_hints", field_name))
            return try serializeMap(self.slot_hints, self.fieldNameFor("slot_hints"), options, out_stream);
        return false;
    }
};

pub const RuntimeHintDetails = struct {
    runtime_hint_values: ?[]RuntimeHintValue = null,
    sub_slot_hints: ?[]struct {
        key: ?[]const u8 = null,
        value: ?RuntimeHintDetails = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .runtime_hint_values = "runtimeHintValues",
            .sub_slot_hints = "subSlotHints",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "sub_slot_hints", field_name))
            return try serializeMap(self.sub_slot_hints, self.fieldNameFor("sub_slot_hints"), options, out_stream);
        return false;
    }
};

pub const RuntimeHintValue = struct {
    phrase: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phrase = "phrase",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveContext = struct {
    name: []const u8,
    time_to_live: ActiveContextTimeToLive,
    context_attributes: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .time_to_live = "timeToLive",
            .context_attributes = "contextAttributes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "context_attributes", field_name))
            return try serializeMap(self.context_attributes, self.fieldNameFor("context_attributes"), options, out_stream);
        return false;
    }
};

pub const ActiveContextTimeToLive = struct {
    time_to_live_in_seconds: i64,
    turns_to_live: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_to_live_in_seconds = "timeToLiveInSeconds",
            .turns_to_live = "turnsToLive",
        };
        return @field(mappings, field_name);
    }
};

pub const Intent = struct {
    name: []const u8,
    slots: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Slot = null,
    } = null,
    state: ?[]const u8 = null,
    confirmation_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .slots = "slots",
            .state = "state",
            .confirmation_state = "confirmationState",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "slots", field_name))
            return try serializeMap(self.slots, self.fieldNameFor("slots"), options, out_stream);
        return false;
    }
};

pub const Slot = struct {
    value: ?Value = null,
    shape: ?[]const u8 = null,
    values: ?[]Slot = null,
    sub_slots: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Slot = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .shape = "shape",
            .values = "values",
            .sub_slots = "subSlots",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "sub_slots", field_name))
            return try serializeMap(self.sub_slots, self.fieldNameFor("sub_slots"), options, out_stream);
        return false;
    }
};

pub const Value = struct {
    original_value: ?[]const u8 = null,
    interpreted_value: []const u8,
    resolved_values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .original_value = "originalValue",
            .interpreted_value = "interpretedValue",
            .resolved_values = "resolvedValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DialogAction = struct {
    type: []const u8,
    slot_to_elicit: ?[]const u8 = null,
    slot_elicitation_style: ?[]const u8 = null,
    sub_slot_to_elicit: ?ElicitSubSlot = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .slot_to_elicit = "slotToElicit",
            .slot_elicitation_style = "slotElicitationStyle",
            .sub_slot_to_elicit = "subSlotToElicit",
        };
        return @field(mappings, field_name);
    }
};

pub const ElicitSubSlot = struct {
    name: []const u8,
    sub_slot_to_elicit: ?ElicitSubSlot = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .sub_slot_to_elicit = "subSlotToElicit",
        };
        return @field(mappings, field_name);
    }
};

pub const Interpretation = struct {
    nlu_confidence: ?ConfidenceScore = null,
    sentiment_response: ?SentimentResponse = null,
    intent: ?Intent = null,
    interpretation_source: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nlu_confidence = "nluConfidence",
            .sentiment_response = "sentimentResponse",
            .intent = "intent",
            .interpretation_source = "interpretationSource",
        };
        return @field(mappings, field_name);
    }
};

pub const SentimentResponse = struct {
    sentiment: ?[]const u8 = null,
    sentiment_score: ?SentimentScore = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sentiment = "sentiment",
            .sentiment_score = "sentimentScore",
        };
        return @field(mappings, field_name);
    }
};

pub const SentimentScore = struct {
    positive: ?f64 = null,
    negative: ?f64 = null,
    neutral: ?f64 = null,
    mixed: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .positive = "positive",
            .negative = "negative",
            .neutral = "neutral",
            .mixed = "mixed",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfidenceScore = struct {
    score: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .score = "score",
        };
        return @field(mappings, field_name);
    }
};
