const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-08-01";
pub const sdk_id: []const u8 = "License Manager";
pub const arn_namespace: ?[]const u8 = "license-manager";
pub const endpoint_prefix: []const u8 = "license-manager";
pub const sigv4_name: []const u8 = "license-manager";
pub const name: []const u8 = "AWSLicenseManager";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-08-01",
    sdk_id: []const u8 = "License Manager",
    arn_namespace: ?[]const u8 = "license-manager",
    endpoint_prefix: []const u8 = "license-manager",
    sigv4_name: []const u8 = "license-manager",
    name: []const u8 = "AWSLicenseManager",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const accept_grant: struct {
    action_name: []const u8 = "AcceptGrant",
    Request: type = struct {
        grant_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arn = "GrantArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_grant) } {
            return .{ .service_metadata = service_metadata, .action = accept_grant };
        }
    },
    Response: type = struct {
        grant_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arn = "GrantArn",
                .status = "Status",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const check_in_license: struct {
    action_name: []const u8 = "CheckInLicense",
    Request: type = struct {
        license_consumption_token: []const u8,
        beneficiary: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_consumption_token = "LicenseConsumptionToken",
                .beneficiary = "Beneficiary",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(check_in_license) } {
            return .{ .service_metadata = service_metadata, .action = check_in_license };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        Conflict,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceNotFound,
        ServerInternal,
        Validation,
    },
} = .{};
pub const checkout_borrow_license: struct {
    action_name: []const u8 = "CheckoutBorrowLicense",
    Request: type = struct {
        license_arn: []const u8,
        entitlements: []EntitlementData,
        digital_signature_method: []const u8,
        node_id: ?[]const u8 = null,
        checkout_metadata: ?[]Metadata = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
                .entitlements = "Entitlements",
                .digital_signature_method = "DigitalSignatureMethod",
                .node_id = "NodeId",
                .checkout_metadata = "CheckoutMetadata",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(checkout_borrow_license) } {
            return .{ .service_metadata = service_metadata, .action = checkout_borrow_license };
        }
    },
    Response: type = struct {
        license_arn: ?[]const u8 = null,
        license_consumption_token: ?[]const u8 = null,
        entitlements_allowed: ?[]EntitlementData = null,
        node_id: ?[]const u8 = null,
        signed_token: ?[]const u8 = null,
        issued_at: ?[]const u8 = null,
        expiration: ?[]const u8 = null,
        checkout_metadata: ?[]Metadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
                .license_consumption_token = "LicenseConsumptionToken",
                .entitlements_allowed = "EntitlementsAllowed",
                .node_id = "NodeId",
                .signed_token = "SignedToken",
                .issued_at = "IssuedAt",
                .expiration = "Expiration",
                .checkout_metadata = "CheckoutMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        EntitlementNotAllowed,
        InvalidParameterValue,
        NoEntitlementsAllowed,
        RateLimitExceeded,
        Redirect,
        ResourceNotFound,
        ServerInternal,
        UnsupportedDigitalSignatureMethod,
        Validation,
    },
} = .{};
pub const checkout_license: struct {
    action_name: []const u8 = "CheckoutLicense",
    Request: type = struct {
        product_sku: []const u8,
        checkout_type: []const u8,
        key_fingerprint: []const u8,
        entitlements: []EntitlementData,
        client_token: []const u8,
        beneficiary: ?[]const u8 = null,
        node_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_sku = "ProductSKU",
                .checkout_type = "CheckoutType",
                .key_fingerprint = "KeyFingerprint",
                .entitlements = "Entitlements",
                .client_token = "ClientToken",
                .beneficiary = "Beneficiary",
                .node_id = "NodeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(checkout_license) } {
            return .{ .service_metadata = service_metadata, .action = checkout_license };
        }
    },
    Response: type = struct {
        checkout_type: ?[]const u8 = null,
        license_consumption_token: ?[]const u8 = null,
        entitlements_allowed: ?[]EntitlementData = null,
        signed_token: ?[]const u8 = null,
        node_id: ?[]const u8 = null,
        issued_at: ?[]const u8 = null,
        expiration: ?[]const u8 = null,
        license_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .checkout_type = "CheckoutType",
                .license_consumption_token = "LicenseConsumptionToken",
                .entitlements_allowed = "EntitlementsAllowed",
                .signed_token = "SignedToken",
                .node_id = "NodeId",
                .issued_at = "IssuedAt",
                .expiration = "Expiration",
                .license_arn = "LicenseArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        NoEntitlementsAllowed,
        RateLimitExceeded,
        Redirect,
        ResourceNotFound,
        ServerInternal,
        UnsupportedDigitalSignatureMethod,
        Validation,
    },
} = .{};
pub const create_grant: struct {
    action_name: []const u8 = "CreateGrant",
    Request: type = struct {
        client_token: []const u8,
        grant_name: []const u8,
        license_arn: []const u8,
        principals: [][]const u8,
        home_region: []const u8,
        allowed_operations: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .grant_name = "GrantName",
                .license_arn = "LicenseArn",
                .principals = "Principals",
                .home_region = "HomeRegion",
                .allowed_operations = "AllowedOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_grant) } {
            return .{ .service_metadata = service_metadata, .action = create_grant };
        }
    },
    Response: type = struct {
        grant_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arn = "GrantArn",
                .status = "Status",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const create_grant_version: struct {
    action_name: []const u8 = "CreateGrantVersion",
    Request: type = struct {
        client_token: []const u8,
        grant_arn: []const u8,
        grant_name: ?[]const u8 = null,
        allowed_operations: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        source_version: ?[]const u8 = null,
        options: ?Options = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .grant_arn = "GrantArn",
                .grant_name = "GrantName",
                .allowed_operations = "AllowedOperations",
                .status = "Status",
                .status_reason = "StatusReason",
                .source_version = "SourceVersion",
                .options = "Options",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_grant_version) } {
            return .{ .service_metadata = service_metadata, .action = create_grant_version };
        }
    },
    Response: type = struct {
        grant_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arn = "GrantArn",
                .status = "Status",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const create_license: struct {
    action_name: []const u8 = "CreateLicense",
    Request: type = struct {
        license_name: []const u8,
        product_name: []const u8,
        product_sku: []const u8,
        issuer: Issuer,
        home_region: []const u8,
        validity: DatetimeRange,
        entitlements: []Entitlement,
        beneficiary: []const u8,
        consumption_configuration: ConsumptionConfiguration,
        license_metadata: ?[]Metadata = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_name = "LicenseName",
                .product_name = "ProductName",
                .product_sku = "ProductSKU",
                .issuer = "Issuer",
                .home_region = "HomeRegion",
                .validity = "Validity",
                .entitlements = "Entitlements",
                .beneficiary = "Beneficiary",
                .consumption_configuration = "ConsumptionConfiguration",
                .license_metadata = "LicenseMetadata",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_license) } {
            return .{ .service_metadata = service_metadata, .action = create_license };
        }
    },
    Response: type = struct {
        license_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
                .status = "Status",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        Redirect,
        ServerInternal,
        Validation,
    },
} = .{};
pub const create_license_configuration: struct {
    action_name: []const u8 = "CreateLicenseConfiguration",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        license_counting_type: []const u8,
        license_count: ?i64 = null,
        license_count_hard_limit: ?bool = null,
        license_rules: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        disassociate_when_not_found: ?bool = null,
        product_information_list: ?[]ProductInformation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .license_counting_type = "LicenseCountingType",
                .license_count = "LicenseCount",
                .license_count_hard_limit = "LicenseCountHardLimit",
                .license_rules = "LicenseRules",
                .tags = "Tags",
                .disassociate_when_not_found = "DisassociateWhenNotFound",
                .product_information_list = "ProductInformationList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_license_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_license_configuration };
        }
    },
    Response: type = struct {
        license_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_arn = "LicenseConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const create_license_conversion_task_for_resource: struct {
    action_name: []const u8 = "CreateLicenseConversionTaskForResource",
    Request: type = struct {
        resource_arn: []const u8,
        source_license_context: LicenseConversionContext,
        destination_license_context: LicenseConversionContext,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .source_license_context = "SourceLicenseContext",
                .destination_license_context = "DestinationLicenseContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_license_conversion_task_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = create_license_conversion_task_for_resource };
        }
    },
    Response: type = struct {
        license_conversion_task_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_conversion_task_id = "LicenseConversionTaskId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const create_license_manager_report_generator: struct {
    action_name: []const u8 = "CreateLicenseManagerReportGenerator",
    Request: type = struct {
        report_generator_name: []const u8,
        type: [][]const u8,
        report_context: ReportContext,
        report_frequency: ReportFrequency,
        client_token: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_generator_name = "ReportGeneratorName",
                .type = "Type",
                .report_context = "ReportContext",
                .report_frequency = "ReportFrequency",
                .client_token = "ClientToken",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_license_manager_report_generator) } {
            return .{ .service_metadata = service_metadata, .action = create_license_manager_report_generator };
        }
    },
    Response: type = struct {
        license_manager_report_generator_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_manager_report_generator_arn = "LicenseManagerReportGeneratorArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ResourceNotFound,
        ServerInternal,
        Validation,
    },
} = .{};
pub const create_license_version: struct {
    action_name: []const u8 = "CreateLicenseVersion",
    Request: type = struct {
        license_arn: []const u8,
        license_name: []const u8,
        product_name: []const u8,
        issuer: Issuer,
        home_region: []const u8,
        validity: DatetimeRange,
        license_metadata: ?[]Metadata = null,
        entitlements: []Entitlement,
        consumption_configuration: ConsumptionConfiguration,
        status: []const u8,
        client_token: []const u8,
        source_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
                .license_name = "LicenseName",
                .product_name = "ProductName",
                .issuer = "Issuer",
                .home_region = "HomeRegion",
                .validity = "Validity",
                .license_metadata = "LicenseMetadata",
                .entitlements = "Entitlements",
                .consumption_configuration = "ConsumptionConfiguration",
                .status = "Status",
                .client_token = "ClientToken",
                .source_version = "SourceVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_license_version) } {
            return .{ .service_metadata = service_metadata, .action = create_license_version };
        }
    },
    Response: type = struct {
        license_arn: ?[]const u8 = null,
        version: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
                .version = "Version",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        Conflict,
        RateLimitExceeded,
        Redirect,
        ResourceNotFound,
        ServerInternal,
        Validation,
    },
} = .{};
pub const create_token: struct {
    action_name: []const u8 = "CreateToken",
    Request: type = struct {
        license_arn: []const u8,
        role_arns: ?[][]const u8 = null,
        expiration_in_days: ?i64 = null,
        token_properties: ?[][]const u8 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
                .role_arns = "RoleArns",
                .expiration_in_days = "ExpirationInDays",
                .token_properties = "TokenProperties",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_token) } {
            return .{ .service_metadata = service_metadata, .action = create_token };
        }
    },
    Response: type = struct {
        token_id: ?[]const u8 = null,
        token_type: ?[]const u8 = null,
        token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token_id = "TokenId",
                .token_type = "TokenType",
                .token = "Token",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        RateLimitExceeded,
        Redirect,
        ResourceLimitExceeded,
        ResourceNotFound,
        ServerInternal,
        Validation,
    },
} = .{};
pub const delete_grant: struct {
    action_name: []const u8 = "DeleteGrant",
    Request: type = struct {
        grant_arn: []const u8,
        status_reason: ?[]const u8 = null,
        version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arn = "GrantArn",
                .status_reason = "StatusReason",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_grant) } {
            return .{ .service_metadata = service_metadata, .action = delete_grant };
        }
    },
    Response: type = struct {
        grant_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arn = "GrantArn",
                .status = "Status",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const delete_license: struct {
    action_name: []const u8 = "DeleteLicense",
    Request: type = struct {
        license_arn: []const u8,
        source_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
                .source_version = "SourceVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_license) } {
            return .{ .service_metadata = service_metadata, .action = delete_license };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        deletion_date: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .deletion_date = "DeletionDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        Conflict,
        InvalidParameterValue,
        RateLimitExceeded,
        Redirect,
        ServerInternal,
        Validation,
    },
} = .{};
pub const delete_license_configuration: struct {
    action_name: []const u8 = "DeleteLicenseConfiguration",
    Request: type = struct {
        license_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_arn = "LicenseConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_license_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_license_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const delete_license_manager_report_generator: struct {
    action_name: []const u8 = "DeleteLicenseManagerReportGenerator",
    Request: type = struct {
        license_manager_report_generator_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_manager_report_generator_arn = "LicenseManagerReportGeneratorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_license_manager_report_generator) } {
            return .{ .service_metadata = service_metadata, .action = delete_license_manager_report_generator };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ResourceNotFound,
        ServerInternal,
        Validation,
    },
} = .{};
pub const delete_token: struct {
    action_name: []const u8 = "DeleteToken",
    Request: type = struct {
        token_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token_id = "TokenId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_token) } {
            return .{ .service_metadata = service_metadata, .action = delete_token };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        RateLimitExceeded,
        Redirect,
        ResourceNotFound,
        ServerInternal,
        Validation,
    },
} = .{};
pub const extend_license_consumption: struct {
    action_name: []const u8 = "ExtendLicenseConsumption",
    Request: type = struct {
        license_consumption_token: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_consumption_token = "LicenseConsumptionToken",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(extend_license_consumption) } {
            return .{ .service_metadata = service_metadata, .action = extend_license_consumption };
        }
    },
    Response: type = struct {
        license_consumption_token: ?[]const u8 = null,
        expiration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_consumption_token = "LicenseConsumptionToken",
                .expiration = "Expiration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceNotFound,
        ServerInternal,
        Validation,
    },
} = .{};
pub const get_access_token: struct {
    action_name: []const u8 = "GetAccessToken",
    Request: type = struct {
        token: []const u8,
        token_properties: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token = "Token",
                .token_properties = "TokenProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_token) } {
            return .{ .service_metadata = service_metadata, .action = get_access_token };
        }
    },
    Response: type = struct {
        access_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "AccessToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        RateLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const get_grant: struct {
    action_name: []const u8 = "GetGrant",
    Request: type = struct {
        grant_arn: []const u8,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arn = "GrantArn",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_grant) } {
            return .{ .service_metadata = service_metadata, .action = get_grant };
        }
    },
    Response: type = struct {
        grant: ?Grant = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant = "Grant",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const get_license: struct {
    action_name: []const u8 = "GetLicense",
    Request: type = struct {
        license_arn: []const u8,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_license) } {
            return .{ .service_metadata = service_metadata, .action = get_license };
        }
    },
    Response: type = struct {
        license: ?License = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license = "License",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const get_license_configuration: struct {
    action_name: []const u8 = "GetLicenseConfiguration",
    Request: type = struct {
        license_configuration_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_arn = "LicenseConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_license_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_license_configuration };
        }
    },
    Response: type = struct {
        license_configuration_id: ?[]const u8 = null,
        license_configuration_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        license_counting_type: ?[]const u8 = null,
        license_rules: ?[][]const u8 = null,
        license_count: ?i64 = null,
        license_count_hard_limit: ?bool = null,
        consumed_licenses: ?i64 = null,
        status: ?[]const u8 = null,
        owner_account_id: ?[]const u8 = null,
        consumed_license_summary_list: ?[]ConsumedLicenseSummary = null,
        managed_resource_summary_list: ?[]ManagedResourceSummary = null,
        tags: ?[]Tag = null,
        product_information_list: ?[]ProductInformation = null,
        automated_discovery_information: ?AutomatedDiscoveryInformation = null,
        disassociate_when_not_found: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_id = "LicenseConfigurationId",
                .license_configuration_arn = "LicenseConfigurationArn",
                .name = "Name",
                .description = "Description",
                .license_counting_type = "LicenseCountingType",
                .license_rules = "LicenseRules",
                .license_count = "LicenseCount",
                .license_count_hard_limit = "LicenseCountHardLimit",
                .consumed_licenses = "ConsumedLicenses",
                .status = "Status",
                .owner_account_id = "OwnerAccountId",
                .consumed_license_summary_list = "ConsumedLicenseSummaryList",
                .managed_resource_summary_list = "ManagedResourceSummaryList",
                .tags = "Tags",
                .product_information_list = "ProductInformationList",
                .automated_discovery_information = "AutomatedDiscoveryInformation",
                .disassociate_when_not_found = "DisassociateWhenNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const get_license_conversion_task: struct {
    action_name: []const u8 = "GetLicenseConversionTask",
    Request: type = struct {
        license_conversion_task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_conversion_task_id = "LicenseConversionTaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_license_conversion_task) } {
            return .{ .service_metadata = service_metadata, .action = get_license_conversion_task };
        }
    },
    Response: type = struct {
        license_conversion_task_id: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        source_license_context: ?LicenseConversionContext = null,
        destination_license_context: ?LicenseConversionContext = null,
        status_message: ?[]const u8 = null,
        status: ?[]const u8 = null,
        start_time: ?i64 = null,
        license_conversion_time: ?i64 = null,
        end_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_conversion_task_id = "LicenseConversionTaskId",
                .resource_arn = "ResourceArn",
                .source_license_context = "SourceLicenseContext",
                .destination_license_context = "DestinationLicenseContext",
                .status_message = "StatusMessage",
                .status = "Status",
                .start_time = "StartTime",
                .license_conversion_time = "LicenseConversionTime",
                .end_time = "EndTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const get_license_manager_report_generator: struct {
    action_name: []const u8 = "GetLicenseManagerReportGenerator",
    Request: type = struct {
        license_manager_report_generator_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_manager_report_generator_arn = "LicenseManagerReportGeneratorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_license_manager_report_generator) } {
            return .{ .service_metadata = service_metadata, .action = get_license_manager_report_generator };
        }
    },
    Response: type = struct {
        report_generator: ?ReportGenerator = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_generator = "ReportGenerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ResourceNotFound,
        ServerInternal,
        Validation,
    },
} = .{};
pub const get_license_usage: struct {
    action_name: []const u8 = "GetLicenseUsage",
    Request: type = struct {
        license_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_license_usage) } {
            return .{ .service_metadata = service_metadata, .action = get_license_usage };
        }
    },
    Response: type = struct {
        license_usage: ?struct {
            entitlement_usages: ?[]struct {
                name: []const u8,
                consumed_value: []const u8,
                max_count: ?[]const u8 = null,
                unit: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .consumed_value = "ConsumedValue",
                        .max_count = "MaxCount",
                        .unit = "Unit",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entitlement_usages = "EntitlementUsages",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_usage = "LicenseUsage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const get_service_settings: struct {
    action_name: []const u8 = "GetServiceSettings",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_service_settings };
        }
    },
    Response: type = struct {
        s3_bucket_arn: ?[]const u8 = null,
        sns_topic_arn: ?[]const u8 = null,
        organization_configuration: ?OrganizationConfiguration = null,
        enable_cross_accounts_discovery: ?bool = null,
        license_manager_resource_share_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_bucket_arn = "S3BucketArn",
                .sns_topic_arn = "SnsTopicArn",
                .organization_configuration = "OrganizationConfiguration",
                .enable_cross_accounts_discovery = "EnableCrossAccountsDiscovery",
                .license_manager_resource_share_arn = "LicenseManagerResourceShareArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const list_associations_for_license_configuration: struct {
    action_name: []const u8 = "ListAssociationsForLicenseConfiguration",
    Request: type = struct {
        license_configuration_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_arn = "LicenseConfigurationArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associations_for_license_configuration) } {
            return .{ .service_metadata = service_metadata, .action = list_associations_for_license_configuration };
        }
    },
    Response: type = struct {
        license_configuration_associations: ?[]struct {
            resource_arn: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_owner_id: ?[]const u8 = null,
            association_time: ?i64 = null,
            ami_association_scope: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "ResourceArn",
                    .resource_type = "ResourceType",
                    .resource_owner_id = "ResourceOwnerId",
                    .association_time = "AssociationTime",
                    .ami_association_scope = "AmiAssociationScope",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_associations = "LicenseConfigurationAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        FilterLimitExceeded,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const list_distributed_grants: struct {
    action_name: []const u8 = "ListDistributedGrants",
    Request: type = struct {
        grant_arns: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arns = "GrantArns",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_distributed_grants) } {
            return .{ .service_metadata = service_metadata, .action = list_distributed_grants };
        }
    },
    Response: type = struct {
        grants: ?[]Grant = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grants = "Grants",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const list_failures_for_license_configuration_operations: struct {
    action_name: []const u8 = "ListFailuresForLicenseConfigurationOperations",
    Request: type = struct {
        license_configuration_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_arn = "LicenseConfigurationArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_failures_for_license_configuration_operations) } {
            return .{ .service_metadata = service_metadata, .action = list_failures_for_license_configuration_operations };
        }
    },
    Response: type = struct {
        license_operation_failure_list: ?[]struct {
            resource_arn: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            failure_time: ?i64 = null,
            operation_name: ?[]const u8 = null,
            resource_owner_id: ?[]const u8 = null,
            operation_requested_by: ?[]const u8 = null,
            metadata_list: ?[]Metadata = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "ResourceArn",
                    .resource_type = "ResourceType",
                    .error_message = "ErrorMessage",
                    .failure_time = "FailureTime",
                    .operation_name = "OperationName",
                    .resource_owner_id = "ResourceOwnerId",
                    .operation_requested_by = "OperationRequestedBy",
                    .metadata_list = "MetadataList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_operation_failure_list = "LicenseOperationFailureList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const list_license_configurations: struct {
    action_name: []const u8 = "ListLicenseConfigurations",
    Request: type = struct {
        license_configuration_arns: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_arns = "LicenseConfigurationArns",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_license_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_license_configurations };
        }
    },
    Response: type = struct {
        license_configurations: ?[]struct {
            license_configuration_id: ?[]const u8 = null,
            license_configuration_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            license_counting_type: ?[]const u8 = null,
            license_rules: ?[][]const u8 = null,
            license_count: ?i64 = null,
            license_count_hard_limit: ?bool = null,
            disassociate_when_not_found: ?bool = null,
            consumed_licenses: ?i64 = null,
            status: ?[]const u8 = null,
            owner_account_id: ?[]const u8 = null,
            consumed_license_summary_list: ?[]ConsumedLicenseSummary = null,
            managed_resource_summary_list: ?[]ManagedResourceSummary = null,
            product_information_list: ?[]ProductInformation = null,
            automated_discovery_information: ?AutomatedDiscoveryInformation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .license_configuration_id = "LicenseConfigurationId",
                    .license_configuration_arn = "LicenseConfigurationArn",
                    .name = "Name",
                    .description = "Description",
                    .license_counting_type = "LicenseCountingType",
                    .license_rules = "LicenseRules",
                    .license_count = "LicenseCount",
                    .license_count_hard_limit = "LicenseCountHardLimit",
                    .disassociate_when_not_found = "DisassociateWhenNotFound",
                    .consumed_licenses = "ConsumedLicenses",
                    .status = "Status",
                    .owner_account_id = "OwnerAccountId",
                    .consumed_license_summary_list = "ConsumedLicenseSummaryList",
                    .managed_resource_summary_list = "ManagedResourceSummaryList",
                    .product_information_list = "ProductInformationList",
                    .automated_discovery_information = "AutomatedDiscoveryInformation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configurations = "LicenseConfigurations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        FilterLimitExceeded,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const list_license_conversion_tasks: struct {
    action_name: []const u8 = "ListLicenseConversionTasks",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_license_conversion_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_license_conversion_tasks };
        }
    },
    Response: type = struct {
        license_conversion_tasks: ?[]struct {
            license_conversion_task_id: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            source_license_context: ?LicenseConversionContext = null,
            destination_license_context: ?LicenseConversionContext = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            start_time: ?i64 = null,
            license_conversion_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .license_conversion_task_id = "LicenseConversionTaskId",
                    .resource_arn = "ResourceArn",
                    .source_license_context = "SourceLicenseContext",
                    .destination_license_context = "DestinationLicenseContext",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .start_time = "StartTime",
                    .license_conversion_time = "LicenseConversionTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_conversion_tasks = "LicenseConversionTasks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const list_license_manager_report_generators: struct {
    action_name: []const u8 = "ListLicenseManagerReportGenerators",
    Request: type = struct {
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_license_manager_report_generators) } {
            return .{ .service_metadata = service_metadata, .action = list_license_manager_report_generators };
        }
    },
    Response: type = struct {
        report_generators: ?[]ReportGenerator = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_generators = "ReportGenerators",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ResourceNotFound,
        ServerInternal,
        Validation,
    },
} = .{};
pub const list_licenses: struct {
    action_name: []const u8 = "ListLicenses",
    Request: type = struct {
        license_arns: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arns = "LicenseArns",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_licenses) } {
            return .{ .service_metadata = service_metadata, .action = list_licenses };
        }
    },
    Response: type = struct {
        licenses: ?[]License = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .licenses = "Licenses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const list_license_specifications_for_resource: struct {
    action_name: []const u8 = "ListLicenseSpecificationsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_license_specifications_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_license_specifications_for_resource };
        }
    },
    Response: type = struct {
        license_specifications: ?[]LicenseSpecification = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_specifications = "LicenseSpecifications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const list_license_versions: struct {
    action_name: []const u8 = "ListLicenseVersions",
    Request: type = struct {
        license_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_license_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_license_versions };
        }
    },
    Response: type = struct {
        licenses: ?[]License = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .licenses = "Licenses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const list_received_grants: struct {
    action_name: []const u8 = "ListReceivedGrants",
    Request: type = struct {
        grant_arns: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arns = "GrantArns",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_received_grants) } {
            return .{ .service_metadata = service_metadata, .action = list_received_grants };
        }
    },
    Response: type = struct {
        grants: ?[]Grant = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grants = "Grants",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const list_received_grants_for_organization: struct {
    action_name: []const u8 = "ListReceivedGrantsForOrganization",
    Request: type = struct {
        license_arn: []const u8,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arn = "LicenseArn",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_received_grants_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = list_received_grants_for_organization };
        }
    },
    Response: type = struct {
        grants: ?[]Grant = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grants = "Grants",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const list_received_licenses: struct {
    action_name: []const u8 = "ListReceivedLicenses",
    Request: type = struct {
        license_arns: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_arns = "LicenseArns",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_received_licenses) } {
            return .{ .service_metadata = service_metadata, .action = list_received_licenses };
        }
    },
    Response: type = struct {
        licenses: ?[]GrantedLicense = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .licenses = "Licenses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const list_received_licenses_for_organization: struct {
    action_name: []const u8 = "ListReceivedLicensesForOrganization",
    Request: type = struct {
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_received_licenses_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = list_received_licenses_for_organization };
        }
    },
    Response: type = struct {
        licenses: ?[]GrantedLicense = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .licenses = "Licenses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const list_resource_inventory: struct {
    action_name: []const u8 = "ListResourceInventory",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            condition: []const u8,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .condition = "Condition",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_inventory) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_inventory };
        }
    },
    Response: type = struct {
        resource_inventory_list: ?[]struct {
            resource_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            platform_version: ?[]const u8 = null,
            resource_owning_account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_id = "ResourceId",
                    .resource_type = "ResourceType",
                    .resource_arn = "ResourceArn",
                    .platform = "Platform",
                    .platform_version = "PlatformVersion",
                    .resource_owning_account_id = "ResourceOwningAccountId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_inventory_list = "ResourceInventoryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        FailedDependency,
        FilterLimitExceeded,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const list_tokens: struct {
    action_name: []const u8 = "ListTokens",
    Request: type = struct {
        token_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token_ids = "TokenIds",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tokens) } {
            return .{ .service_metadata = service_metadata, .action = list_tokens };
        }
    },
    Response: type = struct {
        tokens: ?[]struct {
            token_id: ?[]const u8 = null,
            token_type: ?[]const u8 = null,
            license_arn: ?[]const u8 = null,
            expiration_time: ?[]const u8 = null,
            token_properties: ?[][]const u8 = null,
            role_arns: ?[][]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .token_id = "TokenId",
                    .token_type = "TokenType",
                    .license_arn = "LicenseArn",
                    .expiration_time = "ExpirationTime",
                    .token_properties = "TokenProperties",
                    .role_arns = "RoleArns",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tokens = "Tokens",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        RateLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const list_usage_for_license_configuration: struct {
    action_name: []const u8 = "ListUsageForLicenseConfiguration",
    Request: type = struct {
        license_configuration_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_arn = "LicenseConfigurationArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_usage_for_license_configuration) } {
            return .{ .service_metadata = service_metadata, .action = list_usage_for_license_configuration };
        }
    },
    Response: type = struct {
        license_configuration_usage_list: ?[]struct {
            resource_arn: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_status: ?[]const u8 = null,
            resource_owner_id: ?[]const u8 = null,
            association_time: ?i64 = null,
            consumed_licenses: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "ResourceArn",
                    .resource_type = "ResourceType",
                    .resource_status = "ResourceStatus",
                    .resource_owner_id = "ResourceOwnerId",
                    .association_time = "AssociationTime",
                    .consumed_licenses = "ConsumedLicenses",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_usage_list = "LicenseConfigurationUsageList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        FilterLimitExceeded,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const reject_grant: struct {
    action_name: []const u8 = "RejectGrant",
    Request: type = struct {
        grant_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arn = "GrantArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_grant) } {
            return .{ .service_metadata = service_metadata, .action = reject_grant };
        }
    },
    Response: type = struct {
        grant_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grant_arn = "GrantArn",
                .status = "Status",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const update_license_configuration: struct {
    action_name: []const u8 = "UpdateLicenseConfiguration",
    Request: type = struct {
        license_configuration_arn: []const u8,
        license_configuration_status: ?[]const u8 = null,
        license_rules: ?[][]const u8 = null,
        license_count: ?i64 = null,
        license_count_hard_limit: ?bool = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        product_information_list: ?[]ProductInformation = null,
        disassociate_when_not_found: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_configuration_arn = "LicenseConfigurationArn",
                .license_configuration_status = "LicenseConfigurationStatus",
                .license_rules = "LicenseRules",
                .license_count = "LicenseCount",
                .license_count_hard_limit = "LicenseCountHardLimit",
                .name = "Name",
                .description = "Description",
                .product_information_list = "ProductInformationList",
                .disassociate_when_not_found = "DisassociateWhenNotFound",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_license_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_license_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const update_license_manager_report_generator: struct {
    action_name: []const u8 = "UpdateLicenseManagerReportGenerator",
    Request: type = struct {
        license_manager_report_generator_arn: []const u8,
        report_generator_name: []const u8,
        type: [][]const u8,
        report_context: ReportContext,
        report_frequency: ReportFrequency,
        client_token: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .license_manager_report_generator_arn = "LicenseManagerReportGeneratorArn",
                .report_generator_name = "ReportGeneratorName",
                .type = "Type",
                .report_context = "ReportContext",
                .report_frequency = "ReportFrequency",
                .client_token = "ClientToken",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_license_manager_report_generator) } {
            return .{ .service_metadata = service_metadata, .action = update_license_manager_report_generator };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ResourceLimitExceeded,
        ResourceNotFound,
        ServerInternal,
        Validation,
    },
} = .{};
pub const update_license_specifications_for_resource: struct {
    action_name: []const u8 = "UpdateLicenseSpecificationsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        add_license_specifications: ?[]LicenseSpecification = null,
        remove_license_specifications: ?[]LicenseSpecification = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .add_license_specifications = "AddLicenseSpecifications",
                .remove_license_specifications = "RemoveLicenseSpecifications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_license_specifications_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = update_license_specifications_for_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        InvalidResourceState,
        LicenseUsage,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};
pub const update_service_settings: struct {
    action_name: []const u8 = "UpdateServiceSettings",
    Request: type = struct {
        s3_bucket_arn: ?[]const u8 = null,
        sns_topic_arn: ?[]const u8 = null,
        organization_configuration: ?OrganizationConfiguration = null,
        enable_cross_accounts_discovery: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_bucket_arn = "S3BucketArn",
                .sns_topic_arn = "SnsTopicArn",
                .organization_configuration = "OrganizationConfiguration",
                .enable_cross_accounts_discovery = "EnableCrossAccountsDiscovery",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_service_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_service_settings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Authorization,
        InvalidParameterValue,
        RateLimitExceeded,
        ServerInternal,
    },
} = .{};

pub const OrganizationConfiguration = struct {
    enable_integration: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_integration = "EnableIntegration",
        };
        return @field(mappings, field_name);
    }
};

pub const LicenseSpecification = struct {
    license_configuration_arn: []const u8,
    ami_association_scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .license_configuration_arn = "LicenseConfigurationArn",
            .ami_association_scope = "AmiAssociationScope",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportFrequency = struct {
    value: ?i64 = null,
    period: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .period = "period",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportContext = struct {
    license_configuration_arns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .license_configuration_arns = "licenseConfigurationArns",
        };
        return @field(mappings, field_name);
    }
};

pub const ProductInformation = struct {
    resource_type: []const u8,
    product_information_filter_list: []ProductInformationFilter,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "ResourceType",
            .product_information_filter_list = "ProductInformationFilterList",
        };
        return @field(mappings, field_name);
    }
};

pub const ProductInformationFilter = struct {
    product_information_filter_name: []const u8,
    product_information_filter_value: ?[][]const u8 = null,
    product_information_filter_comparator: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_information_filter_name = "ProductInformationFilterName",
            .product_information_filter_value = "ProductInformationFilterValue",
            .product_information_filter_comparator = "ProductInformationFilterComparator",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const GrantedLicense = struct {
    license_arn: ?[]const u8 = null,
    license_name: ?[]const u8 = null,
    product_name: ?[]const u8 = null,
    product_sku: ?[]const u8 = null,
    issuer: ?IssuerDetails = null,
    home_region: ?[]const u8 = null,
    status: ?[]const u8 = null,
    validity: ?DatetimeRange = null,
    beneficiary: ?[]const u8 = null,
    entitlements: ?[]Entitlement = null,
    consumption_configuration: ?ConsumptionConfiguration = null,
    license_metadata: ?[]Metadata = null,
    create_time: ?[]const u8 = null,
    version: ?[]const u8 = null,
    received_metadata: ?ReceivedMetadata = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .license_arn = "LicenseArn",
            .license_name = "LicenseName",
            .product_name = "ProductName",
            .product_sku = "ProductSKU",
            .issuer = "Issuer",
            .home_region = "HomeRegion",
            .status = "Status",
            .validity = "Validity",
            .beneficiary = "Beneficiary",
            .entitlements = "Entitlements",
            .consumption_configuration = "ConsumptionConfiguration",
            .license_metadata = "LicenseMetadata",
            .create_time = "CreateTime",
            .version = "Version",
            .received_metadata = "ReceivedMetadata",
        };
        return @field(mappings, field_name);
    }
};

pub const ReceivedMetadata = struct {
    received_status: ?[]const u8 = null,
    received_status_reason: ?[]const u8 = null,
    allowed_operations: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .received_status = "ReceivedStatus",
            .received_status_reason = "ReceivedStatusReason",
            .allowed_operations = "AllowedOperations",
        };
        return @field(mappings, field_name);
    }
};

pub const Metadata = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ConsumptionConfiguration = struct {
    renew_type: ?[]const u8 = null,
    provisional_configuration: ?ProvisionalConfiguration = null,
    borrow_configuration: ?BorrowConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .renew_type = "RenewType",
            .provisional_configuration = "ProvisionalConfiguration",
            .borrow_configuration = "BorrowConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const BorrowConfiguration = struct {
    allow_early_check_in: bool,
    max_time_to_live_in_minutes: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_early_check_in = "AllowEarlyCheckIn",
            .max_time_to_live_in_minutes = "MaxTimeToLiveInMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisionalConfiguration = struct {
    max_time_to_live_in_minutes: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_time_to_live_in_minutes = "MaxTimeToLiveInMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const Entitlement = struct {
    name: []const u8,
    value: ?[]const u8 = null,
    max_count: ?i64 = null,
    overage: ?bool = null,
    unit: []const u8,
    allow_check_in: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
            .max_count = "MaxCount",
            .overage = "Overage",
            .unit = "Unit",
            .allow_check_in = "AllowCheckIn",
        };
        return @field(mappings, field_name);
    }
};

pub const DatetimeRange = struct {
    begin: []const u8,
    end: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .begin = "Begin",
            .end = "End",
        };
        return @field(mappings, field_name);
    }
};

pub const IssuerDetails = struct {
    name: ?[]const u8 = null,
    sign_key: ?[]const u8 = null,
    key_fingerprint: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .sign_key = "SignKey",
            .key_fingerprint = "KeyFingerprint",
        };
        return @field(mappings, field_name);
    }
};

pub const Grant = struct {
    grant_arn: []const u8,
    grant_name: []const u8,
    parent_arn: []const u8,
    license_arn: []const u8,
    grantee_principal_arn: []const u8,
    home_region: []const u8,
    grant_status: []const u8,
    status_reason: ?[]const u8 = null,
    version: []const u8,
    granted_operations: [][]const u8,
    options: ?Options = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grant_arn = "GrantArn",
            .grant_name = "GrantName",
            .parent_arn = "ParentArn",
            .license_arn = "LicenseArn",
            .grantee_principal_arn = "GranteePrincipalArn",
            .home_region = "HomeRegion",
            .grant_status = "GrantStatus",
            .status_reason = "StatusReason",
            .version = "Version",
            .granted_operations = "GrantedOperations",
            .options = "Options",
        };
        return @field(mappings, field_name);
    }
};

pub const Options = struct {
    activation_override_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activation_override_behavior = "ActivationOverrideBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const License = struct {
    license_arn: ?[]const u8 = null,
    license_name: ?[]const u8 = null,
    product_name: ?[]const u8 = null,
    product_sku: ?[]const u8 = null,
    issuer: ?IssuerDetails = null,
    home_region: ?[]const u8 = null,
    status: ?[]const u8 = null,
    validity: ?DatetimeRange = null,
    beneficiary: ?[]const u8 = null,
    entitlements: ?[]Entitlement = null,
    consumption_configuration: ?ConsumptionConfiguration = null,
    license_metadata: ?[]Metadata = null,
    create_time: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .license_arn = "LicenseArn",
            .license_name = "LicenseName",
            .product_name = "ProductName",
            .product_sku = "ProductSKU",
            .issuer = "Issuer",
            .home_region = "HomeRegion",
            .status = "Status",
            .validity = "Validity",
            .beneficiary = "Beneficiary",
            .entitlements = "Entitlements",
            .consumption_configuration = "ConsumptionConfiguration",
            .license_metadata = "LicenseMetadata",
            .create_time = "CreateTime",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportGenerator = struct {
    report_generator_name: ?[]const u8 = null,
    report_type: ?[][]const u8 = null,
    report_context: ?ReportContext = null,
    report_frequency: ?ReportFrequency = null,
    license_manager_report_generator_arn: ?[]const u8 = null,
    last_run_status: ?[]const u8 = null,
    last_run_failure_reason: ?[]const u8 = null,
    last_report_generation_time: ?[]const u8 = null,
    report_creator_account: ?[]const u8 = null,
    description: ?[]const u8 = null,
    s3_location: ?S3Location = null,
    create_time: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report_generator_name = "ReportGeneratorName",
            .report_type = "ReportType",
            .report_context = "ReportContext",
            .report_frequency = "ReportFrequency",
            .license_manager_report_generator_arn = "LicenseManagerReportGeneratorArn",
            .last_run_status = "LastRunStatus",
            .last_run_failure_reason = "LastRunFailureReason",
            .last_report_generation_time = "LastReportGenerationTime",
            .report_creator_account = "ReportCreatorAccount",
            .description = "Description",
            .s3_location = "S3Location",
            .create_time = "CreateTime",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    bucket: ?[]const u8 = null,
    key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key_prefix = "keyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const LicenseConversionContext = struct {
    usage_operation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .usage_operation = "UsageOperation",
        };
        return @field(mappings, field_name);
    }
};

pub const AutomatedDiscoveryInformation = struct {
    last_run_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_run_time = "LastRunTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ManagedResourceSummary = struct {
    resource_type: ?[]const u8 = null,
    association_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "ResourceType",
            .association_count = "AssociationCount",
        };
        return @field(mappings, field_name);
    }
};

pub const ConsumedLicenseSummary = struct {
    resource_type: ?[]const u8 = null,
    consumed_licenses: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "ResourceType",
            .consumed_licenses = "ConsumedLicenses",
        };
        return @field(mappings, field_name);
    }
};

pub const Issuer = struct {
    name: []const u8,
    sign_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .sign_key = "SignKey",
        };
        return @field(mappings, field_name);
    }
};

pub const EntitlementData = struct {
    name: []const u8,
    value: ?[]const u8 = null,
    unit: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};
