const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-10";
pub const sdk_id: []const u8 = "License Manager Linux Subscriptions";
pub const arn_namespace: ?[]const u8 = "license-manager-linux-subscriptions";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "license-manager-linux-subscriptions";
pub const name: []const u8 = "LicenseManagerLinuxSubscriptions";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-10",
    sdk_id: []const u8 = "License Manager Linux Subscriptions",
    arn_namespace: ?[]const u8 = "license-manager-linux-subscriptions",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "license-manager-linux-subscriptions",
    name: []const u8 = "LicenseManagerLinuxSubscriptions",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const get_service_settings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/subscription/GetServiceSettings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetServiceSettings",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_service_settings };
        }
    },
    Response: type = struct {
        linux_subscriptions_discovery: ?[]const u8 = null,
        linux_subscriptions_discovery_settings: ?LinuxSubscriptionsDiscoverySettings = null,
        status: ?[]const u8 = null,
        status_message: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        home_regions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .linux_subscriptions_discovery = "LinuxSubscriptionsDiscovery",
                .linux_subscriptions_discovery_settings = "LinuxSubscriptionsDiscoverySettings",
                .status = "Status",
                .status_message = "StatusMessage",
                .home_regions = "HomeRegions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "status_message", field_name))
                return try serializeMap(self.status_message, self.fieldNameFor("status_message"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_linux_subscription_instances: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/subscription/ListLinuxSubscriptionInstances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLinuxSubscriptionInstances",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_linux_subscription_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_linux_subscription_instances };
        }
    },
    Response: type = struct {
        instances: ?[]struct {
            ami_id: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            region: ?[]const u8 = null,
            usage_operation: ?[]const u8 = null,
            product_code: ?[][]const u8 = null,
            last_updated_time: ?[]const u8 = null,
            subscription_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ami_id = "AmiId",
                    .instance_id = "InstanceID",
                    .instance_type = "InstanceType",
                    .account_id = "AccountID",
                    .status = "Status",
                    .region = "Region",
                    .usage_operation = "UsageOperation",
                    .product_code = "ProductCode",
                    .last_updated_time = "LastUpdatedTime",
                    .subscription_name = "SubscriptionName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "Instances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_linux_subscriptions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/subscription/ListLinuxSubscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLinuxSubscriptions",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_linux_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = list_linux_subscriptions };
        }
    },
    Response: type = struct {
        subscriptions: ?[]struct {
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            instance_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .type = "Type",
                    .instance_count = "InstanceCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscriptions = "Subscriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_service_settings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/subscription/UpdateServiceSettings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateServiceSettings",
    Request: type = struct {
        linux_subscriptions_discovery: []const u8,
        linux_subscriptions_discovery_settings: LinuxSubscriptionsDiscoverySettings,
        allow_update: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .linux_subscriptions_discovery = "LinuxSubscriptionsDiscovery",
                .linux_subscriptions_discovery_settings = "LinuxSubscriptionsDiscoverySettings",
                .allow_update = "AllowUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_service_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_service_settings };
        }
    },
    Response: type = struct {
        linux_subscriptions_discovery: ?[]const u8 = null,
        linux_subscriptions_discovery_settings: ?LinuxSubscriptionsDiscoverySettings = null,
        status: ?[]const u8 = null,
        status_message: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        home_regions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .linux_subscriptions_discovery = "LinuxSubscriptionsDiscovery",
                .linux_subscriptions_discovery_settings = "LinuxSubscriptionsDiscoverySettings",
                .status = "Status",
                .status_message = "StatusMessage",
                .home_regions = "HomeRegions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "status_message", field_name))
                return try serializeMap(self.status_message, self.fieldNameFor("status_message"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const LinuxSubscriptionsDiscoverySettings = struct {
    source_regions: [][]const u8,
    organization_integration: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_regions = "SourceRegions",
            .organization_integration = "OrganizationIntegration",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,
    operator: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
            .operator = "Operator",
        };
        return @field(mappings, field_name);
    }
};
