const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-10";
pub const sdk_id: []const u8 = "License Manager User Subscriptions";
pub const arn_namespace: ?[]const u8 = "license-manager-user-subscriptions";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "license-manager-user-subscriptions";
pub const name: []const u8 = "LicenseManagerUserSubscriptions";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-10",
    sdk_id: []const u8 = "License Manager User Subscriptions",
    arn_namespace: ?[]const u8 = "license-manager-user-subscriptions",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "license-manager-user-subscriptions",
    name: []const u8 = "LicenseManagerUserSubscriptions",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user/AssociateUser",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateUser",
    Request: type = struct {
        username: []const u8,
        instance_id: []const u8,
        identity_provider: IdentityProvider,
        domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .username = "Username",
                .instance_id = "InstanceId",
                .identity_provider = "IdentityProvider",
                .domain = "Domain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_user) } {
            return .{ .service_metadata = service_metadata, .action = associate_user };
        }
    },
    Response: type = struct {
        instance_user_summary: InstanceUserSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_user_summary = "InstanceUserSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const deregister_identity_provider: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identity-provider/DeregisterIdentityProvider",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterIdentityProvider",
    Request: type = struct {
        identity_provider: IdentityProvider,
        product: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider = "IdentityProvider",
                .product = "Product",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_identity_provider) } {
            return .{ .service_metadata = service_metadata, .action = deregister_identity_provider };
        }
    },
    Response: type = struct {
        identity_provider_summary: IdentityProviderSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider_summary = "IdentityProviderSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user/DisassociateUser",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateUser",
    Request: type = struct {
        username: []const u8,
        instance_id: []const u8,
        identity_provider: IdentityProvider,
        domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .username = "Username",
                .instance_id = "InstanceId",
                .identity_provider = "IdentityProvider",
                .domain = "Domain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_user) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_user };
        }
    },
    Response: type = struct {
        instance_user_summary: InstanceUserSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_user_summary = "InstanceUserSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_identity_providers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identity-provider/ListIdentityProviders",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIdentityProviders",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_identity_providers) } {
            return .{ .service_metadata = service_metadata, .action = list_identity_providers };
        }
    },
    Response: type = struct {
        identity_provider_summaries: []IdentityProviderSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider_summaries = "IdentityProviderSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_instances: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/instance/ListInstances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInstances",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_instances };
        }
    },
    Response: type = struct {
        instance_summaries: ?[]struct {
            instance_id: []const u8,
            status: []const u8,
            products: [][]const u8,
            last_status_check_date: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "InstanceId",
                    .status = "Status",
                    .products = "Products",
                    .last_status_check_date = "LastStatusCheckDate",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_summaries = "InstanceSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_product_subscriptions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user/ListProductSubscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProductSubscriptions",
    Request: type = struct {
        product: []const u8,
        identity_provider: IdentityProvider,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product = "Product",
                .identity_provider = "IdentityProvider",
                .max_results = "MaxResults",
                .filters = "Filters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_product_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = list_product_subscriptions };
        }
    },
    Response: type = struct {
        product_user_summaries: ?[]ProductUserSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_user_summaries = "ProductUserSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_user_associations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user/ListUserAssociations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUserAssociations",
    Request: type = struct {
        instance_id: []const u8,
        identity_provider: IdentityProvider,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .identity_provider = "IdentityProvider",
                .max_results = "MaxResults",
                .filters = "Filters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_user_associations };
        }
    },
    Response: type = struct {
        instance_user_summaries: ?[]InstanceUserSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_user_summaries = "InstanceUserSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const register_identity_provider: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identity-provider/RegisterIdentityProvider",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterIdentityProvider",
    Request: type = struct {
        identity_provider: IdentityProvider,
        product: []const u8,
        settings: ?Settings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider = "IdentityProvider",
                .product = "Product",
                .settings = "Settings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_identity_provider) } {
            return .{ .service_metadata = service_metadata, .action = register_identity_provider };
        }
    },
    Response: type = struct {
        identity_provider_summary: IdentityProviderSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider_summary = "IdentityProviderSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_product_subscription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user/StartProductSubscription",
        .success_code = 200,
    };

    action_name: []const u8 = "StartProductSubscription",
    Request: type = struct {
        username: []const u8,
        identity_provider: IdentityProvider,
        product: []const u8,
        domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .username = "Username",
                .identity_provider = "IdentityProvider",
                .product = "Product",
                .domain = "Domain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_product_subscription) } {
            return .{ .service_metadata = service_metadata, .action = start_product_subscription };
        }
    },
    Response: type = struct {
        product_user_summary: ProductUserSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_user_summary = "ProductUserSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_product_subscription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user/StopProductSubscription",
        .success_code = 200,
    };

    action_name: []const u8 = "StopProductSubscription",
    Request: type = struct {
        username: []const u8,
        identity_provider: IdentityProvider,
        product: []const u8,
        domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .username = "Username",
                .identity_provider = "IdentityProvider",
                .product = "Product",
                .domain = "Domain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_product_subscription) } {
            return .{ .service_metadata = service_metadata, .action = stop_product_subscription };
        }
    },
    Response: type = struct {
        product_user_summary: ProductUserSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_user_summary = "ProductUserSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_identity_provider_settings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/identity-provider/UpdateIdentityProviderSettings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIdentityProviderSettings",
    Request: type = struct {
        identity_provider: IdentityProvider,
        product: []const u8,
        update_settings: struct {
            add_subnets: [][]const u8,
            remove_subnets: [][]const u8,
            security_group_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add_subnets = "AddSubnets",
                    .remove_subnets = "RemoveSubnets",
                    .security_group_id = "SecurityGroupId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider = "IdentityProvider",
                .product = "Product",
                .update_settings = "UpdateSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_identity_provider_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_identity_provider_settings };
        }
    },
    Response: type = struct {
        identity_provider_summary: IdentityProviderSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider_summary = "IdentityProviderSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const IdentityProviderSummary = struct {
    identity_provider: IdentityProvider,
    settings: Settings,
    product: []const u8,
    status: []const u8,
    failure_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity_provider = "IdentityProvider",
            .settings = "Settings",
            .product = "Product",
            .status = "Status",
            .failure_message = "FailureMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const Settings = struct {
    subnets: [][]const u8,
    security_group_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnets = "Subnets",
            .security_group_id = "SecurityGroupId",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityProvider = union {
    active_directory_identity_provider: ?ActiveDirectoryIdentityProvider,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_directory_identity_provider = "ActiveDirectoryIdentityProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveDirectoryIdentityProvider = struct {
    directory_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .directory_id = "DirectoryId",
        };
        return @field(mappings, field_name);
    }
};

pub const ProductUserSummary = struct {
    username: []const u8,
    product: []const u8,
    identity_provider: IdentityProvider,
    status: []const u8,
    status_message: ?[]const u8 = null,
    domain: ?[]const u8 = null,
    subscription_start_date: ?[]const u8 = null,
    subscription_end_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .product = "Product",
            .identity_provider = "IdentityProvider",
            .status = "Status",
            .status_message = "StatusMessage",
            .domain = "Domain",
            .subscription_start_date = "SubscriptionStartDate",
            .subscription_end_date = "SubscriptionEndDate",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceUserSummary = struct {
    username: []const u8,
    instance_id: []const u8,
    identity_provider: IdentityProvider,
    status: []const u8,
    status_message: ?[]const u8 = null,
    domain: ?[]const u8 = null,
    association_date: ?[]const u8 = null,
    disassociation_date: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .instance_id = "InstanceId",
            .identity_provider = "IdentityProvider",
            .status = "Status",
            .status_message = "StatusMessage",
            .domain = "Domain",
            .association_date = "AssociationDate",
            .disassociation_date = "DisassociationDate",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    attribute: ?[]const u8 = null,
    operation: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute = "Attribute",
            .operation = "Operation",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
