const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-12-15";
pub const sdk_id: []const u8 = "LookoutEquipment";
pub const arn_namespace: ?[]const u8 = "lookoutequipment";
pub const endpoint_prefix: []const u8 = "lookoutequipment";
pub const sigv4_name: []const u8 = "lookoutequipment";
pub const name: []const u8 = "AWSLookoutEquipmentFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2020-12-15",
    sdk_id: []const u8 = "LookoutEquipment",
    arn_namespace: ?[]const u8 = "lookoutequipment",
    endpoint_prefix: []const u8 = "lookoutequipment",
    sigv4_name: []const u8 = "lookoutequipment",
    name: []const u8 = "AWSLookoutEquipmentFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const create_dataset: struct {
    action_name: []const u8 = "CreateDataset",
    Request: type = struct {
        dataset_name: []const u8,
        dataset_schema: ?DatasetSchema = null,
        server_side_kms_key_id: ?[]const u8 = null,
        client_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .dataset_schema = "DatasetSchema",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset };
        }
    },
    Response: type = struct {
        dataset_name: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .dataset_arn = "DatasetArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_inference_scheduler: struct {
    action_name: []const u8 = "CreateInferenceScheduler",
    Request: type = struct {
        model_name: []const u8,
        inference_scheduler_name: []const u8,
        data_delay_offset_in_minutes: ?i64 = null,
        data_upload_frequency: []const u8,
        data_input_configuration: InferenceInputConfiguration,
        data_output_configuration: InferenceOutputConfiguration,
        role_arn: []const u8,
        server_side_kms_key_id: ?[]const u8 = null,
        client_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .inference_scheduler_name = "InferenceSchedulerName",
                .data_delay_offset_in_minutes = "DataDelayOffsetInMinutes",
                .data_upload_frequency = "DataUploadFrequency",
                .data_input_configuration = "DataInputConfiguration",
                .data_output_configuration = "DataOutputConfiguration",
                .role_arn = "RoleArn",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = create_inference_scheduler };
        }
    },
    Response: type = struct {
        inference_scheduler_arn: ?[]const u8 = null,
        inference_scheduler_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        model_quality: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_arn = "InferenceSchedulerArn",
                .inference_scheduler_name = "InferenceSchedulerName",
                .status = "Status",
                .model_quality = "ModelQuality",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_label: struct {
    action_name: []const u8 = "CreateLabel",
    Request: type = struct {
        label_group_name: []const u8,
        start_time: i64,
        end_time: i64,
        rating: []const u8,
        fault_code: ?[]const u8 = null,
        notes: ?[]const u8 = null,
        equipment: ?[]const u8 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .rating = "Rating",
                .fault_code = "FaultCode",
                .notes = "Notes",
                .equipment = "Equipment",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_label) } {
            return .{ .service_metadata = service_metadata, .action = create_label };
        }
    },
    Response: type = struct {
        label_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_id = "LabelId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_label_group: struct {
    action_name: []const u8 = "CreateLabelGroup",
    Request: type = struct {
        label_group_name: []const u8,
        fault_codes: ?[][]const u8 = null,
        client_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
                .fault_codes = "FaultCodes",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_label_group) } {
            return .{ .service_metadata = service_metadata, .action = create_label_group };
        }
    },
    Response: type = struct {
        label_group_name: ?[]const u8 = null,
        label_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
                .label_group_arn = "LabelGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_model: struct {
    action_name: []const u8 = "CreateModel",
    Request: type = struct {
        model_name: []const u8,
        dataset_name: []const u8,
        dataset_schema: ?DatasetSchema = null,
        labels_input_configuration: ?LabelsInputConfiguration = null,
        client_token: []const u8,
        training_data_start_time: ?i64 = null,
        training_data_end_time: ?i64 = null,
        evaluation_data_start_time: ?i64 = null,
        evaluation_data_end_time: ?i64 = null,
        role_arn: ?[]const u8 = null,
        data_pre_processing_configuration: ?DataPreProcessingConfiguration = null,
        server_side_kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        off_condition: ?[]const u8 = null,
        model_diagnostics_output_configuration: ?ModelDiagnosticsOutputConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .dataset_name = "DatasetName",
                .dataset_schema = "DatasetSchema",
                .labels_input_configuration = "LabelsInputConfiguration",
                .client_token = "ClientToken",
                .training_data_start_time = "TrainingDataStartTime",
                .training_data_end_time = "TrainingDataEndTime",
                .evaluation_data_start_time = "EvaluationDataStartTime",
                .evaluation_data_end_time = "EvaluationDataEndTime",
                .role_arn = "RoleArn",
                .data_pre_processing_configuration = "DataPreProcessingConfiguration",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .tags = "Tags",
                .off_condition = "OffCondition",
                .model_diagnostics_output_configuration = "ModelDiagnosticsOutputConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model) } {
            return .{ .service_metadata = service_metadata, .action = create_model };
        }
    },
    Response: type = struct {
        model_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_arn = "ModelArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_retraining_scheduler: struct {
    action_name: []const u8 = "CreateRetrainingScheduler",
    Request: type = struct {
        model_name: []const u8,
        retraining_start_date: ?i64 = null,
        retraining_frequency: []const u8,
        lookback_window: []const u8,
        promote_mode: ?[]const u8 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .retraining_start_date = "RetrainingStartDate",
                .retraining_frequency = "RetrainingFrequency",
                .lookback_window = "LookbackWindow",
                .promote_mode = "PromoteMode",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_retraining_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = create_retraining_scheduler };
        }
    },
    Response: type = struct {
        model_name: ?[]const u8 = null,
        model_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_arn = "ModelArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_dataset: struct {
    action_name: []const u8 = "DeleteDataset",
    Request: type = struct {
        dataset_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_inference_scheduler: struct {
    action_name: []const u8 = "DeleteInferenceScheduler",
    Request: type = struct {
        inference_scheduler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_name = "InferenceSchedulerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = delete_inference_scheduler };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_label: struct {
    action_name: []const u8 = "DeleteLabel",
    Request: type = struct {
        label_group_name: []const u8,
        label_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
                .label_id = "LabelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_label) } {
            return .{ .service_metadata = service_metadata, .action = delete_label };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_label_group: struct {
    action_name: []const u8 = "DeleteLabelGroup",
    Request: type = struct {
        label_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_label_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_label_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_model: struct {
    action_name: []const u8 = "DeleteModel",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_model };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_retraining_scheduler: struct {
    action_name: []const u8 = "DeleteRetrainingScheduler",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_retraining_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = delete_retraining_scheduler };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_data_ingestion_job: struct {
    action_name: []const u8 = "DescribeDataIngestionJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_ingestion_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_ingestion_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        ingestion_input_configuration: ?IngestionInputConfiguration = null,
        role_arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        status: ?[]const u8 = null,
        failed_reason: ?[]const u8 = null,
        data_quality_summary: ?DataQualitySummary = null,
        ingested_files_summary: ?IngestedFilesSummary = null,
        status_detail: ?[]const u8 = null,
        ingested_data_size: ?i64 = null,
        data_start_time: ?i64 = null,
        data_end_time: ?i64 = null,
        source_dataset_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .dataset_arn = "DatasetArn",
                .ingestion_input_configuration = "IngestionInputConfiguration",
                .role_arn = "RoleArn",
                .created_at = "CreatedAt",
                .status = "Status",
                .failed_reason = "FailedReason",
                .data_quality_summary = "DataQualitySummary",
                .ingested_files_summary = "IngestedFilesSummary",
                .status_detail = "StatusDetail",
                .ingested_data_size = "IngestedDataSize",
                .data_start_time = "DataStartTime",
                .data_end_time = "DataEndTime",
                .source_dataset_arn = "SourceDatasetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_dataset: struct {
    action_name: []const u8 = "DescribeDataset",
    Request: type = struct {
        dataset_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset };
        }
    },
    Response: type = struct {
        dataset_name: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        status: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        server_side_kms_key_id: ?[]const u8 = null,
        ingestion_input_configuration: ?IngestionInputConfiguration = null,
        data_quality_summary: ?DataQualitySummary = null,
        ingested_files_summary: ?IngestedFilesSummary = null,
        role_arn: ?[]const u8 = null,
        data_start_time: ?i64 = null,
        data_end_time: ?i64 = null,
        source_dataset_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .dataset_arn = "DatasetArn",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .status = "Status",
                .schema = "Schema",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .ingestion_input_configuration = "IngestionInputConfiguration",
                .data_quality_summary = "DataQualitySummary",
                .ingested_files_summary = "IngestedFilesSummary",
                .role_arn = "RoleArn",
                .data_start_time = "DataStartTime",
                .data_end_time = "DataEndTime",
                .source_dataset_arn = "SourceDatasetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_inference_scheduler: struct {
    action_name: []const u8 = "DescribeInferenceScheduler",
    Request: type = struct {
        inference_scheduler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_name = "InferenceSchedulerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = describe_inference_scheduler };
        }
    },
    Response: type = struct {
        model_arn: ?[]const u8 = null,
        model_name: ?[]const u8 = null,
        inference_scheduler_name: ?[]const u8 = null,
        inference_scheduler_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        data_delay_offset_in_minutes: ?i64 = null,
        data_upload_frequency: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        data_input_configuration: ?InferenceInputConfiguration = null,
        data_output_configuration: ?InferenceOutputConfiguration = null,
        role_arn: ?[]const u8 = null,
        server_side_kms_key_id: ?[]const u8 = null,
        latest_inference_result: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_arn = "ModelArn",
                .model_name = "ModelName",
                .inference_scheduler_name = "InferenceSchedulerName",
                .inference_scheduler_arn = "InferenceSchedulerArn",
                .status = "Status",
                .data_delay_offset_in_minutes = "DataDelayOffsetInMinutes",
                .data_upload_frequency = "DataUploadFrequency",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .data_input_configuration = "DataInputConfiguration",
                .data_output_configuration = "DataOutputConfiguration",
                .role_arn = "RoleArn",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .latest_inference_result = "LatestInferenceResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_label: struct {
    action_name: []const u8 = "DescribeLabel",
    Request: type = struct {
        label_group_name: []const u8,
        label_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
                .label_id = "LabelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_label) } {
            return .{ .service_metadata = service_metadata, .action = describe_label };
        }
    },
    Response: type = struct {
        label_group_name: ?[]const u8 = null,
        label_group_arn: ?[]const u8 = null,
        label_id: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        rating: ?[]const u8 = null,
        fault_code: ?[]const u8 = null,
        notes: ?[]const u8 = null,
        equipment: ?[]const u8 = null,
        created_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
                .label_group_arn = "LabelGroupArn",
                .label_id = "LabelId",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .rating = "Rating",
                .fault_code = "FaultCode",
                .notes = "Notes",
                .equipment = "Equipment",
                .created_at = "CreatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_label_group: struct {
    action_name: []const u8 = "DescribeLabelGroup",
    Request: type = struct {
        label_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_label_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_label_group };
        }
    },
    Response: type = struct {
        label_group_name: ?[]const u8 = null,
        label_group_arn: ?[]const u8 = null,
        fault_codes: ?[][]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
                .label_group_arn = "LabelGroupArn",
                .fault_codes = "FaultCodes",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_model: struct {
    action_name: []const u8 = "DescribeModel",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model) } {
            return .{ .service_metadata = service_metadata, .action = describe_model };
        }
    },
    Response: type = struct {
        model_name: ?[]const u8 = null,
        model_arn: ?[]const u8 = null,
        dataset_name: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        labels_input_configuration: ?LabelsInputConfiguration = null,
        training_data_start_time: ?i64 = null,
        training_data_end_time: ?i64 = null,
        evaluation_data_start_time: ?i64 = null,
        evaluation_data_end_time: ?i64 = null,
        role_arn: ?[]const u8 = null,
        data_pre_processing_configuration: ?DataPreProcessingConfiguration = null,
        status: ?[]const u8 = null,
        training_execution_start_time: ?i64 = null,
        training_execution_end_time: ?i64 = null,
        failed_reason: ?[]const u8 = null,
        model_metrics: ?[]const u8 = null,
        last_updated_time: ?i64 = null,
        created_at: ?i64 = null,
        server_side_kms_key_id: ?[]const u8 = null,
        off_condition: ?[]const u8 = null,
        source_model_version_arn: ?[]const u8 = null,
        import_job_start_time: ?i64 = null,
        import_job_end_time: ?i64 = null,
        active_model_version: ?i64 = null,
        active_model_version_arn: ?[]const u8 = null,
        model_version_activated_at: ?i64 = null,
        previous_active_model_version: ?i64 = null,
        previous_active_model_version_arn: ?[]const u8 = null,
        previous_model_version_activated_at: ?i64 = null,
        prior_model_metrics: ?[]const u8 = null,
        latest_scheduled_retraining_failed_reason: ?[]const u8 = null,
        latest_scheduled_retraining_status: ?[]const u8 = null,
        latest_scheduled_retraining_model_version: ?i64 = null,
        latest_scheduled_retraining_start_time: ?i64 = null,
        latest_scheduled_retraining_available_data_in_days: ?i64 = null,
        next_scheduled_retraining_start_date: ?i64 = null,
        accumulated_inference_data_start_time: ?i64 = null,
        accumulated_inference_data_end_time: ?i64 = null,
        retraining_scheduler_status: ?[]const u8 = null,
        model_diagnostics_output_configuration: ?ModelDiagnosticsOutputConfiguration = null,
        model_quality: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_arn = "ModelArn",
                .dataset_name = "DatasetName",
                .dataset_arn = "DatasetArn",
                .schema = "Schema",
                .labels_input_configuration = "LabelsInputConfiguration",
                .training_data_start_time = "TrainingDataStartTime",
                .training_data_end_time = "TrainingDataEndTime",
                .evaluation_data_start_time = "EvaluationDataStartTime",
                .evaluation_data_end_time = "EvaluationDataEndTime",
                .role_arn = "RoleArn",
                .data_pre_processing_configuration = "DataPreProcessingConfiguration",
                .status = "Status",
                .training_execution_start_time = "TrainingExecutionStartTime",
                .training_execution_end_time = "TrainingExecutionEndTime",
                .failed_reason = "FailedReason",
                .model_metrics = "ModelMetrics",
                .last_updated_time = "LastUpdatedTime",
                .created_at = "CreatedAt",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .off_condition = "OffCondition",
                .source_model_version_arn = "SourceModelVersionArn",
                .import_job_start_time = "ImportJobStartTime",
                .import_job_end_time = "ImportJobEndTime",
                .active_model_version = "ActiveModelVersion",
                .active_model_version_arn = "ActiveModelVersionArn",
                .model_version_activated_at = "ModelVersionActivatedAt",
                .previous_active_model_version = "PreviousActiveModelVersion",
                .previous_active_model_version_arn = "PreviousActiveModelVersionArn",
                .previous_model_version_activated_at = "PreviousModelVersionActivatedAt",
                .prior_model_metrics = "PriorModelMetrics",
                .latest_scheduled_retraining_failed_reason = "LatestScheduledRetrainingFailedReason",
                .latest_scheduled_retraining_status = "LatestScheduledRetrainingStatus",
                .latest_scheduled_retraining_model_version = "LatestScheduledRetrainingModelVersion",
                .latest_scheduled_retraining_start_time = "LatestScheduledRetrainingStartTime",
                .latest_scheduled_retraining_available_data_in_days = "LatestScheduledRetrainingAvailableDataInDays",
                .next_scheduled_retraining_start_date = "NextScheduledRetrainingStartDate",
                .accumulated_inference_data_start_time = "AccumulatedInferenceDataStartTime",
                .accumulated_inference_data_end_time = "AccumulatedInferenceDataEndTime",
                .retraining_scheduler_status = "RetrainingSchedulerStatus",
                .model_diagnostics_output_configuration = "ModelDiagnosticsOutputConfiguration",
                .model_quality = "ModelQuality",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_model_version: struct {
    action_name: []const u8 = "DescribeModelVersion",
    Request: type = struct {
        model_name: []const u8,
        model_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_version = "ModelVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model_version) } {
            return .{ .service_metadata = service_metadata, .action = describe_model_version };
        }
    },
    Response: type = struct {
        model_name: ?[]const u8 = null,
        model_arn: ?[]const u8 = null,
        model_version: ?i64 = null,
        model_version_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        dataset_name: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        labels_input_configuration: ?LabelsInputConfiguration = null,
        training_data_start_time: ?i64 = null,
        training_data_end_time: ?i64 = null,
        evaluation_data_start_time: ?i64 = null,
        evaluation_data_end_time: ?i64 = null,
        role_arn: ?[]const u8 = null,
        data_pre_processing_configuration: ?DataPreProcessingConfiguration = null,
        training_execution_start_time: ?i64 = null,
        training_execution_end_time: ?i64 = null,
        failed_reason: ?[]const u8 = null,
        model_metrics: ?[]const u8 = null,
        last_updated_time: ?i64 = null,
        created_at: ?i64 = null,
        server_side_kms_key_id: ?[]const u8 = null,
        off_condition: ?[]const u8 = null,
        source_model_version_arn: ?[]const u8 = null,
        import_job_start_time: ?i64 = null,
        import_job_end_time: ?i64 = null,
        imported_data_size_in_bytes: ?i64 = null,
        prior_model_metrics: ?[]const u8 = null,
        retraining_available_data_in_days: ?i64 = null,
        auto_promotion_result: ?[]const u8 = null,
        auto_promotion_result_reason: ?[]const u8 = null,
        model_diagnostics_output_configuration: ?ModelDiagnosticsOutputConfiguration = null,
        model_diagnostics_results_object: ?S3Object = null,
        model_quality: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_arn = "ModelArn",
                .model_version = "ModelVersion",
                .model_version_arn = "ModelVersionArn",
                .status = "Status",
                .source_type = "SourceType",
                .dataset_name = "DatasetName",
                .dataset_arn = "DatasetArn",
                .schema = "Schema",
                .labels_input_configuration = "LabelsInputConfiguration",
                .training_data_start_time = "TrainingDataStartTime",
                .training_data_end_time = "TrainingDataEndTime",
                .evaluation_data_start_time = "EvaluationDataStartTime",
                .evaluation_data_end_time = "EvaluationDataEndTime",
                .role_arn = "RoleArn",
                .data_pre_processing_configuration = "DataPreProcessingConfiguration",
                .training_execution_start_time = "TrainingExecutionStartTime",
                .training_execution_end_time = "TrainingExecutionEndTime",
                .failed_reason = "FailedReason",
                .model_metrics = "ModelMetrics",
                .last_updated_time = "LastUpdatedTime",
                .created_at = "CreatedAt",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .off_condition = "OffCondition",
                .source_model_version_arn = "SourceModelVersionArn",
                .import_job_start_time = "ImportJobStartTime",
                .import_job_end_time = "ImportJobEndTime",
                .imported_data_size_in_bytes = "ImportedDataSizeInBytes",
                .prior_model_metrics = "PriorModelMetrics",
                .retraining_available_data_in_days = "RetrainingAvailableDataInDays",
                .auto_promotion_result = "AutoPromotionResult",
                .auto_promotion_result_reason = "AutoPromotionResultReason",
                .model_diagnostics_output_configuration = "ModelDiagnosticsOutputConfiguration",
                .model_diagnostics_results_object = "ModelDiagnosticsResultsObject",
                .model_quality = "ModelQuality",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_resource_policy: struct {
    action_name: []const u8 = "DescribeResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource_policy };
        }
    },
    Response: type = struct {
        policy_revision_id: ?[]const u8 = null,
        resource_policy: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_revision_id = "PolicyRevisionId",
                .resource_policy = "ResourcePolicy",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_retraining_scheduler: struct {
    action_name: []const u8 = "DescribeRetrainingScheduler",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_retraining_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = describe_retraining_scheduler };
        }
    },
    Response: type = struct {
        model_name: ?[]const u8 = null,
        model_arn: ?[]const u8 = null,
        retraining_start_date: ?i64 = null,
        retraining_frequency: ?[]const u8 = null,
        lookback_window: ?[]const u8 = null,
        status: ?[]const u8 = null,
        promote_mode: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_arn = "ModelArn",
                .retraining_start_date = "RetrainingStartDate",
                .retraining_frequency = "RetrainingFrequency",
                .lookback_window = "LookbackWindow",
                .status = "Status",
                .promote_mode = "PromoteMode",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const import_dataset: struct {
    action_name: []const u8 = "ImportDataset",
    Request: type = struct {
        source_dataset_arn: []const u8,
        dataset_name: ?[]const u8 = null,
        client_token: []const u8,
        server_side_kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_dataset_arn = "SourceDatasetArn",
                .dataset_name = "DatasetName",
                .client_token = "ClientToken",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_dataset) } {
            return .{ .service_metadata = service_metadata, .action = import_dataset };
        }
    },
    Response: type = struct {
        dataset_name: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .dataset_arn = "DatasetArn",
                .status = "Status",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const import_model_version: struct {
    action_name: []const u8 = "ImportModelVersion",
    Request: type = struct {
        source_model_version_arn: []const u8,
        model_name: ?[]const u8 = null,
        dataset_name: []const u8,
        labels_input_configuration: ?LabelsInputConfiguration = null,
        client_token: []const u8,
        role_arn: ?[]const u8 = null,
        server_side_kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        inference_data_import_strategy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_model_version_arn = "SourceModelVersionArn",
                .model_name = "ModelName",
                .dataset_name = "DatasetName",
                .labels_input_configuration = "LabelsInputConfiguration",
                .client_token = "ClientToken",
                .role_arn = "RoleArn",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .tags = "Tags",
                .inference_data_import_strategy = "InferenceDataImportStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_model_version) } {
            return .{ .service_metadata = service_metadata, .action = import_model_version };
        }
    },
    Response: type = struct {
        model_name: ?[]const u8 = null,
        model_arn: ?[]const u8 = null,
        model_version_arn: ?[]const u8 = null,
        model_version: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_arn = "ModelArn",
                .model_version_arn = "ModelVersionArn",
                .model_version = "ModelVersion",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_ingestion_jobs: struct {
    action_name: []const u8 = "ListDataIngestionJobs",
    Request: type = struct {
        dataset_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_ingestion_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_data_ingestion_jobs };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        data_ingestion_job_summaries: ?[]struct {
            job_id: ?[]const u8 = null,
            dataset_name: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            ingestion_input_configuration: ?IngestionInputConfiguration = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .dataset_name = "DatasetName",
                    .dataset_arn = "DatasetArn",
                    .ingestion_input_configuration = "IngestionInputConfiguration",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .data_ingestion_job_summaries = "DataIngestionJobSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_datasets: struct {
    action_name: []const u8 = "ListDatasets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dataset_name_begins_with: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .dataset_name_begins_with = "DatasetNameBeginsWith",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_datasets) } {
            return .{ .service_metadata = service_metadata, .action = list_datasets };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        dataset_summaries: ?[]struct {
            dataset_name: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dataset_name = "DatasetName",
                    .dataset_arn = "DatasetArn",
                    .status = "Status",
                    .created_at = "CreatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .dataset_summaries = "DatasetSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_inference_events: struct {
    action_name: []const u8 = "ListInferenceEvents",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        inference_scheduler_name: []const u8,
        interval_start_time: i64,
        interval_end_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .inference_scheduler_name = "InferenceSchedulerName",
                .interval_start_time = "IntervalStartTime",
                .interval_end_time = "IntervalEndTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_inference_events) } {
            return .{ .service_metadata = service_metadata, .action = list_inference_events };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        inference_event_summaries: ?[]struct {
            inference_scheduler_arn: ?[]const u8 = null,
            inference_scheduler_name: ?[]const u8 = null,
            event_start_time: ?i64 = null,
            event_end_time: ?i64 = null,
            diagnostics: ?[]const u8 = null,
            event_duration_in_seconds: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .inference_scheduler_arn = "InferenceSchedulerArn",
                    .inference_scheduler_name = "InferenceSchedulerName",
                    .event_start_time = "EventStartTime",
                    .event_end_time = "EventEndTime",
                    .diagnostics = "Diagnostics",
                    .event_duration_in_seconds = "EventDurationInSeconds",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .inference_event_summaries = "InferenceEventSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_inference_executions: struct {
    action_name: []const u8 = "ListInferenceExecutions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        inference_scheduler_name: []const u8,
        data_start_time_after: ?i64 = null,
        data_end_time_before: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .inference_scheduler_name = "InferenceSchedulerName",
                .data_start_time_after = "DataStartTimeAfter",
                .data_end_time_before = "DataEndTimeBefore",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_inference_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_inference_executions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        inference_execution_summaries: ?[]struct {
            model_name: ?[]const u8 = null,
            model_arn: ?[]const u8 = null,
            inference_scheduler_name: ?[]const u8 = null,
            inference_scheduler_arn: ?[]const u8 = null,
            scheduled_start_time: ?i64 = null,
            data_start_time: ?i64 = null,
            data_end_time: ?i64 = null,
            data_input_configuration: ?InferenceInputConfiguration = null,
            data_output_configuration: ?InferenceOutputConfiguration = null,
            customer_result_object: ?S3Object = null,
            status: ?[]const u8 = null,
            failed_reason: ?[]const u8 = null,
            model_version: ?i64 = null,
            model_version_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_arn = "ModelArn",
                    .inference_scheduler_name = "InferenceSchedulerName",
                    .inference_scheduler_arn = "InferenceSchedulerArn",
                    .scheduled_start_time = "ScheduledStartTime",
                    .data_start_time = "DataStartTime",
                    .data_end_time = "DataEndTime",
                    .data_input_configuration = "DataInputConfiguration",
                    .data_output_configuration = "DataOutputConfiguration",
                    .customer_result_object = "CustomerResultObject",
                    .status = "Status",
                    .failed_reason = "FailedReason",
                    .model_version = "ModelVersion",
                    .model_version_arn = "ModelVersionArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .inference_execution_summaries = "InferenceExecutionSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_inference_schedulers: struct {
    action_name: []const u8 = "ListInferenceSchedulers",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        inference_scheduler_name_begins_with: ?[]const u8 = null,
        model_name: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .inference_scheduler_name_begins_with = "InferenceSchedulerNameBeginsWith",
                .model_name = "ModelName",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_inference_schedulers) } {
            return .{ .service_metadata = service_metadata, .action = list_inference_schedulers };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        inference_scheduler_summaries: ?[]struct {
            model_name: ?[]const u8 = null,
            model_arn: ?[]const u8 = null,
            inference_scheduler_name: ?[]const u8 = null,
            inference_scheduler_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            data_delay_offset_in_minutes: ?i64 = null,
            data_upload_frequency: ?[]const u8 = null,
            latest_inference_result: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_arn = "ModelArn",
                    .inference_scheduler_name = "InferenceSchedulerName",
                    .inference_scheduler_arn = "InferenceSchedulerArn",
                    .status = "Status",
                    .data_delay_offset_in_minutes = "DataDelayOffsetInMinutes",
                    .data_upload_frequency = "DataUploadFrequency",
                    .latest_inference_result = "LatestInferenceResult",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .inference_scheduler_summaries = "InferenceSchedulerSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_label_groups: struct {
    action_name: []const u8 = "ListLabelGroups",
    Request: type = struct {
        label_group_name_begins_with: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name_begins_with = "LabelGroupNameBeginsWith",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_label_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_label_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        label_group_summaries: ?[]struct {
            label_group_name: ?[]const u8 = null,
            label_group_arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .label_group_name = "LabelGroupName",
                    .label_group_arn = "LabelGroupArn",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .label_group_summaries = "LabelGroupSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_labels: struct {
    action_name: []const u8 = "ListLabels",
    Request: type = struct {
        label_group_name: []const u8,
        interval_start_time: ?i64 = null,
        interval_end_time: ?i64 = null,
        fault_code: ?[]const u8 = null,
        equipment: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
                .interval_start_time = "IntervalStartTime",
                .interval_end_time = "IntervalEndTime",
                .fault_code = "FaultCode",
                .equipment = "Equipment",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_labels) } {
            return .{ .service_metadata = service_metadata, .action = list_labels };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        label_summaries: ?[]struct {
            label_group_name: ?[]const u8 = null,
            label_id: ?[]const u8 = null,
            label_group_arn: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            rating: ?[]const u8 = null,
            fault_code: ?[]const u8 = null,
            equipment: ?[]const u8 = null,
            created_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .label_group_name = "LabelGroupName",
                    .label_id = "LabelId",
                    .label_group_arn = "LabelGroupArn",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .rating = "Rating",
                    .fault_code = "FaultCode",
                    .equipment = "Equipment",
                    .created_at = "CreatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .label_summaries = "LabelSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_models: struct {
    action_name: []const u8 = "ListModels",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,
        model_name_begins_with: ?[]const u8 = null,
        dataset_name_begins_with: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status = "Status",
                .model_name_begins_with = "ModelNameBeginsWith",
                .dataset_name_begins_with = "DatasetNameBeginsWith",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_models) } {
            return .{ .service_metadata = service_metadata, .action = list_models };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        model_summaries: ?[]struct {
            model_name: ?[]const u8 = null,
            model_arn: ?[]const u8 = null,
            dataset_name: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            active_model_version: ?i64 = null,
            active_model_version_arn: ?[]const u8 = null,
            latest_scheduled_retraining_status: ?[]const u8 = null,
            latest_scheduled_retraining_model_version: ?i64 = null,
            latest_scheduled_retraining_start_time: ?i64 = null,
            next_scheduled_retraining_start_date: ?i64 = null,
            retraining_scheduler_status: ?[]const u8 = null,
            model_diagnostics_output_configuration: ?ModelDiagnosticsOutputConfiguration = null,
            model_quality: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_arn = "ModelArn",
                    .dataset_name = "DatasetName",
                    .dataset_arn = "DatasetArn",
                    .status = "Status",
                    .created_at = "CreatedAt",
                    .active_model_version = "ActiveModelVersion",
                    .active_model_version_arn = "ActiveModelVersionArn",
                    .latest_scheduled_retraining_status = "LatestScheduledRetrainingStatus",
                    .latest_scheduled_retraining_model_version = "LatestScheduledRetrainingModelVersion",
                    .latest_scheduled_retraining_start_time = "LatestScheduledRetrainingStartTime",
                    .next_scheduled_retraining_start_date = "NextScheduledRetrainingStartDate",
                    .retraining_scheduler_status = "RetrainingSchedulerStatus",
                    .model_diagnostics_output_configuration = "ModelDiagnosticsOutputConfiguration",
                    .model_quality = "ModelQuality",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .model_summaries = "ModelSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_model_versions: struct {
    action_name: []const u8 = "ListModelVersions",
    Request: type = struct {
        model_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        created_at_end_time: ?i64 = null,
        created_at_start_time: ?i64 = null,
        max_model_version: ?i64 = null,
        min_model_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status = "Status",
                .source_type = "SourceType",
                .created_at_end_time = "CreatedAtEndTime",
                .created_at_start_time = "CreatedAtStartTime",
                .max_model_version = "MaxModelVersion",
                .min_model_version = "MinModelVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_model_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_model_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        model_version_summaries: ?[]struct {
            model_name: ?[]const u8 = null,
            model_arn: ?[]const u8 = null,
            model_version: ?i64 = null,
            model_version_arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            status: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            model_quality: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_arn = "ModelArn",
                    .model_version = "ModelVersion",
                    .model_version_arn = "ModelVersionArn",
                    .created_at = "CreatedAt",
                    .status = "Status",
                    .source_type = "SourceType",
                    .model_quality = "ModelQuality",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .model_version_summaries = "ModelVersionSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_retraining_schedulers: struct {
    action_name: []const u8 = "ListRetrainingSchedulers",
    Request: type = struct {
        model_name_begins_with: ?[]const u8 = null,
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name_begins_with = "ModelNameBeginsWith",
                .status = "Status",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_retraining_schedulers) } {
            return .{ .service_metadata = service_metadata, .action = list_retraining_schedulers };
        }
    },
    Response: type = struct {
        retraining_scheduler_summaries: ?[]struct {
            model_name: ?[]const u8 = null,
            model_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            retraining_start_date: ?i64 = null,
            retraining_frequency: ?[]const u8 = null,
            lookback_window: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_arn = "ModelArn",
                    .status = "Status",
                    .retraining_start_date = "RetrainingStartDate",
                    .retraining_frequency = "RetrainingFrequency",
                    .lookback_window = "LookbackWindow",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retraining_scheduler_summaries = "RetrainingSchedulerSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_sensor_statistics: struct {
    action_name: []const u8 = "ListSensorStatistics",
    Request: type = struct {
        dataset_name: []const u8,
        ingestion_job_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .ingestion_job_id = "IngestionJobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sensor_statistics) } {
            return .{ .service_metadata = service_metadata, .action = list_sensor_statistics };
        }
    },
    Response: type = struct {
        sensor_statistics_summaries: ?[]struct {
            component_name: ?[]const u8 = null,
            sensor_name: ?[]const u8 = null,
            data_exists: ?bool = null,
            missing_values: ?CountPercent = null,
            invalid_values: ?CountPercent = null,
            invalid_date_entries: ?CountPercent = null,
            duplicate_timestamps: ?CountPercent = null,
            categorical_values: ?struct {
                status: []const u8,
                number_of_category: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "Status",
                        .number_of_category = "NumberOfCategory",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            multiple_operating_modes: ?struct {
                status: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "Status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            large_timestamp_gaps: ?struct {
                status: []const u8,
                number_of_large_timestamp_gaps: ?i64 = null,
                max_timestamp_gap_in_days: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "Status",
                        .number_of_large_timestamp_gaps = "NumberOfLargeTimestampGaps",
                        .max_timestamp_gap_in_days = "MaxTimestampGapInDays",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            monotonic_values: ?struct {
                status: []const u8,
                monotonicity: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "Status",
                        .monotonicity = "Monotonicity",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            data_start_time: ?i64 = null,
            data_end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .component_name = "ComponentName",
                    .sensor_name = "SensorName",
                    .data_exists = "DataExists",
                    .missing_values = "MissingValues",
                    .invalid_values = "InvalidValues",
                    .invalid_date_entries = "InvalidDateEntries",
                    .duplicate_timestamps = "DuplicateTimestamps",
                    .categorical_values = "CategoricalValues",
                    .multiple_operating_modes = "MultipleOperatingModes",
                    .large_timestamp_gaps = "LargeTimestampGaps",
                    .monotonic_values = "MonotonicValues",
                    .data_start_time = "DataStartTime",
                    .data_end_time = "DataEndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sensor_statistics_summaries = "SensorStatisticsSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        resource_policy: []const u8,
        policy_revision_id: ?[]const u8 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_policy = "ResourcePolicy",
                .policy_revision_id = "PolicyRevisionId",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        policy_revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy_revision_id = "PolicyRevisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_data_ingestion_job: struct {
    action_name: []const u8 = "StartDataIngestionJob",
    Request: type = struct {
        dataset_name: []const u8,
        ingestion_input_configuration: IngestionInputConfiguration,
        role_arn: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .ingestion_input_configuration = "IngestionInputConfiguration",
                .role_arn = "RoleArn",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_data_ingestion_job) } {
            return .{ .service_metadata = service_metadata, .action = start_data_ingestion_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_inference_scheduler: struct {
    action_name: []const u8 = "StartInferenceScheduler",
    Request: type = struct {
        inference_scheduler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_name = "InferenceSchedulerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = start_inference_scheduler };
        }
    },
    Response: type = struct {
        model_arn: ?[]const u8 = null,
        model_name: ?[]const u8 = null,
        inference_scheduler_name: ?[]const u8 = null,
        inference_scheduler_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_arn = "ModelArn",
                .model_name = "ModelName",
                .inference_scheduler_name = "InferenceSchedulerName",
                .inference_scheduler_arn = "InferenceSchedulerArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_retraining_scheduler: struct {
    action_name: []const u8 = "StartRetrainingScheduler",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_retraining_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = start_retraining_scheduler };
        }
    },
    Response: type = struct {
        model_name: ?[]const u8 = null,
        model_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_arn = "ModelArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_inference_scheduler: struct {
    action_name: []const u8 = "StopInferenceScheduler",
    Request: type = struct {
        inference_scheduler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_name = "InferenceSchedulerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = stop_inference_scheduler };
        }
    },
    Response: type = struct {
        model_arn: ?[]const u8 = null,
        model_name: ?[]const u8 = null,
        inference_scheduler_name: ?[]const u8 = null,
        inference_scheduler_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_arn = "ModelArn",
                .model_name = "ModelName",
                .inference_scheduler_name = "InferenceSchedulerName",
                .inference_scheduler_arn = "InferenceSchedulerArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_retraining_scheduler: struct {
    action_name: []const u8 = "StopRetrainingScheduler",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_retraining_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = stop_retraining_scheduler };
        }
    },
    Response: type = struct {
        model_name: ?[]const u8 = null,
        model_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_arn = "ModelArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_active_model_version: struct {
    action_name: []const u8 = "UpdateActiveModelVersion",
    Request: type = struct {
        model_name: []const u8,
        model_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_version = "ModelVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_active_model_version) } {
            return .{ .service_metadata = service_metadata, .action = update_active_model_version };
        }
    },
    Response: type = struct {
        model_name: ?[]const u8 = null,
        model_arn: ?[]const u8 = null,
        current_active_version: ?i64 = null,
        previous_active_version: ?i64 = null,
        current_active_version_arn: ?[]const u8 = null,
        previous_active_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_arn = "ModelArn",
                .current_active_version = "CurrentActiveVersion",
                .previous_active_version = "PreviousActiveVersion",
                .current_active_version_arn = "CurrentActiveVersionArn",
                .previous_active_version_arn = "PreviousActiveVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_inference_scheduler: struct {
    action_name: []const u8 = "UpdateInferenceScheduler",
    Request: type = struct {
        inference_scheduler_name: []const u8,
        data_delay_offset_in_minutes: ?i64 = null,
        data_upload_frequency: ?[]const u8 = null,
        data_input_configuration: ?InferenceInputConfiguration = null,
        data_output_configuration: ?InferenceOutputConfiguration = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_name = "InferenceSchedulerName",
                .data_delay_offset_in_minutes = "DataDelayOffsetInMinutes",
                .data_upload_frequency = "DataUploadFrequency",
                .data_input_configuration = "DataInputConfiguration",
                .data_output_configuration = "DataOutputConfiguration",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = update_inference_scheduler };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_label_group: struct {
    action_name: []const u8 = "UpdateLabelGroup",
    Request: type = struct {
        label_group_name: []const u8,
        fault_codes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_group_name = "LabelGroupName",
                .fault_codes = "FaultCodes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_label_group) } {
            return .{ .service_metadata = service_metadata, .action = update_label_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_model: struct {
    action_name: []const u8 = "UpdateModel",
    Request: type = struct {
        model_name: []const u8,
        labels_input_configuration: ?LabelsInputConfiguration = null,
        role_arn: ?[]const u8 = null,
        model_diagnostics_output_configuration: ?ModelDiagnosticsOutputConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .labels_input_configuration = "LabelsInputConfiguration",
                .role_arn = "RoleArn",
                .model_diagnostics_output_configuration = "ModelDiagnosticsOutputConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_model) } {
            return .{ .service_metadata = service_metadata, .action = update_model };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_retraining_scheduler: struct {
    action_name: []const u8 = "UpdateRetrainingScheduler",
    Request: type = struct {
        model_name: []const u8,
        retraining_start_date: ?i64 = null,
        retraining_frequency: ?[]const u8 = null,
        lookback_window: ?[]const u8 = null,
        promote_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .retraining_start_date = "RetrainingStartDate",
                .retraining_frequency = "RetrainingFrequency",
                .lookback_window = "LookbackWindow",
                .promote_mode = "PromoteMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_retraining_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = update_retraining_scheduler };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const ModelDiagnosticsOutputConfiguration = struct {
    s3_output_configuration: ModelDiagnosticsS3OutputConfiguration,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_output_configuration = "S3OutputConfiguration",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelDiagnosticsS3OutputConfiguration = struct {
    bucket: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelsInputConfiguration = struct {
    s3_input_configuration: ?LabelsS3InputConfiguration = null,
    label_group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_input_configuration = "S3InputConfiguration",
            .label_group_name = "LabelGroupName",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelsS3InputConfiguration = struct {
    bucket: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceOutputConfiguration = struct {
    s3_output_configuration: InferenceS3OutputConfiguration,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_output_configuration = "S3OutputConfiguration",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceS3OutputConfiguration = struct {
    bucket: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceInputConfiguration = struct {
    s3_input_configuration: ?InferenceS3InputConfiguration = null,
    input_time_zone_offset: ?[]const u8 = null,
    inference_input_name_configuration: ?InferenceInputNameConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_input_configuration = "S3InputConfiguration",
            .input_time_zone_offset = "InputTimeZoneOffset",
            .inference_input_name_configuration = "InferenceInputNameConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceInputNameConfiguration = struct {
    timestamp_format: ?[]const u8 = null,
    component_timestamp_delimiter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestamp_format = "TimestampFormat",
            .component_timestamp_delimiter = "ComponentTimestampDelimiter",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceS3InputConfiguration = struct {
    bucket: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const IngestionInputConfiguration = struct {
    s3_input_configuration: IngestionS3InputConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_input_configuration = "S3InputConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const IngestionS3InputConfiguration = struct {
    bucket: []const u8,
    prefix: ?[]const u8 = null,
    key_pattern: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
            .key_pattern = "KeyPattern",
        };
        return @field(mappings, field_name);
    }
};

pub const CountPercent = struct {
    count: i64,
    percentage: f32,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .percentage = "Percentage",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Object = struct {
    bucket: []const u8,
    key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPreProcessingConfiguration = struct {
    target_sampling_rate: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_sampling_rate = "TargetSamplingRate",
        };
        return @field(mappings, field_name);
    }
};

pub const IngestedFilesSummary = struct {
    total_number_of_files: i64,
    ingested_number_of_files: i64,
    discarded_files: ?[]S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_number_of_files = "TotalNumberOfFiles",
            .ingested_number_of_files = "IngestedNumberOfFiles",
            .discarded_files = "DiscardedFiles",
        };
        return @field(mappings, field_name);
    }
};

pub const DataQualitySummary = struct {
    insufficient_sensor_data: InsufficientSensorData,
    missing_sensor_data: MissingSensorData,
    invalid_sensor_data: InvalidSensorData,
    unsupported_timestamps: UnsupportedTimestamps,
    duplicate_timestamps: DuplicateTimestamps,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insufficient_sensor_data = "InsufficientSensorData",
            .missing_sensor_data = "MissingSensorData",
            .invalid_sensor_data = "InvalidSensorData",
            .unsupported_timestamps = "UnsupportedTimestamps",
            .duplicate_timestamps = "DuplicateTimestamps",
        };
        return @field(mappings, field_name);
    }
};

pub const DuplicateTimestamps = struct {
    total_number_of_duplicate_timestamps: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_number_of_duplicate_timestamps = "TotalNumberOfDuplicateTimestamps",
        };
        return @field(mappings, field_name);
    }
};

pub const UnsupportedTimestamps = struct {
    total_number_of_unsupported_timestamps: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_number_of_unsupported_timestamps = "TotalNumberOfUnsupportedTimestamps",
        };
        return @field(mappings, field_name);
    }
};

pub const InvalidSensorData = struct {
    affected_sensor_count: i64,
    total_number_of_invalid_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .affected_sensor_count = "AffectedSensorCount",
            .total_number_of_invalid_values = "TotalNumberOfInvalidValues",
        };
        return @field(mappings, field_name);
    }
};

pub const MissingSensorData = struct {
    affected_sensor_count: i64,
    total_number_of_missing_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .affected_sensor_count = "AffectedSensorCount",
            .total_number_of_missing_values = "TotalNumberOfMissingValues",
        };
        return @field(mappings, field_name);
    }
};

pub const InsufficientSensorData = struct {
    missing_complete_sensor_data: MissingCompleteSensorData,
    sensors_with_short_date_range: SensorsWithShortDateRange,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .missing_complete_sensor_data = "MissingCompleteSensorData",
            .sensors_with_short_date_range = "SensorsWithShortDateRange",
        };
        return @field(mappings, field_name);
    }
};

pub const SensorsWithShortDateRange = struct {
    affected_sensor_count: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .affected_sensor_count = "AffectedSensorCount",
        };
        return @field(mappings, field_name);
    }
};

pub const MissingCompleteSensorData = struct {
    affected_sensor_count: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .affected_sensor_count = "AffectedSensorCount",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetSchema = struct {
    inline_data_schema: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inline_data_schema = "InlineDataSchema",
        };
        return @field(mappings, field_name);
    }
};
