const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-25";
pub const sdk_id: []const u8 = "LookoutMetrics";
pub const arn_namespace: ?[]const u8 = "lookoutmetrics";
pub const endpoint_prefix: []const u8 = "lookoutmetrics";
pub const sigv4_name: []const u8 = "lookoutmetrics";
pub const name: []const u8 = "LookoutMetrics";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-25",
    sdk_id: []const u8 = "LookoutMetrics",
    arn_namespace: ?[]const u8 = "lookoutmetrics",
    endpoint_prefix: []const u8 = "lookoutmetrics",
    sigv4_name: []const u8 = "lookoutmetrics",
    name: []const u8 = "LookoutMetrics",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const activate_anomaly_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ActivateAnomalyDetector",
        .success_code = 200,
    };

    action_name: []const u8 = "ActivateAnomalyDetector",
    Request: type = struct {
        anomaly_detector_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(activate_anomaly_detector) } {
            return .{ .service_metadata = service_metadata, .action = activate_anomaly_detector };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const back_test_anomaly_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/BackTestAnomalyDetector",
        .success_code = 200,
    };

    action_name: []const u8 = "BackTestAnomalyDetector",
    Request: type = struct {
        anomaly_detector_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(back_test_anomaly_detector) } {
            return .{ .service_metadata = service_metadata, .action = back_test_anomaly_detector };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const create_alert: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateAlert",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAlert",
    Request: type = struct {
        alert_name: []const u8,
        alert_sensitivity_threshold: ?i64 = null,
        alert_description: ?[]const u8 = null,
        anomaly_detector_arn: []const u8,
        action: Action,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        alert_filters: ?AlertFilters = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alert_name = "AlertName",
                .alert_sensitivity_threshold = "AlertSensitivityThreshold",
                .alert_description = "AlertDescription",
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .action = "Action",
                .tags = "Tags",
                .alert_filters = "AlertFilters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_alert) } {
            return .{ .service_metadata = service_metadata, .action = create_alert };
        }
    },
    Response: type = struct {
        alert_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alert_arn = "AlertArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const create_anomaly_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateAnomalyDetector",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAnomalyDetector",
    Request: type = struct {
        anomaly_detector_name: []const u8,
        anomaly_detector_description: ?[]const u8 = null,
        anomaly_detector_config: AnomalyDetectorConfig,
        kms_key_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_name = "AnomalyDetectorName",
                .anomaly_detector_description = "AnomalyDetectorDescription",
                .anomaly_detector_config = "AnomalyDetectorConfig",
                .kms_key_arn = "KmsKeyArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_anomaly_detector) } {
            return .{ .service_metadata = service_metadata, .action = create_anomaly_detector };
        }
    },
    Response: type = struct {
        anomaly_detector_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const create_metric_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateMetricSet",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMetricSet",
    Request: type = struct {
        anomaly_detector_arn: []const u8,
        metric_set_name: []const u8,
        metric_set_description: ?[]const u8 = null,
        metric_list: []Metric,
        offset: ?i64 = null,
        timestamp_column: ?TimestampColumn = null,
        dimension_list: ?[][]const u8 = null,
        metric_set_frequency: ?[]const u8 = null,
        metric_source: MetricSource,
        timezone: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        dimension_filter_list: ?[]MetricSetDimensionFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .metric_set_name = "MetricSetName",
                .metric_set_description = "MetricSetDescription",
                .metric_list = "MetricList",
                .offset = "Offset",
                .timestamp_column = "TimestampColumn",
                .dimension_list = "DimensionList",
                .metric_set_frequency = "MetricSetFrequency",
                .metric_source = "MetricSource",
                .timezone = "Timezone",
                .tags = "Tags",
                .dimension_filter_list = "DimensionFilterList",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_metric_set) } {
            return .{ .service_metadata = service_metadata, .action = create_metric_set };
        }
    },
    Response: type = struct {
        metric_set_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_set_arn = "MetricSetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const deactivate_anomaly_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeactivateAnomalyDetector",
        .success_code = 200,
    };

    action_name: []const u8 = "DeactivateAnomalyDetector",
    Request: type = struct {
        anomaly_detector_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deactivate_anomaly_detector) } {
            return .{ .service_metadata = service_metadata, .action = deactivate_anomaly_detector };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const delete_alert: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteAlert",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAlert",
    Request: type = struct {
        alert_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alert_arn = "AlertArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_alert) } {
            return .{ .service_metadata = service_metadata, .action = delete_alert };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const delete_anomaly_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteAnomalyDetector",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAnomalyDetector",
    Request: type = struct {
        anomaly_detector_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_anomaly_detector) } {
            return .{ .service_metadata = service_metadata, .action = delete_anomaly_detector };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const describe_alert: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeAlert",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAlert",
    Request: type = struct {
        alert_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alert_arn = "AlertArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_alert) } {
            return .{ .service_metadata = service_metadata, .action = describe_alert };
        }
    },
    Response: type = struct {
        alert: ?struct {
            action: ?Action = null,
            alert_description: ?[]const u8 = null,
            alert_arn: ?[]const u8 = null,
            anomaly_detector_arn: ?[]const u8 = null,
            alert_name: ?[]const u8 = null,
            alert_sensitivity_threshold: ?i64 = null,
            alert_type: ?[]const u8 = null,
            alert_status: ?[]const u8 = null,
            last_modification_time: ?i64 = null,
            creation_time: ?i64 = null,
            alert_filters: ?AlertFilters = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .alert_description = "AlertDescription",
                    .alert_arn = "AlertArn",
                    .anomaly_detector_arn = "AnomalyDetectorArn",
                    .alert_name = "AlertName",
                    .alert_sensitivity_threshold = "AlertSensitivityThreshold",
                    .alert_type = "AlertType",
                    .alert_status = "AlertStatus",
                    .last_modification_time = "LastModificationTime",
                    .creation_time = "CreationTime",
                    .alert_filters = "AlertFilters",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alert = "Alert",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const describe_anomaly_detection_executions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeAnomalyDetectionExecutions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAnomalyDetectionExecutions",
    Request: type = struct {
        anomaly_detector_arn: []const u8,
        timestamp: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .timestamp = "Timestamp",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_anomaly_detection_executions) } {
            return .{ .service_metadata = service_metadata, .action = describe_anomaly_detection_executions };
        }
    },
    Response: type = struct {
        execution_list: ?[]struct {
            timestamp: ?[]const u8 = null,
            status: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .status = "Status",
                    .failure_reason = "FailureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_list = "ExecutionList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const describe_anomaly_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeAnomalyDetector",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAnomalyDetector",
    Request: type = struct {
        anomaly_detector_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_anomaly_detector) } {
            return .{ .service_metadata = service_metadata, .action = describe_anomaly_detector };
        }
    },
    Response: type = struct {
        anomaly_detector_arn: ?[]const u8 = null,
        anomaly_detector_name: ?[]const u8 = null,
        anomaly_detector_description: ?[]const u8 = null,
        anomaly_detector_config: ?struct {
            anomaly_detector_frequency: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .anomaly_detector_frequency = "AnomalyDetectorFrequency",
                };
                return @field(mappings, field_name);
            }
        } = null,
        creation_time: ?i64 = null,
        last_modification_time: ?i64 = null,
        status: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        failure_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .anomaly_detector_name = "AnomalyDetectorName",
                .anomaly_detector_description = "AnomalyDetectorDescription",
                .anomaly_detector_config = "AnomalyDetectorConfig",
                .creation_time = "CreationTime",
                .last_modification_time = "LastModificationTime",
                .status = "Status",
                .failure_reason = "FailureReason",
                .kms_key_arn = "KmsKeyArn",
                .failure_type = "FailureType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const describe_metric_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeMetricSet",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeMetricSet",
    Request: type = struct {
        metric_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_set_arn = "MetricSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_metric_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_metric_set };
        }
    },
    Response: type = struct {
        metric_set_arn: ?[]const u8 = null,
        anomaly_detector_arn: ?[]const u8 = null,
        metric_set_name: ?[]const u8 = null,
        metric_set_description: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modification_time: ?i64 = null,
        offset: ?i64 = null,
        metric_list: ?[]Metric = null,
        timestamp_column: ?TimestampColumn = null,
        dimension_list: ?[][]const u8 = null,
        metric_set_frequency: ?[]const u8 = null,
        timezone: ?[]const u8 = null,
        metric_source: ?MetricSource = null,
        dimension_filter_list: ?[]MetricSetDimensionFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_set_arn = "MetricSetArn",
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .metric_set_name = "MetricSetName",
                .metric_set_description = "MetricSetDescription",
                .creation_time = "CreationTime",
                .last_modification_time = "LastModificationTime",
                .offset = "Offset",
                .metric_list = "MetricList",
                .timestamp_column = "TimestampColumn",
                .dimension_list = "DimensionList",
                .metric_set_frequency = "MetricSetFrequency",
                .timezone = "Timezone",
                .metric_source = "MetricSource",
                .dimension_filter_list = "DimensionFilterList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const detect_metric_set_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DetectMetricSetConfig",
        .success_code = 200,
    };

    action_name: []const u8 = "DetectMetricSetConfig",
    Request: type = struct {
        anomaly_detector_arn: []const u8,
        auto_detection_metric_source: struct {
            s3_source_config: ?struct {
                templated_path_list: ?[][]const u8 = null,
                historical_data_path_list: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .templated_path_list = "TemplatedPathList",
                        .historical_data_path_list = "HistoricalDataPathList",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_source_config = "S3SourceConfig",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .auto_detection_metric_source = "AutoDetectionMetricSource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_metric_set_config) } {
            return .{ .service_metadata = service_metadata, .action = detect_metric_set_config };
        }
    },
    Response: type = struct {
        detected_metric_set_config: ?struct {
            offset: ?DetectedField = null,
            metric_set_frequency: ?DetectedField = null,
            metric_source: ?struct {
                s3_source_config: ?struct {
                    file_format_descriptor: ?struct {
                        csv_format_descriptor: ?struct {
                            file_compression: ?DetectedField = null,
                            charset: ?DetectedField = null,
                            contains_header: ?DetectedField = null,
                            delimiter: ?DetectedField = null,
                            header_list: ?DetectedField = null,
                            quote_symbol: ?DetectedField = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .file_compression = "FileCompression",
                                    .charset = "Charset",
                                    .contains_header = "ContainsHeader",
                                    .delimiter = "Delimiter",
                                    .header_list = "HeaderList",
                                    .quote_symbol = "QuoteSymbol",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        json_format_descriptor: ?struct {
                            file_compression: ?DetectedField = null,
                            charset: ?DetectedField = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .file_compression = "FileCompression",
                                    .charset = "Charset",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .csv_format_descriptor = "CsvFormatDescriptor",
                                .json_format_descriptor = "JsonFormatDescriptor",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .file_format_descriptor = "FileFormatDescriptor",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3_source_config = "S3SourceConfig",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .offset = "Offset",
                    .metric_set_frequency = "MetricSetFrequency",
                    .metric_source = "MetricSource",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detected_metric_set_config = "DetectedMetricSetConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const get_anomaly_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetAnomalyGroup",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAnomalyGroup",
    Request: type = struct {
        anomaly_group_id: []const u8,
        anomaly_detector_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_group_id = "AnomalyGroupId",
                .anomaly_detector_arn = "AnomalyDetectorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_anomaly_group) } {
            return .{ .service_metadata = service_metadata, .action = get_anomaly_group };
        }
    },
    Response: type = struct {
        anomaly_group: ?struct {
            start_time: ?[]const u8 = null,
            end_time: ?[]const u8 = null,
            anomaly_group_id: ?[]const u8 = null,
            anomaly_group_score: ?f64 = null,
            primary_metric_name: ?[]const u8 = null,
            metric_level_impact_list: ?[]struct {
                metric_name: ?[]const u8 = null,
                num_time_series: ?i64 = null,
                contribution_matrix: ?struct {
                    dimension_contribution_list: ?[]struct {
                        dimension_name: ?[]const u8 = null,
                        dimension_value_contribution_list: ?[]struct {
                            dimension_value: ?[]const u8 = null,
                            contribution_score: ?f64 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .dimension_value = "DimensionValue",
                                    .contribution_score = "ContributionScore",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .dimension_name = "DimensionName",
                                .dimension_value_contribution_list = "DimensionValueContributionList",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .dimension_contribution_list = "DimensionContributionList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metric_name = "MetricName",
                        .num_time_series = "NumTimeSeries",
                        .contribution_matrix = "ContributionMatrix",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .anomaly_group_id = "AnomalyGroupId",
                    .anomaly_group_score = "AnomalyGroupScore",
                    .primary_metric_name = "PrimaryMetricName",
                    .metric_level_impact_list = "MetricLevelImpactList",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_group = "AnomalyGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const get_data_quality_metrics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetDataQualityMetrics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataQualityMetrics",
    Request: type = struct {
        anomaly_detector_arn: []const u8,
        metric_set_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .metric_set_arn = "MetricSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_quality_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_data_quality_metrics };
        }
    },
    Response: type = struct {
        anomaly_detector_data_quality_metric_list: ?[]struct {
            start_timestamp: ?i64 = null,
            metric_set_data_quality_metric_list: ?[]struct {
                metric_set_arn: ?[]const u8 = null,
                data_quality_metric_list: ?[]struct {
                    metric_type: ?[]const u8 = null,
                    metric_description: ?[]const u8 = null,
                    related_column_name: ?[]const u8 = null,
                    metric_value: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .metric_type = "MetricType",
                            .metric_description = "MetricDescription",
                            .related_column_name = "RelatedColumnName",
                            .metric_value = "MetricValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metric_set_arn = "MetricSetArn",
                        .data_quality_metric_list = "DataQualityMetricList",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_timestamp = "StartTimestamp",
                    .metric_set_data_quality_metric_list = "MetricSetDataQualityMetricList",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_data_quality_metric_list = "AnomalyDetectorDataQualityMetricList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const get_feedback: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetFeedback",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFeedback",
    Request: type = struct {
        anomaly_detector_arn: []const u8,
        anomaly_group_time_series_feedback: struct {
            anomaly_group_id: []const u8,
            time_series_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .anomaly_group_id = "AnomalyGroupId",
                    .time_series_id = "TimeSeriesId",
                };
                return @field(mappings, field_name);
            }
        },
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .anomaly_group_time_series_feedback = "AnomalyGroupTimeSeriesFeedback",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_feedback) } {
            return .{ .service_metadata = service_metadata, .action = get_feedback };
        }
    },
    Response: type = struct {
        anomaly_group_time_series_feedback: ?[]struct {
            time_series_id: ?[]const u8 = null,
            is_anomaly: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .time_series_id = "TimeSeriesId",
                    .is_anomaly = "IsAnomaly",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_group_time_series_feedback = "AnomalyGroupTimeSeriesFeedback",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const get_sample_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetSampleData",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSampleData",
    Request: type = struct {
        s3_source_config: ?struct {
            role_arn: []const u8,
            templated_path_list: ?[][]const u8 = null,
            historical_data_path_list: ?[][]const u8 = null,
            file_format_descriptor: FileFormatDescriptor,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .role_arn = "RoleArn",
                    .templated_path_list = "TemplatedPathList",
                    .historical_data_path_list = "HistoricalDataPathList",
                    .file_format_descriptor = "FileFormatDescriptor",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_source_config = "S3SourceConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sample_data) } {
            return .{ .service_metadata = service_metadata, .action = get_sample_data };
        }
    },
    Response: type = struct {
        header_values: ?[][]const u8 = null,
        sample_rows: ?[][][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .header_values = "HeaderValues",
                .sample_rows = "SampleRows",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_alerts: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListAlerts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAlerts",
    Request: type = struct {
        anomaly_detector_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_alerts) } {
            return .{ .service_metadata = service_metadata, .action = list_alerts };
        }
    },
    Response: type = struct {
        alert_summary_list: ?[]struct {
            alert_arn: ?[]const u8 = null,
            anomaly_detector_arn: ?[]const u8 = null,
            alert_name: ?[]const u8 = null,
            alert_sensitivity_threshold: ?i64 = null,
            alert_type: ?[]const u8 = null,
            alert_status: ?[]const u8 = null,
            last_modification_time: ?i64 = null,
            creation_time: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .alert_arn = "AlertArn",
                    .anomaly_detector_arn = "AnomalyDetectorArn",
                    .alert_name = "AlertName",
                    .alert_sensitivity_threshold = "AlertSensitivityThreshold",
                    .alert_type = "AlertType",
                    .alert_status = "AlertStatus",
                    .last_modification_time = "LastModificationTime",
                    .creation_time = "CreationTime",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alert_summary_list = "AlertSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_anomaly_detectors: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListAnomalyDetectors",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnomalyDetectors",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_anomaly_detectors) } {
            return .{ .service_metadata = service_metadata, .action = list_anomaly_detectors };
        }
    },
    Response: type = struct {
        anomaly_detector_summary_list: ?[]struct {
            anomaly_detector_arn: ?[]const u8 = null,
            anomaly_detector_name: ?[]const u8 = null,
            anomaly_detector_description: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modification_time: ?i64 = null,
            status: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .anomaly_detector_arn = "AnomalyDetectorArn",
                    .anomaly_detector_name = "AnomalyDetectorName",
                    .anomaly_detector_description = "AnomalyDetectorDescription",
                    .creation_time = "CreationTime",
                    .last_modification_time = "LastModificationTime",
                    .status = "Status",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_summary_list = "AnomalyDetectorSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_anomaly_group_related_metrics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListAnomalyGroupRelatedMetrics",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnomalyGroupRelatedMetrics",
    Request: type = struct {
        anomaly_detector_arn: []const u8,
        anomaly_group_id: []const u8,
        relationship_type_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .anomaly_group_id = "AnomalyGroupId",
                .relationship_type_filter = "RelationshipTypeFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_anomaly_group_related_metrics) } {
            return .{ .service_metadata = service_metadata, .action = list_anomaly_group_related_metrics };
        }
    },
    Response: type = struct {
        inter_metric_impact_list: ?[]struct {
            metric_name: ?[]const u8 = null,
            anomaly_group_id: ?[]const u8 = null,
            relationship_type: ?[]const u8 = null,
            contribution_percentage: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .metric_name = "MetricName",
                    .anomaly_group_id = "AnomalyGroupId",
                    .relationship_type = "RelationshipType",
                    .contribution_percentage = "ContributionPercentage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inter_metric_impact_list = "InterMetricImpactList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_anomaly_group_summaries: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListAnomalyGroupSummaries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnomalyGroupSummaries",
    Request: type = struct {
        anomaly_detector_arn: []const u8,
        sensitivity_threshold: i64,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .sensitivity_threshold = "SensitivityThreshold",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_anomaly_group_summaries) } {
            return .{ .service_metadata = service_metadata, .action = list_anomaly_group_summaries };
        }
    },
    Response: type = struct {
        anomaly_group_summary_list: ?[]struct {
            start_time: ?[]const u8 = null,
            end_time: ?[]const u8 = null,
            anomaly_group_id: ?[]const u8 = null,
            anomaly_group_score: ?f64 = null,
            primary_metric_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .anomaly_group_id = "AnomalyGroupId",
                    .anomaly_group_score = "AnomalyGroupScore",
                    .primary_metric_name = "PrimaryMetricName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        anomaly_group_statistics: ?struct {
            evaluation_start_date: ?[]const u8 = null,
            total_count: ?i64 = null,
            itemized_metric_stats_list: ?[]struct {
                metric_name: ?[]const u8 = null,
                occurrence_count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metric_name = "MetricName",
                        .occurrence_count = "OccurrenceCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_start_date = "EvaluationStartDate",
                    .total_count = "TotalCount",
                    .itemized_metric_stats_list = "ItemizedMetricStatsList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_group_summary_list = "AnomalyGroupSummaryList",
                .anomaly_group_statistics = "AnomalyGroupStatistics",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_anomaly_group_time_series: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListAnomalyGroupTimeSeries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnomalyGroupTimeSeries",
    Request: type = struct {
        anomaly_detector_arn: []const u8,
        anomaly_group_id: []const u8,
        metric_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .anomaly_group_id = "AnomalyGroupId",
                .metric_name = "MetricName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_anomaly_group_time_series) } {
            return .{ .service_metadata = service_metadata, .action = list_anomaly_group_time_series };
        }
    },
    Response: type = struct {
        anomaly_group_id: ?[]const u8 = null,
        metric_name: ?[]const u8 = null,
        timestamp_list: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        time_series_list: ?[]struct {
            time_series_id: []const u8,
            dimension_list: []struct {
                dimension_name: []const u8,
                dimension_value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .dimension_name = "DimensionName",
                        .dimension_value = "DimensionValue",
                    };
                    return @field(mappings, field_name);
                }
            },
            metric_value_list: []f64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .time_series_id = "TimeSeriesId",
                    .dimension_list = "DimensionList",
                    .metric_value_list = "MetricValueList",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_group_id = "AnomalyGroupId",
                .metric_name = "MetricName",
                .timestamp_list = "TimestampList",
                .next_token = "NextToken",
                .time_series_list = "TimeSeriesList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_metric_sets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListMetricSets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMetricSets",
    Request: type = struct {
        anomaly_detector_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_metric_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_metric_sets };
        }
    },
    Response: type = struct {
        metric_set_summary_list: ?[]struct {
            metric_set_arn: ?[]const u8 = null,
            anomaly_detector_arn: ?[]const u8 = null,
            metric_set_description: ?[]const u8 = null,
            metric_set_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modification_time: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .metric_set_arn = "MetricSetArn",
                    .anomaly_detector_arn = "AnomalyDetectorArn",
                    .metric_set_description = "MetricSetDescription",
                    .metric_set_name = "MetricSetName",
                    .creation_time = "CreationTime",
                    .last_modification_time = "LastModificationTime",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_set_summary_list = "MetricSetSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_feedback: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/PutFeedback",
        .success_code = 200,
    };

    action_name: []const u8 = "PutFeedback",
    Request: type = struct {
        anomaly_detector_arn: []const u8,
        anomaly_group_time_series_feedback: struct {
            anomaly_group_id: []const u8,
            time_series_id: []const u8,
            is_anomaly: bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .anomaly_group_id = "AnomalyGroupId",
                    .time_series_id = "TimeSeriesId",
                    .is_anomaly = "IsAnomaly",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .anomaly_group_time_series_feedback = "AnomalyGroupTimeSeriesFeedback",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_feedback) } {
            return .{ .service_metadata = service_metadata, .action = put_feedback };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_alert: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateAlert",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAlert",
    Request: type = struct {
        alert_arn: []const u8,
        alert_description: ?[]const u8 = null,
        alert_sensitivity_threshold: ?i64 = null,
        action: ?Action = null,
        alert_filters: ?AlertFilters = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alert_arn = "AlertArn",
                .alert_description = "AlertDescription",
                .alert_sensitivity_threshold = "AlertSensitivityThreshold",
                .action = "Action",
                .alert_filters = "AlertFilters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_alert) } {
            return .{ .service_metadata = service_metadata, .action = update_alert };
        }
    },
    Response: type = struct {
        alert_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alert_arn = "AlertArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const update_anomaly_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateAnomalyDetector",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAnomalyDetector",
    Request: type = struct {
        anomaly_detector_arn: []const u8,
        kms_key_arn: ?[]const u8 = null,
        anomaly_detector_description: ?[]const u8 = null,
        anomaly_detector_config: ?AnomalyDetectorConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
                .kms_key_arn = "KmsKeyArn",
                .anomaly_detector_description = "AnomalyDetectorDescription",
                .anomaly_detector_config = "AnomalyDetectorConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_anomaly_detector) } {
            return .{ .service_metadata = service_metadata, .action = update_anomaly_detector };
        }
    },
    Response: type = struct {
        anomaly_detector_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .anomaly_detector_arn = "AnomalyDetectorArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const update_metric_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateMetricSet",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMetricSet",
    Request: type = struct {
        metric_set_arn: []const u8,
        metric_set_description: ?[]const u8 = null,
        metric_list: ?[]Metric = null,
        offset: ?i64 = null,
        timestamp_column: ?TimestampColumn = null,
        dimension_list: ?[][]const u8 = null,
        metric_set_frequency: ?[]const u8 = null,
        metric_source: ?MetricSource = null,
        dimension_filter_list: ?[]MetricSetDimensionFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_set_arn = "MetricSetArn",
                .metric_set_description = "MetricSetDescription",
                .metric_list = "MetricList",
                .offset = "Offset",
                .timestamp_column = "TimestampColumn",
                .dimension_list = "DimensionList",
                .metric_set_frequency = "MetricSetFrequency",
                .metric_source = "MetricSource",
                .dimension_filter_list = "DimensionFilterList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_metric_set) } {
            return .{ .service_metadata = service_metadata, .action = update_metric_set };
        }
    },
    Response: type = struct {
        metric_set_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_set_arn = "MetricSetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        TooManyRequests,
        Validation,
    },
} = .{};

pub const MetricSetDimensionFilter = struct {
    name: ?[]const u8 = null,
    filter_list: ?[]Filter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .filter_list = "FilterList",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    dimension_value: ?[]const u8 = null,
    filter_operation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_value = "DimensionValue",
            .filter_operation = "FilterOperation",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricSource = struct {
    s3_source_config: ?S3SourceConfig = null,
    app_flow_config: ?AppFlowConfig = null,
    cloud_watch_config: ?CloudWatchConfig = null,
    rds_source_config: ?RDSSourceConfig = null,
    redshift_source_config: ?RedshiftSourceConfig = null,
    athena_source_config: ?AthenaSourceConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_source_config = "S3SourceConfig",
            .app_flow_config = "AppFlowConfig",
            .cloud_watch_config = "CloudWatchConfig",
            .rds_source_config = "RDSSourceConfig",
            .redshift_source_config = "RedshiftSourceConfig",
            .athena_source_config = "AthenaSourceConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AthenaSourceConfig = struct {
    role_arn: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    data_catalog: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    work_group_name: ?[]const u8 = null,
    s3_results_path: ?[]const u8 = null,
    back_test_configuration: ?BackTestConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .database_name = "DatabaseName",
            .data_catalog = "DataCatalog",
            .table_name = "TableName",
            .work_group_name = "WorkGroupName",
            .s3_results_path = "S3ResultsPath",
            .back_test_configuration = "BackTestConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const BackTestConfiguration = struct {
    run_back_test_mode: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .run_back_test_mode = "RunBackTestMode",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftSourceConfig = struct {
    cluster_identifier: ?[]const u8 = null,
    database_host: ?[]const u8 = null,
    database_port: ?i64 = null,
    secret_manager_arn: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    vpc_configuration: ?VpcConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_identifier = "ClusterIdentifier",
            .database_host = "DatabaseHost",
            .database_port = "DatabasePort",
            .secret_manager_arn = "SecretManagerArn",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .role_arn = "RoleArn",
            .vpc_configuration = "VpcConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfiguration = struct {
    subnet_id_list: [][]const u8,
    security_group_id_list: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_id_list = "SubnetIdList",
            .security_group_id_list = "SecurityGroupIdList",
        };
        return @field(mappings, field_name);
    }
};

pub const RDSSourceConfig = struct {
    db_instance_identifier: ?[]const u8 = null,
    database_host: ?[]const u8 = null,
    database_port: ?i64 = null,
    secret_manager_arn: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    vpc_configuration: ?VpcConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .db_instance_identifier = "DBInstanceIdentifier",
            .database_host = "DatabaseHost",
            .database_port = "DatabasePort",
            .secret_manager_arn = "SecretManagerArn",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .role_arn = "RoleArn",
            .vpc_configuration = "VpcConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchConfig = struct {
    role_arn: ?[]const u8 = null,
    back_test_configuration: ?BackTestConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .back_test_configuration = "BackTestConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AppFlowConfig = struct {
    role_arn: ?[]const u8 = null,
    flow_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .flow_name = "FlowName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SourceConfig = struct {
    role_arn: ?[]const u8 = null,
    templated_path_list: ?[][]const u8 = null,
    historical_data_path_list: ?[][]const u8 = null,
    file_format_descriptor: ?FileFormatDescriptor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .templated_path_list = "TemplatedPathList",
            .historical_data_path_list = "HistoricalDataPathList",
            .file_format_descriptor = "FileFormatDescriptor",
        };
        return @field(mappings, field_name);
    }
};

pub const FileFormatDescriptor = struct {
    csv_format_descriptor: ?CsvFormatDescriptor = null,
    json_format_descriptor: ?JsonFormatDescriptor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .csv_format_descriptor = "CsvFormatDescriptor",
            .json_format_descriptor = "JsonFormatDescriptor",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonFormatDescriptor = struct {
    file_compression: ?[]const u8 = null,
    charset: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_compression = "FileCompression",
            .charset = "Charset",
        };
        return @field(mappings, field_name);
    }
};

pub const CsvFormatDescriptor = struct {
    file_compression: ?[]const u8 = null,
    charset: ?[]const u8 = null,
    contains_header: ?bool = null,
    delimiter: ?[]const u8 = null,
    header_list: ?[][]const u8 = null,
    quote_symbol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_compression = "FileCompression",
            .charset = "Charset",
            .contains_header = "ContainsHeader",
            .delimiter = "Delimiter",
            .header_list = "HeaderList",
            .quote_symbol = "QuoteSymbol",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestampColumn = struct {
    column_name: ?[]const u8 = null,
    column_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .column_format = "ColumnFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const Metric = struct {
    metric_name: []const u8,
    aggregation_function: []const u8,
    namespace: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .aggregation_function = "AggregationFunction",
            .namespace = "Namespace",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalyDetectorConfig = struct {
    anomaly_detector_frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .anomaly_detector_frequency = "AnomalyDetectorFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const AlertFilters = struct {
    metric_list: ?[][]const u8 = null,
    dimension_filter_list: ?[]DimensionFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_list = "MetricList",
            .dimension_filter_list = "DimensionFilterList",
        };
        return @field(mappings, field_name);
    }
};

pub const DimensionFilter = struct {
    dimension_name: ?[]const u8 = null,
    dimension_value_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_name = "DimensionName",
            .dimension_value_list = "DimensionValueList",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    sns_configuration: ?SNSConfiguration = null,
    lambda_configuration: ?LambdaConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_configuration = "SNSConfiguration",
            .lambda_configuration = "LambdaConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaConfiguration = struct {
    role_arn: []const u8,
    lambda_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .lambda_arn = "LambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SNSConfiguration = struct {
    role_arn: []const u8,
    sns_topic_arn: []const u8,
    sns_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .sns_topic_arn = "SnsTopicArn",
            .sns_format = "SnsFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectedField = struct {
    value: ?AttributeValue = null,
    confidence: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeValue = struct {
    s: ?[]const u8 = null,
    n: ?[]const u8 = null,
    b: ?[]const u8 = null,
    ss: ?[][]const u8 = null,
    ns: ?[][]const u8 = null,
    bs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s = "S",
            .n = "N",
            .b = "B",
            .ss = "SS",
            .ns = "NS",
            .bs = "BS",
        };
        return @field(mappings, field_name);
    }
};
