const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-11-20";
pub const sdk_id: []const u8 = "LookoutVision";
pub const arn_namespace: ?[]const u8 = "lookoutvision";
pub const endpoint_prefix: []const u8 = "lookoutvision";
pub const sigv4_name: []const u8 = "lookoutvision";
pub const name: []const u8 = "LookoutVisionService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-11-20",
    sdk_id: []const u8 = "LookoutVision",
    arn_namespace: ?[]const u8 = "lookoutvision",
    endpoint_prefix: []const u8 = "lookoutvision",
    sigv4_name: []const u8 = "lookoutvision",
    name: []const u8 = "LookoutVisionService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_dataset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-11-20/projects/{ProjectName}/datasets",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateDataset",
    Request: type = struct {
        project_name: []const u8,
        dataset_type: []const u8,
        dataset_source: ?struct {
            ground_truth_manifest: ?struct {
                s3_object: ?struct {
                    bucket: []const u8,
                    key: []const u8,
                    version_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bucket = "Bucket",
                            .key = "Key",
                            .version_id = "VersionId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3_object = "S3Object",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ground_truth_manifest = "GroundTruthManifest",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_token: ?[]const u8 = null,
        pub const http_header = .{
            .client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .dataset_type = "DatasetType",
                .dataset_source = "DatasetSource",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset };
        }
    },
    Response: type = struct {
        dataset_metadata: ?DatasetMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_metadata = "DatasetMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-11-20/projects/{ProjectName}/models",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateModel",
    Request: type = struct {
        project_name: []const u8,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        output_config: OutputConfig,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        pub const http_header = .{
            .client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .description = "Description",
                .client_token = "ClientToken",
                .output_config = "OutputConfig",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model) } {
            return .{ .service_metadata = service_metadata, .action = create_model };
        }
    },
    Response: type = struct {
        model_metadata: ?ModelMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_metadata = "ModelMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_project: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-11-20/projects",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        project_name: []const u8,
        client_token: ?[]const u8 = null,
        pub const http_header = .{
            .client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {
        project_metadata: ?ProjectMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_metadata = "ProjectMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_dataset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-11-20/projects/{ProjectName}/datasets/{DatasetType}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteDataset",
    Request: type = struct {
        project_name: []const u8,
        dataset_type: []const u8,
        client_token: ?[]const u8 = null,
        pub const http_header = .{
            .client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .dataset_type = "DatasetType",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_model: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-11-20/projects/{ProjectName}/models/{ModelVersion}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteModel",
    Request: type = struct {
        project_name: []const u8,
        model_version: []const u8,
        client_token: ?[]const u8 = null,
        pub const http_header = .{
            .client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .model_version = "ModelVersion",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_model };
        }
    },
    Response: type = struct {
        model_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_arn = "ModelArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_project: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-11-20/projects/{ProjectName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        project_name: []const u8,
        client_token: ?[]const u8 = null,
        pub const http_header = .{
            .client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {
        project_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_dataset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-11-20/projects/{ProjectName}/datasets/{DatasetType}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataset",
    Request: type = struct {
        project_name: []const u8,
        dataset_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .dataset_type = "DatasetType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset };
        }
    },
    Response: type = struct {
        dataset_description: ?struct {
            project_name: ?[]const u8 = null,
            dataset_type: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            image_stats: ?struct {
                total: ?i64 = null,
                labeled: ?i64 = null,
                normal: ?i64 = null,
                anomaly: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .total = "Total",
                        .labeled = "Labeled",
                        .normal = "Normal",
                        .anomaly = "Anomaly",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_name = "ProjectName",
                    .dataset_type = "DatasetType",
                    .creation_timestamp = "CreationTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .image_stats = "ImageStats",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_description = "DatasetDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_model: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-11-20/projects/{ProjectName}/models/{ModelVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeModel",
    Request: type = struct {
        project_name: []const u8,
        model_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .model_version = "ModelVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model) } {
            return .{ .service_metadata = service_metadata, .action = describe_model };
        }
    },
    Response: type = struct {
        model_description: ?struct {
            model_version: ?[]const u8 = null,
            model_arn: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            performance: ?ModelPerformance = null,
            output_config: ?OutputConfig = null,
            evaluation_manifest: ?OutputS3Object = null,
            evaluation_result: ?OutputS3Object = null,
            evaluation_end_timestamp: ?i64 = null,
            kms_key_id: ?[]const u8 = null,
            min_inference_units: ?i64 = null,
            max_inference_units: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_version = "ModelVersion",
                    .model_arn = "ModelArn",
                    .creation_timestamp = "CreationTimestamp",
                    .description = "Description",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .performance = "Performance",
                    .output_config = "OutputConfig",
                    .evaluation_manifest = "EvaluationManifest",
                    .evaluation_result = "EvaluationResult",
                    .evaluation_end_timestamp = "EvaluationEndTimestamp",
                    .kms_key_id = "KmsKeyId",
                    .min_inference_units = "MinInferenceUnits",
                    .max_inference_units = "MaxInferenceUnits",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_description = "ModelDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_model_packaging_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-11-20/projects/{ProjectName}/modelpackagingjobs/{JobName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeModelPackagingJob",
    Request: type = struct {
        project_name: []const u8,
        job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model_packaging_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_model_packaging_job };
        }
    },
    Response: type = struct {
        model_packaging_description: ?struct {
            job_name: ?[]const u8 = null,
            project_name: ?[]const u8 = null,
            model_version: ?[]const u8 = null,
            model_packaging_configuration: ?ModelPackagingConfiguration = null,
            model_packaging_job_description: ?[]const u8 = null,
            model_packaging_method: ?[]const u8 = null,
            model_packaging_output_details: ?struct {
                greengrass: ?struct {
                    component_version_arn: ?[]const u8 = null,
                    component_name: ?[]const u8 = null,
                    component_version: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .component_version_arn = "ComponentVersionArn",
                            .component_name = "ComponentName",
                            .component_version = "ComponentVersion",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .greengrass = "Greengrass",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "JobName",
                    .project_name = "ProjectName",
                    .model_version = "ModelVersion",
                    .model_packaging_configuration = "ModelPackagingConfiguration",
                    .model_packaging_job_description = "ModelPackagingJobDescription",
                    .model_packaging_method = "ModelPackagingMethod",
                    .model_packaging_output_details = "ModelPackagingOutputDetails",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .creation_timestamp = "CreationTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_packaging_description = "ModelPackagingDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_project: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-11-20/projects/{ProjectName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProject",
    Request: type = struct {
        project_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_project) } {
            return .{ .service_metadata = service_metadata, .action = describe_project };
        }
    },
    Response: type = struct {
        project_description: ?struct {
            project_arn: ?[]const u8 = null,
            project_name: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            datasets: ?[]DatasetMetadata = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_arn = "ProjectArn",
                    .project_name = "ProjectName",
                    .creation_timestamp = "CreationTimestamp",
                    .datasets = "Datasets",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_description = "ProjectDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const detect_anomalies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-11-20/projects/{ProjectName}/models/{ModelVersion}/detect",
        .success_code = 200,
    };

    action_name: []const u8 = "DetectAnomalies",
    Request: type = struct {
        project_name: []const u8,
        model_version: []const u8,
        body: []const u8,
        content_type: []const u8,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .model_version = "ModelVersion",
                .body = "Body",
                .content_type = "ContentType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_anomalies) } {
            return .{ .service_metadata = service_metadata, .action = detect_anomalies };
        }
    },
    Response: type = struct {
        detect_anomaly_result: ?struct {
            source: ?struct {
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            is_anomalous: ?bool = null,
            confidence: ?f32 = null,
            anomalies: ?[]struct {
                name: ?[]const u8 = null,
                pixel_anomaly: ?struct {
                    total_percentage_area: ?f32 = null,
                    color: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .total_percentage_area = "TotalPercentageArea",
                            .color = "Color",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .pixel_anomaly = "PixelAnomaly",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            anomaly_mask: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source = "Source",
                    .is_anomalous = "IsAnomalous",
                    .confidence = "Confidence",
                    .anomalies = "Anomalies",
                    .anomaly_mask = "AnomalyMask",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detect_anomaly_result = "DetectAnomalyResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_dataset_entries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-11-20/projects/{ProjectName}/datasets/{DatasetType}/entries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDatasetEntries",
    Request: type = struct {
        project_name: []const u8,
        dataset_type: []const u8,
        labeled: ?bool = null,
        anomaly_class: ?[]const u8 = null,
        before_creation_date: ?i64 = null,
        after_creation_date: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        source_ref_contains: ?[]const u8 = null,

        pub const http_query = .{
            .labeled = "labeled",
            .anomaly_class = "anomalyClass",
            .before_creation_date = "createdBefore",
            .after_creation_date = "createdAfter",
            .next_token = "nextToken",
            .max_results = "maxResults",
            .source_ref_contains = "sourceRefContains",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .dataset_type = "DatasetType",
                .labeled = "Labeled",
                .anomaly_class = "AnomalyClass",
                .before_creation_date = "BeforeCreationDate",
                .after_creation_date = "AfterCreationDate",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .source_ref_contains = "SourceRefContains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dataset_entries) } {
            return .{ .service_metadata = service_metadata, .action = list_dataset_entries };
        }
    },
    Response: type = struct {
        dataset_entries: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_entries = "DatasetEntries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_model_packaging_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-11-20/projects/{ProjectName}/modelpackagingjobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListModelPackagingJobs",
    Request: type = struct {
        project_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_model_packaging_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_model_packaging_jobs };
        }
    },
    Response: type = struct {
        model_packaging_jobs: ?[]struct {
            job_name: ?[]const u8 = null,
            project_name: ?[]const u8 = null,
            model_version: ?[]const u8 = null,
            model_packaging_job_description: ?[]const u8 = null,
            model_packaging_method: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "JobName",
                    .project_name = "ProjectName",
                    .model_version = "ModelVersion",
                    .model_packaging_job_description = "ModelPackagingJobDescription",
                    .model_packaging_method = "ModelPackagingMethod",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .creation_timestamp = "CreationTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_packaging_jobs = "ModelPackagingJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_models: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-11-20/projects/{ProjectName}/models",
        .success_code = 200,
    };

    action_name: []const u8 = "ListModels",
    Request: type = struct {
        project_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_models) } {
            return .{ .service_metadata = service_metadata, .action = list_models };
        }
    },
    Response: type = struct {
        models: ?[]ModelMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .models = "Models",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_projects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-11-20/projects",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProjects",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_projects) } {
            return .{ .service_metadata = service_metadata, .action = list_projects };
        }
    },
    Response: type = struct {
        projects: ?[]ProjectMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .projects = "Projects",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-11-20/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-11-20/projects/{ProjectName}/models/{ModelVersion}/start",
        .success_code = 202,
    };

    action_name: []const u8 = "StartModel",
    Request: type = struct {
        project_name: []const u8,
        model_version: []const u8,
        min_inference_units: i64,
        client_token: ?[]const u8 = null,
        max_inference_units: ?i64 = null,
        pub const http_header = .{
            .client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .model_version = "ModelVersion",
                .min_inference_units = "MinInferenceUnits",
                .client_token = "ClientToken",
                .max_inference_units = "MaxInferenceUnits",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_model) } {
            return .{ .service_metadata = service_metadata, .action = start_model };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_model_packaging_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-11-20/projects/{ProjectName}/modelpackagingjobs",
        .success_code = 200,
    };

    action_name: []const u8 = "StartModelPackagingJob",
    Request: type = struct {
        project_name: []const u8,
        model_version: []const u8,
        job_name: ?[]const u8 = null,
        configuration: ModelPackagingConfiguration,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        pub const http_header = .{
            .client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .model_version = "ModelVersion",
                .job_name = "JobName",
                .configuration = "Configuration",
                .description = "Description",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_model_packaging_job) } {
            return .{ .service_metadata = service_metadata, .action = start_model_packaging_job };
        }
    },
    Response: type = struct {
        job_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-11-20/projects/{ProjectName}/models/{ModelVersion}/stop",
        .success_code = 202,
    };

    action_name: []const u8 = "StopModel",
    Request: type = struct {
        project_name: []const u8,
        model_version: []const u8,
        client_token: ?[]const u8 = null,
        pub const http_header = .{
            .client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .model_version = "ModelVersion",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_model) } {
            return .{ .service_metadata = service_metadata, .action = stop_model };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-11-20/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-11-20/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_dataset_entries: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/2020-11-20/projects/{ProjectName}/datasets/{DatasetType}/entries",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateDatasetEntries",
    Request: type = struct {
        project_name: []const u8,
        dataset_type: []const u8,
        changes: []const u8,
        client_token: ?[]const u8 = null,
        pub const http_header = .{
            .client_token = "X-Amzn-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .dataset_type = "DatasetType",
                .changes = "Changes",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dataset_entries) } {
            return .{ .service_metadata = service_metadata, .action = update_dataset_entries };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelPackagingConfiguration = struct {
    greengrass: GreengrassConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .greengrass = "Greengrass",
        };
        return @field(mappings, field_name);
    }
};

pub const GreengrassConfiguration = struct {
    compiler_options: ?[]const u8 = null,
    target_device: ?[]const u8 = null,
    target_platform: ?TargetPlatform = null,
    s3_output_location: S3Location,
    component_name: []const u8,
    component_version: ?[]const u8 = null,
    component_description: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compiler_options = "CompilerOptions",
            .target_device = "TargetDevice",
            .target_platform = "TargetPlatform",
            .s3_output_location = "S3OutputLocation",
            .component_name = "ComponentName",
            .component_version = "ComponentVersion",
            .component_description = "ComponentDescription",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    bucket: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetPlatform = struct {
    os: []const u8,
    arch: []const u8,
    accelerator: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .os = "Os",
            .arch = "Arch",
            .accelerator = "Accelerator",
        };
        return @field(mappings, field_name);
    }
};

pub const ProjectMetadata = struct {
    project_arn: ?[]const u8 = null,
    project_name: ?[]const u8 = null,
    creation_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .project_arn = "ProjectArn",
            .project_name = "ProjectName",
            .creation_timestamp = "CreationTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelMetadata = struct {
    creation_timestamp: ?i64 = null,
    model_version: ?[]const u8 = null,
    model_arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    performance: ?ModelPerformance = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_timestamp = "CreationTimestamp",
            .model_version = "ModelVersion",
            .model_arn = "ModelArn",
            .description = "Description",
            .status = "Status",
            .status_message = "StatusMessage",
            .performance = "Performance",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelPerformance = struct {
    f1_score: ?f32 = null,
    recall: ?f32 = null,
    precision: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .f1_score = "F1Score",
            .recall = "Recall",
            .precision = "Precision",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetMetadata = struct {
    dataset_type: ?[]const u8 = null,
    creation_timestamp: ?i64 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dataset_type = "DatasetType",
            .creation_timestamp = "CreationTimestamp",
            .status = "Status",
            .status_message = "StatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputS3Object = struct {
    bucket: []const u8,
    key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputConfig = struct {
    s3_location: S3Location,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_location = "S3Location",
        };
        return @field(mappings, field_name);
    }
};
