const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2014-12-12";
pub const sdk_id: []const u8 = "Machine Learning";
pub const arn_namespace: ?[]const u8 = "machinelearning";
pub const endpoint_prefix: []const u8 = "machinelearning";
pub const sigv4_name: []const u8 = "machinelearning";
pub const name: []const u8 = "AmazonML_20141212";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2014-12-12",
    sdk_id: []const u8 = "Machine Learning",
    arn_namespace: ?[]const u8 = "machinelearning",
    endpoint_prefix: []const u8 = "machinelearning",
    sigv4_name: []const u8 = "machinelearning",
    name: []const u8 = "AmazonML_20141212",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_tags: struct {
    action_name: []const u8 = "AddTags",
    Request: type = struct {
        tags: []Tag,
        resource_id: []const u8,
        resource_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags) } {
            return .{ .service_metadata = service_metadata, .action = add_tags };
        }
    },
    Response: type = struct {
        resource_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        InvalidTag,
        ResourceNotFound,
        TagLimitExceeded,
    },
} = .{};
pub const create_batch_prediction: struct {
    action_name: []const u8 = "CreateBatchPrediction",
    Request: type = struct {
        batch_prediction_id: []const u8,
        batch_prediction_name: ?[]const u8 = null,
        ml_model_id: []const u8,
        batch_prediction_data_source_id: []const u8,
        output_uri: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_prediction_id = "BatchPredictionId",
                .batch_prediction_name = "BatchPredictionName",
                .ml_model_id = "MLModelId",
                .batch_prediction_data_source_id = "BatchPredictionDataSourceId",
                .output_uri = "OutputUri",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_batch_prediction) } {
            return .{ .service_metadata = service_metadata, .action = create_batch_prediction };
        }
    },
    Response: type = struct {
        batch_prediction_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_prediction_id = "BatchPredictionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidInput,
    },
} = .{};
pub const create_data_source_from_rds: struct {
    action_name: []const u8 = "CreateDataSourceFromRDS",
    Request: type = struct {
        data_source_id: []const u8,
        data_source_name: ?[]const u8 = null,
        rds_data: struct {
            database_information: RDSDatabase,
            select_sql_query: []const u8,
            database_credentials: struct {
                username: []const u8,
                password: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .username = "Username",
                        .password = "Password",
                    };
                    return @field(mappings, field_name);
                }
            },
            s3_staging_location: []const u8,
            data_rearrangement: ?[]const u8 = null,
            data_schema: ?[]const u8 = null,
            data_schema_uri: ?[]const u8 = null,
            resource_role: []const u8,
            service_role: []const u8,
            subnet_id: []const u8,
            security_group_ids: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database_information = "DatabaseInformation",
                    .select_sql_query = "SelectSqlQuery",
                    .database_credentials = "DatabaseCredentials",
                    .s3_staging_location = "S3StagingLocation",
                    .data_rearrangement = "DataRearrangement",
                    .data_schema = "DataSchema",
                    .data_schema_uri = "DataSchemaUri",
                    .resource_role = "ResourceRole",
                    .service_role = "ServiceRole",
                    .subnet_id = "SubnetId",
                    .security_group_ids = "SecurityGroupIds",
                };
                return @field(mappings, field_name);
            }
        },
        role_arn: []const u8,
        compute_statistics: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
                .data_source_name = "DataSourceName",
                .rds_data = "RDSData",
                .role_arn = "RoleARN",
                .compute_statistics = "ComputeStatistics",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_source_from_rds) } {
            return .{ .service_metadata = service_metadata, .action = create_data_source_from_rds };
        }
    },
    Response: type = struct {
        data_source_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidInput,
    },
} = .{};
pub const create_data_source_from_redshift: struct {
    action_name: []const u8 = "CreateDataSourceFromRedshift",
    Request: type = struct {
        data_source_id: []const u8,
        data_source_name: ?[]const u8 = null,
        data_spec: struct {
            database_information: RedshiftDatabase,
            select_sql_query: []const u8,
            database_credentials: struct {
                username: []const u8,
                password: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .username = "Username",
                        .password = "Password",
                    };
                    return @field(mappings, field_name);
                }
            },
            s3_staging_location: []const u8,
            data_rearrangement: ?[]const u8 = null,
            data_schema: ?[]const u8 = null,
            data_schema_uri: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database_information = "DatabaseInformation",
                    .select_sql_query = "SelectSqlQuery",
                    .database_credentials = "DatabaseCredentials",
                    .s3_staging_location = "S3StagingLocation",
                    .data_rearrangement = "DataRearrangement",
                    .data_schema = "DataSchema",
                    .data_schema_uri = "DataSchemaUri",
                };
                return @field(mappings, field_name);
            }
        },
        role_arn: []const u8,
        compute_statistics: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
                .data_source_name = "DataSourceName",
                .data_spec = "DataSpec",
                .role_arn = "RoleARN",
                .compute_statistics = "ComputeStatistics",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_source_from_redshift) } {
            return .{ .service_metadata = service_metadata, .action = create_data_source_from_redshift };
        }
    },
    Response: type = struct {
        data_source_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidInput,
    },
} = .{};
pub const create_data_source_from_s3: struct {
    action_name: []const u8 = "CreateDataSourceFromS3",
    Request: type = struct {
        data_source_id: []const u8,
        data_source_name: ?[]const u8 = null,
        data_spec: struct {
            data_location_s3: []const u8,
            data_rearrangement: ?[]const u8 = null,
            data_schema: ?[]const u8 = null,
            data_schema_location_s3: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_location_s3 = "DataLocationS3",
                    .data_rearrangement = "DataRearrangement",
                    .data_schema = "DataSchema",
                    .data_schema_location_s3 = "DataSchemaLocationS3",
                };
                return @field(mappings, field_name);
            }
        },
        compute_statistics: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
                .data_source_name = "DataSourceName",
                .data_spec = "DataSpec",
                .compute_statistics = "ComputeStatistics",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_source_from_s3) } {
            return .{ .service_metadata = service_metadata, .action = create_data_source_from_s3 };
        }
    },
    Response: type = struct {
        data_source_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidInput,
    },
} = .{};
pub const create_evaluation: struct {
    action_name: []const u8 = "CreateEvaluation",
    Request: type = struct {
        evaluation_id: []const u8,
        evaluation_name: ?[]const u8 = null,
        ml_model_id: []const u8,
        evaluation_data_source_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
                .evaluation_name = "EvaluationName",
                .ml_model_id = "MLModelId",
                .evaluation_data_source_id = "EvaluationDataSourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = create_evaluation };
        }
    },
    Response: type = struct {
        evaluation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidInput,
    },
} = .{};
pub const create_ml_model: struct {
    action_name: []const u8 = "CreateMLModel",
    Request: type = struct {
        ml_model_id: []const u8,
        ml_model_name: ?[]const u8 = null,
        ml_model_type: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        training_data_source_id: []const u8,
        recipe: ?[]const u8 = null,
        recipe_uri: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
                .ml_model_name = "MLModelName",
                .ml_model_type = "MLModelType",
                .parameters = "Parameters",
                .training_data_source_id = "TrainingDataSourceId",
                .recipe = "Recipe",
                .recipe_uri = "RecipeUri",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ml_model) } {
            return .{ .service_metadata = service_metadata, .action = create_ml_model };
        }
    },
    Response: type = struct {
        ml_model_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidInput,
    },
} = .{};
pub const create_realtime_endpoint: struct {
    action_name: []const u8 = "CreateRealtimeEndpoint",
    Request: type = struct {
        ml_model_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_realtime_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_realtime_endpoint };
        }
    },
    Response: type = struct {
        ml_model_id: ?[]const u8 = null,
        realtime_endpoint_info: ?RealtimeEndpointInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
                .realtime_endpoint_info = "RealtimeEndpointInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const delete_batch_prediction: struct {
    action_name: []const u8 = "DeleteBatchPrediction",
    Request: type = struct {
        batch_prediction_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_prediction_id = "BatchPredictionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_batch_prediction) } {
            return .{ .service_metadata = service_metadata, .action = delete_batch_prediction };
        }
    },
    Response: type = struct {
        batch_prediction_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_prediction_id = "BatchPredictionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const delete_data_source: struct {
    action_name: []const u8 = "DeleteDataSource",
    Request: type = struct {
        data_source_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_source) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_source };
        }
    },
    Response: type = struct {
        data_source_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const delete_evaluation: struct {
    action_name: []const u8 = "DeleteEvaluation",
    Request: type = struct {
        evaluation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = delete_evaluation };
        }
    },
    Response: type = struct {
        evaluation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const delete_ml_model: struct {
    action_name: []const u8 = "DeleteMLModel",
    Request: type = struct {
        ml_model_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ml_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_ml_model };
        }
    },
    Response: type = struct {
        ml_model_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const delete_realtime_endpoint: struct {
    action_name: []const u8 = "DeleteRealtimeEndpoint",
    Request: type = struct {
        ml_model_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_realtime_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_realtime_endpoint };
        }
    },
    Response: type = struct {
        ml_model_id: ?[]const u8 = null,
        realtime_endpoint_info: ?RealtimeEndpointInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
                .realtime_endpoint_info = "RealtimeEndpointInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const delete_tags: struct {
    action_name: []const u8 = "DeleteTags",
    Request: type = struct {
        tag_keys: [][]const u8,
        resource_id: []const u8,
        resource_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_keys = "TagKeys",
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tags) } {
            return .{ .service_metadata = service_metadata, .action = delete_tags };
        }
    },
    Response: type = struct {
        resource_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        InvalidTag,
        ResourceNotFound,
    },
} = .{};
pub const describe_batch_predictions: struct {
    action_name: []const u8 = "DescribeBatchPredictions",
    Request: type = struct {
        filter_variable: ?[]const u8 = null,
        eq: ?[]const u8 = null,
        gt: ?[]const u8 = null,
        lt: ?[]const u8 = null,
        ge: ?[]const u8 = null,
        le: ?[]const u8 = null,
        ne: ?[]const u8 = null,
        prefix: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_variable = "FilterVariable",
                .eq = "EQ",
                .gt = "GT",
                .lt = "LT",
                .ge = "GE",
                .le = "LE",
                .ne = "NE",
                .prefix = "Prefix",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_batch_predictions) } {
            return .{ .service_metadata = service_metadata, .action = describe_batch_predictions };
        }
    },
    Response: type = struct {
        results: ?[]struct {
            batch_prediction_id: ?[]const u8 = null,
            ml_model_id: ?[]const u8 = null,
            batch_prediction_data_source_id: ?[]const u8 = null,
            input_data_location_s3: ?[]const u8 = null,
            created_by_iam_user: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            output_uri: ?[]const u8 = null,
            message: ?[]const u8 = null,
            compute_time: ?i64 = null,
            finished_at: ?i64 = null,
            started_at: ?i64 = null,
            total_record_count: ?i64 = null,
            invalid_record_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .batch_prediction_id = "BatchPredictionId",
                    .ml_model_id = "MLModelId",
                    .batch_prediction_data_source_id = "BatchPredictionDataSourceId",
                    .input_data_location_s3 = "InputDataLocationS3",
                    .created_by_iam_user = "CreatedByIamUser",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                    .name = "Name",
                    .status = "Status",
                    .output_uri = "OutputUri",
                    .message = "Message",
                    .compute_time = "ComputeTime",
                    .finished_at = "FinishedAt",
                    .started_at = "StartedAt",
                    .total_record_count = "TotalRecordCount",
                    .invalid_record_count = "InvalidRecordCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
    },
} = .{};
pub const describe_data_sources: struct {
    action_name: []const u8 = "DescribeDataSources",
    Request: type = struct {
        filter_variable: ?[]const u8 = null,
        eq: ?[]const u8 = null,
        gt: ?[]const u8 = null,
        lt: ?[]const u8 = null,
        ge: ?[]const u8 = null,
        le: ?[]const u8 = null,
        ne: ?[]const u8 = null,
        prefix: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_variable = "FilterVariable",
                .eq = "EQ",
                .gt = "GT",
                .lt = "LT",
                .ge = "GE",
                .le = "LE",
                .ne = "NE",
                .prefix = "Prefix",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_sources) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_sources };
        }
    },
    Response: type = struct {
        results: ?[]struct {
            data_source_id: ?[]const u8 = null,
            data_location_s3: ?[]const u8 = null,
            data_rearrangement: ?[]const u8 = null,
            created_by_iam_user: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            data_size_in_bytes: ?i64 = null,
            number_of_files: ?i64 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            message: ?[]const u8 = null,
            redshift_metadata: ?RedshiftMetadata = null,
            rds_metadata: ?RDSMetadata = null,
            role_arn: ?[]const u8 = null,
            compute_statistics: ?bool = null,
            compute_time: ?i64 = null,
            finished_at: ?i64 = null,
            started_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_source_id = "DataSourceId",
                    .data_location_s3 = "DataLocationS3",
                    .data_rearrangement = "DataRearrangement",
                    .created_by_iam_user = "CreatedByIamUser",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                    .data_size_in_bytes = "DataSizeInBytes",
                    .number_of_files = "NumberOfFiles",
                    .name = "Name",
                    .status = "Status",
                    .message = "Message",
                    .redshift_metadata = "RedshiftMetadata",
                    .rds_metadata = "RDSMetadata",
                    .role_arn = "RoleARN",
                    .compute_statistics = "ComputeStatistics",
                    .compute_time = "ComputeTime",
                    .finished_at = "FinishedAt",
                    .started_at = "StartedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
    },
} = .{};
pub const describe_evaluations: struct {
    action_name: []const u8 = "DescribeEvaluations",
    Request: type = struct {
        filter_variable: ?[]const u8 = null,
        eq: ?[]const u8 = null,
        gt: ?[]const u8 = null,
        lt: ?[]const u8 = null,
        ge: ?[]const u8 = null,
        le: ?[]const u8 = null,
        ne: ?[]const u8 = null,
        prefix: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_variable = "FilterVariable",
                .eq = "EQ",
                .gt = "GT",
                .lt = "LT",
                .ge = "GE",
                .le = "LE",
                .ne = "NE",
                .prefix = "Prefix",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_evaluations) } {
            return .{ .service_metadata = service_metadata, .action = describe_evaluations };
        }
    },
    Response: type = struct {
        results: ?[]struct {
            evaluation_id: ?[]const u8 = null,
            ml_model_id: ?[]const u8 = null,
            evaluation_data_source_id: ?[]const u8 = null,
            input_data_location_s3: ?[]const u8 = null,
            created_by_iam_user: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            performance_metrics: ?PerformanceMetrics = null,
            message: ?[]const u8 = null,
            compute_time: ?i64 = null,
            finished_at: ?i64 = null,
            started_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_id = "EvaluationId",
                    .ml_model_id = "MLModelId",
                    .evaluation_data_source_id = "EvaluationDataSourceId",
                    .input_data_location_s3 = "InputDataLocationS3",
                    .created_by_iam_user = "CreatedByIamUser",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                    .name = "Name",
                    .status = "Status",
                    .performance_metrics = "PerformanceMetrics",
                    .message = "Message",
                    .compute_time = "ComputeTime",
                    .finished_at = "FinishedAt",
                    .started_at = "StartedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
    },
} = .{};
pub const describe_ml_models: struct {
    action_name: []const u8 = "DescribeMLModels",
    Request: type = struct {
        filter_variable: ?[]const u8 = null,
        eq: ?[]const u8 = null,
        gt: ?[]const u8 = null,
        lt: ?[]const u8 = null,
        ge: ?[]const u8 = null,
        le: ?[]const u8 = null,
        ne: ?[]const u8 = null,
        prefix: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_variable = "FilterVariable",
                .eq = "EQ",
                .gt = "GT",
                .lt = "LT",
                .ge = "GE",
                .le = "LE",
                .ne = "NE",
                .prefix = "Prefix",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ml_models) } {
            return .{ .service_metadata = service_metadata, .action = describe_ml_models };
        }
    },
    Response: type = struct {
        results: ?[]struct {
            ml_model_id: ?[]const u8 = null,
            training_data_source_id: ?[]const u8 = null,
            created_by_iam_user: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            size_in_bytes: ?i64 = null,
            endpoint_info: ?RealtimeEndpointInfo = null,
            training_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            input_data_location_s3: ?[]const u8 = null,
            algorithm: ?[]const u8 = null,
            ml_model_type: ?[]const u8 = null,
            score_threshold: ?f32 = null,
            score_threshold_last_updated_at: ?i64 = null,
            message: ?[]const u8 = null,
            compute_time: ?i64 = null,
            finished_at: ?i64 = null,
            started_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ml_model_id = "MLModelId",
                    .training_data_source_id = "TrainingDataSourceId",
                    .created_by_iam_user = "CreatedByIamUser",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                    .name = "Name",
                    .status = "Status",
                    .size_in_bytes = "SizeInBytes",
                    .endpoint_info = "EndpointInfo",
                    .training_parameters = "TrainingParameters",
                    .input_data_location_s3 = "InputDataLocationS3",
                    .algorithm = "Algorithm",
                    .ml_model_type = "MLModelType",
                    .score_threshold = "ScoreThreshold",
                    .score_threshold_last_updated_at = "ScoreThresholdLastUpdatedAt",
                    .message = "Message",
                    .compute_time = "ComputeTime",
                    .finished_at = "FinishedAt",
                    .started_at = "StartedAt",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "training_parameters", field_name))
                    return try serializeMap(self.training_parameters, self.fieldNameFor("training_parameters"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
    },
} = .{};
pub const describe_tags: struct {
    action_name: []const u8 = "DescribeTags",
    Request: type = struct {
        resource_id: []const u8,
        resource_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tags) } {
            return .{ .service_metadata = service_metadata, .action = describe_tags };
        }
    },
    Response: type = struct {
        resource_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const get_batch_prediction: struct {
    action_name: []const u8 = "GetBatchPrediction",
    Request: type = struct {
        batch_prediction_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_prediction_id = "BatchPredictionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_batch_prediction) } {
            return .{ .service_metadata = service_metadata, .action = get_batch_prediction };
        }
    },
    Response: type = struct {
        batch_prediction_id: ?[]const u8 = null,
        ml_model_id: ?[]const u8 = null,
        batch_prediction_data_source_id: ?[]const u8 = null,
        input_data_location_s3: ?[]const u8 = null,
        created_by_iam_user: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        output_uri: ?[]const u8 = null,
        log_uri: ?[]const u8 = null,
        message: ?[]const u8 = null,
        compute_time: ?i64 = null,
        finished_at: ?i64 = null,
        started_at: ?i64 = null,
        total_record_count: ?i64 = null,
        invalid_record_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_prediction_id = "BatchPredictionId",
                .ml_model_id = "MLModelId",
                .batch_prediction_data_source_id = "BatchPredictionDataSourceId",
                .input_data_location_s3 = "InputDataLocationS3",
                .created_by_iam_user = "CreatedByIamUser",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .name = "Name",
                .status = "Status",
                .output_uri = "OutputUri",
                .log_uri = "LogUri",
                .message = "Message",
                .compute_time = "ComputeTime",
                .finished_at = "FinishedAt",
                .started_at = "StartedAt",
                .total_record_count = "TotalRecordCount",
                .invalid_record_count = "InvalidRecordCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const get_data_source: struct {
    action_name: []const u8 = "GetDataSource",
    Request: type = struct {
        data_source_id: []const u8,
        verbose: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
                .verbose = "Verbose",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_source) } {
            return .{ .service_metadata = service_metadata, .action = get_data_source };
        }
    },
    Response: type = struct {
        data_source_id: ?[]const u8 = null,
        data_location_s3: ?[]const u8 = null,
        data_rearrangement: ?[]const u8 = null,
        created_by_iam_user: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        data_size_in_bytes: ?i64 = null,
        number_of_files: ?i64 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        log_uri: ?[]const u8 = null,
        message: ?[]const u8 = null,
        redshift_metadata: ?RedshiftMetadata = null,
        rds_metadata: ?RDSMetadata = null,
        role_arn: ?[]const u8 = null,
        compute_statistics: ?bool = null,
        compute_time: ?i64 = null,
        finished_at: ?i64 = null,
        started_at: ?i64 = null,
        data_source_schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
                .data_location_s3 = "DataLocationS3",
                .data_rearrangement = "DataRearrangement",
                .created_by_iam_user = "CreatedByIamUser",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .data_size_in_bytes = "DataSizeInBytes",
                .number_of_files = "NumberOfFiles",
                .name = "Name",
                .status = "Status",
                .log_uri = "LogUri",
                .message = "Message",
                .redshift_metadata = "RedshiftMetadata",
                .rds_metadata = "RDSMetadata",
                .role_arn = "RoleARN",
                .compute_statistics = "ComputeStatistics",
                .compute_time = "ComputeTime",
                .finished_at = "FinishedAt",
                .started_at = "StartedAt",
                .data_source_schema = "DataSourceSchema",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const get_evaluation: struct {
    action_name: []const u8 = "GetEvaluation",
    Request: type = struct {
        evaluation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = get_evaluation };
        }
    },
    Response: type = struct {
        evaluation_id: ?[]const u8 = null,
        ml_model_id: ?[]const u8 = null,
        evaluation_data_source_id: ?[]const u8 = null,
        input_data_location_s3: ?[]const u8 = null,
        created_by_iam_user: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        performance_metrics: ?PerformanceMetrics = null,
        log_uri: ?[]const u8 = null,
        message: ?[]const u8 = null,
        compute_time: ?i64 = null,
        finished_at: ?i64 = null,
        started_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
                .ml_model_id = "MLModelId",
                .evaluation_data_source_id = "EvaluationDataSourceId",
                .input_data_location_s3 = "InputDataLocationS3",
                .created_by_iam_user = "CreatedByIamUser",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .name = "Name",
                .status = "Status",
                .performance_metrics = "PerformanceMetrics",
                .log_uri = "LogUri",
                .message = "Message",
                .compute_time = "ComputeTime",
                .finished_at = "FinishedAt",
                .started_at = "StartedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const get_ml_model: struct {
    action_name: []const u8 = "GetMLModel",
    Request: type = struct {
        ml_model_id: []const u8,
        verbose: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
                .verbose = "Verbose",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_model) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_model };
        }
    },
    Response: type = struct {
        ml_model_id: ?[]const u8 = null,
        training_data_source_id: ?[]const u8 = null,
        created_by_iam_user: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        size_in_bytes: ?i64 = null,
        endpoint_info: ?RealtimeEndpointInfo = null,
        training_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        input_data_location_s3: ?[]const u8 = null,
        ml_model_type: ?[]const u8 = null,
        score_threshold: ?f32 = null,
        score_threshold_last_updated_at: ?i64 = null,
        log_uri: ?[]const u8 = null,
        message: ?[]const u8 = null,
        compute_time: ?i64 = null,
        finished_at: ?i64 = null,
        started_at: ?i64 = null,
        recipe: ?[]const u8 = null,
        schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
                .training_data_source_id = "TrainingDataSourceId",
                .created_by_iam_user = "CreatedByIamUser",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .name = "Name",
                .status = "Status",
                .size_in_bytes = "SizeInBytes",
                .endpoint_info = "EndpointInfo",
                .training_parameters = "TrainingParameters",
                .input_data_location_s3 = "InputDataLocationS3",
                .ml_model_type = "MLModelType",
                .score_threshold = "ScoreThreshold",
                .score_threshold_last_updated_at = "ScoreThresholdLastUpdatedAt",
                .log_uri = "LogUri",
                .message = "Message",
                .compute_time = "ComputeTime",
                .finished_at = "FinishedAt",
                .started_at = "StartedAt",
                .recipe = "Recipe",
                .schema = "Schema",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "training_parameters", field_name))
                return try serializeMap(self.training_parameters, self.fieldNameFor("training_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const predict: struct {
    action_name: []const u8 = "Predict",
    Request: type = struct {
        ml_model_id: []const u8,
        record: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        predict_endpoint: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
                .record = "Record",
                .predict_endpoint = "PredictEndpoint",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "record", field_name))
                return try serializeMap(self.record, self.fieldNameFor("record"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(predict) } {
            return .{ .service_metadata = service_metadata, .action = predict };
        }
    },
    Response: type = struct {
        prediction: ?struct {
            predicted_label: ?[]const u8 = null,
            predicted_value: ?f32 = null,
            predicted_scores: ?[]struct {
                key: ?[]const u8 = null,
                value: ?f32 = null,
            } = null,
            details: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .predicted_label = "predictedLabel",
                    .predicted_value = "predictedValue",
                    .predicted_scores = "predictedScores",
                    .details = "details",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "predicted_scores", field_name))
                    return try serializeMap(self.predicted_scores, self.fieldNameFor("predicted_scores"), options, out_stream);
                if (std.mem.eql(u8, "details", field_name))
                    return try serializeMap(self.details, self.fieldNameFor("details"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prediction = "Prediction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        LimitExceeded,
        PredictorNotMounted,
        ResourceNotFound,
    },
} = .{};
pub const update_batch_prediction: struct {
    action_name: []const u8 = "UpdateBatchPrediction",
    Request: type = struct {
        batch_prediction_id: []const u8,
        batch_prediction_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_prediction_id = "BatchPredictionId",
                .batch_prediction_name = "BatchPredictionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_batch_prediction) } {
            return .{ .service_metadata = service_metadata, .action = update_batch_prediction };
        }
    },
    Response: type = struct {
        batch_prediction_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_prediction_id = "BatchPredictionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const update_data_source: struct {
    action_name: []const u8 = "UpdateDataSource",
    Request: type = struct {
        data_source_id: []const u8,
        data_source_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
                .data_source_name = "DataSourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_source) } {
            return .{ .service_metadata = service_metadata, .action = update_data_source };
        }
    },
    Response: type = struct {
        data_source_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const update_evaluation: struct {
    action_name: []const u8 = "UpdateEvaluation",
    Request: type = struct {
        evaluation_id: []const u8,
        evaluation_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
                .evaluation_name = "EvaluationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = update_evaluation };
        }
    },
    Response: type = struct {
        evaluation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const update_ml_model: struct {
    action_name: []const u8 = "UpdateMLModel",
    Request: type = struct {
        ml_model_id: []const u8,
        ml_model_name: ?[]const u8 = null,
        score_threshold: ?f32 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
                .ml_model_name = "MLModelName",
                .score_threshold = "ScoreThreshold",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ml_model) } {
            return .{ .service_metadata = service_metadata, .action = update_ml_model };
        }
    },
    Response: type = struct {
        ml_model_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ml_model_id = "MLModelId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidInput,
        ResourceNotFound,
    },
} = .{};

pub const RealtimeEndpointInfo = struct {
    peak_requests_per_second: ?i64 = null,
    created_at: ?i64 = null,
    endpoint_url: ?[]const u8 = null,
    endpoint_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .peak_requests_per_second = "PeakRequestsPerSecond",
            .created_at = "CreatedAt",
            .endpoint_url = "EndpointUrl",
            .endpoint_status = "EndpointStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const PerformanceMetrics = struct {
    properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .properties = "Properties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "properties", field_name))
            return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
        return false;
    }
};

pub const RDSMetadata = struct {
    database: ?RDSDatabase = null,
    database_user_name: ?[]const u8 = null,
    select_sql_query: ?[]const u8 = null,
    resource_role: ?[]const u8 = null,
    service_role: ?[]const u8 = null,
    data_pipeline_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database = "Database",
            .database_user_name = "DatabaseUserName",
            .select_sql_query = "SelectSqlQuery",
            .resource_role = "ResourceRole",
            .service_role = "ServiceRole",
            .data_pipeline_id = "DataPipelineId",
        };
        return @field(mappings, field_name);
    }
};

pub const RDSDatabase = struct {
    instance_identifier: []const u8,
    database_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_identifier = "InstanceIdentifier",
            .database_name = "DatabaseName",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftMetadata = struct {
    redshift_database: ?RedshiftDatabase = null,
    database_user_name: ?[]const u8 = null,
    select_sql_query: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .redshift_database = "RedshiftDatabase",
            .database_user_name = "DatabaseUserName",
            .select_sql_query = "SelectSqlQuery",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftDatabase = struct {
    database_name: []const u8,
    cluster_identifier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .cluster_identifier = "ClusterIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
