const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-01-01";
pub const sdk_id: []const u8 = "Macie2";
pub const arn_namespace: ?[]const u8 = "macie2";
pub const endpoint_prefix: []const u8 = "macie2";
pub const sigv4_name: []const u8 = "macie2";
pub const name: []const u8 = "Macie2";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-01-01",
    sdk_id: []const u8 = "Macie2",
    arn_namespace: ?[]const u8 = "macie2",
    endpoint_prefix: []const u8 = "macie2",
    sigv4_name: []const u8 = "macie2",
    name: []const u8 = "Macie2",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_invitation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitations/accept",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptInvitation",
    Request: type = struct {
        administrator_account_id: ?[]const u8 = null,
        invitation_id: []const u8,
        master_account: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .administrator_account_id = "administratorAccountId",
                .invitation_id = "invitationId",
                .master_account = "masterAccount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_invitation) } {
            return .{ .service_metadata = service_metadata, .action = accept_invitation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_get_custom_data_identifiers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/custom-data-identifiers/get",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetCustomDataIdentifiers",
    Request: type = struct {
        ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_custom_data_identifiers) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_custom_data_identifiers };
        }
    },
    Response: type = struct {
        custom_data_identifiers: ?[]struct {
            arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            deleted: ?bool = null,
            description: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .created_at = "createdAt",
                    .deleted = "deleted",
                    .description = "description",
                    .id = "id",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        not_found_identifier_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_data_identifiers = "customDataIdentifiers",
                .not_found_identifier_ids = "notFoundIdentifierIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_allow_list: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/allow-lists",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAllowList",
    Request: type = struct {
        client_token: []const u8,
        criteria: AllowListCriteria,
        description: ?[]const u8 = null,
        name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .criteria = "criteria",
                .description = "description",
                .name = "name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_allow_list) } {
            return .{ .service_metadata = service_metadata, .action = create_allow_list };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_classification_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateClassificationJob",
    Request: type = struct {
        allow_list_ids: ?[][]const u8 = null,
        client_token: []const u8,
        custom_data_identifier_ids: ?[][]const u8 = null,
        description: ?[]const u8 = null,
        initial_run: ?bool = null,
        job_type: []const u8,
        managed_data_identifier_ids: ?[][]const u8 = null,
        managed_data_identifier_selector: ?[]const u8 = null,
        name: []const u8,
        s3_job_definition: S3JobDefinition,
        sampling_percentage: ?i64 = null,
        schedule_frequency: ?JobScheduleFrequency = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allow_list_ids = "allowListIds",
                .client_token = "clientToken",
                .custom_data_identifier_ids = "customDataIdentifierIds",
                .description = "description",
                .initial_run = "initialRun",
                .job_type = "jobType",
                .managed_data_identifier_ids = "managedDataIdentifierIds",
                .managed_data_identifier_selector = "managedDataIdentifierSelector",
                .name = "name",
                .s3_job_definition = "s3JobDefinition",
                .sampling_percentage = "samplingPercentage",
                .schedule_frequency = "scheduleFrequency",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_classification_job) } {
            return .{ .service_metadata = service_metadata, .action = create_classification_job };
        }
    },
    Response: type = struct {
        job_arn: ?[]const u8 = null,
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_arn = "jobArn",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_custom_data_identifier: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/custom-data-identifiers",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCustomDataIdentifier",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        ignore_words: ?[][]const u8 = null,
        keywords: ?[][]const u8 = null,
        maximum_match_distance: ?i64 = null,
        name: []const u8,
        regex: []const u8,
        severity_levels: ?[]SeverityLevel = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .description = "description",
                .ignore_words = "ignoreWords",
                .keywords = "keywords",
                .maximum_match_distance = "maximumMatchDistance",
                .name = "name",
                .regex = "regex",
                .severity_levels = "severityLevels",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_data_identifier) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_data_identifier };
        }
    },
    Response: type = struct {
        custom_data_identifier_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_data_identifier_id = "customDataIdentifierId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_findings_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findingsfilters",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFindingsFilter",
    Request: type = struct {
        action: []const u8,
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        finding_criteria: FindingCriteria,
        name: []const u8,
        position: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "action",
                .client_token = "clientToken",
                .description = "description",
                .finding_criteria = "findingCriteria",
                .name = "name",
                .position = "position",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_findings_filter) } {
            return .{ .service_metadata = service_metadata, .action = create_findings_filter };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateInvitations",
    Request: type = struct {
        account_ids: [][]const u8,
        disable_email_notification: ?bool = null,
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .disable_email_notification = "disableEmailNotification",
                .message = "message",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_invitations) } {
            return .{ .service_metadata = service_metadata, .action = create_invitations };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]UnprocessedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_member: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMember",
    Request: type = struct {
        account: struct {
            account_id: []const u8,
            email: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .email = "email",
                };
                return @field(mappings, field_name);
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account = "account",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_member) } {
            return .{ .service_metadata = service_metadata, .action = create_member };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_sample_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings/sample",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSampleFindings",
    Request: type = struct {
        finding_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_types = "findingTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sample_findings) } {
            return .{ .service_metadata = service_metadata, .action = create_sample_findings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const decline_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitations/decline",
        .success_code = 200,
    };

    action_name: []const u8 = "DeclineInvitations",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decline_invitations) } {
            return .{ .service_metadata = service_metadata, .action = decline_invitations };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]UnprocessedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_allow_list: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/allow-lists/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAllowList",
    Request: type = struct {
        id: []const u8,
        ignore_job_checks: ?[]const u8 = null,

        pub const http_query = .{
            .ignore_job_checks = "ignoreJobChecks",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .ignore_job_checks = "ignoreJobChecks",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_allow_list) } {
            return .{ .service_metadata = service_metadata, .action = delete_allow_list };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_custom_data_identifier: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/custom-data-identifiers/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCustomDataIdentifier",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_data_identifier) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_data_identifier };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_findings_filter: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/findingsfilters/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFindingsFilter",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_findings_filter) } {
            return .{ .service_metadata = service_metadata, .action = delete_findings_filter };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/invitations/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInvitations",
    Request: type = struct {
        account_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_invitations) } {
            return .{ .service_metadata = service_metadata, .action = delete_invitations };
        }
    },
    Response: type = struct {
        unprocessed_accounts: ?[]UnprocessedAccount = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_accounts = "unprocessedAccounts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_member: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/members/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMember",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_member) } {
            return .{ .service_metadata = service_metadata, .action = delete_member };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_buckets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasources/s3",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBuckets",
    Request: type = struct {
        criteria: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                eq: ?[][]const u8 = null,
                gt: ?i64 = null,
                gte: ?i64 = null,
                lt: ?i64 = null,
                lte: ?i64 = null,
                neq: ?[][]const u8 = null,
                prefix: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .eq = "eq",
                        .gt = "gt",
                        .gte = "gte",
                        .lt = "lt",
                        .lte = "lte",
                        .neq = "neq",
                        .prefix = "prefix",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_criteria: ?struct {
            attribute_name: ?[]const u8 = null,
            order_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_name = "attributeName",
                    .order_by = "orderBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .criteria = "criteria",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .sort_criteria = "sortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "criteria", field_name))
                return try serializeMap(self.criteria, self.fieldNameFor("criteria"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_buckets) } {
            return .{ .service_metadata = service_metadata, .action = describe_buckets };
        }
    },
    Response: type = struct {
        buckets: ?[]struct {
            account_id: ?[]const u8 = null,
            allows_unencrypted_object_uploads: ?[]const u8 = null,
            bucket_arn: ?[]const u8 = null,
            bucket_created_at: ?i64 = null,
            bucket_name: ?[]const u8 = null,
            classifiable_object_count: ?i64 = null,
            classifiable_size_in_bytes: ?i64 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            job_details: ?JobDetails = null,
            last_automated_discovery_time: ?i64 = null,
            last_updated: ?i64 = null,
            object_count: ?i64 = null,
            object_count_by_encryption_type: ?ObjectCountByEncryptionType = null,
            public_access: ?BucketPublicAccess = null,
            region: ?[]const u8 = null,
            replication_details: ?struct {
                replicated: ?bool = null,
                replicated_externally: ?bool = null,
                replication_accounts: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .replicated = "replicated",
                        .replicated_externally = "replicatedExternally",
                        .replication_accounts = "replicationAccounts",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            sensitivity_score: ?i64 = null,
            server_side_encryption: ?struct {
                kms_master_key_id: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .kms_master_key_id = "kmsMasterKeyId",
                        .type = "type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            shared_access: ?[]const u8 = null,
            size_in_bytes: ?i64 = null,
            size_in_bytes_compressed: ?i64 = null,
            tags: ?[]KeyValuePair = null,
            unclassifiable_object_count: ?ObjectLevelStatistics = null,
            unclassifiable_object_size_in_bytes: ?ObjectLevelStatistics = null,
            versioning: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .allows_unencrypted_object_uploads = "allowsUnencryptedObjectUploads",
                    .bucket_arn = "bucketArn",
                    .bucket_created_at = "bucketCreatedAt",
                    .bucket_name = "bucketName",
                    .classifiable_object_count = "classifiableObjectCount",
                    .classifiable_size_in_bytes = "classifiableSizeInBytes",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                    .job_details = "jobDetails",
                    .last_automated_discovery_time = "lastAutomatedDiscoveryTime",
                    .last_updated = "lastUpdated",
                    .object_count = "objectCount",
                    .object_count_by_encryption_type = "objectCountByEncryptionType",
                    .public_access = "publicAccess",
                    .region = "region",
                    .replication_details = "replicationDetails",
                    .sensitivity_score = "sensitivityScore",
                    .server_side_encryption = "serverSideEncryption",
                    .shared_access = "sharedAccess",
                    .size_in_bytes = "sizeInBytes",
                    .size_in_bytes_compressed = "sizeInBytesCompressed",
                    .tags = "tags",
                    .unclassifiable_object_count = "unclassifiableObjectCount",
                    .unclassifiable_object_size_in_bytes = "unclassifiableObjectSizeInBytes",
                    .versioning = "versioning",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .buckets = "buckets",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_classification_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeClassificationJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_classification_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_classification_job };
        }
    },
    Response: type = struct {
        allow_list_ids: ?[][]const u8 = null,
        client_token: ?[]const u8 = null,
        created_at: ?i64 = null,
        custom_data_identifier_ids: ?[][]const u8 = null,
        description: ?[]const u8 = null,
        initial_run: ?bool = null,
        job_arn: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        job_status: ?[]const u8 = null,
        job_type: ?[]const u8 = null,
        last_run_error_status: ?LastRunErrorStatus = null,
        last_run_time: ?i64 = null,
        managed_data_identifier_ids: ?[][]const u8 = null,
        managed_data_identifier_selector: ?[]const u8 = null,
        name: ?[]const u8 = null,
        s3_job_definition: ?S3JobDefinition = null,
        sampling_percentage: ?i64 = null,
        schedule_frequency: ?JobScheduleFrequency = null,
        statistics: ?struct {
            approximate_number_of_objects_to_process: ?f64 = null,
            number_of_runs: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .approximate_number_of_objects_to_process = "approximateNumberOfObjectsToProcess",
                    .number_of_runs = "numberOfRuns",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        user_paused_details: ?UserPausedDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allow_list_ids = "allowListIds",
                .client_token = "clientToken",
                .created_at = "createdAt",
                .custom_data_identifier_ids = "customDataIdentifierIds",
                .description = "description",
                .initial_run = "initialRun",
                .job_arn = "jobArn",
                .job_id = "jobId",
                .job_status = "jobStatus",
                .job_type = "jobType",
                .last_run_error_status = "lastRunErrorStatus",
                .last_run_time = "lastRunTime",
                .managed_data_identifier_ids = "managedDataIdentifierIds",
                .managed_data_identifier_selector = "managedDataIdentifierSelector",
                .name = "name",
                .s3_job_definition = "s3JobDefinition",
                .sampling_percentage = "samplingPercentage",
                .schedule_frequency = "scheduleFrequency",
                .statistics = "statistics",
                .tags = "tags",
                .user_paused_details = "userPausedDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_organization_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/admin/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOrganizationConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization_configuration };
        }
    },
    Response: type = struct {
        auto_enable: ?bool = null,
        max_account_limit_reached: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "autoEnable",
                .max_account_limit_reached = "maxAccountLimitReached",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const disable_macie: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/macie",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableMacie",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_macie) } {
            return .{ .service_metadata = service_metadata, .action = disable_macie };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const disable_organization_admin_account: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/admin",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableOrganizationAdminAccount",
    Request: type = struct {
        admin_account_id: []const u8,

        pub const http_query = .{
            .admin_account_id = "adminAccountId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "adminAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = disable_organization_admin_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_from_administrator_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/administrator/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateFromAdministratorAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_from_administrator_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_from_administrator_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_from_master_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/master/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateFromMasterAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_from_master_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_from_master_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_member: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/members/disassociate/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateMember",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_member) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_member };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const enable_macie: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/macie",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableMacie",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        finding_publishing_frequency: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .finding_publishing_frequency = "findingPublishingFrequency",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_macie) } {
            return .{ .service_metadata = service_metadata, .action = enable_macie };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const enable_organization_admin_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/admin",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableOrganizationAdminAccount",
    Request: type = struct {
        admin_account_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_account_id = "adminAccountId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_organization_admin_account) } {
            return .{ .service_metadata = service_metadata, .action = enable_organization_admin_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_administrator_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/administrator",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAdministratorAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_administrator_account) } {
            return .{ .service_metadata = service_metadata, .action = get_administrator_account };
        }
    },
    Response: type = struct {
        administrator: ?Invitation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .administrator = "administrator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_allow_list: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/allow-lists/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAllowList",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_allow_list) } {
            return .{ .service_metadata = service_metadata, .action = get_allow_list };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        criteria: ?AllowListCriteria = null,
        description: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        status: ?struct {
            code: []const u8,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code = "code",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created_at = "createdAt",
                .criteria = "criteria",
                .description = "description",
                .id = "id",
                .name = "name",
                .status = "status",
                .tags = "tags",
                .updated_at = "updatedAt",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_automated_discovery_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/automated-discovery/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAutomatedDiscoveryConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_automated_discovery_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_automated_discovery_configuration };
        }
    },
    Response: type = struct {
        classification_scope_id: ?[]const u8 = null,
        disabled_at: ?i64 = null,
        first_enabled_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        sensitivity_inspection_template_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .classification_scope_id = "classificationScopeId",
                .disabled_at = "disabledAt",
                .first_enabled_at = "firstEnabledAt",
                .last_updated_at = "lastUpdatedAt",
                .sensitivity_inspection_template_id = "sensitivityInspectionTemplateId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_bucket_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasources/s3/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketStatistics",
    Request: type = struct {
        account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_statistics };
        }
    },
    Response: type = struct {
        bucket_count: ?i64 = null,
        bucket_count_by_effective_permission: ?struct {
            publicly_accessible: ?i64 = null,
            publicly_readable: ?i64 = null,
            publicly_writable: ?i64 = null,
            unknown: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .publicly_accessible = "publiclyAccessible",
                    .publicly_readable = "publiclyReadable",
                    .publicly_writable = "publiclyWritable",
                    .unknown = "unknown",
                };
                return @field(mappings, field_name);
            }
        } = null,
        bucket_count_by_encryption_type: ?struct {
            kms_managed: ?i64 = null,
            s3_managed: ?i64 = null,
            unencrypted: ?i64 = null,
            unknown: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .kms_managed = "kmsManaged",
                    .s3_managed = "s3Managed",
                    .unencrypted = "unencrypted",
                    .unknown = "unknown",
                };
                return @field(mappings, field_name);
            }
        } = null,
        bucket_count_by_object_encryption_requirement: ?struct {
            allows_unencrypted_object_uploads: ?i64 = null,
            denies_unencrypted_object_uploads: ?i64 = null,
            unknown: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .allows_unencrypted_object_uploads = "allowsUnencryptedObjectUploads",
                    .denies_unencrypted_object_uploads = "deniesUnencryptedObjectUploads",
                    .unknown = "unknown",
                };
                return @field(mappings, field_name);
            }
        } = null,
        bucket_count_by_shared_access_type: ?struct {
            external: ?i64 = null,
            internal: ?i64 = null,
            not_shared: ?i64 = null,
            unknown: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .external = "external",
                    .internal = "internal",
                    .not_shared = "notShared",
                    .unknown = "unknown",
                };
                return @field(mappings, field_name);
            }
        } = null,
        bucket_statistics_by_sensitivity: ?struct {
            classification_error: ?SensitivityAggregations = null,
            not_classified: ?SensitivityAggregations = null,
            not_sensitive: ?SensitivityAggregations = null,
            sensitive: ?SensitivityAggregations = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .classification_error = "classificationError",
                    .not_classified = "notClassified",
                    .not_sensitive = "notSensitive",
                    .sensitive = "sensitive",
                };
                return @field(mappings, field_name);
            }
        } = null,
        classifiable_object_count: ?i64 = null,
        classifiable_size_in_bytes: ?i64 = null,
        last_updated: ?i64 = null,
        object_count: ?i64 = null,
        size_in_bytes: ?i64 = null,
        size_in_bytes_compressed: ?i64 = null,
        unclassifiable_object_count: ?ObjectLevelStatistics = null,
        unclassifiable_object_size_in_bytes: ?ObjectLevelStatistics = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket_count = "bucketCount",
                .bucket_count_by_effective_permission = "bucketCountByEffectivePermission",
                .bucket_count_by_encryption_type = "bucketCountByEncryptionType",
                .bucket_count_by_object_encryption_requirement = "bucketCountByObjectEncryptionRequirement",
                .bucket_count_by_shared_access_type = "bucketCountBySharedAccessType",
                .bucket_statistics_by_sensitivity = "bucketStatisticsBySensitivity",
                .classifiable_object_count = "classifiableObjectCount",
                .classifiable_size_in_bytes = "classifiableSizeInBytes",
                .last_updated = "lastUpdated",
                .object_count = "objectCount",
                .size_in_bytes = "sizeInBytes",
                .size_in_bytes_compressed = "sizeInBytesCompressed",
                .unclassifiable_object_count = "unclassifiableObjectCount",
                .unclassifiable_object_size_in_bytes = "unclassifiableObjectSizeInBytes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_classification_export_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/classification-export-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetClassificationExportConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_classification_export_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_classification_export_configuration };
        }
    },
    Response: type = struct {
        configuration: ?ClassificationExportConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "configuration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_classification_scope: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/classification-scopes/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetClassificationScope",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_classification_scope) } {
            return .{ .service_metadata = service_metadata, .action = get_classification_scope };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        s3: ?struct {
            excludes: struct {
                bucket_names: [][]const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bucket_names = "bucketNames",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .excludes = "excludes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .s3 = "s3",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_custom_data_identifier: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/custom-data-identifiers/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCustomDataIdentifier",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_custom_data_identifier) } {
            return .{ .service_metadata = service_metadata, .action = get_custom_data_identifier };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        deleted: ?bool = null,
        description: ?[]const u8 = null,
        id: ?[]const u8 = null,
        ignore_words: ?[][]const u8 = null,
        keywords: ?[][]const u8 = null,
        maximum_match_distance: ?i64 = null,
        name: ?[]const u8 = null,
        regex: ?[]const u8 = null,
        severity_levels: ?[]SeverityLevel = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created_at = "createdAt",
                .deleted = "deleted",
                .description = "description",
                .id = "id",
                .ignore_words = "ignoreWords",
                .keywords = "keywords",
                .maximum_match_distance = "maximumMatchDistance",
                .name = "name",
                .regex = "regex",
                .severity_levels = "severityLevels",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings/describe",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindings",
    Request: type = struct {
        finding_ids: [][]const u8,
        sort_criteria: ?SortCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_ids = "findingIds",
                .sort_criteria = "sortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_findings) } {
            return .{ .service_metadata = service_metadata, .action = get_findings };
        }
    },
    Response: type = struct {
        findings: ?[]struct {
            account_id: ?[]const u8 = null,
            archived: ?bool = null,
            category: ?[]const u8 = null,
            classification_details: ?struct {
                detailed_results_location: ?[]const u8 = null,
                job_arn: ?[]const u8 = null,
                job_id: ?[]const u8 = null,
                origin_type: ?[]const u8 = null,
                result: ?struct {
                    additional_occurrences: ?bool = null,
                    custom_data_identifiers: ?struct {
                        detections: ?[]struct {
                            arn: ?[]const u8 = null,
                            count: ?i64 = null,
                            name: ?[]const u8 = null,
                            occurrences: ?Occurrences = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .arn = "arn",
                                    .count = "count",
                                    .name = "name",
                                    .occurrences = "occurrences",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        total_count: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .detections = "detections",
                                .total_count = "totalCount",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    mime_type: ?[]const u8 = null,
                    sensitive_data: ?[]struct {
                        category: ?[]const u8 = null,
                        detections: ?[]struct {
                            count: ?i64 = null,
                            occurrences: ?Occurrences = null,
                            type: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .count = "count",
                                    .occurrences = "occurrences",
                                    .type = "type",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        total_count: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .category = "category",
                                .detections = "detections",
                                .total_count = "totalCount",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    size_classified: ?i64 = null,
                    status: ?struct {
                        code: ?[]const u8 = null,
                        reason: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .code = "code",
                                .reason = "reason",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .additional_occurrences = "additionalOccurrences",
                            .custom_data_identifiers = "customDataIdentifiers",
                            .mime_type = "mimeType",
                            .sensitive_data = "sensitiveData",
                            .size_classified = "sizeClassified",
                            .status = "status",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .detailed_results_location = "detailedResultsLocation",
                        .job_arn = "jobArn",
                        .job_id = "jobId",
                        .origin_type = "originType",
                        .result = "result",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            count: ?i64 = null,
            created_at: ?i64 = null,
            description: ?[]const u8 = null,
            id: ?[]const u8 = null,
            partition: ?[]const u8 = null,
            policy_details: ?struct {
                action: ?struct {
                    action_type: ?[]const u8 = null,
                    api_call_details: ?struct {
                        api: ?[]const u8 = null,
                        api_service_name: ?[]const u8 = null,
                        first_seen: ?i64 = null,
                        last_seen: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .api = "api",
                                .api_service_name = "apiServiceName",
                                .first_seen = "firstSeen",
                                .last_seen = "lastSeen",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .action_type = "actionType",
                            .api_call_details = "apiCallDetails",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                actor: ?struct {
                    domain_details: ?struct {
                        domain_name: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .domain_name = "domainName",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    ip_address_details: ?struct {
                        ip_address_v4: ?[]const u8 = null,
                        ip_city: ?struct {
                            name: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .name = "name",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        ip_country: ?struct {
                            code: ?[]const u8 = null,
                            name: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .code = "code",
                                    .name = "name",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        ip_geo_location: ?struct {
                            lat: ?f64 = null,
                            lon: ?f64 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .lat = "lat",
                                    .lon = "lon",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        ip_owner: ?struct {
                            asn: ?[]const u8 = null,
                            asn_org: ?[]const u8 = null,
                            isp: ?[]const u8 = null,
                            org: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .asn = "asn",
                                    .asn_org = "asnOrg",
                                    .isp = "isp",
                                    .org = "org",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .ip_address_v4 = "ipAddressV4",
                                .ip_city = "ipCity",
                                .ip_country = "ipCountry",
                                .ip_geo_location = "ipGeoLocation",
                                .ip_owner = "ipOwner",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    user_identity: ?struct {
                        assumed_role: ?struct {
                            access_key_id: ?[]const u8 = null,
                            account_id: ?[]const u8 = null,
                            arn: ?[]const u8 = null,
                            principal_id: ?[]const u8 = null,
                            session_context: ?SessionContext = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .access_key_id = "accessKeyId",
                                    .account_id = "accountId",
                                    .arn = "arn",
                                    .principal_id = "principalId",
                                    .session_context = "sessionContext",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        aws_account: ?struct {
                            account_id: ?[]const u8 = null,
                            principal_id: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .account_id = "accountId",
                                    .principal_id = "principalId",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        aws_service: ?struct {
                            invoked_by: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .invoked_by = "invokedBy",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        federated_user: ?struct {
                            access_key_id: ?[]const u8 = null,
                            account_id: ?[]const u8 = null,
                            arn: ?[]const u8 = null,
                            principal_id: ?[]const u8 = null,
                            session_context: ?SessionContext = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .access_key_id = "accessKeyId",
                                    .account_id = "accountId",
                                    .arn = "arn",
                                    .principal_id = "principalId",
                                    .session_context = "sessionContext",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        iam_user: ?struct {
                            account_id: ?[]const u8 = null,
                            arn: ?[]const u8 = null,
                            principal_id: ?[]const u8 = null,
                            user_name: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .account_id = "accountId",
                                    .arn = "arn",
                                    .principal_id = "principalId",
                                    .user_name = "userName",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        root: ?struct {
                            account_id: ?[]const u8 = null,
                            arn: ?[]const u8 = null,
                            principal_id: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .account_id = "accountId",
                                    .arn = "arn",
                                    .principal_id = "principalId",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        type: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .assumed_role = "assumedRole",
                                .aws_account = "awsAccount",
                                .aws_service = "awsService",
                                .federated_user = "federatedUser",
                                .iam_user = "iamUser",
                                .root = "root",
                                .type = "type",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .domain_details = "domainDetails",
                            .ip_address_details = "ipAddressDetails",
                            .user_identity = "userIdentity",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action = "action",
                        .actor = "actor",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            region: ?[]const u8 = null,
            resources_affected: ?struct {
                s3_bucket: ?struct {
                    allows_unencrypted_object_uploads: ?[]const u8 = null,
                    arn: ?[]const u8 = null,
                    created_at: ?i64 = null,
                    default_server_side_encryption: ?ServerSideEncryption = null,
                    name: ?[]const u8 = null,
                    owner: ?struct {
                        display_name: ?[]const u8 = null,
                        id: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .display_name = "displayName",
                                .id = "id",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    public_access: ?BucketPublicAccess = null,
                    tags: ?[]KeyValuePair = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .allows_unencrypted_object_uploads = "allowsUnencryptedObjectUploads",
                            .arn = "arn",
                            .created_at = "createdAt",
                            .default_server_side_encryption = "defaultServerSideEncryption",
                            .name = "name",
                            .owner = "owner",
                            .public_access = "publicAccess",
                            .tags = "tags",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                s3_object: ?struct {
                    bucket_arn: ?[]const u8 = null,
                    e_tag: ?[]const u8 = null,
                    extension: ?[]const u8 = null,
                    key: ?[]const u8 = null,
                    last_modified: ?i64 = null,
                    path: ?[]const u8 = null,
                    public_access: ?bool = null,
                    server_side_encryption: ?ServerSideEncryption = null,
                    size: ?i64 = null,
                    storage_class: ?[]const u8 = null,
                    tags: ?[]KeyValuePair = null,
                    version_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bucket_arn = "bucketArn",
                            .e_tag = "eTag",
                            .extension = "extension",
                            .key = "key",
                            .last_modified = "lastModified",
                            .path = "path",
                            .public_access = "publicAccess",
                            .server_side_encryption = "serverSideEncryption",
                            .size = "size",
                            .storage_class = "storageClass",
                            .tags = "tags",
                            .version_id = "versionId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3_bucket = "s3Bucket",
                        .s3_object = "s3Object",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            sample: ?bool = null,
            schema_version: ?[]const u8 = null,
            severity: ?struct {
                description: ?[]const u8 = null,
                score: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .description = "description",
                        .score = "score",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            title: ?[]const u8 = null,
            type: ?[]const u8 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .archived = "archived",
                    .category = "category",
                    .classification_details = "classificationDetails",
                    .count = "count",
                    .created_at = "createdAt",
                    .description = "description",
                    .id = "id",
                    .partition = "partition",
                    .policy_details = "policyDetails",
                    .region = "region",
                    .resources_affected = "resourcesAffected",
                    .sample = "sample",
                    .schema_version = "schemaVersion",
                    .severity = "severity",
                    .title = "title",
                    .type = "type",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_findings_filter: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/findingsfilters/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindingsFilter",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_findings_filter) } {
            return .{ .service_metadata = service_metadata, .action = get_findings_filter };
        }
    },
    Response: type = struct {
        action: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        finding_criteria: ?FindingCriteria = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        position: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "action",
                .arn = "arn",
                .description = "description",
                .finding_criteria = "findingCriteria",
                .id = "id",
                .name = "name",
                .position = "position",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_findings_publication_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/findings-publication-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindingsPublicationConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_findings_publication_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_findings_publication_configuration };
        }
    },
    Response: type = struct {
        security_hub_configuration: ?SecurityHubConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_hub_configuration = "securityHubConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_finding_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFindingStatistics",
    Request: type = struct {
        finding_criteria: ?FindingCriteria = null,
        group_by: []const u8,
        size: ?i64 = null,
        sort_criteria: ?struct {
            attribute_name: ?[]const u8 = null,
            order_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_name = "attributeName",
                    .order_by = "orderBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_criteria = "findingCriteria",
                .group_by = "groupBy",
                .size = "size",
                .sort_criteria = "sortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_finding_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_finding_statistics };
        }
    },
    Response: type = struct {
        counts_by_group: ?[]struct {
            count: ?i64 = null,
            group_key: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .count = "count",
                    .group_key = "groupKey",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .counts_by_group = "countsByGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_invitations_count: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/invitations/count",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInvitationsCount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_invitations_count) } {
            return .{ .service_metadata = service_metadata, .action = get_invitations_count };
        }
    },
    Response: type = struct {
        invitations_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitations_count = "invitationsCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_macie_session: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/macie",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMacieSession",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_macie_session) } {
            return .{ .service_metadata = service_metadata, .action = get_macie_session };
        }
    },
    Response: type = struct {
        created_at: ?i64 = null,
        finding_publishing_frequency: ?[]const u8 = null,
        service_role: ?[]const u8 = null,
        status: ?[]const u8 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_at = "createdAt",
                .finding_publishing_frequency = "findingPublishingFrequency",
                .service_role = "serviceRole",
                .status = "status",
                .updated_at = "updatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_master_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/master",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMasterAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_master_account) } {
            return .{ .service_metadata = service_metadata, .action = get_master_account };
        }
    },
    Response: type = struct {
        master: ?Invitation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .master = "master",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_member: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/members/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMember",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_member) } {
            return .{ .service_metadata = service_metadata, .action = get_member };
        }
    },
    Response: type = struct {
        account_id: ?[]const u8 = null,
        administrator_account_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        email: ?[]const u8 = null,
        invited_at: ?i64 = null,
        master_account_id: ?[]const u8 = null,
        relationship_status: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
                .administrator_account_id = "administratorAccountId",
                .arn = "arn",
                .email = "email",
                .invited_at = "invitedAt",
                .master_account_id = "masterAccountId",
                .relationship_status = "relationshipStatus",
                .tags = "tags",
                .updated_at = "updatedAt",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resource-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceProfile",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_profile };
        }
    },
    Response: type = struct {
        profile_updated_at: ?i64 = null,
        sensitivity_score: ?i64 = null,
        sensitivity_score_overridden: ?bool = null,
        statistics: ?struct {
            total_bytes_classified: ?i64 = null,
            total_detections: ?i64 = null,
            total_detections_suppressed: ?i64 = null,
            total_items_classified: ?i64 = null,
            total_items_sensitive: ?i64 = null,
            total_items_skipped: ?i64 = null,
            total_items_skipped_invalid_encryption: ?i64 = null,
            total_items_skipped_invalid_kms: ?i64 = null,
            total_items_skipped_permission_denied: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .total_bytes_classified = "totalBytesClassified",
                    .total_detections = "totalDetections",
                    .total_detections_suppressed = "totalDetectionsSuppressed",
                    .total_items_classified = "totalItemsClassified",
                    .total_items_sensitive = "totalItemsSensitive",
                    .total_items_skipped = "totalItemsSkipped",
                    .total_items_skipped_invalid_encryption = "totalItemsSkippedInvalidEncryption",
                    .total_items_skipped_invalid_kms = "totalItemsSkippedInvalidKms",
                    .total_items_skipped_permission_denied = "totalItemsSkippedPermissionDenied",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_updated_at = "profileUpdatedAt",
                .sensitivity_score = "sensitivityScore",
                .sensitivity_score_overridden = "sensitivityScoreOverridden",
                .statistics = "statistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_reveal_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/reveal-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRevealConfiguration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_reveal_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_reveal_configuration };
        }
    },
    Response: type = struct {
        configuration: ?RevealConfiguration = null,
        retrieval_configuration: ?RetrievalConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "configuration",
                .retrieval_configuration = "retrievalConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sensitive_data_occurrences: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/findings/{findingId}/reveal",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSensitiveDataOccurrences",
    Request: type = struct {
        finding_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_id = "findingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sensitive_data_occurrences) } {
            return .{ .service_metadata = service_metadata, .action = get_sensitive_data_occurrences };
        }
    },
    Response: type = struct {
        @"error": ?[]const u8 = null,
        sensitive_data_occurrences: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .@"error" = "error",
                .sensitive_data_occurrences = "sensitiveDataOccurrences",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "sensitive_data_occurrences", field_name))
                return try serializeMap(self.sensitive_data_occurrences, self.fieldNameFor("sensitive_data_occurrences"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        UnprocessableEntity,
    },
} = .{};
pub const get_sensitive_data_occurrences_availability: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/findings/{findingId}/reveal/availability",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSensitiveDataOccurrencesAvailability",
    Request: type = struct {
        finding_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_id = "findingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sensitive_data_occurrences_availability) } {
            return .{ .service_metadata = service_metadata, .action = get_sensitive_data_occurrences_availability };
        }
    },
    Response: type = struct {
        code: ?[]const u8 = null,
        reasons: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code = "code",
                .reasons = "reasons",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_sensitivity_inspection_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/templates/sensitivity-inspections/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSensitivityInspectionTemplate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sensitivity_inspection_template) } {
            return .{ .service_metadata = service_metadata, .action = get_sensitivity_inspection_template };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        excludes: ?SensitivityInspectionTemplateExcludes = null,
        includes: ?SensitivityInspectionTemplateIncludes = null,
        name: ?[]const u8 = null,
        sensitivity_inspection_template_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .excludes = "excludes",
                .includes = "includes",
                .name = "name",
                .sensitivity_inspection_template_id = "sensitivityInspectionTemplateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_usage_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/usage/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUsageStatistics",
    Request: type = struct {
        filter_by: ?[]struct {
            comparator: ?[]const u8 = null,
            key: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .comparator = "comparator",
                    .key = "key",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?struct {
            key: ?[]const u8 = null,
            order_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .order_by = "orderBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        time_range: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_by = "filterBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .sort_by = "sortBy",
                .time_range = "timeRange",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_usage_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_usage_statistics };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        records: ?[]struct {
            account_id: ?[]const u8 = null,
            automated_discovery_free_trial_start_date: ?i64 = null,
            free_trial_start_date: ?i64 = null,
            usage: ?[]struct {
                currency: ?[]const u8 = null,
                estimated_cost: ?[]const u8 = null,
                service_limit: ?struct {
                    is_service_limited: ?bool = null,
                    unit: ?[]const u8 = null,
                    value: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .is_service_limited = "isServiceLimited",
                            .unit = "unit",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .currency = "currency",
                        .estimated_cost = "estimatedCost",
                        .service_limit = "serviceLimit",
                        .type = "type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .automated_discovery_free_trial_start_date = "automatedDiscoveryFreeTrialStartDate",
                    .free_trial_start_date = "freeTrialStartDate",
                    .usage = "usage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        time_range: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .records = "records",
                .time_range = "timeRange",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_usage_totals: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/usage",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUsageTotals",
    Request: type = struct {
        time_range: ?[]const u8 = null,

        pub const http_query = .{
            .time_range = "timeRange",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_range = "timeRange",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_usage_totals) } {
            return .{ .service_metadata = service_metadata, .action = get_usage_totals };
        }
    },
    Response: type = struct {
        time_range: ?[]const u8 = null,
        usage_totals: ?[]struct {
            currency: ?[]const u8 = null,
            estimated_cost: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .currency = "currency",
                    .estimated_cost = "estimatedCost",
                    .type = "type",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_range = "timeRange",
                .usage_totals = "usageTotals",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_allow_lists: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/allow-lists",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAllowLists",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_allow_lists) } {
            return .{ .service_metadata = service_metadata, .action = list_allow_lists };
        }
    },
    Response: type = struct {
        allow_lists: ?[]struct {
            arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            description: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .created_at = "createdAt",
                    .description = "description",
                    .id = "id",
                    .name = "name",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .allow_lists = "allowLists",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_classification_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/jobs/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListClassificationJobs",
    Request: type = struct {
        filter_criteria: ?struct {
            excludes: ?[]ListJobsFilterTerm = null,
            includes: ?[]ListJobsFilterTerm = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .excludes = "excludes",
                    .includes = "includes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_criteria: ?struct {
            attribute_name: ?[]const u8 = null,
            order_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_name = "attributeName",
                    .order_by = "orderBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_criteria = "filterCriteria",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .sort_criteria = "sortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_classification_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_classification_jobs };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            bucket_criteria: ?S3BucketCriteriaForJob = null,
            bucket_definitions: ?[]S3BucketDefinitionForJob = null,
            created_at: ?i64 = null,
            job_id: ?[]const u8 = null,
            job_status: ?[]const u8 = null,
            job_type: ?[]const u8 = null,
            last_run_error_status: ?LastRunErrorStatus = null,
            name: ?[]const u8 = null,
            user_paused_details: ?UserPausedDetails = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bucket_criteria = "bucketCriteria",
                    .bucket_definitions = "bucketDefinitions",
                    .created_at = "createdAt",
                    .job_id = "jobId",
                    .job_status = "jobStatus",
                    .job_type = "jobType",
                    .last_run_error_status = "lastRunErrorStatus",
                    .name = "name",
                    .user_paused_details = "userPausedDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_classification_scopes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/classification-scopes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListClassificationScopes",
    Request: type = struct {
        name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .name = "name",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_classification_scopes) } {
            return .{ .service_metadata = service_metadata, .action = list_classification_scopes };
        }
    },
    Response: type = struct {
        classification_scopes: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .classification_scopes = "classificationScopes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_custom_data_identifiers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/custom-data-identifiers/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCustomDataIdentifiers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_data_identifiers) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_data_identifiers };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            description: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .created_at = "createdAt",
                    .description = "description",
                    .id = "id",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/findings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFindings",
    Request: type = struct {
        finding_criteria: ?FindingCriteria = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_criteria: ?SortCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_criteria = "findingCriteria",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .sort_criteria = "sortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_findings) } {
            return .{ .service_metadata = service_metadata, .action = list_findings };
        }
    },
    Response: type = struct {
        finding_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_ids = "findingIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_findings_filters: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/findingsfilters",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFindingsFilters",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_findings_filters) } {
            return .{ .service_metadata = service_metadata, .action = list_findings_filters };
        }
    },
    Response: type = struct {
        findings_filter_list_items: ?[]struct {
            action: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "action",
                    .arn = "arn",
                    .id = "id",
                    .name = "name",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings_filter_list_items = "findingsFilterListItems",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_invitations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/invitations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInvitations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_invitations) } {
            return .{ .service_metadata = service_metadata, .action = list_invitations };
        }
    },
    Response: type = struct {
        invitations: ?[]Invitation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitations = "invitations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_managed_data_identifiers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/managed-data-identifiers/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListManagedDataIdentifiers",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_managed_data_identifiers) } {
            return .{ .service_metadata = service_metadata, .action = list_managed_data_identifiers };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            category: ?[]const u8 = null,
            id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .category = "category",
                    .id = "id",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "items",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_members: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/members",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMembers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        only_associated: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .only_associated = "onlyAssociated",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .only_associated = "onlyAssociated",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_members) } {
            return .{ .service_metadata = service_metadata, .action = list_members };
        }
    },
    Response: type = struct {
        members: ?[]struct {
            account_id: ?[]const u8 = null,
            administrator_account_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            email: ?[]const u8 = null,
            invited_at: ?i64 = null,
            master_account_id: ?[]const u8 = null,
            relationship_status: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .administrator_account_id = "administratorAccountId",
                    .arn = "arn",
                    .email = "email",
                    .invited_at = "invitedAt",
                    .master_account_id = "masterAccountId",
                    .relationship_status = "relationshipStatus",
                    .tags = "tags",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "members",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_organization_admin_accounts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/admin",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrganizationAdminAccounts",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_admin_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_admin_accounts };
        }
    },
    Response: type = struct {
        admin_accounts: ?[]struct {
            account_id: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_accounts = "adminAccounts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_resource_profile_artifacts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resource-profiles/artifacts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResourceProfileArtifacts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        resource_arn: []const u8,

        pub const http_query = .{
            .next_token = "nextToken",
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_profile_artifacts) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_profile_artifacts };
        }
    },
    Response: type = struct {
        artifacts: ?[]struct {
            arn: []const u8,
            classification_result_status: []const u8,
            sensitive: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .classification_result_status = "classificationResultStatus",
                    .sensitive = "sensitive",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifacts = "artifacts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_resource_profile_detections: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resource-profiles/detections",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResourceProfileDetections",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        resource_arn: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_profile_detections) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_profile_detections };
        }
    },
    Response: type = struct {
        detections: ?[]struct {
            arn: ?[]const u8 = null,
            count: ?i64 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            suppressed: ?bool = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .count = "count",
                    .id = "id",
                    .name = "name",
                    .suppressed = "suppressed",
                    .type = "type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detections = "detections",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_sensitivity_inspection_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/templates/sensitivity-inspections",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSensitivityInspectionTemplates",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sensitivity_inspection_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_sensitivity_inspection_templates };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        sensitivity_inspection_templates: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .sensitivity_inspection_templates = "sensitivityInspectionTemplates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const put_classification_export_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/classification-export-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutClassificationExportConfiguration",
    Request: type = struct {
        configuration: ClassificationExportConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_classification_export_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_classification_export_configuration };
        }
    },
    Response: type = struct {
        configuration: ?ClassificationExportConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "configuration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const put_findings_publication_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/findings-publication-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutFindingsPublicationConfiguration",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        security_hub_configuration: ?SecurityHubConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .security_hub_configuration = "securityHubConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_findings_publication_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_findings_publication_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const search_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datasources/search-resources",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchResources",
    Request: type = struct {
        bucket_criteria: ?struct {
            excludes: ?SearchResourcesCriteriaBlock = null,
            includes: ?SearchResourcesCriteriaBlock = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .excludes = "excludes",
                    .includes = "includes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_criteria: ?struct {
            attribute_name: ?[]const u8 = null,
            order_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_name = "attributeName",
                    .order_by = "orderBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket_criteria = "bucketCriteria",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .sort_criteria = "sortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_resources) } {
            return .{ .service_metadata = service_metadata, .action = search_resources };
        }
    },
    Response: type = struct {
        matching_resources: ?[]struct {
            matching_bucket: ?struct {
                account_id: ?[]const u8 = null,
                bucket_name: ?[]const u8 = null,
                classifiable_object_count: ?i64 = null,
                classifiable_size_in_bytes: ?i64 = null,
                error_code: ?[]const u8 = null,
                error_message: ?[]const u8 = null,
                job_details: ?JobDetails = null,
                last_automated_discovery_time: ?i64 = null,
                object_count: ?i64 = null,
                object_count_by_encryption_type: ?ObjectCountByEncryptionType = null,
                sensitivity_score: ?i64 = null,
                size_in_bytes: ?i64 = null,
                size_in_bytes_compressed: ?i64 = null,
                unclassifiable_object_count: ?ObjectLevelStatistics = null,
                unclassifiable_object_size_in_bytes: ?ObjectLevelStatistics = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .account_id = "accountId",
                        .bucket_name = "bucketName",
                        .classifiable_object_count = "classifiableObjectCount",
                        .classifiable_size_in_bytes = "classifiableSizeInBytes",
                        .error_code = "errorCode",
                        .error_message = "errorMessage",
                        .job_details = "jobDetails",
                        .last_automated_discovery_time = "lastAutomatedDiscoveryTime",
                        .object_count = "objectCount",
                        .object_count_by_encryption_type = "objectCountByEncryptionType",
                        .sensitivity_score = "sensitivityScore",
                        .size_in_bytes = "sizeInBytes",
                        .size_in_bytes_compressed = "sizeInBytesCompressed",
                        .unclassifiable_object_count = "unclassifiableObjectCount",
                        .unclassifiable_object_size_in_bytes = "unclassifiableObjectSizeInBytes",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .matching_bucket = "matchingBucket",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .matching_resources = "matchingResources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const test_custom_data_identifier: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/custom-data-identifiers/test",
        .success_code = 200,
    };

    action_name: []const u8 = "TestCustomDataIdentifier",
    Request: type = struct {
        ignore_words: ?[][]const u8 = null,
        keywords: ?[][]const u8 = null,
        maximum_match_distance: ?i64 = null,
        regex: []const u8,
        sample_text: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ignore_words = "ignoreWords",
                .keywords = "keywords",
                .maximum_match_distance = "maximumMatchDistance",
                .regex = "regex",
                .sample_text = "sampleText",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_custom_data_identifier) } {
            return .{ .service_metadata = service_metadata, .action = test_custom_data_identifier };
        }
    },
    Response: type = struct {
        match_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .match_count = "matchCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_allow_list: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/allow-lists/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAllowList",
    Request: type = struct {
        criteria: AllowListCriteria,
        description: ?[]const u8 = null,
        id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .criteria = "criteria",
                .description = "description",
                .id = "id",
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_allow_list) } {
            return .{ .service_metadata = service_metadata, .action = update_allow_list };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_automated_discovery_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/automated-discovery/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAutomatedDiscoveryConfiguration",
    Request: type = struct {
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_automated_discovery_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_automated_discovery_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_classification_job: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateClassificationJob",
    Request: type = struct {
        job_id: []const u8,
        job_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .job_status = "jobStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_classification_job) } {
            return .{ .service_metadata = service_metadata, .action = update_classification_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_classification_scope: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/classification-scopes/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateClassificationScope",
    Request: type = struct {
        id: []const u8,
        s3: ?struct {
            excludes: struct {
                bucket_names: [][]const u8,
                operation: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bucket_names = "bucketNames",
                        .operation = "operation",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .excludes = "excludes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .s3 = "s3",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_classification_scope) } {
            return .{ .service_metadata = service_metadata, .action = update_classification_scope };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_findings_filter: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/findingsfilters/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFindingsFilter",
    Request: type = struct {
        action: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        finding_criteria: ?FindingCriteria = null,
        id: []const u8,
        name: ?[]const u8 = null,
        position: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "action",
                .client_token = "clientToken",
                .description = "description",
                .finding_criteria = "findingCriteria",
                .id = "id",
                .name = "name",
                .position = "position",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_findings_filter) } {
            return .{ .service_metadata = service_metadata, .action = update_findings_filter };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_macie_session: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/macie",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMacieSession",
    Request: type = struct {
        finding_publishing_frequency: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .finding_publishing_frequency = "findingPublishingFrequency",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_macie_session) } {
            return .{ .service_metadata = service_metadata, .action = update_macie_session };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_member_session: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/macie/members/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMemberSession",
    Request: type = struct {
        id: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_member_session) } {
            return .{ .service_metadata = service_metadata, .action = update_member_session };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_organization_configuration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/admin/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOrganizationConfiguration",
    Request: type = struct {
        auto_enable: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_enable = "autoEnable",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_organization_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_organization_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_resource_profile: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/resource-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResourceProfile",
    Request: type = struct {
        resource_arn: []const u8,
        sensitivity_score_override: ?i64 = null,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .sensitivity_score_override = "sensitivityScoreOverride",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_resource_profile_detections: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/resource-profiles/detections",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResourceProfileDetections",
    Request: type = struct {
        resource_arn: []const u8,
        suppress_data_identifiers: ?[]struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .type = "type",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .suppress_data_identifiers = "suppressDataIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_profile_detections) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_profile_detections };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_reveal_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/reveal-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRevealConfiguration",
    Request: type = struct {
        configuration: RevealConfiguration,
        retrieval_configuration: ?struct {
            retrieval_mode: []const u8,
            role_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .retrieval_mode = "retrievalMode",
                    .role_name = "roleName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "configuration",
                .retrieval_configuration = "retrievalConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_reveal_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_reveal_configuration };
        }
    },
    Response: type = struct {
        configuration: ?RevealConfiguration = null,
        retrieval_configuration: ?RetrievalConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "configuration",
                .retrieval_configuration = "retrievalConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_sensitivity_inspection_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/templates/sensitivity-inspections/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSensitivityInspectionTemplate",
    Request: type = struct {
        description: ?[]const u8 = null,
        excludes: ?SensitivityInspectionTemplateExcludes = null,
        id: []const u8,
        includes: ?SensitivityInspectionTemplateIncludes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .excludes = "excludes",
                .id = "id",
                .includes = "includes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sensitivity_inspection_template) } {
            return .{ .service_metadata = service_metadata, .action = update_sensitivity_inspection_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const SensitivityInspectionTemplateIncludes = struct {
    allow_list_ids: ?[][]const u8 = null,
    custom_data_identifier_ids: ?[][]const u8 = null,
    managed_data_identifier_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_list_ids = "allowListIds",
            .custom_data_identifier_ids = "customDataIdentifierIds",
            .managed_data_identifier_ids = "managedDataIdentifierIds",
        };
        return @field(mappings, field_name);
    }
};

pub const SensitivityInspectionTemplateExcludes = struct {
    managed_data_identifier_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .managed_data_identifier_ids = "managedDataIdentifierIds",
        };
        return @field(mappings, field_name);
    }
};

pub const RetrievalConfiguration = struct {
    external_id: ?[]const u8 = null,
    retrieval_mode: []const u8,
    role_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_id = "externalId",
            .retrieval_mode = "retrievalMode",
            .role_name = "roleName",
        };
        return @field(mappings, field_name);
    }
};

pub const RevealConfiguration = struct {
    kms_key_id: ?[]const u8 = null,
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "kmsKeyId",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const FindingCriteria = struct {
    criterion: ?[]struct {
        key: ?[]const u8 = null,
        value: ?CriterionAdditionalProperties = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .criterion = "criterion",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "criterion", field_name))
            return try serializeMap(self.criterion, self.fieldNameFor("criterion"), options, out_stream);
        return false;
    }
};

pub const CriterionAdditionalProperties = struct {
    eq: ?[][]const u8 = null,
    eq_exact_match: ?[][]const u8 = null,
    gt: ?i64 = null,
    gte: ?i64 = null,
    lt: ?i64 = null,
    lte: ?i64 = null,
    neq: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .eq = "eq",
            .eq_exact_match = "eqExactMatch",
            .gt = "gt",
            .gte = "gte",
            .lt = "lt",
            .lte = "lte",
            .neq = "neq",
        };
        return @field(mappings, field_name);
    }
};

pub const AllowListCriteria = struct {
    regex: ?[]const u8 = null,
    s3_words_list: ?S3WordsList = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .regex = "regex",
            .s3_words_list = "s3WordsList",
        };
        return @field(mappings, field_name);
    }
};

pub const S3WordsList = struct {
    bucket_name: []const u8,
    object_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .object_key = "objectKey",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLevelStatistics = struct {
    file_type: ?i64 = null,
    storage_class: ?i64 = null,
    total: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_type = "fileType",
            .storage_class = "storageClass",
            .total = "total",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectCountByEncryptionType = struct {
    customer_managed: ?i64 = null,
    kms_managed: ?i64 = null,
    s3_managed: ?i64 = null,
    unencrypted: ?i64 = null,
    unknown: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_managed = "customerManaged",
            .kms_managed = "kmsManaged",
            .s3_managed = "s3Managed",
            .unencrypted = "unencrypted",
            .unknown = "unknown",
        };
        return @field(mappings, field_name);
    }
};

pub const JobDetails = struct {
    is_defined_in_job: ?[]const u8 = null,
    is_monitored_by_job: ?[]const u8 = null,
    last_job_id: ?[]const u8 = null,
    last_job_run_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_defined_in_job = "isDefinedInJob",
            .is_monitored_by_job = "isMonitoredByJob",
            .last_job_id = "lastJobId",
            .last_job_run_time = "lastJobRunTime",
        };
        return @field(mappings, field_name);
    }
};

pub const SearchResourcesCriteriaBlock = struct {
    @"and": ?[]SearchResourcesCriteria = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .@"and" = "and",
        };
        return @field(mappings, field_name);
    }
};

pub const SearchResourcesCriteria = struct {
    simple_criterion: ?SearchResourcesSimpleCriterion = null,
    tag_criterion: ?SearchResourcesTagCriterion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple_criterion = "simpleCriterion",
            .tag_criterion = "tagCriterion",
        };
        return @field(mappings, field_name);
    }
};

pub const SearchResourcesTagCriterion = struct {
    comparator: ?[]const u8 = null,
    tag_values: ?[]SearchResourcesTagCriterionPair = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparator = "comparator",
            .tag_values = "tagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const SearchResourcesTagCriterionPair = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const SearchResourcesSimpleCriterion = struct {
    comparator: ?[]const u8 = null,
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparator = "comparator",
            .key = "key",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityHubConfiguration = struct {
    publish_classification_findings: bool,
    publish_policy_findings: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .publish_classification_findings = "publishClassificationFindings",
            .publish_policy_findings = "publishPolicyFindings",
        };
        return @field(mappings, field_name);
    }
};

pub const ClassificationExportConfiguration = struct {
    s3_destination: ?S3Destination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_destination = "s3Destination",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Destination = struct {
    bucket_name: []const u8,
    key_prefix: ?[]const u8 = null,
    kms_key_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .key_prefix = "keyPrefix",
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Invitation = struct {
    account_id: ?[]const u8 = null,
    invitation_id: ?[]const u8 = null,
    invited_at: ?i64 = null,
    relationship_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .invitation_id = "invitationId",
            .invited_at = "invitedAt",
            .relationship_status = "relationshipStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const SortCriteria = struct {
    attribute_name: ?[]const u8 = null,
    order_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "attributeName",
            .order_by = "orderBy",
        };
        return @field(mappings, field_name);
    }
};

pub const UserPausedDetails = struct {
    job_expires_at: ?i64 = null,
    job_imminent_expiration_health_event_arn: ?[]const u8 = null,
    job_paused_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_expires_at = "jobExpiresAt",
            .job_imminent_expiration_health_event_arn = "jobImminentExpirationHealthEventArn",
            .job_paused_at = "jobPausedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const LastRunErrorStatus = struct {
    code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketDefinitionForJob = struct {
    account_id: []const u8,
    buckets: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .buckets = "buckets",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketCriteriaForJob = struct {
    excludes: ?CriteriaBlockForJob = null,
    includes: ?CriteriaBlockForJob = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .excludes = "excludes",
            .includes = "includes",
        };
        return @field(mappings, field_name);
    }
};

pub const CriteriaBlockForJob = struct {
    @"and": ?[]CriteriaForJob = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .@"and" = "and",
        };
        return @field(mappings, field_name);
    }
};

pub const CriteriaForJob = struct {
    simple_criterion: ?SimpleCriterionForJob = null,
    tag_criterion: ?TagCriterionForJob = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple_criterion = "simpleCriterion",
            .tag_criterion = "tagCriterion",
        };
        return @field(mappings, field_name);
    }
};

pub const TagCriterionForJob = struct {
    comparator: ?[]const u8 = null,
    tag_values: ?[]TagCriterionPairForJob = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparator = "comparator",
            .tag_values = "tagValues",
        };
        return @field(mappings, field_name);
    }
};

pub const TagCriterionPairForJob = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const SimpleCriterionForJob = struct {
    comparator: ?[]const u8 = null,
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparator = "comparator",
            .key = "key",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const ListJobsFilterTerm = struct {
    comparator: ?[]const u8 = null,
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparator = "comparator",
            .key = "key",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyValuePair = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerSideEncryption = struct {
    encryption_type: ?[]const u8 = null,
    kms_master_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_type = "encryptionType",
            .kms_master_key_id = "kmsMasterKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const BucketPublicAccess = struct {
    effective_permission: ?[]const u8 = null,
    permission_configuration: ?BucketPermissionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .effective_permission = "effectivePermission",
            .permission_configuration = "permissionConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const BucketPermissionConfiguration = struct {
    account_level_permissions: ?AccountLevelPermissions = null,
    bucket_level_permissions: ?BucketLevelPermissions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_level_permissions = "accountLevelPermissions",
            .bucket_level_permissions = "bucketLevelPermissions",
        };
        return @field(mappings, field_name);
    }
};

pub const BucketLevelPermissions = struct {
    access_control_list: ?AccessControlList = null,
    block_public_access: ?BlockPublicAccess = null,
    bucket_policy: ?BucketPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_control_list = "accessControlList",
            .block_public_access = "blockPublicAccess",
            .bucket_policy = "bucketPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const BucketPolicy = struct {
    allows_public_read_access: ?bool = null,
    allows_public_write_access: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allows_public_read_access = "allowsPublicReadAccess",
            .allows_public_write_access = "allowsPublicWriteAccess",
        };
        return @field(mappings, field_name);
    }
};

pub const BlockPublicAccess = struct {
    block_public_acls: ?bool = null,
    block_public_policy: ?bool = null,
    ignore_public_acls: ?bool = null,
    restrict_public_buckets: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_public_acls = "blockPublicAcls",
            .block_public_policy = "blockPublicPolicy",
            .ignore_public_acls = "ignorePublicAcls",
            .restrict_public_buckets = "restrictPublicBuckets",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessControlList = struct {
    allows_public_read_access: ?bool = null,
    allows_public_write_access: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allows_public_read_access = "allowsPublicReadAccess",
            .allows_public_write_access = "allowsPublicWriteAccess",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountLevelPermissions = struct {
    block_public_access: ?BlockPublicAccess = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_public_access = "blockPublicAccess",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionContext = struct {
    attributes: ?SessionContextAttributes = null,
    session_issuer: ?SessionIssuer = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "attributes",
            .session_issuer = "sessionIssuer",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionIssuer = struct {
    account_id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    user_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .arn = "arn",
            .principal_id = "principalId",
            .type = "type",
            .user_name = "userName",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionContextAttributes = struct {
    creation_date: ?i64 = null,
    mfa_authenticated: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_date = "creationDate",
            .mfa_authenticated = "mfaAuthenticated",
        };
        return @field(mappings, field_name);
    }
};

pub const Occurrences = struct {
    cells: ?[]Cell = null,
    line_ranges: ?[]Range = null,
    offset_ranges: ?[]Range = null,
    pages: ?[]Page = null,
    records: ?[]Record = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cells = "cells",
            .line_ranges = "lineRanges",
            .offset_ranges = "offsetRanges",
            .pages = "pages",
            .records = "records",
        };
        return @field(mappings, field_name);
    }
};

pub const Record = struct {
    json_path: ?[]const u8 = null,
    record_index: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .json_path = "jsonPath",
            .record_index = "recordIndex",
        };
        return @field(mappings, field_name);
    }
};

pub const Page = struct {
    line_range: ?Range = null,
    offset_range: ?Range = null,
    page_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .line_range = "lineRange",
            .offset_range = "offsetRange",
            .page_number = "pageNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const Range = struct {
    end: ?i64 = null,
    start: ?i64 = null,
    start_column: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .end = "end",
            .start = "start",
            .start_column = "startColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const Cell = struct {
    cell_reference: ?[]const u8 = null,
    column: ?i64 = null,
    column_name: ?[]const u8 = null,
    row: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cell_reference = "cellReference",
            .column = "column",
            .column_name = "columnName",
            .row = "row",
        };
        return @field(mappings, field_name);
    }
};

pub const SeverityLevel = struct {
    occurrences_threshold: i64,
    severity: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .occurrences_threshold = "occurrencesThreshold",
            .severity = "severity",
        };
        return @field(mappings, field_name);
    }
};

pub const SensitivityAggregations = struct {
    classifiable_size_in_bytes: ?i64 = null,
    publicly_accessible_count: ?i64 = null,
    total_count: ?i64 = null,
    total_size_in_bytes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .classifiable_size_in_bytes = "classifiableSizeInBytes",
            .publicly_accessible_count = "publiclyAccessibleCount",
            .total_count = "totalCount",
            .total_size_in_bytes = "totalSizeInBytes",
        };
        return @field(mappings, field_name);
    }
};

pub const JobScheduleFrequency = struct {
    daily_schedule: ?DailySchedule = null,
    monthly_schedule: ?MonthlySchedule = null,
    weekly_schedule: ?WeeklySchedule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .daily_schedule = "dailySchedule",
            .monthly_schedule = "monthlySchedule",
            .weekly_schedule = "weeklySchedule",
        };
        return @field(mappings, field_name);
    }
};

pub const WeeklySchedule = struct {
    day_of_week: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .day_of_week = "dayOfWeek",
        };
        return @field(mappings, field_name);
    }
};

pub const MonthlySchedule = struct {
    day_of_month: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .day_of_month = "dayOfMonth",
        };
        return @field(mappings, field_name);
    }
};

pub const DailySchedule = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const S3JobDefinition = struct {
    bucket_criteria: ?S3BucketCriteriaForJob = null,
    bucket_definitions: ?[]S3BucketDefinitionForJob = null,
    scoping: ?Scoping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_criteria = "bucketCriteria",
            .bucket_definitions = "bucketDefinitions",
            .scoping = "scoping",
        };
        return @field(mappings, field_name);
    }
};

pub const Scoping = struct {
    excludes: ?JobScopingBlock = null,
    includes: ?JobScopingBlock = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .excludes = "excludes",
            .includes = "includes",
        };
        return @field(mappings, field_name);
    }
};

pub const JobScopingBlock = struct {
    @"and": ?[]JobScopeTerm = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .@"and" = "and",
        };
        return @field(mappings, field_name);
    }
};

pub const JobScopeTerm = struct {
    simple_scope_term: ?SimpleScopeTerm = null,
    tag_scope_term: ?TagScopeTerm = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple_scope_term = "simpleScopeTerm",
            .tag_scope_term = "tagScopeTerm",
        };
        return @field(mappings, field_name);
    }
};

pub const TagScopeTerm = struct {
    comparator: ?[]const u8 = null,
    key: ?[]const u8 = null,
    tag_values: ?[]TagValuePair = null,
    target: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparator = "comparator",
            .key = "key",
            .tag_values = "tagValues",
            .target = "target",
        };
        return @field(mappings, field_name);
    }
};

pub const TagValuePair = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const SimpleScopeTerm = struct {
    comparator: ?[]const u8 = null,
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparator = "comparator",
            .key = "key",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const UnprocessedAccount = struct {
    account_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
            .error_code = "errorCode",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};
