const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-09-24";
pub const sdk_id: []const u8 = "ManagedBlockchain";
pub const arn_namespace: ?[]const u8 = "managedblockchain";
pub const endpoint_prefix: []const u8 = "managedblockchain";
pub const sigv4_name: []const u8 = "managedblockchain";
pub const name: []const u8 = "TaigaWebService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-09-24",
    sdk_id: []const u8 = "ManagedBlockchain",
    arn_namespace: ?[]const u8 = "managedblockchain",
    endpoint_prefix: []const u8 = "managedblockchain",
    sigv4_name: []const u8 = "managedblockchain",
    name: []const u8 = "TaigaWebService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_accessor: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accessors",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessor",
    Request: type = struct {
        client_request_token: []const u8,
        accessor_type: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        network_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .accessor_type = "AccessorType",
                .tags = "Tags",
                .network_type = "NetworkType",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_accessor) } {
            return .{ .service_metadata = service_metadata, .action = create_accessor };
        }
    },
    Response: type = struct {
        accessor_id: ?[]const u8 = null,
        billing_token: ?[]const u8 = null,
        network_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accessor_id = "AccessorId",
                .billing_token = "BillingToken",
                .network_type = "NetworkType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        Throttling,
        TooManyTags,
    },
} = .{};
pub const create_member: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/networks/{NetworkId}/members",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMember",
    Request: type = struct {
        client_request_token: []const u8,
        invitation_id: []const u8,
        network_id: []const u8,
        member_configuration: MemberConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .invitation_id = "InvitationId",
                .network_id = "NetworkId",
                .member_configuration = "MemberConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_member) } {
            return .{ .service_metadata = service_metadata, .action = create_member };
        }
    },
    Response: type = struct {
        member_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_id = "MemberId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
        TooManyTags,
    },
} = .{};
pub const create_network: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/networks",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateNetwork",
    Request: type = struct {
        client_request_token: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        framework: []const u8,
        framework_version: []const u8,
        framework_configuration: ?struct {
            fabric: ?struct {
                edition: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .edition = "Edition",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fabric = "Fabric",
                };
                return @field(mappings, field_name);
            }
        } = null,
        voting_policy: VotingPolicy,
        member_configuration: MemberConfiguration,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .name = "Name",
                .description = "Description",
                .framework = "Framework",
                .framework_version = "FrameworkVersion",
                .framework_configuration = "FrameworkConfiguration",
                .voting_policy = "VotingPolicy",
                .member_configuration = "MemberConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network) } {
            return .{ .service_metadata = service_metadata, .action = create_network };
        }
    },
    Response: type = struct {
        network_id: ?[]const u8 = null,
        member_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .member_id = "MemberId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        Throttling,
        TooManyTags,
    },
} = .{};
pub const create_node: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/networks/{NetworkId}/nodes",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateNode",
    Request: type = struct {
        client_request_token: []const u8,
        network_id: []const u8,
        member_id: ?[]const u8 = null,
        node_configuration: struct {
            instance_type: []const u8,
            availability_zone: ?[]const u8 = null,
            log_publishing_configuration: ?NodeLogPublishingConfiguration = null,
            state_db: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_type = "InstanceType",
                    .availability_zone = "AvailabilityZone",
                    .log_publishing_configuration = "LogPublishingConfiguration",
                    .state_db = "StateDB",
                };
                return @field(mappings, field_name);
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .network_id = "NetworkId",
                .member_id = "MemberId",
                .node_configuration = "NodeConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_node) } {
            return .{ .service_metadata = service_metadata, .action = create_node };
        }
    },
    Response: type = struct {
        node_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_id = "NodeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
        TooManyTags,
    },
} = .{};
pub const create_proposal: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/networks/{NetworkId}/proposals",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProposal",
    Request: type = struct {
        client_request_token: []const u8,
        network_id: []const u8,
        member_id: []const u8,
        actions: ProposalActions,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .network_id = "NetworkId",
                .member_id = "MemberId",
                .actions = "Actions",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_proposal) } {
            return .{ .service_metadata = service_metadata, .action = create_proposal };
        }
    },
    Response: type = struct {
        proposal_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proposal_id = "ProposalId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
        TooManyTags,
    },
} = .{};
pub const delete_accessor: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accessors/{AccessorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessor",
    Request: type = struct {
        accessor_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accessor_id = "AccessorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_accessor) } {
            return .{ .service_metadata = service_metadata, .action = delete_accessor };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_member: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/networks/{NetworkId}/members/{MemberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMember",
    Request: type = struct {
        network_id: []const u8,
        member_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .member_id = "MemberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_member) } {
            return .{ .service_metadata = service_metadata, .action = delete_member };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
    },
} = .{};
pub const delete_node: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/networks/{NetworkId}/nodes/{NodeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteNode",
    Request: type = struct {
        network_id: []const u8,
        member_id: ?[]const u8 = null,
        node_id: []const u8,

        pub const http_query = .{
            .member_id = "memberId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .member_id = "MemberId",
                .node_id = "NodeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_node) } {
            return .{ .service_metadata = service_metadata, .action = delete_node };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
    },
} = .{};
pub const get_accessor: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accessors/{AccessorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessor",
    Request: type = struct {
        accessor_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accessor_id = "AccessorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_accessor) } {
            return .{ .service_metadata = service_metadata, .action = get_accessor };
        }
    },
    Response: type = struct {
        accessor: ?struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            billing_token: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,
            arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            network_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                    .billing_token = "BillingToken",
                    .status = "Status",
                    .creation_date = "CreationDate",
                    .arn = "Arn",
                    .tags = "Tags",
                    .network_type = "NetworkType",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accessor = "Accessor",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_member: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/networks/{NetworkId}/members/{MemberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMember",
    Request: type = struct {
        network_id: []const u8,
        member_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .member_id = "MemberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_member) } {
            return .{ .service_metadata = service_metadata, .action = get_member };
        }
    },
    Response: type = struct {
        member: ?struct {
            network_id: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            framework_attributes: ?struct {
                fabric: ?struct {
                    admin_username: ?[]const u8 = null,
                    ca_endpoint: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .admin_username = "AdminUsername",
                            .ca_endpoint = "CaEndpoint",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .fabric = "Fabric",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            log_publishing_configuration: ?MemberLogPublishingConfiguration = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            arn: ?[]const u8 = null,
            kms_key_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .network_id = "NetworkId",
                    .id = "Id",
                    .name = "Name",
                    .description = "Description",
                    .framework_attributes = "FrameworkAttributes",
                    .log_publishing_configuration = "LogPublishingConfiguration",
                    .status = "Status",
                    .creation_date = "CreationDate",
                    .tags = "Tags",
                    .arn = "Arn",
                    .kms_key_arn = "KmsKeyArn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member = "Member",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_network: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/networks/{NetworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNetwork",
    Request: type = struct {
        network_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network) } {
            return .{ .service_metadata = service_metadata, .action = get_network };
        }
    },
    Response: type = struct {
        network: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            framework: ?[]const u8 = null,
            framework_version: ?[]const u8 = null,
            framework_attributes: ?struct {
                fabric: ?struct {
                    ordering_service_endpoint: ?[]const u8 = null,
                    edition: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .ordering_service_endpoint = "OrderingServiceEndpoint",
                            .edition = "Edition",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                ethereum: ?struct {
                    chain_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .chain_id = "ChainId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .fabric = "Fabric",
                        .ethereum = "Ethereum",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            vpc_endpoint_service_name: ?[]const u8 = null,
            voting_policy: ?VotingPolicy = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .description = "Description",
                    .framework = "Framework",
                    .framework_version = "FrameworkVersion",
                    .framework_attributes = "FrameworkAttributes",
                    .vpc_endpoint_service_name = "VpcEndpointServiceName",
                    .voting_policy = "VotingPolicy",
                    .status = "Status",
                    .creation_date = "CreationDate",
                    .tags = "Tags",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network = "Network",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_node: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/networks/{NetworkId}/nodes/{NodeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNode",
    Request: type = struct {
        network_id: []const u8,
        member_id: ?[]const u8 = null,
        node_id: []const u8,

        pub const http_query = .{
            .member_id = "memberId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .member_id = "MemberId",
                .node_id = "NodeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_node) } {
            return .{ .service_metadata = service_metadata, .action = get_node };
        }
    },
    Response: type = struct {
        node: ?struct {
            network_id: ?[]const u8 = null,
            member_id: ?[]const u8 = null,
            id: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            availability_zone: ?[]const u8 = null,
            framework_attributes: ?struct {
                fabric: ?struct {
                    peer_endpoint: ?[]const u8 = null,
                    peer_event_endpoint: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .peer_endpoint = "PeerEndpoint",
                            .peer_event_endpoint = "PeerEventEndpoint",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                ethereum: ?struct {
                    http_endpoint: ?[]const u8 = null,
                    web_socket_endpoint: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .http_endpoint = "HttpEndpoint",
                            .web_socket_endpoint = "WebSocketEndpoint",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .fabric = "Fabric",
                        .ethereum = "Ethereum",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            log_publishing_configuration: ?NodeLogPublishingConfiguration = null,
            state_db: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            arn: ?[]const u8 = null,
            kms_key_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .network_id = "NetworkId",
                    .member_id = "MemberId",
                    .id = "Id",
                    .instance_type = "InstanceType",
                    .availability_zone = "AvailabilityZone",
                    .framework_attributes = "FrameworkAttributes",
                    .log_publishing_configuration = "LogPublishingConfiguration",
                    .state_db = "StateDB",
                    .status = "Status",
                    .creation_date = "CreationDate",
                    .tags = "Tags",
                    .arn = "Arn",
                    .kms_key_arn = "KmsKeyArn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node = "Node",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_proposal: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/networks/{NetworkId}/proposals/{ProposalId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProposal",
    Request: type = struct {
        network_id: []const u8,
        proposal_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .proposal_id = "ProposalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_proposal) } {
            return .{ .service_metadata = service_metadata, .action = get_proposal };
        }
    },
    Response: type = struct {
        proposal: ?struct {
            proposal_id: ?[]const u8 = null,
            network_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            actions: ?ProposalActions = null,
            proposed_by_member_id: ?[]const u8 = null,
            proposed_by_member_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,
            expiration_date: ?i64 = null,
            yes_vote_count: ?i64 = null,
            no_vote_count: ?i64 = null,
            outstanding_vote_count: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .proposal_id = "ProposalId",
                    .network_id = "NetworkId",
                    .description = "Description",
                    .actions = "Actions",
                    .proposed_by_member_id = "ProposedByMemberId",
                    .proposed_by_member_name = "ProposedByMemberName",
                    .status = "Status",
                    .creation_date = "CreationDate",
                    .expiration_date = "ExpirationDate",
                    .yes_vote_count = "YesVoteCount",
                    .no_vote_count = "NoVoteCount",
                    .outstanding_vote_count = "OutstandingVoteCount",
                    .tags = "Tags",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proposal = "Proposal",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_accessors: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accessors",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessors",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        network_type: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .network_type = "networkType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .network_type = "NetworkType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accessors) } {
            return .{ .service_metadata = service_metadata, .action = list_accessors };
        }
    },
    Response: type = struct {
        accessors: ?[]struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,
            arn: ?[]const u8 = null,
            network_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                    .status = "Status",
                    .creation_date = "CreationDate",
                    .arn = "Arn",
                    .network_type = "NetworkType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accessors = "Accessors",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_invitations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/invitations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInvitations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_invitations) } {
            return .{ .service_metadata = service_metadata, .action = list_invitations };
        }
    },
    Response: type = struct {
        invitations: ?[]struct {
            invitation_id: ?[]const u8 = null,
            creation_date: ?i64 = null,
            expiration_date: ?i64 = null,
            status: ?[]const u8 = null,
            network_summary: ?NetworkSummary = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .invitation_id = "InvitationId",
                    .creation_date = "CreationDate",
                    .expiration_date = "ExpirationDate",
                    .status = "Status",
                    .network_summary = "NetworkSummary",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitations = "Invitations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceLimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_members: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/networks/{NetworkId}/members",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMembers",
    Request: type = struct {
        network_id: []const u8,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        is_owned: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .name = "name",
            .status = "status",
            .is_owned = "isOwned",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .name = "Name",
                .status = "Status",
                .is_owned = "IsOwned",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_members) } {
            return .{ .service_metadata = service_metadata, .action = list_members };
        }
    },
    Response: type = struct {
        members: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,
            is_owned: ?bool = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .description = "Description",
                    .status = "Status",
                    .creation_date = "CreationDate",
                    .is_owned = "IsOwned",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "Members",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_networks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/networks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNetworks",
    Request: type = struct {
        name: ?[]const u8 = null,
        framework: ?[]const u8 = null,
        status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .name = "name",
            .framework = "framework",
            .status = "status",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .framework = "Framework",
                .status = "Status",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_networks) } {
            return .{ .service_metadata = service_metadata, .action = list_networks };
        }
    },
    Response: type = struct {
        networks: ?[]NetworkSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .networks = "Networks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_nodes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/networks/{NetworkId}/nodes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNodes",
    Request: type = struct {
        network_id: []const u8,
        member_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .member_id = "memberId",
            .status = "status",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .member_id = "MemberId",
                .status = "Status",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_nodes) } {
            return .{ .service_metadata = service_metadata, .action = list_nodes };
        }
    },
    Response: type = struct {
        nodes: ?[]struct {
            id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,
            availability_zone: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .status = "Status",
                    .creation_date = "CreationDate",
                    .availability_zone = "AvailabilityZone",
                    .instance_type = "InstanceType",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nodes = "Nodes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_proposals: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/networks/{NetworkId}/proposals",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProposals",
    Request: type = struct {
        network_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_proposals) } {
            return .{ .service_metadata = service_metadata, .action = list_proposals };
        }
    },
    Response: type = struct {
        proposals: ?[]struct {
            proposal_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            proposed_by_member_id: ?[]const u8 = null,
            proposed_by_member_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date: ?i64 = null,
            expiration_date: ?i64 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .proposal_id = "ProposalId",
                    .description = "Description",
                    .proposed_by_member_id = "ProposedByMemberId",
                    .proposed_by_member_name = "ProposedByMemberName",
                    .status = "Status",
                    .creation_date = "CreationDate",
                    .expiration_date = "ExpirationDate",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proposals = "Proposals",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_proposal_votes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/networks/{NetworkId}/proposals/{ProposalId}/votes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProposalVotes",
    Request: type = struct {
        network_id: []const u8,
        proposal_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .proposal_id = "ProposalId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_proposal_votes) } {
            return .{ .service_metadata = service_metadata, .action = list_proposal_votes };
        }
    },
    Response: type = struct {
        proposal_votes: ?[]struct {
            vote: ?[]const u8 = null,
            member_name: ?[]const u8 = null,
            member_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vote = "Vote",
                    .member_name = "MemberName",
                    .member_id = "MemberId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proposal_votes = "ProposalVotes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ResourceNotReady,
    },
} = .{};
pub const reject_invitation: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/invitations/{InvitationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "RejectInvitation",
    Request: type = struct {
        invitation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invitation_id = "InvitationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_invitation) } {
            return .{ .service_metadata = service_metadata, .action = reject_invitation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalAction,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ResourceNotReady,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ResourceNotReady,
    },
} = .{};
pub const update_member: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/networks/{NetworkId}/members/{MemberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMember",
    Request: type = struct {
        network_id: []const u8,
        member_id: []const u8,
        log_publishing_configuration: ?MemberLogPublishingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .member_id = "MemberId",
                .log_publishing_configuration = "LogPublishingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_member) } {
            return .{ .service_metadata = service_metadata, .action = update_member };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_node: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/networks/{NetworkId}/nodes/{NodeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateNode",
    Request: type = struct {
        network_id: []const u8,
        member_id: ?[]const u8 = null,
        node_id: []const u8,
        log_publishing_configuration: ?NodeLogPublishingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .member_id = "MemberId",
                .node_id = "NodeId",
                .log_publishing_configuration = "LogPublishingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_node) } {
            return .{ .service_metadata = service_metadata, .action = update_node };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const vote_on_proposal: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/networks/{NetworkId}/proposals/{ProposalId}/votes",
        .success_code = 200,
    };

    action_name: []const u8 = "VoteOnProposal",
    Request: type = struct {
        network_id: []const u8,
        proposal_id: []const u8,
        voter_member_id: []const u8,
        vote: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_id = "NetworkId",
                .proposal_id = "ProposalId",
                .voter_member_id = "VoterMemberId",
                .vote = "Vote",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(vote_on_proposal) } {
            return .{ .service_metadata = service_metadata, .action = vote_on_proposal };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IllegalAction,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const NodeLogPublishingConfiguration = struct {
    fabric: ?NodeFabricLogPublishingConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fabric = "Fabric",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeFabricLogPublishingConfiguration = struct {
    chaincode_logs: ?LogConfigurations = null,
    peer_logs: ?LogConfigurations = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .chaincode_logs = "ChaincodeLogs",
            .peer_logs = "PeerLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const LogConfigurations = struct {
    cloudwatch: ?LogConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloudwatch = "Cloudwatch",
        };
        return @field(mappings, field_name);
    }
};

pub const LogConfiguration = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const MemberLogPublishingConfiguration = struct {
    fabric: ?MemberFabricLogPublishingConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fabric = "Fabric",
        };
        return @field(mappings, field_name);
    }
};

pub const MemberFabricLogPublishingConfiguration = struct {
    ca_logs: ?LogConfigurations = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ca_logs = "CaLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkSummary = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    framework: ?[]const u8 = null,
    framework_version: ?[]const u8 = null,
    status: ?[]const u8 = null,
    creation_date: ?i64 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .description = "Description",
            .framework = "Framework",
            .framework_version = "FrameworkVersion",
            .status = "Status",
            .creation_date = "CreationDate",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const ProposalActions = struct {
    invitations: ?[]InviteAction = null,
    removals: ?[]RemoveAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .invitations = "Invitations",
            .removals = "Removals",
        };
        return @field(mappings, field_name);
    }
};

pub const RemoveAction = struct {
    member_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .member_id = "MemberId",
        };
        return @field(mappings, field_name);
    }
};

pub const InviteAction = struct {
    principal: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal = "Principal",
        };
        return @field(mappings, field_name);
    }
};

pub const VotingPolicy = struct {
    approval_threshold_policy: ?ApprovalThresholdPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .approval_threshold_policy = "ApprovalThresholdPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const ApprovalThresholdPolicy = struct {
    threshold_percentage: ?i64 = null,
    proposal_duration_in_hours: ?i64 = null,
    threshold_comparator: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .threshold_percentage = "ThresholdPercentage",
            .proposal_duration_in_hours = "ProposalDurationInHours",
            .threshold_comparator = "ThresholdComparator",
        };
        return @field(mappings, field_name);
    }
};

pub const MemberConfiguration = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    framework_configuration: MemberFrameworkConfiguration,
    log_publishing_configuration: ?MemberLogPublishingConfiguration = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .framework_configuration = "FrameworkConfiguration",
            .log_publishing_configuration = "LogPublishingConfiguration",
            .tags = "Tags",
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const MemberFrameworkConfiguration = struct {
    fabric: ?MemberFabricConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fabric = "Fabric",
        };
        return @field(mappings, field_name);
    }
};

pub const MemberFabricConfiguration = struct {
    admin_username: []const u8,
    admin_password: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .admin_username = "AdminUsername",
            .admin_password = "AdminPassword",
        };
        return @field(mappings, field_name);
    }
};
