const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2023-05-04";
pub const sdk_id: []const u8 = "ManagedBlockchain Query";
pub const arn_namespace: ?[]const u8 = "managedblockchain-query";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "managedblockchain-query";
pub const name: []const u8 = "TietonChainQueryService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2023-05-04",
    sdk_id: []const u8 = "ManagedBlockchain Query",
    arn_namespace: ?[]const u8 = "managedblockchain-query",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "managedblockchain-query",
    name: []const u8 = "TietonChainQueryService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_get_token_balance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/batch-get-token-balance",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetTokenBalance",
    Request: type = struct {
        get_token_balance_inputs: ?[]struct {
            token_identifier: TokenIdentifier,
            owner_identifier: OwnerIdentifier,
            at_blockchain_instant: ?BlockchainInstant = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .token_identifier = "tokenIdentifier",
                    .owner_identifier = "ownerIdentifier",
                    .at_blockchain_instant = "atBlockchainInstant",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .get_token_balance_inputs = "getTokenBalanceInputs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_token_balance) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_token_balance };
        }
    },
    Response: type = struct {
        token_balances: []struct {
            owner_identifier: ?OwnerIdentifier = null,
            token_identifier: ?TokenIdentifier = null,
            balance: []const u8,
            at_blockchain_instant: BlockchainInstant,
            last_updated_time: ?BlockchainInstant = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .owner_identifier = "ownerIdentifier",
                    .token_identifier = "tokenIdentifier",
                    .balance = "balance",
                    .at_blockchain_instant = "atBlockchainInstant",
                    .last_updated_time = "lastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        },
        errors: []struct {
            token_identifier: ?TokenIdentifier = null,
            owner_identifier: ?OwnerIdentifier = null,
            at_blockchain_instant: ?BlockchainInstant = null,
            error_code: []const u8,
            error_message: []const u8,
            error_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .token_identifier = "tokenIdentifier",
                    .owner_identifier = "ownerIdentifier",
                    .at_blockchain_instant = "atBlockchainInstant",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                    .error_type = "errorType",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token_balances = "tokenBalances",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_asset_contract: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-asset-contract",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAssetContract",
    Request: type = struct {
        contract_identifier: ContractIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contract_identifier = "contractIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_asset_contract) } {
            return .{ .service_metadata = service_metadata, .action = get_asset_contract };
        }
    },
    Response: type = struct {
        contract_identifier: ContractIdentifier,
        token_standard: []const u8,
        deployer_address: []const u8,
        metadata: ?struct {
            name: ?[]const u8 = null,
            symbol: ?[]const u8 = null,
            decimals: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .symbol = "symbol",
                    .decimals = "decimals",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contract_identifier = "contractIdentifier",
                .token_standard = "tokenStandard",
                .deployer_address = "deployerAddress",
                .metadata = "metadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_token_balance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-token-balance",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTokenBalance",
    Request: type = struct {
        token_identifier: TokenIdentifier,
        owner_identifier: OwnerIdentifier,
        at_blockchain_instant: ?BlockchainInstant = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token_identifier = "tokenIdentifier",
                .owner_identifier = "ownerIdentifier",
                .at_blockchain_instant = "atBlockchainInstant",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_token_balance) } {
            return .{ .service_metadata = service_metadata, .action = get_token_balance };
        }
    },
    Response: type = struct {
        owner_identifier: ?OwnerIdentifier = null,
        token_identifier: ?TokenIdentifier = null,
        balance: []const u8,
        at_blockchain_instant: BlockchainInstant,
        last_updated_time: ?BlockchainInstant = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_identifier = "ownerIdentifier",
                .token_identifier = "tokenIdentifier",
                .balance = "balance",
                .at_blockchain_instant = "atBlockchainInstant",
                .last_updated_time = "lastUpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_transaction: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-transaction",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTransaction",
    Request: type = struct {
        transaction_hash: []const u8,
        network: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_hash = "transactionHash",
                .network = "network",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transaction) } {
            return .{ .service_metadata = service_metadata, .action = get_transaction };
        }
    },
    Response: type = struct {
        transaction: struct {
            network: []const u8,
            block_hash: ?[]const u8 = null,
            transaction_hash: []const u8,
            block_number: ?[]const u8 = null,
            transaction_timestamp: i64,
            transaction_index: i64,
            number_of_transactions: i64,
            to: []const u8,
            from: ?[]const u8 = null,
            contract_address: ?[]const u8 = null,
            gas_used: ?[]const u8 = null,
            cumulative_gas_used: ?[]const u8 = null,
            effective_gas_price: ?[]const u8 = null,
            signaturev: ?i64 = null,
            signaturer: ?[]const u8 = null,
            signatures: ?[]const u8 = null,
            transaction_fee: ?[]const u8 = null,
            transaction_id: ?[]const u8 = null,
            confirmation_status: ?[]const u8 = null,
            execution_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .network = "network",
                    .block_hash = "blockHash",
                    .transaction_hash = "transactionHash",
                    .block_number = "blockNumber",
                    .transaction_timestamp = "transactionTimestamp",
                    .transaction_index = "transactionIndex",
                    .number_of_transactions = "numberOfTransactions",
                    .to = "to",
                    .from = "from",
                    .contract_address = "contractAddress",
                    .gas_used = "gasUsed",
                    .cumulative_gas_used = "cumulativeGasUsed",
                    .effective_gas_price = "effectiveGasPrice",
                    .signaturev = "signatureV",
                    .signaturer = "signatureR",
                    .signatures = "signatureS",
                    .transaction_fee = "transactionFee",
                    .transaction_id = "transactionId",
                    .confirmation_status = "confirmationStatus",
                    .execution_status = "executionStatus",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction = "transaction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_asset_contracts: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-asset-contracts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssetContracts",
    Request: type = struct {
        contract_filter: struct {
            network: []const u8,
            token_standard: []const u8,
            deployer_address: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .network = "network",
                    .token_standard = "tokenStandard",
                    .deployer_address = "deployerAddress",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contract_filter = "contractFilter",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_asset_contracts) } {
            return .{ .service_metadata = service_metadata, .action = list_asset_contracts };
        }
    },
    Response: type = struct {
        contracts: []struct {
            contract_identifier: ContractIdentifier,
            token_standard: []const u8,
            deployer_address: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .contract_identifier = "contractIdentifier",
                    .token_standard = "tokenStandard",
                    .deployer_address = "deployerAddress",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contracts = "contracts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_token_balances: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-token-balances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTokenBalances",
    Request: type = struct {
        owner_filter: ?struct {
            address: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .address = "address",
                };
                return @field(mappings, field_name);
            }
        } = null,
        token_filter: struct {
            network: []const u8,
            contract_address: ?[]const u8 = null,
            token_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .network = "network",
                    .contract_address = "contractAddress",
                    .token_id = "tokenId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_filter = "ownerFilter",
                .token_filter = "tokenFilter",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_token_balances) } {
            return .{ .service_metadata = service_metadata, .action = list_token_balances };
        }
    },
    Response: type = struct {
        token_balances: []struct {
            owner_identifier: ?OwnerIdentifier = null,
            token_identifier: ?TokenIdentifier = null,
            balance: []const u8,
            at_blockchain_instant: BlockchainInstant,
            last_updated_time: ?BlockchainInstant = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .owner_identifier = "ownerIdentifier",
                    .token_identifier = "tokenIdentifier",
                    .balance = "balance",
                    .at_blockchain_instant = "atBlockchainInstant",
                    .last_updated_time = "lastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token_balances = "tokenBalances",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_transaction_events: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-transaction-events",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTransactionEvents",
    Request: type = struct {
        transaction_hash: []const u8,
        network: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_hash = "transactionHash",
                .network = "network",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_transaction_events) } {
            return .{ .service_metadata = service_metadata, .action = list_transaction_events };
        }
    },
    Response: type = struct {
        events: []struct {
            network: []const u8,
            transaction_hash: []const u8,
            event_type: []const u8,
            from: ?[]const u8 = null,
            to: ?[]const u8 = null,
            value: ?[]const u8 = null,
            contract_address: ?[]const u8 = null,
            token_id: ?[]const u8 = null,
            transaction_id: ?[]const u8 = null,
            vout_index: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .network = "network",
                    .transaction_hash = "transactionHash",
                    .event_type = "eventType",
                    .from = "from",
                    .to = "to",
                    .value = "value",
                    .contract_address = "contractAddress",
                    .token_id = "tokenId",
                    .transaction_id = "transactionId",
                    .vout_index = "voutIndex",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "events",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_transactions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-transactions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTransactions",
    Request: type = struct {
        address: []const u8,
        network: []const u8,
        from_blockchain_instant: ?BlockchainInstant = null,
        to_blockchain_instant: ?BlockchainInstant = null,
        sort: ?struct {
            sort_by: ?[]const u8 = null,
            sort_order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sort_by = "sortBy",
                    .sort_order = "sortOrder",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        confirmation_status_filter: ?struct {
            include: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .include = "include",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address = "address",
                .network = "network",
                .from_blockchain_instant = "fromBlockchainInstant",
                .to_blockchain_instant = "toBlockchainInstant",
                .sort = "sort",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .confirmation_status_filter = "confirmationStatusFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_transactions) } {
            return .{ .service_metadata = service_metadata, .action = list_transactions };
        }
    },
    Response: type = struct {
        transactions: []struct {
            transaction_hash: []const u8,
            network: []const u8,
            transaction_timestamp: i64,
            confirmation_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transaction_hash = "transactionHash",
                    .network = "network",
                    .transaction_timestamp = "transactionTimestamp",
                    .confirmation_status = "confirmationStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transactions = "transactions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const BlockchainInstant = struct {
    time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time = "time",
        };
        return @field(mappings, field_name);
    }
};

pub const TokenIdentifier = struct {
    network: []const u8,
    contract_address: ?[]const u8 = null,
    token_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network = "network",
            .contract_address = "contractAddress",
            .token_id = "tokenId",
        };
        return @field(mappings, field_name);
    }
};

pub const OwnerIdentifier = struct {
    address: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "address",
        };
        return @field(mappings, field_name);
    }
};

pub const ContractIdentifier = struct {
    network: []const u8,
    contract_address: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network = "network",
            .contract_address = "contractAddress",
        };
        return @field(mappings, field_name);
    }
};
