const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-03-01";
pub const sdk_id: []const u8 = "Marketplace Agreement";
pub const arn_namespace: ?[]const u8 = null;
pub const endpoint_prefix: []const u8 = "agreement-marketplace";
pub const sigv4_name: []const u8 = "aws-marketplace";
pub const name: []const u8 = "AWSMPCommerceService_v20200301";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2020-03-01",
    sdk_id: []const u8 = "Marketplace Agreement",
    arn_namespace: ?[]const u8 = null,
    endpoint_prefix: []const u8 = "agreement-marketplace",
    sigv4_name: []const u8 = "aws-marketplace",
    name: []const u8 = "AWSMPCommerceService_v20200301",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const describe_agreement: struct {
    action_name: []const u8 = "DescribeAgreement",
    Request: type = struct {
        agreement_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement_id = "agreementId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_agreement) } {
            return .{ .service_metadata = service_metadata, .action = describe_agreement };
        }
    },
    Response: type = struct {
        agreement_id: ?[]const u8 = null,
        acceptor: ?Acceptor = null,
        proposer: ?Proposer = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        acceptance_time: ?i64 = null,
        agreement_type: ?[]const u8 = null,
        estimated_charges: ?struct {
            currency_code: ?[]const u8 = null,
            agreement_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .currency_code = "currencyCode",
                    .agreement_value = "agreementValue",
                };
                return @field(mappings, field_name);
            }
        } = null,
        proposal_summary: ?ProposalSummary = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement_id = "agreementId",
                .acceptor = "acceptor",
                .proposer = "proposer",
                .start_time = "startTime",
                .end_time = "endTime",
                .acceptance_time = "acceptanceTime",
                .agreement_type = "agreementType",
                .estimated_charges = "estimatedCharges",
                .proposal_summary = "proposalSummary",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_agreement_terms: struct {
    action_name: []const u8 = "GetAgreementTerms",
    Request: type = struct {
        agreement_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement_id = "agreementId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_agreement_terms) } {
            return .{ .service_metadata = service_metadata, .action = get_agreement_terms };
        }
    },
    Response: type = struct {
        accepted_terms: ?[]union {
            legal_term: ?struct {
                type: ?[]const u8 = null,
                documents: ?[]struct {
                    type: ?[]const u8 = null,
                    url: ?[]const u8 = null,
                    version: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .type = "type",
                            .url = "url",
                            .version = "version",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .documents = "documents",
                    };
                    return @field(mappings, field_name);
                }
            },
            support_term: ?struct {
                type: ?[]const u8 = null,
                refund_policy: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .refund_policy = "refundPolicy",
                    };
                    return @field(mappings, field_name);
                }
            },
            renewal_term: ?struct {
                type: ?[]const u8 = null,
                configuration: ?struct {
                    enable_auto_renew: bool,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .enable_auto_renew = "enableAutoRenew",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .configuration = "configuration",
                    };
                    return @field(mappings, field_name);
                }
            },
            usage_based_pricing_term: ?struct {
                type: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,
                rate_cards: ?[]struct {
                    rate_card: ?[]RateCardItem = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .rate_card = "rateCard",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .currency_code = "currencyCode",
                        .rate_cards = "rateCards",
                    };
                    return @field(mappings, field_name);
                }
            },
            configurable_upfront_pricing_term: ?struct {
                type: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,
                rate_cards: ?[]struct {
                    selector: ?struct {
                        type: ?[]const u8 = null,
                        value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .type = "type",
                                .value = "value",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    constraints: ?struct {
                        multiple_dimension_selection: ?[]const u8 = null,
                        quantity_configuration: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .multiple_dimension_selection = "multipleDimensionSelection",
                                .quantity_configuration = "quantityConfiguration",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    rate_card: ?[]RateCardItem = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .selector = "selector",
                            .constraints = "constraints",
                            .rate_card = "rateCard",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                configuration: ?struct {
                    selector_value: []const u8,
                    dimensions: []struct {
                        dimension_key: []const u8,
                        dimension_value: i64,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .dimension_key = "dimensionKey",
                                .dimension_value = "dimensionValue",
                            };
                            return @field(mappings, field_name);
                        }
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .selector_value = "selectorValue",
                            .dimensions = "dimensions",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .currency_code = "currencyCode",
                        .rate_cards = "rateCards",
                        .configuration = "configuration",
                    };
                    return @field(mappings, field_name);
                }
            },
            byol_pricing_term: ?struct {
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                    };
                    return @field(mappings, field_name);
                }
            },
            recurring_payment_term: ?struct {
                type: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,
                billing_period: ?[]const u8 = null,
                price: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .currency_code = "currencyCode",
                        .billing_period = "billingPeriod",
                        .price = "price",
                    };
                    return @field(mappings, field_name);
                }
            },
            validity_term: ?struct {
                type: ?[]const u8 = null,
                agreement_duration: ?[]const u8 = null,
                agreement_start_date: ?i64 = null,
                agreement_end_date: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .agreement_duration = "agreementDuration",
                        .agreement_start_date = "agreementStartDate",
                        .agreement_end_date = "agreementEndDate",
                    };
                    return @field(mappings, field_name);
                }
            },
            payment_schedule_term: ?struct {
                type: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,
                schedule: ?[]struct {
                    charge_date: ?i64 = null,
                    charge_amount: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .charge_date = "chargeDate",
                            .charge_amount = "chargeAmount",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .currency_code = "currencyCode",
                        .schedule = "schedule",
                    };
                    return @field(mappings, field_name);
                }
            },
            free_trial_pricing_term: ?struct {
                type: ?[]const u8 = null,
                duration: ?[]const u8 = null,
                grants: ?[]GrantItem = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .duration = "duration",
                        .grants = "grants",
                    };
                    return @field(mappings, field_name);
                }
            },
            fixed_upfront_pricing_term: ?struct {
                type: ?[]const u8 = null,
                currency_code: ?[]const u8 = null,
                duration: ?[]const u8 = null,
                price: ?[]const u8 = null,
                grants: ?[]GrantItem = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .currency_code = "currencyCode",
                        .duration = "duration",
                        .price = "price",
                        .grants = "grants",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .legal_term = "legalTerm",
                    .support_term = "supportTerm",
                    .renewal_term = "renewalTerm",
                    .usage_based_pricing_term = "usageBasedPricingTerm",
                    .configurable_upfront_pricing_term = "configurableUpfrontPricingTerm",
                    .byol_pricing_term = "byolPricingTerm",
                    .recurring_payment_term = "recurringPaymentTerm",
                    .validity_term = "validityTerm",
                    .payment_schedule_term = "paymentScheduleTerm",
                    .free_trial_pricing_term = "freeTrialPricingTerm",
                    .fixed_upfront_pricing_term = "fixedUpfrontPricingTerm",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accepted_terms = "acceptedTerms",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const search_agreements: struct {
    action_name: []const u8 = "SearchAgreements",
    Request: type = struct {
        catalog: ?[]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sort: ?struct {
            sort_by: ?[]const u8 = null,
            sort_order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sort_by = "sortBy",
                    .sort_order = "sortOrder",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "catalog",
                .filters = "filters",
                .sort = "sort",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_agreements) } {
            return .{ .service_metadata = service_metadata, .action = search_agreements };
        }
    },
    Response: type = struct {
        agreement_view_summaries: ?[]struct {
            agreement_id: ?[]const u8 = null,
            acceptance_time: ?i64 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            agreement_type: ?[]const u8 = null,
            acceptor: ?Acceptor = null,
            proposer: ?Proposer = null,
            proposal_summary: ?ProposalSummary = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .agreement_id = "agreementId",
                    .acceptance_time = "acceptanceTime",
                    .start_time = "startTime",
                    .end_time = "endTime",
                    .agreement_type = "agreementType",
                    .acceptor = "acceptor",
                    .proposer = "proposer",
                    .proposal_summary = "proposalSummary",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement_view_summaries = "agreementViewSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const ProposalSummary = struct {
    resources: ?[]Resource = null,
    offer_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resources = "resources",
            .offer_id = "offerId",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    id: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const Proposer = struct {
    account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
        };
        return @field(mappings, field_name);
    }
};

pub const Acceptor = struct {
    account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "accountId",
        };
        return @field(mappings, field_name);
    }
};

pub const GrantItem = struct {
    dimension_key: ?[]const u8 = null,
    max_quantity: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_key = "dimensionKey",
            .max_quantity = "maxQuantity",
        };
        return @field(mappings, field_name);
    }
};

pub const RateCardItem = struct {
    dimension_key: ?[]const u8 = null,
    price: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_key = "dimensionKey",
            .price = "price",
        };
        return @field(mappings, field_name);
    }
};
