const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-09-17";
pub const sdk_id: []const u8 = "Marketplace Catalog";
pub const arn_namespace: ?[]const u8 = "aws-marketplace";
pub const endpoint_prefix: []const u8 = "catalog.marketplace";
pub const sigv4_name: []const u8 = "aws-marketplace";
pub const name: []const u8 = "AWSMPSeymour";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-09-17",
    sdk_id: []const u8 = "Marketplace Catalog",
    arn_namespace: ?[]const u8 = "aws-marketplace",
    endpoint_prefix: []const u8 = "catalog.marketplace",
    sigv4_name: []const u8 = "aws-marketplace",
    name: []const u8 = "AWSMPSeymour",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_describe_entities: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/BatchDescribeEntities",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDescribeEntities",
    Request: type = struct {
        entity_request_list: []struct {
            catalog: []const u8,
            entity_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .catalog = "Catalog",
                    .entity_id = "EntityId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_request_list = "EntityRequestList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_describe_entities) } {
            return .{ .service_metadata = service_metadata, .action = batch_describe_entities };
        }
    },
    Response: type = struct {
        entity_details: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                entity_type: ?[]const u8 = null,
                entity_arn: ?[]const u8 = null,
                entity_identifier: ?[]const u8 = null,
                last_modified_date: ?[]const u8 = null,
                details_document: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .entity_type = "EntityType",
                        .entity_arn = "EntityArn",
                        .entity_identifier = "EntityIdentifier",
                        .last_modified_date = "LastModifiedDate",
                        .details_document = "DetailsDocument",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        errors: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                error_code: ?[]const u8 = null,
                error_message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "ErrorCode",
                        .error_message = "ErrorMessage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_details = "EntityDetails",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "entity_details", field_name))
                return try serializeMap(self.entity_details, self.fieldNameFor("entity_details"), options, out_stream);
            if (std.mem.eql(u8, "errors", field_name))
                return try serializeMap(self.errors, self.fieldNameFor("errors"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        Throttling,
        Validation,
    },
} = .{};
pub const cancel_change_set: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/CancelChangeSet",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelChangeSet",
    Request: type = struct {
        catalog: []const u8,
        change_set_id: []const u8,

        pub const http_query = .{
            .catalog = "catalog",
            .change_set_id = "changeSetId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .change_set_id = "ChangeSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_change_set) } {
            return .{ .service_metadata = service_metadata, .action = cancel_change_set };
        }
    },
    Response: type = struct {
        change_set_id: ?[]const u8 = null,
        change_set_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_set_id = "ChangeSetId",
                .change_set_arn = "ChangeSetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resource_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteResourcePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_change_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/DescribeChangeSet",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChangeSet",
    Request: type = struct {
        catalog: []const u8,
        change_set_id: []const u8,

        pub const http_query = .{
            .catalog = "catalog",
            .change_set_id = "changeSetId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .change_set_id = "ChangeSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_change_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_change_set };
        }
    },
    Response: type = struct {
        change_set_id: ?[]const u8 = null,
        change_set_arn: ?[]const u8 = null,
        change_set_name: ?[]const u8 = null,
        intent: ?[]const u8 = null,
        start_time: ?[]const u8 = null,
        end_time: ?[]const u8 = null,
        status: ?[]const u8 = null,
        failure_code: ?[]const u8 = null,
        failure_description: ?[]const u8 = null,
        change_set: ?[]struct {
            change_type: ?[]const u8 = null,
            entity: ?Entity = null,
            details: ?[]const u8 = null,
            details_document: ?[]const u8 = null,
            error_detail_list: ?[]struct {
                error_code: ?[]const u8 = null,
                error_message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "ErrorCode",
                        .error_message = "ErrorMessage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            change_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .change_type = "ChangeType",
                    .entity = "Entity",
                    .details = "Details",
                    .details_document = "DetailsDocument",
                    .error_detail_list = "ErrorDetailList",
                    .change_name = "ChangeName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_set_id = "ChangeSetId",
                .change_set_arn = "ChangeSetArn",
                .change_set_name = "ChangeSetName",
                .intent = "Intent",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .status = "Status",
                .failure_code = "FailureCode",
                .failure_description = "FailureDescription",
                .change_set = "ChangeSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_entity: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/DescribeEntity",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeEntity",
    Request: type = struct {
        catalog: []const u8,
        entity_id: []const u8,

        pub const http_query = .{
            .catalog = "catalog",
            .entity_id = "entityId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .entity_id = "EntityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_entity) } {
            return .{ .service_metadata = service_metadata, .action = describe_entity };
        }
    },
    Response: type = struct {
        entity_type: ?[]const u8 = null,
        entity_identifier: ?[]const u8 = null,
        entity_arn: ?[]const u8 = null,
        last_modified_date: ?[]const u8 = null,
        details: ?[]const u8 = null,
        details_document: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_type = "EntityType",
                .entity_identifier = "EntityIdentifier",
                .entity_arn = "EntityArn",
                .last_modified_date = "LastModifiedDate",
                .details = "Details",
                .details_document = "DetailsDocument",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        ResourceNotSupported,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetResourcePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_change_sets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListChangeSets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChangeSets",
    Request: type = struct {
        catalog: []const u8,
        filter_list: ?[]Filter = null,
        sort: ?Sort = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .filter_list = "FilterList",
                .sort = "Sort",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_change_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_change_sets };
        }
    },
    Response: type = struct {
        change_set_summary_list: ?[]struct {
            change_set_id: ?[]const u8 = null,
            change_set_arn: ?[]const u8 = null,
            change_set_name: ?[]const u8 = null,
            start_time: ?[]const u8 = null,
            end_time: ?[]const u8 = null,
            status: ?[]const u8 = null,
            entity_id_list: ?[][]const u8 = null,
            failure_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .change_set_id = "ChangeSetId",
                    .change_set_arn = "ChangeSetArn",
                    .change_set_name = "ChangeSetName",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .status = "Status",
                    .entity_id_list = "EntityIdList",
                    .failure_code = "FailureCode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_set_summary_list = "ChangeSetSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        Throttling,
        Validation,
    },
} = .{};
pub const list_entities: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListEntities",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEntities",
    Request: type = struct {
        catalog: []const u8,
        entity_type: []const u8,
        filter_list: ?[]Filter = null,
        sort: ?Sort = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        ownership_type: ?[]const u8 = null,
        entity_type_filters: ?union {
            data_product_filters: ?struct {
                entity_id: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                product_title: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                visibility: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                last_modified_date: ?struct {
                    date_range: ?struct {
                        after_value: ?[]const u8 = null,
                        before_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .after_value = "AfterValue",
                                .before_value = "BeforeValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date_range = "DateRange",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .entity_id = "EntityId",
                        .product_title = "ProductTitle",
                        .visibility = "Visibility",
                        .last_modified_date = "LastModifiedDate",
                    };
                    return @field(mappings, field_name);
                }
            },
            saa_s_product_filters: ?struct {
                entity_id: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                product_title: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                visibility: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                last_modified_date: ?struct {
                    date_range: ?struct {
                        after_value: ?[]const u8 = null,
                        before_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .after_value = "AfterValue",
                                .before_value = "BeforeValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date_range = "DateRange",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .entity_id = "EntityId",
                        .product_title = "ProductTitle",
                        .visibility = "Visibility",
                        .last_modified_date = "LastModifiedDate",
                    };
                    return @field(mappings, field_name);
                }
            },
            ami_product_filters: ?struct {
                entity_id: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                last_modified_date: ?struct {
                    date_range: ?struct {
                        after_value: ?[]const u8 = null,
                        before_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .after_value = "AfterValue",
                                .before_value = "BeforeValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date_range = "DateRange",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                product_title: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                visibility: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .entity_id = "EntityId",
                        .last_modified_date = "LastModifiedDate",
                        .product_title = "ProductTitle",
                        .visibility = "Visibility",
                    };
                    return @field(mappings, field_name);
                }
            },
            offer_filters: ?struct {
                entity_id: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                name: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                product_id: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                release_date: ?struct {
                    date_range: ?struct {
                        after_value: ?[]const u8 = null,
                        before_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .after_value = "AfterValue",
                                .before_value = "BeforeValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date_range = "DateRange",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                availability_end_date: ?struct {
                    date_range: ?struct {
                        after_value: ?[]const u8 = null,
                        before_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .after_value = "AfterValue",
                                .before_value = "BeforeValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date_range = "DateRange",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                buyer_accounts: ?struct {
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                state: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                targeting: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                last_modified_date: ?struct {
                    date_range: ?struct {
                        after_value: ?[]const u8 = null,
                        before_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .after_value = "AfterValue",
                                .before_value = "BeforeValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date_range = "DateRange",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .entity_id = "EntityId",
                        .name = "Name",
                        .product_id = "ProductId",
                        .release_date = "ReleaseDate",
                        .availability_end_date = "AvailabilityEndDate",
                        .buyer_accounts = "BuyerAccounts",
                        .state = "State",
                        .targeting = "Targeting",
                        .last_modified_date = "LastModifiedDate",
                    };
                    return @field(mappings, field_name);
                }
            },
            container_product_filters: ?struct {
                entity_id: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                last_modified_date: ?struct {
                    date_range: ?struct {
                        after_value: ?[]const u8 = null,
                        before_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .after_value = "AfterValue",
                                .before_value = "BeforeValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date_range = "DateRange",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                product_title: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                visibility: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .entity_id = "EntityId",
                        .last_modified_date = "LastModifiedDate",
                        .product_title = "ProductTitle",
                        .visibility = "Visibility",
                    };
                    return @field(mappings, field_name);
                }
            },
            resale_authorization_filters: ?struct {
                entity_id: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                name: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                product_id: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                created_date: ?struct {
                    date_range: ?struct {
                        after_value: ?[]const u8 = null,
                        before_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .after_value = "AfterValue",
                                .before_value = "BeforeValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date_range = "DateRange",
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                availability_end_date: ?struct {
                    date_range: ?struct {
                        after_value: ?[]const u8 = null,
                        before_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .after_value = "AfterValue",
                                .before_value = "BeforeValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date_range = "DateRange",
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                manufacturer_account_id: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                product_name: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                manufacturer_legal_name: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                reseller_account_id: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                reseller_legal_name: ?struct {
                    value_list: ?[][]const u8 = null,
                    wild_card_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                            .wild_card_value = "WildCardValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                status: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                offer_extended_status: ?struct {
                    value_list: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value_list = "ValueList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                last_modified_date: ?struct {
                    date_range: ?struct {
                        after_value: ?[]const u8 = null,
                        before_value: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .after_value = "AfterValue",
                                .before_value = "BeforeValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date_range = "DateRange",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .entity_id = "EntityId",
                        .name = "Name",
                        .product_id = "ProductId",
                        .created_date = "CreatedDate",
                        .availability_end_date = "AvailabilityEndDate",
                        .manufacturer_account_id = "ManufacturerAccountId",
                        .product_name = "ProductName",
                        .manufacturer_legal_name = "ManufacturerLegalName",
                        .reseller_account_id = "ResellerAccountID",
                        .reseller_legal_name = "ResellerLegalName",
                        .status = "Status",
                        .offer_extended_status = "OfferExtendedStatus",
                        .last_modified_date = "LastModifiedDate",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_product_filters = "DataProductFilters",
                    .saa_s_product_filters = "SaaSProductFilters",
                    .ami_product_filters = "AmiProductFilters",
                    .offer_filters = "OfferFilters",
                    .container_product_filters = "ContainerProductFilters",
                    .resale_authorization_filters = "ResaleAuthorizationFilters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        entity_type_sort: ?union {
            data_product_sort: ?struct {
                sort_by: ?[]const u8 = null,
                sort_order: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .sort_by = "SortBy",
                        .sort_order = "SortOrder",
                    };
                    return @field(mappings, field_name);
                }
            },
            saa_s_product_sort: ?struct {
                sort_by: ?[]const u8 = null,
                sort_order: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .sort_by = "SortBy",
                        .sort_order = "SortOrder",
                    };
                    return @field(mappings, field_name);
                }
            },
            ami_product_sort: ?struct {
                sort_by: ?[]const u8 = null,
                sort_order: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .sort_by = "SortBy",
                        .sort_order = "SortOrder",
                    };
                    return @field(mappings, field_name);
                }
            },
            offer_sort: ?struct {
                sort_by: ?[]const u8 = null,
                sort_order: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .sort_by = "SortBy",
                        .sort_order = "SortOrder",
                    };
                    return @field(mappings, field_name);
                }
            },
            container_product_sort: ?struct {
                sort_by: ?[]const u8 = null,
                sort_order: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .sort_by = "SortBy",
                        .sort_order = "SortOrder",
                    };
                    return @field(mappings, field_name);
                }
            },
            resale_authorization_sort: ?struct {
                sort_by: ?[]const u8 = null,
                sort_order: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .sort_by = "SortBy",
                        .sort_order = "SortOrder",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_product_sort = "DataProductSort",
                    .saa_s_product_sort = "SaaSProductSort",
                    .ami_product_sort = "AmiProductSort",
                    .offer_sort = "OfferSort",
                    .container_product_sort = "ContainerProductSort",
                    .resale_authorization_sort = "ResaleAuthorizationSort",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .entity_type = "EntityType",
                .filter_list = "FilterList",
                .sort = "Sort",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .ownership_type = "OwnershipType",
                .entity_type_filters = "EntityTypeFilters",
                .entity_type_sort = "EntityTypeSort",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_entities) } {
            return .{ .service_metadata = service_metadata, .action = list_entities };
        }
    },
    Response: type = struct {
        entity_summary_list: ?[]struct {
            name: ?[]const u8 = null,
            entity_type: ?[]const u8 = null,
            entity_id: ?[]const u8 = null,
            entity_arn: ?[]const u8 = null,
            last_modified_date: ?[]const u8 = null,
            visibility: ?[]const u8 = null,
            ami_product_summary: ?struct {
                product_title: ?[]const u8 = null,
                visibility: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .product_title = "ProductTitle",
                        .visibility = "Visibility",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            container_product_summary: ?struct {
                product_title: ?[]const u8 = null,
                visibility: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .product_title = "ProductTitle",
                        .visibility = "Visibility",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            data_product_summary: ?struct {
                product_title: ?[]const u8 = null,
                visibility: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .product_title = "ProductTitle",
                        .visibility = "Visibility",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            saa_s_product_summary: ?struct {
                product_title: ?[]const u8 = null,
                visibility: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .product_title = "ProductTitle",
                        .visibility = "Visibility",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            offer_summary: ?struct {
                name: ?[]const u8 = null,
                product_id: ?[]const u8 = null,
                release_date: ?[]const u8 = null,
                availability_end_date: ?[]const u8 = null,
                buyer_accounts: ?[][]const u8 = null,
                state: ?[]const u8 = null,
                targeting: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .product_id = "ProductId",
                        .release_date = "ReleaseDate",
                        .availability_end_date = "AvailabilityEndDate",
                        .buyer_accounts = "BuyerAccounts",
                        .state = "State",
                        .targeting = "Targeting",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            resale_authorization_summary: ?struct {
                name: ?[]const u8 = null,
                product_id: ?[]const u8 = null,
                product_name: ?[]const u8 = null,
                manufacturer_account_id: ?[]const u8 = null,
                manufacturer_legal_name: ?[]const u8 = null,
                reseller_account_id: ?[]const u8 = null,
                reseller_legal_name: ?[]const u8 = null,
                status: ?[]const u8 = null,
                offer_extended_status: ?[]const u8 = null,
                created_date: ?[]const u8 = null,
                availability_end_date: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .product_id = "ProductId",
                        .product_name = "ProductName",
                        .manufacturer_account_id = "ManufacturerAccountId",
                        .manufacturer_legal_name = "ManufacturerLegalName",
                        .reseller_account_id = "ResellerAccountID",
                        .reseller_legal_name = "ResellerLegalName",
                        .status = "Status",
                        .offer_extended_status = "OfferExtendedStatus",
                        .created_date = "CreatedDate",
                        .availability_end_date = "AvailabilityEndDate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .entity_type = "EntityType",
                    .entity_id = "EntityId",
                    .entity_arn = "EntityArn",
                    .last_modified_date = "LastModifiedDate",
                    .visibility = "Visibility",
                    .ami_product_summary = "AmiProductSummary",
                    .container_product_summary = "ContainerProductSummary",
                    .data_product_summary = "DataProductSummary",
                    .saa_s_product_summary = "SaaSProductSummary",
                    .offer_summary = "OfferSummary",
                    .resale_authorization_summary = "ResaleAuthorizationSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_summary_list = "EntitySummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListTagsForResource",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_resource_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/PutResourcePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_change_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/StartChangeSet",
        .success_code = 200,
    };

    action_name: []const u8 = "StartChangeSet",
    Request: type = struct {
        catalog: []const u8,
        change_set: []struct {
            change_type: []const u8,
            entity: Entity,
            entity_tags: ?[]Tag = null,
            details: ?[]const u8 = null,
            details_document: ?[]const u8 = null,
            change_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .change_type = "ChangeType",
                    .entity = "Entity",
                    .entity_tags = "EntityTags",
                    .details = "Details",
                    .details_document = "DetailsDocument",
                    .change_name = "ChangeName",
                };
                return @field(mappings, field_name);
            }
        },
        change_set_name: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        change_set_tags: ?[]Tag = null,
        intent: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .change_set = "ChangeSet",
                .change_set_name = "ChangeSetName",
                .client_request_token = "ClientRequestToken",
                .change_set_tags = "ChangeSetTags",
                .intent = "Intent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_change_set) } {
            return .{ .service_metadata = service_metadata, .action = start_change_set };
        }
    },
    Response: type = struct {
        change_set_id: ?[]const u8 = null,
        change_set_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_set_id = "ChangeSetId",
                .change_set_arn = "ChangeSetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceInUse,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/TagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UntagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Entity = struct {
    type: []const u8,
    identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .identifier = "Identifier",
        };
        return @field(mappings, field_name);
    }
};

pub const Sort = struct {
    sort_by: ?[]const u8 = null,
    sort_order: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sort_by = "SortBy",
            .sort_order = "SortOrder",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    value_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value_list = "ValueList",
        };
        return @field(mappings, field_name);
    }
};
