const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-07-01";
pub const sdk_id: []const u8 = "Marketplace Commerce Analytics";
pub const arn_namespace: ?[]const u8 = "marketplacecommerceanalytics";
pub const endpoint_prefix: []const u8 = "marketplacecommerceanalytics";
pub const sigv4_name: []const u8 = "marketplacecommerceanalytics";
pub const name: []const u8 = "MarketplaceCommerceAnalytics20150701";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-07-01",
    sdk_id: []const u8 = "Marketplace Commerce Analytics",
    arn_namespace: ?[]const u8 = "marketplacecommerceanalytics",
    endpoint_prefix: []const u8 = "marketplacecommerceanalytics",
    sigv4_name: []const u8 = "marketplacecommerceanalytics",
    name: []const u8 = "MarketplaceCommerceAnalytics20150701",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const generate_data_set: struct {
    action_name: []const u8 = "GenerateDataSet",
    Request: type = struct {
        data_set_type: []const u8,
        data_set_publication_date: i64,
        role_name_arn: []const u8,
        destination_s3_bucket_name: []const u8,
        destination_s3_prefix: ?[]const u8 = null,
        sns_topic_arn: []const u8,
        customer_defined_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_type = "dataSetType",
                .data_set_publication_date = "dataSetPublicationDate",
                .role_name_arn = "roleNameArn",
                .destination_s3_bucket_name = "destinationS3BucketName",
                .destination_s3_prefix = "destinationS3Prefix",
                .sns_topic_arn = "snsTopicArn",
                .customer_defined_values = "customerDefinedValues",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "customer_defined_values", field_name))
                return try serializeMap(self.customer_defined_values, self.fieldNameFor("customer_defined_values"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_data_set) } {
            return .{ .service_metadata = service_metadata, .action = generate_data_set };
        }
    },
    Response: type = struct {
        data_set_request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_request_id = "dataSetRequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        MarketplaceCommerceAnalytics,
    },
} = .{};
pub const start_support_data_export: struct {
    action_name: []const u8 = "StartSupportDataExport",
    Request: type = struct {
        data_set_type: []const u8,
        from_date: i64,
        role_name_arn: []const u8,
        destination_s3_bucket_name: []const u8,
        destination_s3_prefix: ?[]const u8 = null,
        sns_topic_arn: []const u8,
        customer_defined_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_type = "dataSetType",
                .from_date = "fromDate",
                .role_name_arn = "roleNameArn",
                .destination_s3_bucket_name = "destinationS3BucketName",
                .destination_s3_prefix = "destinationS3Prefix",
                .sns_topic_arn = "snsTopicArn",
                .customer_defined_values = "customerDefinedValues",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "customer_defined_values", field_name))
                return try serializeMap(self.customer_defined_values, self.fieldNameFor("customer_defined_values"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_support_data_export) } {
            return .{ .service_metadata = service_metadata, .action = start_support_data_export };
        }
    },
    Response: type = struct {
        data_set_request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_request_id = "dataSetRequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        MarketplaceCommerceAnalytics,
    },
} = .{};
