const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-01-11";
pub const sdk_id: []const u8 = "Marketplace Entitlement Service";
pub const arn_namespace: ?[]const u8 = "aws-marketplace";
pub const endpoint_prefix: []const u8 = "entitlement.marketplace";
pub const sigv4_name: []const u8 = "aws-marketplace";
pub const name: []const u8 = "AWSMPEntitlementService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-01-11",
    sdk_id: []const u8 = "Marketplace Entitlement Service",
    arn_namespace: ?[]const u8 = "aws-marketplace",
    endpoint_prefix: []const u8 = "entitlement.marketplace",
    sigv4_name: []const u8 = "aws-marketplace",
    name: []const u8 = "AWSMPEntitlementService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const get_entitlements: struct {
    action_name: []const u8 = "GetEntitlements",
    Request: type = struct {
        product_code: []const u8,
        filter: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_code = "ProductCode",
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filter", field_name))
                return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_entitlements) } {
            return .{ .service_metadata = service_metadata, .action = get_entitlements };
        }
    },
    Response: type = struct {
        entitlements: ?[]struct {
            product_code: ?[]const u8 = null,
            dimension: ?[]const u8 = null,
            customer_identifier: ?[]const u8 = null,
            value: ?struct {
                integer_value: ?i64 = null,
                double_value: ?f64 = null,
                boolean_value: ?bool = null,
                string_value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .integer_value = "IntegerValue",
                        .double_value = "DoubleValue",
                        .boolean_value = "BooleanValue",
                        .string_value = "StringValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            expiration_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .product_code = "ProductCode",
                    .dimension = "Dimension",
                    .customer_identifier = "CustomerIdentifier",
                    .value = "Value",
                    .expiration_date = "ExpirationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitlements = "Entitlements",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        Throttling,
    },
} = .{};
