const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-01-14";
pub const sdk_id: []const u8 = "Marketplace Metering";
pub const arn_namespace: ?[]const u8 = "aws-marketplace";
pub const endpoint_prefix: []const u8 = "metering.marketplace";
pub const sigv4_name: []const u8 = "aws-marketplace";
pub const name: []const u8 = "AWSMPMeteringService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-01-14",
    sdk_id: []const u8 = "Marketplace Metering",
    arn_namespace: ?[]const u8 = "aws-marketplace",
    endpoint_prefix: []const u8 = "metering.marketplace",
    sigv4_name: []const u8 = "aws-marketplace",
    name: []const u8 = "AWSMPMeteringService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_meter_usage: struct {
    action_name: []const u8 = "BatchMeterUsage",
    Request: type = struct {
        usage_records: []UsageRecord,
        product_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_records = "UsageRecords",
                .product_code = "ProductCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_meter_usage) } {
            return .{ .service_metadata = service_metadata, .action = batch_meter_usage };
        }
    },
    Response: type = struct {
        results: ?[]struct {
            usage_record: ?UsageRecord = null,
            metering_record_id: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .usage_record = "UsageRecord",
                    .metering_record_id = "MeteringRecordId",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unprocessed_records: ?[]UsageRecord = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .unprocessed_records = "UnprocessedRecords",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledApi,
        InternalServiceError,
        InvalidCustomerIdentifier,
        InvalidProductCode,
        InvalidTag,
        InvalidUsageAllocations,
        InvalidUsageDimension,
        Throttling,
        TimestampOutOfBounds,
    },
} = .{};
pub const meter_usage: struct {
    action_name: []const u8 = "MeterUsage",
    Request: type = struct {
        product_code: []const u8,
        timestamp: i64,
        usage_dimension: []const u8,
        usage_quantity: ?i64 = null,
        dry_run: ?bool = null,
        usage_allocations: ?[]UsageAllocation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_code = "ProductCode",
                .timestamp = "Timestamp",
                .usage_dimension = "UsageDimension",
                .usage_quantity = "UsageQuantity",
                .dry_run = "DryRun",
                .usage_allocations = "UsageAllocations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(meter_usage) } {
            return .{ .service_metadata = service_metadata, .action = meter_usage };
        }
    },
    Response: type = struct {
        metering_record_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metering_record_id = "MeteringRecordId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomerNotEntitled,
        DuplicateRequest,
        InternalServiceError,
        InvalidEndpointRegion,
        InvalidProductCode,
        InvalidTag,
        InvalidUsageAllocations,
        InvalidUsageDimension,
        Throttling,
        TimestampOutOfBounds,
    },
} = .{};
pub const register_usage: struct {
    action_name: []const u8 = "RegisterUsage",
    Request: type = struct {
        product_code: []const u8,
        public_key_version: i64,
        nonce: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_code = "ProductCode",
                .public_key_version = "PublicKeyVersion",
                .nonce = "Nonce",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_usage) } {
            return .{ .service_metadata = service_metadata, .action = register_usage };
        }
    },
    Response: type = struct {
        public_key_rotation_timestamp: ?i64 = null,
        signature: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_key_rotation_timestamp = "PublicKeyRotationTimestamp",
                .signature = "Signature",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomerNotEntitled,
        DisabledApi,
        InternalServiceError,
        InvalidProductCode,
        InvalidPublicKeyVersion,
        InvalidRegion,
        PlatformNotSupported,
        Throttling,
    },
} = .{};
pub const resolve_customer: struct {
    action_name: []const u8 = "ResolveCustomer",
    Request: type = struct {
        registration_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_token = "RegistrationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resolve_customer) } {
            return .{ .service_metadata = service_metadata, .action = resolve_customer };
        }
    },
    Response: type = struct {
        customer_identifier: ?[]const u8 = null,
        product_code: ?[]const u8 = null,
        customer_aws_account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_identifier = "CustomerIdentifier",
                .product_code = "ProductCode",
                .customer_aws_account_id = "CustomerAWSAccountId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledApi,
        ExpiredToken,
        InternalServiceError,
        InvalidToken,
        Throttling,
    },
} = .{};

pub const UsageAllocation = struct {
    allocated_usage_quantity: i64,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allocated_usage_quantity = "AllocatedUsageQuantity",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const UsageRecord = struct {
    timestamp: i64,
    customer_identifier: []const u8,
    dimension: []const u8,
    quantity: ?i64 = null,
    usage_allocations: ?[]UsageAllocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestamp = "Timestamp",
            .customer_identifier = "CustomerIdentifier",
            .dimension = "Dimension",
            .quantity = "Quantity",
            .usage_allocations = "UsageAllocations",
        };
        return @field(mappings, field_name);
    }
};
