const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-14";
pub const sdk_id: []const u8 = "MediaConnect";
pub const arn_namespace: ?[]const u8 = "mediaconnect";
pub const endpoint_prefix: []const u8 = "mediaconnect";
pub const sigv4_name: []const u8 = "mediaconnect";
pub const name: []const u8 = "MediaConnect";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-14",
    sdk_id: []const u8 = "MediaConnect",
    arn_namespace: ?[]const u8 = "mediaconnect",
    endpoint_prefix: []const u8 = "mediaconnect",
    sigv4_name: []const u8 = "mediaconnect",
    name: []const u8 = "MediaConnect",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const add_bridge_outputs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/bridges/{BridgeArn}/outputs",
        .success_code = 202,
    };

    action_name: []const u8 = "AddBridgeOutputs",
    Request: type = struct {
        bridge_arn: []const u8,
        outputs: []AddBridgeOutputRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "BridgeArn",
                .outputs = "outputs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_bridge_outputs) } {
            return .{ .service_metadata = service_metadata, .action = add_bridge_outputs };
        }
    },
    Response: type = struct {
        bridge_arn: ?[]const u8 = null,
        outputs: ?[]BridgeOutput = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "bridgeArn",
                .outputs = "outputs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const add_bridge_sources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/bridges/{BridgeArn}/sources",
        .success_code = 202,
    };

    action_name: []const u8 = "AddBridgeSources",
    Request: type = struct {
        bridge_arn: []const u8,
        sources: []AddBridgeSourceRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "BridgeArn",
                .sources = "sources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_bridge_sources) } {
            return .{ .service_metadata = service_metadata, .action = add_bridge_sources };
        }
    },
    Response: type = struct {
        bridge_arn: ?[]const u8 = null,
        sources: ?[]BridgeSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "bridgeArn",
                .sources = "sources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const add_flow_media_streams: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/flows/{FlowArn}/mediaStreams",
        .success_code = 201,
    };

    action_name: []const u8 = "AddFlowMediaStreams",
    Request: type = struct {
        flow_arn: []const u8,
        media_streams: []AddMediaStreamRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
                .media_streams = "mediaStreams",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_flow_media_streams) } {
            return .{ .service_metadata = service_metadata, .action = add_flow_media_streams };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        media_streams: ?[]MediaStream = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .media_streams = "mediaStreams",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const add_flow_outputs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/flows/{FlowArn}/outputs",
        .success_code = 201,
    };

    action_name: []const u8 = "AddFlowOutputs",
    Request: type = struct {
        flow_arn: []const u8,
        outputs: []AddOutputRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
                .outputs = "outputs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_flow_outputs) } {
            return .{ .service_metadata = service_metadata, .action = add_flow_outputs };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        outputs: ?[]Output = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .outputs = "outputs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AddFlowOutputs420,
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const add_flow_sources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/flows/{FlowArn}/source",
        .success_code = 201,
    };

    action_name: []const u8 = "AddFlowSources",
    Request: type = struct {
        flow_arn: []const u8,
        sources: []SetSourceRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
                .sources = "sources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_flow_sources) } {
            return .{ .service_metadata = service_metadata, .action = add_flow_sources };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        sources: ?[]Source = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .sources = "sources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const add_flow_vpc_interfaces: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/flows/{FlowArn}/vpcInterfaces",
        .success_code = 201,
    };

    action_name: []const u8 = "AddFlowVpcInterfaces",
    Request: type = struct {
        flow_arn: []const u8,
        vpc_interfaces: []VpcInterfaceRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
                .vpc_interfaces = "vpcInterfaces",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_flow_vpc_interfaces) } {
            return .{ .service_metadata = service_metadata, .action = add_flow_vpc_interfaces };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        vpc_interfaces: ?[]VpcInterface = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .vpc_interfaces = "vpcInterfaces",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const create_bridge: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/bridges",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateBridge",
    Request: type = struct {
        egress_gateway_bridge: ?struct {
            max_bitrate: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .max_bitrate = "maxBitrate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        ingress_gateway_bridge: ?struct {
            max_bitrate: i64,
            max_outputs: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .max_bitrate = "maxBitrate",
                    .max_outputs = "maxOutputs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        name: []const u8,
        outputs: ?[]AddBridgeOutputRequest = null,
        placement_arn: []const u8,
        source_failover_config: ?FailoverConfig = null,
        sources: []AddBridgeSourceRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .egress_gateway_bridge = "egressGatewayBridge",
                .ingress_gateway_bridge = "ingressGatewayBridge",
                .name = "name",
                .outputs = "outputs",
                .placement_arn = "placementArn",
                .source_failover_config = "sourceFailoverConfig",
                .sources = "sources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bridge) } {
            return .{ .service_metadata = service_metadata, .action = create_bridge };
        }
    },
    Response: type = struct {
        bridge: ?Bridge = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge = "bridge",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        CreateBridge420,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const create_flow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/flows",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateFlow",
    Request: type = struct {
        availability_zone: ?[]const u8 = null,
        entitlements: ?[]GrantEntitlementRequest = null,
        media_streams: ?[]AddMediaStreamRequest = null,
        name: []const u8,
        outputs: ?[]AddOutputRequest = null,
        source: ?SetSourceRequest = null,
        source_failover_config: ?FailoverConfig = null,
        sources: ?[]SetSourceRequest = null,
        vpc_interfaces: ?[]VpcInterfaceRequest = null,
        maintenance: ?struct {
            maintenance_day: []const u8,
            maintenance_start_hour: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .maintenance_day = "maintenanceDay",
                    .maintenance_start_hour = "maintenanceStartHour",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zone = "availabilityZone",
                .entitlements = "entitlements",
                .media_streams = "mediaStreams",
                .name = "name",
                .outputs = "outputs",
                .source = "source",
                .source_failover_config = "sourceFailoverConfig",
                .sources = "sources",
                .vpc_interfaces = "vpcInterfaces",
                .maintenance = "maintenance",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_flow) } {
            return .{ .service_metadata = service_metadata, .action = create_flow };
        }
    },
    Response: type = struct {
        flow: ?Flow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow = "flow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        CreateFlow420,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const create_gateway: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/gateways",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateGateway",
    Request: type = struct {
        egress_cidr_blocks: [][]const u8,
        name: []const u8,
        networks: []GatewayNetwork,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .egress_cidr_blocks = "egressCidrBlocks",
                .name = "name",
                .networks = "networks",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_gateway };
        }
    },
    Response: type = struct {
        gateway: ?Gateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway = "gateway",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        CreateGateway420,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const delete_bridge: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/bridges/{BridgeArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBridge",
    Request: type = struct {
        bridge_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "BridgeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bridge) } {
            return .{ .service_metadata = service_metadata, .action = delete_bridge };
        }
    },
    Response: type = struct {
        bridge_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "bridgeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const delete_flow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/flows/{FlowArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteFlow",
    Request: type = struct {
        flow_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_flow) } {
            return .{ .service_metadata = service_metadata, .action = delete_flow };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const delete_gateway: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/gateways/{GatewayArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGateway",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_gateway };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "gatewayArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const deregister_gateway_instance: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/gateway-instances/{GatewayInstanceArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeregisterGatewayInstance",
    Request: type = struct {
        force: ?bool = null,
        gateway_instance_arn: []const u8,

        pub const http_query = .{
            .force = "force",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .force = "Force",
                .gateway_instance_arn = "GatewayInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_gateway_instance) } {
            return .{ .service_metadata = service_metadata, .action = deregister_gateway_instance };
        }
    },
    Response: type = struct {
        gateway_instance_arn: ?[]const u8 = null,
        instance_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_instance_arn = "gatewayInstanceArn",
                .instance_state = "instanceState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const describe_bridge: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/bridges/{BridgeArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBridge",
    Request: type = struct {
        bridge_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "BridgeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bridge) } {
            return .{ .service_metadata = service_metadata, .action = describe_bridge };
        }
    },
    Response: type = struct {
        bridge: ?Bridge = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge = "bridge",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const describe_flow: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/flows/{FlowArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFlow",
    Request: type = struct {
        flow_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_flow) } {
            return .{ .service_metadata = service_metadata, .action = describe_flow };
        }
    },
    Response: type = struct {
        flow: ?Flow = null,
        messages: ?struct {
            errors: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .errors = "errors",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow = "flow",
                .messages = "messages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const describe_flow_source_metadata: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/flows/{FlowArn}/source-metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFlowSourceMetadata",
    Request: type = struct {
        flow_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_flow_source_metadata) } {
            return .{ .service_metadata = service_metadata, .action = describe_flow_source_metadata };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        messages: ?[]MessageDetail = null,
        timestamp: ?i64 = null,
        transport_media_info: ?struct {
            programs: []struct {
                pcr_pid: i64,
                program_name: ?[]const u8 = null,
                program_number: i64,
                program_pid: i64,
                streams: []struct {
                    channels: ?i64 = null,
                    codec: ?[]const u8 = null,
                    frame_rate: ?[]const u8 = null,
                    frame_resolution: ?struct {
                        frame_height: i64,
                        frame_width: i64,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .frame_height = "frameHeight",
                                .frame_width = "frameWidth",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    pid: i64,
                    sample_rate: ?i64 = null,
                    sample_size: ?i64 = null,
                    stream_type: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .channels = "channels",
                            .codec = "codec",
                            .frame_rate = "frameRate",
                            .frame_resolution = "frameResolution",
                            .pid = "pid",
                            .sample_rate = "sampleRate",
                            .sample_size = "sampleSize",
                            .stream_type = "streamType",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pcr_pid = "pcrPid",
                        .program_name = "programName",
                        .program_number = "programNumber",
                        .program_pid = "programPid",
                        .streams = "streams",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .programs = "programs",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .messages = "messages",
                .timestamp = "timestamp",
                .transport_media_info = "transportMediaInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const describe_gateway: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/gateways/{GatewayArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGateway",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_gateway) } {
            return .{ .service_metadata = service_metadata, .action = describe_gateway };
        }
    },
    Response: type = struct {
        gateway: ?Gateway = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway = "gateway",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const describe_gateway_instance: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/gateway-instances/{GatewayInstanceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGatewayInstance",
    Request: type = struct {
        gateway_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_instance_arn = "GatewayInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_gateway_instance) } {
            return .{ .service_metadata = service_metadata, .action = describe_gateway_instance };
        }
    },
    Response: type = struct {
        gateway_instance: ?struct {
            bridge_placement: []const u8,
            connection_status: []const u8,
            gateway_arn: []const u8,
            gateway_instance_arn: []const u8,
            instance_id: []const u8,
            instance_messages: ?[]MessageDetail = null,
            instance_state: []const u8,
            running_bridge_count: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bridge_placement = "bridgePlacement",
                    .connection_status = "connectionStatus",
                    .gateway_arn = "gatewayArn",
                    .gateway_instance_arn = "gatewayInstanceArn",
                    .instance_id = "instanceId",
                    .instance_messages = "instanceMessages",
                    .instance_state = "instanceState",
                    .running_bridge_count = "runningBridgeCount",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_instance = "gatewayInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const describe_offering: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/offerings/{OfferingArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOffering",
    Request: type = struct {
        offering_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering_arn = "OfferingArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_offering) } {
            return .{ .service_metadata = service_metadata, .action = describe_offering };
        }
    },
    Response: type = struct {
        offering: ?Offering = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering = "offering",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const describe_reservation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/reservations/{ReservationArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeReservation",
    Request: type = struct {
        reservation_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reservation_arn = "ReservationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reservation) } {
            return .{ .service_metadata = service_metadata, .action = describe_reservation };
        }
    },
    Response: type = struct {
        reservation: ?Reservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reservation = "reservation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const grant_flow_entitlements: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/flows/{FlowArn}/entitlements",
        .success_code = 200,
    };

    action_name: []const u8 = "GrantFlowEntitlements",
    Request: type = struct {
        entitlements: []GrantEntitlementRequest,
        flow_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitlements = "entitlements",
                .flow_arn = "FlowArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(grant_flow_entitlements) } {
            return .{ .service_metadata = service_metadata, .action = grant_flow_entitlements };
        }
    },
    Response: type = struct {
        entitlements: ?[]Entitlement = null,
        flow_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitlements = "entitlements",
                .flow_arn = "flowArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        GrantFlowEntitlements420,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const list_bridges: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/bridges",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBridges",
    Request: type = struct {
        filter_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .filter_arn = "filterArn",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_arn = "FilterArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bridges) } {
            return .{ .service_metadata = service_metadata, .action = list_bridges };
        }
    },
    Response: type = struct {
        bridges: ?[]struct {
            bridge_arn: []const u8,
            bridge_state: []const u8,
            bridge_type: []const u8,
            name: []const u8,
            placement_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bridge_arn = "bridgeArn",
                    .bridge_state = "bridgeState",
                    .bridge_type = "bridgeType",
                    .name = "name",
                    .placement_arn = "placementArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridges = "bridges",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const list_entitlements: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/entitlements",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEntitlements",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_entitlements) } {
            return .{ .service_metadata = service_metadata, .action = list_entitlements };
        }
    },
    Response: type = struct {
        entitlements: ?[]struct {
            data_transfer_subscriber_fee_percent: ?i64 = null,
            entitlement_arn: []const u8,
            entitlement_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_transfer_subscriber_fee_percent = "dataTransferSubscriberFeePercent",
                    .entitlement_arn = "entitlementArn",
                    .entitlement_name = "entitlementName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitlements = "entitlements",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const list_flows: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/flows",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFlows",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_flows) } {
            return .{ .service_metadata = service_metadata, .action = list_flows };
        }
    },
    Response: type = struct {
        flows: ?[]struct {
            availability_zone: []const u8,
            description: []const u8,
            flow_arn: []const u8,
            name: []const u8,
            source_type: []const u8,
            status: []const u8,
            maintenance: ?Maintenance = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .availability_zone = "availabilityZone",
                    .description = "description",
                    .flow_arn = "flowArn",
                    .name = "name",
                    .source_type = "sourceType",
                    .status = "status",
                    .maintenance = "maintenance",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flows = "flows",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const list_gateway_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/gateway-instances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGatewayInstances",
    Request: type = struct {
        filter_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .filter_arn = "filterArn",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_arn = "FilterArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_gateway_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_gateway_instances };
        }
    },
    Response: type = struct {
        instances: ?[]struct {
            gateway_arn: []const u8,
            gateway_instance_arn: []const u8,
            instance_id: []const u8,
            instance_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .gateway_arn = "gatewayArn",
                    .gateway_instance_arn = "gatewayInstanceArn",
                    .instance_id = "instanceId",
                    .instance_state = "instanceState",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "instances",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const list_gateways: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/gateways",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGateways",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_gateways) } {
            return .{ .service_metadata = service_metadata, .action = list_gateways };
        }
    },
    Response: type = struct {
        gateways: ?[]struct {
            gateway_arn: []const u8,
            gateway_state: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .gateway_arn = "gatewayArn",
                    .gateway_state = "gatewayState",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateways = "gateways",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const list_offerings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/offerings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOfferings",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_offerings) } {
            return .{ .service_metadata = service_metadata, .action = list_offerings };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        offerings: ?[]Offering = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .offerings = "offerings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const list_reservations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/reservations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReservations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_reservations) } {
            return .{ .service_metadata = service_metadata, .action = list_reservations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        reservations: ?[]Reservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .reservations = "reservations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const purchase_offering: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/offerings/{OfferingArn}",
        .success_code = 201,
    };

    action_name: []const u8 = "PurchaseOffering",
    Request: type = struct {
        offering_arn: []const u8,
        reservation_name: []const u8,
        start: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering_arn = "OfferingArn",
                .reservation_name = "reservationName",
                .start = "start",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_offering) } {
            return .{ .service_metadata = service_metadata, .action = purchase_offering };
        }
    },
    Response: type = struct {
        reservation: ?Reservation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reservation = "reservation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const remove_bridge_output: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/bridges/{BridgeArn}/outputs/{OutputName}",
        .success_code = 202,
    };

    action_name: []const u8 = "RemoveBridgeOutput",
    Request: type = struct {
        bridge_arn: []const u8,
        output_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "BridgeArn",
                .output_name = "OutputName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_bridge_output) } {
            return .{ .service_metadata = service_metadata, .action = remove_bridge_output };
        }
    },
    Response: type = struct {
        bridge_arn: ?[]const u8 = null,
        output_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "bridgeArn",
                .output_name = "outputName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const remove_bridge_source: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/bridges/{BridgeArn}/sources/{SourceName}",
        .success_code = 202,
    };

    action_name: []const u8 = "RemoveBridgeSource",
    Request: type = struct {
        bridge_arn: []const u8,
        source_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "BridgeArn",
                .source_name = "SourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_bridge_source) } {
            return .{ .service_metadata = service_metadata, .action = remove_bridge_source };
        }
    },
    Response: type = struct {
        bridge_arn: ?[]const u8 = null,
        source_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "bridgeArn",
                .source_name = "sourceName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const remove_flow_media_stream: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/flows/{FlowArn}/mediaStreams/{MediaStreamName}",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveFlowMediaStream",
    Request: type = struct {
        flow_arn: []const u8,
        media_stream_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
                .media_stream_name = "MediaStreamName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_flow_media_stream) } {
            return .{ .service_metadata = service_metadata, .action = remove_flow_media_stream };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        media_stream_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .media_stream_name = "mediaStreamName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const remove_flow_output: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/flows/{FlowArn}/outputs/{OutputArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "RemoveFlowOutput",
    Request: type = struct {
        flow_arn: []const u8,
        output_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
                .output_arn = "OutputArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_flow_output) } {
            return .{ .service_metadata = service_metadata, .action = remove_flow_output };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        output_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .output_arn = "outputArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const remove_flow_source: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/flows/{FlowArn}/source/{SourceArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "RemoveFlowSource",
    Request: type = struct {
        flow_arn: []const u8,
        source_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
                .source_arn = "SourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_flow_source) } {
            return .{ .service_metadata = service_metadata, .action = remove_flow_source };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .source_arn = "sourceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const remove_flow_vpc_interface: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/flows/{FlowArn}/vpcInterfaces/{VpcInterfaceName}",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveFlowVpcInterface",
    Request: type = struct {
        flow_arn: []const u8,
        vpc_interface_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
                .vpc_interface_name = "VpcInterfaceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_flow_vpc_interface) } {
            return .{ .service_metadata = service_metadata, .action = remove_flow_vpc_interface };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        non_deleted_network_interface_ids: ?[][]const u8 = null,
        vpc_interface_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .non_deleted_network_interface_ids = "nonDeletedNetworkInterfaceIds",
                .vpc_interface_name = "vpcInterfaceName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const revoke_flow_entitlement: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/flows/{FlowArn}/entitlements/{EntitlementArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "RevokeFlowEntitlement",
    Request: type = struct {
        entitlement_arn: []const u8,
        flow_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitlement_arn = "EntitlementArn",
                .flow_arn = "FlowArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_flow_entitlement) } {
            return .{ .service_metadata = service_metadata, .action = revoke_flow_entitlement };
        }
    },
    Response: type = struct {
        entitlement_arn: ?[]const u8 = null,
        flow_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitlement_arn = "entitlementArn",
                .flow_arn = "flowArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const start_flow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/flows/start/{FlowArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "StartFlow",
    Request: type = struct {
        flow_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_flow) } {
            return .{ .service_metadata = service_metadata, .action = start_flow };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const stop_flow: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/flows/stop/{FlowArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "StopFlow",
    Request: type = struct {
        flow_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_flow) } {
            return .{ .service_metadata = service_metadata, .action = stop_flow };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const update_bridge: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/bridges/{BridgeArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBridge",
    Request: type = struct {
        bridge_arn: []const u8,
        egress_gateway_bridge: ?struct {
            max_bitrate: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .max_bitrate = "maxBitrate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        ingress_gateway_bridge: ?struct {
            max_bitrate: ?i64 = null,
            max_outputs: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .max_bitrate = "maxBitrate",
                    .max_outputs = "maxOutputs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        source_failover_config: ?UpdateFailoverConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "BridgeArn",
                .egress_gateway_bridge = "egressGatewayBridge",
                .ingress_gateway_bridge = "ingressGatewayBridge",
                .source_failover_config = "sourceFailoverConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bridge) } {
            return .{ .service_metadata = service_metadata, .action = update_bridge };
        }
    },
    Response: type = struct {
        bridge: ?Bridge = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge = "bridge",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const update_bridge_output: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/bridges/{BridgeArn}/outputs/{OutputName}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBridgeOutput",
    Request: type = struct {
        bridge_arn: []const u8,
        network_output: ?struct {
            ip_address: ?[]const u8 = null,
            network_name: ?[]const u8 = null,
            port: ?i64 = null,
            protocol: ?[]const u8 = null,
            ttl: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ip_address = "ipAddress",
                    .network_name = "networkName",
                    .port = "port",
                    .protocol = "protocol",
                    .ttl = "ttl",
                };
                return @field(mappings, field_name);
            }
        } = null,
        output_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "BridgeArn",
                .network_output = "networkOutput",
                .output_name = "OutputName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bridge_output) } {
            return .{ .service_metadata = service_metadata, .action = update_bridge_output };
        }
    },
    Response: type = struct {
        bridge_arn: ?[]const u8 = null,
        output: ?BridgeOutput = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "bridgeArn",
                .output = "output",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const update_bridge_source: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/bridges/{BridgeArn}/sources/{SourceName}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBridgeSource",
    Request: type = struct {
        bridge_arn: []const u8,
        flow_source: ?struct {
            flow_arn: ?[]const u8 = null,
            flow_vpc_interface_attachment: ?VpcInterfaceAttachment = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .flow_arn = "flowArn",
                    .flow_vpc_interface_attachment = "flowVpcInterfaceAttachment",
                };
                return @field(mappings, field_name);
            }
        } = null,
        network_source: ?struct {
            multicast_ip: ?[]const u8 = null,
            network_name: ?[]const u8 = null,
            port: ?i64 = null,
            protocol: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .multicast_ip = "multicastIp",
                    .network_name = "networkName",
                    .port = "port",
                    .protocol = "protocol",
                };
                return @field(mappings, field_name);
            }
        } = null,
        source_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "BridgeArn",
                .flow_source = "flowSource",
                .network_source = "networkSource",
                .source_name = "SourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bridge_source) } {
            return .{ .service_metadata = service_metadata, .action = update_bridge_source };
        }
    },
    Response: type = struct {
        bridge_arn: ?[]const u8 = null,
        source: ?BridgeSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "bridgeArn",
                .source = "source",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const update_bridge_state: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/bridges/{BridgeArn}/state",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBridgeState",
    Request: type = struct {
        bridge_arn: []const u8,
        desired_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "BridgeArn",
                .desired_state = "desiredState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bridge_state) } {
            return .{ .service_metadata = service_metadata, .action = update_bridge_state };
        }
    },
    Response: type = struct {
        bridge_arn: ?[]const u8 = null,
        desired_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_arn = "bridgeArn",
                .desired_state = "desiredState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const update_flow: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/flows/{FlowArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateFlow",
    Request: type = struct {
        flow_arn: []const u8,
        source_failover_config: ?UpdateFailoverConfig = null,
        maintenance: ?struct {
            maintenance_day: ?[]const u8 = null,
            maintenance_scheduled_date: ?[]const u8 = null,
            maintenance_start_hour: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .maintenance_day = "maintenanceDay",
                    .maintenance_scheduled_date = "maintenanceScheduledDate",
                    .maintenance_start_hour = "maintenanceStartHour",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "FlowArn",
                .source_failover_config = "sourceFailoverConfig",
                .maintenance = "maintenance",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_flow) } {
            return .{ .service_metadata = service_metadata, .action = update_flow };
        }
    },
    Response: type = struct {
        flow: ?Flow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow = "flow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const update_flow_entitlement: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/flows/{FlowArn}/entitlements/{EntitlementArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateFlowEntitlement",
    Request: type = struct {
        description: ?[]const u8 = null,
        encryption: ?UpdateEncryption = null,
        entitlement_arn: []const u8,
        entitlement_status: ?[]const u8 = null,
        flow_arn: []const u8,
        subscribers: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .encryption = "encryption",
                .entitlement_arn = "EntitlementArn",
                .entitlement_status = "entitlementStatus",
                .flow_arn = "FlowArn",
                .subscribers = "subscribers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_flow_entitlement) } {
            return .{ .service_metadata = service_metadata, .action = update_flow_entitlement };
        }
    },
    Response: type = struct {
        entitlement: ?Entitlement = null,
        flow_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entitlement = "entitlement",
                .flow_arn = "flowArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const update_flow_media_stream: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/flows/{FlowArn}/mediaStreams/{MediaStreamName}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateFlowMediaStream",
    Request: type = struct {
        attributes: ?MediaStreamAttributesRequest = null,
        clock_rate: ?i64 = null,
        description: ?[]const u8 = null,
        flow_arn: []const u8,
        media_stream_name: []const u8,
        media_stream_type: ?[]const u8 = null,
        video_format: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "attributes",
                .clock_rate = "clockRate",
                .description = "description",
                .flow_arn = "FlowArn",
                .media_stream_name = "MediaStreamName",
                .media_stream_type = "mediaStreamType",
                .video_format = "videoFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_flow_media_stream) } {
            return .{ .service_metadata = service_metadata, .action = update_flow_media_stream };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        media_stream: ?MediaStream = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .media_stream = "mediaStream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const update_flow_output: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/flows/{FlowArn}/outputs/{OutputArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateFlowOutput",
    Request: type = struct {
        cidr_allow_list: ?[][]const u8 = null,
        description: ?[]const u8 = null,
        destination: ?[]const u8 = null,
        encryption: ?UpdateEncryption = null,
        flow_arn: []const u8,
        max_latency: ?i64 = null,
        media_stream_output_configurations: ?[]MediaStreamOutputConfigurationRequest = null,
        min_latency: ?i64 = null,
        output_arn: []const u8,
        port: ?i64 = null,
        protocol: ?[]const u8 = null,
        remote_id: ?[]const u8 = null,
        sender_control_port: ?i64 = null,
        sender_ip_address: ?[]const u8 = null,
        smoothing_latency: ?i64 = null,
        stream_id: ?[]const u8 = null,
        vpc_interface_attachment: ?VpcInterfaceAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cidr_allow_list = "cidrAllowList",
                .description = "description",
                .destination = "destination",
                .encryption = "encryption",
                .flow_arn = "FlowArn",
                .max_latency = "maxLatency",
                .media_stream_output_configurations = "mediaStreamOutputConfigurations",
                .min_latency = "minLatency",
                .output_arn = "OutputArn",
                .port = "port",
                .protocol = "protocol",
                .remote_id = "remoteId",
                .sender_control_port = "senderControlPort",
                .sender_ip_address = "senderIpAddress",
                .smoothing_latency = "smoothingLatency",
                .stream_id = "streamId",
                .vpc_interface_attachment = "vpcInterfaceAttachment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_flow_output) } {
            return .{ .service_metadata = service_metadata, .action = update_flow_output };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        output: ?Output = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .output = "output",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const update_flow_source: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/flows/{FlowArn}/source/{SourceArn}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateFlowSource",
    Request: type = struct {
        decryption: ?UpdateEncryption = null,
        description: ?[]const u8 = null,
        entitlement_arn: ?[]const u8 = null,
        flow_arn: []const u8,
        ingest_port: ?i64 = null,
        max_bitrate: ?i64 = null,
        max_latency: ?i64 = null,
        max_sync_buffer: ?i64 = null,
        media_stream_source_configurations: ?[]MediaStreamSourceConfigurationRequest = null,
        min_latency: ?i64 = null,
        protocol: ?[]const u8 = null,
        sender_control_port: ?i64 = null,
        sender_ip_address: ?[]const u8 = null,
        source_arn: []const u8,
        source_listener_address: ?[]const u8 = null,
        source_listener_port: ?i64 = null,
        stream_id: ?[]const u8 = null,
        vpc_interface_name: ?[]const u8 = null,
        whitelist_cidr: ?[]const u8 = null,
        gateway_bridge_source: ?struct {
            bridge_arn: ?[]const u8 = null,
            vpc_interface_attachment: ?VpcInterfaceAttachment = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bridge_arn = "bridgeArn",
                    .vpc_interface_attachment = "vpcInterfaceAttachment",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .decryption = "decryption",
                .description = "description",
                .entitlement_arn = "entitlementArn",
                .flow_arn = "FlowArn",
                .ingest_port = "ingestPort",
                .max_bitrate = "maxBitrate",
                .max_latency = "maxLatency",
                .max_sync_buffer = "maxSyncBuffer",
                .media_stream_source_configurations = "mediaStreamSourceConfigurations",
                .min_latency = "minLatency",
                .protocol = "protocol",
                .sender_control_port = "senderControlPort",
                .sender_ip_address = "senderIpAddress",
                .source_arn = "SourceArn",
                .source_listener_address = "sourceListenerAddress",
                .source_listener_port = "sourceListenerPort",
                .stream_id = "streamId",
                .vpc_interface_name = "vpcInterfaceName",
                .whitelist_cidr = "whitelistCidr",
                .gateway_bridge_source = "gatewayBridgeSource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_flow_source) } {
            return .{ .service_metadata = service_metadata, .action = update_flow_source };
        }
    },
    Response: type = struct {
        flow_arn: ?[]const u8 = null,
        source: ?Source = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_arn = "flowArn",
                .source = "source",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};
pub const update_gateway_instance: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/gateway-instances/{GatewayInstanceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGatewayInstance",
    Request: type = struct {
        bridge_placement: ?[]const u8 = null,
        gateway_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_placement = "bridgePlacement",
                .gateway_instance_arn = "GatewayInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_gateway_instance) } {
            return .{ .service_metadata = service_metadata, .action = update_gateway_instance };
        }
    },
    Response: type = struct {
        bridge_placement: ?[]const u8 = null,
        gateway_instance_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bridge_placement = "bridgePlacement",
                .gateway_instance_arn = "gatewayInstanceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
    },
} = .{};

pub const Source = struct {
    data_transfer_subscriber_fee_percent: ?i64 = null,
    decryption: ?Encryption = null,
    description: ?[]const u8 = null,
    entitlement_arn: ?[]const u8 = null,
    ingest_ip: ?[]const u8 = null,
    ingest_port: ?i64 = null,
    media_stream_source_configurations: ?[]MediaStreamSourceConfiguration = null,
    name: []const u8,
    sender_control_port: ?i64 = null,
    sender_ip_address: ?[]const u8 = null,
    source_arn: []const u8,
    transport: ?Transport = null,
    vpc_interface_name: ?[]const u8 = null,
    whitelist_cidr: ?[]const u8 = null,
    gateway_bridge_source: ?GatewayBridgeSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_transfer_subscriber_fee_percent = "dataTransferSubscriberFeePercent",
            .decryption = "decryption",
            .description = "description",
            .entitlement_arn = "entitlementArn",
            .ingest_ip = "ingestIp",
            .ingest_port = "ingestPort",
            .media_stream_source_configurations = "mediaStreamSourceConfigurations",
            .name = "name",
            .sender_control_port = "senderControlPort",
            .sender_ip_address = "senderIpAddress",
            .source_arn = "sourceArn",
            .transport = "transport",
            .vpc_interface_name = "vpcInterfaceName",
            .whitelist_cidr = "whitelistCidr",
            .gateway_bridge_source = "gatewayBridgeSource",
        };
        return @field(mappings, field_name);
    }
};

pub const GatewayBridgeSource = struct {
    bridge_arn: []const u8,
    vpc_interface_attachment: ?VpcInterfaceAttachment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bridge_arn = "bridgeArn",
            .vpc_interface_attachment = "vpcInterfaceAttachment",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcInterfaceAttachment = struct {
    vpc_interface_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_interface_name = "vpcInterfaceName",
        };
        return @field(mappings, field_name);
    }
};

pub const Transport = struct {
    cidr_allow_list: ?[][]const u8 = null,
    max_bitrate: ?i64 = null,
    max_latency: ?i64 = null,
    max_sync_buffer: ?i64 = null,
    min_latency: ?i64 = null,
    protocol: []const u8,
    remote_id: ?[]const u8 = null,
    sender_control_port: ?i64 = null,
    sender_ip_address: ?[]const u8 = null,
    smoothing_latency: ?i64 = null,
    source_listener_address: ?[]const u8 = null,
    source_listener_port: ?i64 = null,
    stream_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_allow_list = "cidrAllowList",
            .max_bitrate = "maxBitrate",
            .max_latency = "maxLatency",
            .max_sync_buffer = "maxSyncBuffer",
            .min_latency = "minLatency",
            .protocol = "protocol",
            .remote_id = "remoteId",
            .sender_control_port = "senderControlPort",
            .sender_ip_address = "senderIpAddress",
            .smoothing_latency = "smoothingLatency",
            .source_listener_address = "sourceListenerAddress",
            .source_listener_port = "sourceListenerPort",
            .stream_id = "streamId",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaStreamSourceConfiguration = struct {
    encoding_name: []const u8,
    input_configurations: ?[]InputConfiguration = null,
    media_stream_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encoding_name = "encodingName",
            .input_configurations = "inputConfigurations",
            .media_stream_name = "mediaStreamName",
        };
        return @field(mappings, field_name);
    }
};

pub const InputConfiguration = struct {
    input_ip: []const u8,
    input_port: i64,
    interface: Interface,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_ip = "inputIp",
            .input_port = "inputPort",
            .interface = "interface",
        };
        return @field(mappings, field_name);
    }
};

pub const Interface = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const Encryption = struct {
    algorithm: ?[]const u8 = null,
    constant_initialization_vector: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    key_type: ?[]const u8 = null,
    region: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    role_arn: []const u8,
    secret_arn: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .algorithm = "algorithm",
            .constant_initialization_vector = "constantInitializationVector",
            .device_id = "deviceId",
            .key_type = "keyType",
            .region = "region",
            .resource_id = "resourceId",
            .role_arn = "roleArn",
            .secret_arn = "secretArn",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaStreamSourceConfigurationRequest = struct {
    encoding_name: []const u8,
    input_configurations: ?[]InputConfigurationRequest = null,
    media_stream_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encoding_name = "encodingName",
            .input_configurations = "inputConfigurations",
            .media_stream_name = "mediaStreamName",
        };
        return @field(mappings, field_name);
    }
};

pub const InputConfigurationRequest = struct {
    input_port: i64,
    interface: InterfaceRequest,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_port = "inputPort",
            .interface = "interface",
        };
        return @field(mappings, field_name);
    }
};

pub const InterfaceRequest = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateEncryption = struct {
    algorithm: ?[]const u8 = null,
    constant_initialization_vector: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    key_type: ?[]const u8 = null,
    region: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    secret_arn: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .algorithm = "algorithm",
            .constant_initialization_vector = "constantInitializationVector",
            .device_id = "deviceId",
            .key_type = "keyType",
            .region = "region",
            .resource_id = "resourceId",
            .role_arn = "roleArn",
            .secret_arn = "secretArn",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};

pub const Output = struct {
    data_transfer_subscriber_fee_percent: ?i64 = null,
    description: ?[]const u8 = null,
    destination: ?[]const u8 = null,
    encryption: ?Encryption = null,
    entitlement_arn: ?[]const u8 = null,
    listener_address: ?[]const u8 = null,
    media_live_input_arn: ?[]const u8 = null,
    media_stream_output_configurations: ?[]MediaStreamOutputConfiguration = null,
    name: []const u8,
    output_arn: []const u8,
    port: ?i64 = null,
    transport: ?Transport = null,
    vpc_interface_attachment: ?VpcInterfaceAttachment = null,
    bridge_arn: ?[]const u8 = null,
    bridge_ports: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_transfer_subscriber_fee_percent = "dataTransferSubscriberFeePercent",
            .description = "description",
            .destination = "destination",
            .encryption = "encryption",
            .entitlement_arn = "entitlementArn",
            .listener_address = "listenerAddress",
            .media_live_input_arn = "mediaLiveInputArn",
            .media_stream_output_configurations = "mediaStreamOutputConfigurations",
            .name = "name",
            .output_arn = "outputArn",
            .port = "port",
            .transport = "transport",
            .vpc_interface_attachment = "vpcInterfaceAttachment",
            .bridge_arn = "bridgeArn",
            .bridge_ports = "bridgePorts",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaStreamOutputConfiguration = struct {
    destination_configurations: ?[]DestinationConfiguration = null,
    encoding_name: []const u8,
    encoding_parameters: ?EncodingParameters = null,
    media_stream_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_configurations = "destinationConfigurations",
            .encoding_name = "encodingName",
            .encoding_parameters = "encodingParameters",
            .media_stream_name = "mediaStreamName",
        };
        return @field(mappings, field_name);
    }
};

pub const EncodingParameters = struct {
    compression_factor: f64,
    encoder_profile: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compression_factor = "compressionFactor",
            .encoder_profile = "encoderProfile",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationConfiguration = struct {
    destination_ip: []const u8,
    destination_port: i64,
    interface: Interface,
    outbound_ip: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_ip = "destinationIp",
            .destination_port = "destinationPort",
            .interface = "interface",
            .outbound_ip = "outboundIp",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaStreamOutputConfigurationRequest = struct {
    destination_configurations: ?[]DestinationConfigurationRequest = null,
    encoding_name: []const u8,
    encoding_parameters: ?EncodingParametersRequest = null,
    media_stream_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_configurations = "destinationConfigurations",
            .encoding_name = "encodingName",
            .encoding_parameters = "encodingParameters",
            .media_stream_name = "mediaStreamName",
        };
        return @field(mappings, field_name);
    }
};

pub const EncodingParametersRequest = struct {
    compression_factor: f64,
    encoder_profile: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compression_factor = "compressionFactor",
            .encoder_profile = "encoderProfile",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationConfigurationRequest = struct {
    destination_ip: []const u8,
    destination_port: i64,
    interface: InterfaceRequest,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_ip = "destinationIp",
            .destination_port = "destinationPort",
            .interface = "interface",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaStream = struct {
    attributes: ?MediaStreamAttributes = null,
    clock_rate: ?i64 = null,
    description: ?[]const u8 = null,
    fmt: i64,
    media_stream_id: i64,
    media_stream_name: []const u8,
    media_stream_type: []const u8,
    video_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "attributes",
            .clock_rate = "clockRate",
            .description = "description",
            .fmt = "fmt",
            .media_stream_id = "mediaStreamId",
            .media_stream_name = "mediaStreamName",
            .media_stream_type = "mediaStreamType",
            .video_format = "videoFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaStreamAttributes = struct {
    fmtp: Fmtp,
    lang: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fmtp = "fmtp",
            .lang = "lang",
        };
        return @field(mappings, field_name);
    }
};

pub const Fmtp = struct {
    channel_order: ?[]const u8 = null,
    colorimetry: ?[]const u8 = null,
    exact_framerate: ?[]const u8 = null,
    par: ?[]const u8 = null,
    range: ?[]const u8 = null,
    scan_mode: ?[]const u8 = null,
    tcs: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_order = "channelOrder",
            .colorimetry = "colorimetry",
            .exact_framerate = "exactFramerate",
            .par = "par",
            .range = "range",
            .scan_mode = "scanMode",
            .tcs = "tcs",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaStreamAttributesRequest = struct {
    fmtp: ?FmtpRequest = null,
    lang: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fmtp = "fmtp",
            .lang = "lang",
        };
        return @field(mappings, field_name);
    }
};

pub const FmtpRequest = struct {
    channel_order: ?[]const u8 = null,
    colorimetry: ?[]const u8 = null,
    exact_framerate: ?[]const u8 = null,
    par: ?[]const u8 = null,
    range: ?[]const u8 = null,
    scan_mode: ?[]const u8 = null,
    tcs: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_order = "channelOrder",
            .colorimetry = "colorimetry",
            .exact_framerate = "exactFramerate",
            .par = "par",
            .range = "range",
            .scan_mode = "scanMode",
            .tcs = "tcs",
        };
        return @field(mappings, field_name);
    }
};

pub const Entitlement = struct {
    data_transfer_subscriber_fee_percent: ?i64 = null,
    description: ?[]const u8 = null,
    encryption: ?Encryption = null,
    entitlement_arn: []const u8,
    entitlement_status: ?[]const u8 = null,
    name: []const u8,
    subscribers: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_transfer_subscriber_fee_percent = "dataTransferSubscriberFeePercent",
            .description = "description",
            .encryption = "encryption",
            .entitlement_arn = "entitlementArn",
            .entitlement_status = "entitlementStatus",
            .name = "name",
            .subscribers = "subscribers",
        };
        return @field(mappings, field_name);
    }
};

pub const Flow = struct {
    availability_zone: []const u8,
    description: ?[]const u8 = null,
    egress_ip: ?[]const u8 = null,
    entitlements: []Entitlement,
    flow_arn: []const u8,
    media_streams: ?[]MediaStream = null,
    name: []const u8,
    outputs: []Output,
    source: Source,
    source_failover_config: ?FailoverConfig = null,
    sources: ?[]Source = null,
    status: []const u8,
    vpc_interfaces: ?[]VpcInterface = null,
    maintenance: ?Maintenance = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "availabilityZone",
            .description = "description",
            .egress_ip = "egressIp",
            .entitlements = "entitlements",
            .flow_arn = "flowArn",
            .media_streams = "mediaStreams",
            .name = "name",
            .outputs = "outputs",
            .source = "source",
            .source_failover_config = "sourceFailoverConfig",
            .sources = "sources",
            .status = "status",
            .vpc_interfaces = "vpcInterfaces",
            .maintenance = "maintenance",
        };
        return @field(mappings, field_name);
    }
};

pub const Maintenance = struct {
    maintenance_day: ?[]const u8 = null,
    maintenance_deadline: ?[]const u8 = null,
    maintenance_scheduled_date: ?[]const u8 = null,
    maintenance_start_hour: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maintenance_day = "maintenanceDay",
            .maintenance_deadline = "maintenanceDeadline",
            .maintenance_scheduled_date = "maintenanceScheduledDate",
            .maintenance_start_hour = "maintenanceStartHour",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcInterface = struct {
    name: []const u8,
    network_interface_ids: [][]const u8,
    network_interface_type: []const u8,
    role_arn: []const u8,
    security_group_ids: [][]const u8,
    subnet_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .network_interface_ids = "networkInterfaceIds",
            .network_interface_type = "networkInterfaceType",
            .role_arn = "roleArn",
            .security_group_ids = "securityGroupIds",
            .subnet_id = "subnetId",
        };
        return @field(mappings, field_name);
    }
};

pub const FailoverConfig = struct {
    failover_mode: ?[]const u8 = null,
    recovery_window: ?i64 = null,
    source_priority: ?SourcePriority = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failover_mode = "failoverMode",
            .recovery_window = "recoveryWindow",
            .source_priority = "sourcePriority",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const SourcePriority = struct {
    primary_source: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_source = "primarySource",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateFailoverConfig = struct {
    failover_mode: ?[]const u8 = null,
    recovery_window: ?i64 = null,
    source_priority: ?SourcePriority = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failover_mode = "failoverMode",
            .recovery_window = "recoveryWindow",
            .source_priority = "sourcePriority",
            .state = "state",
        };
        return @field(mappings, field_name);
    }
};

pub const BridgeSource = struct {
    flow_source: ?BridgeFlowSource = null,
    network_source: ?BridgeNetworkSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_source = "flowSource",
            .network_source = "networkSource",
        };
        return @field(mappings, field_name);
    }
};

pub const BridgeNetworkSource = struct {
    multicast_ip: []const u8,
    name: []const u8,
    network_name: []const u8,
    port: i64,
    protocol: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .multicast_ip = "multicastIp",
            .name = "name",
            .network_name = "networkName",
            .port = "port",
            .protocol = "protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const BridgeFlowSource = struct {
    flow_arn: []const u8,
    flow_vpc_interface_attachment: ?VpcInterfaceAttachment = null,
    name: []const u8,
    output_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_arn = "flowArn",
            .flow_vpc_interface_attachment = "flowVpcInterfaceAttachment",
            .name = "name",
            .output_arn = "outputArn",
        };
        return @field(mappings, field_name);
    }
};

pub const BridgeOutput = struct {
    flow_output: ?BridgeFlowOutput = null,
    network_output: ?BridgeNetworkOutput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_output = "flowOutput",
            .network_output = "networkOutput",
        };
        return @field(mappings, field_name);
    }
};

pub const BridgeNetworkOutput = struct {
    ip_address: []const u8,
    name: []const u8,
    network_name: []const u8,
    port: i64,
    protocol: []const u8,
    ttl: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address = "ipAddress",
            .name = "name",
            .network_name = "networkName",
            .port = "port",
            .protocol = "protocol",
            .ttl = "ttl",
        };
        return @field(mappings, field_name);
    }
};

pub const BridgeFlowOutput = struct {
    flow_arn: []const u8,
    flow_source_arn: []const u8,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_arn = "flowArn",
            .flow_source_arn = "flowSourceArn",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const Bridge = struct {
    bridge_arn: []const u8,
    bridge_messages: ?[]MessageDetail = null,
    bridge_state: []const u8,
    egress_gateway_bridge: ?EgressGatewayBridge = null,
    ingress_gateway_bridge: ?IngressGatewayBridge = null,
    name: []const u8,
    outputs: ?[]BridgeOutput = null,
    placement_arn: []const u8,
    source_failover_config: ?FailoverConfig = null,
    sources: ?[]BridgeSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bridge_arn = "bridgeArn",
            .bridge_messages = "bridgeMessages",
            .bridge_state = "bridgeState",
            .egress_gateway_bridge = "egressGatewayBridge",
            .ingress_gateway_bridge = "ingressGatewayBridge",
            .name = "name",
            .outputs = "outputs",
            .placement_arn = "placementArn",
            .source_failover_config = "sourceFailoverConfig",
            .sources = "sources",
        };
        return @field(mappings, field_name);
    }
};

pub const IngressGatewayBridge = struct {
    instance_id: ?[]const u8 = null,
    max_bitrate: i64,
    max_outputs: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "instanceId",
            .max_bitrate = "maxBitrate",
            .max_outputs = "maxOutputs",
        };
        return @field(mappings, field_name);
    }
};

pub const EgressGatewayBridge = struct {
    instance_id: ?[]const u8 = null,
    max_bitrate: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "instanceId",
            .max_bitrate = "maxBitrate",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageDetail = struct {
    code: []const u8,
    message: []const u8,
    resource_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
            .resource_name = "resourceName",
        };
        return @field(mappings, field_name);
    }
};

pub const Reservation = struct {
    currency_code: []const u8,
    duration: i64,
    duration_units: []const u8,
    end: []const u8,
    offering_arn: []const u8,
    offering_description: []const u8,
    price_per_unit: []const u8,
    price_units: []const u8,
    reservation_arn: []const u8,
    reservation_name: []const u8,
    reservation_state: []const u8,
    resource_specification: ResourceSpecification,
    start: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .currency_code = "currencyCode",
            .duration = "duration",
            .duration_units = "durationUnits",
            .end = "end",
            .offering_arn = "offeringArn",
            .offering_description = "offeringDescription",
            .price_per_unit = "pricePerUnit",
            .price_units = "priceUnits",
            .reservation_arn = "reservationArn",
            .reservation_name = "reservationName",
            .reservation_state = "reservationState",
            .resource_specification = "resourceSpecification",
            .start = "start",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceSpecification = struct {
    reserved_bitrate: ?i64 = null,
    resource_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reserved_bitrate = "reservedBitrate",
            .resource_type = "resourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const Offering = struct {
    currency_code: []const u8,
    duration: i64,
    duration_units: []const u8,
    offering_arn: []const u8,
    offering_description: []const u8,
    price_per_unit: []const u8,
    price_units: []const u8,
    resource_specification: ResourceSpecification,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .currency_code = "currencyCode",
            .duration = "duration",
            .duration_units = "durationUnits",
            .offering_arn = "offeringArn",
            .offering_description = "offeringDescription",
            .price_per_unit = "pricePerUnit",
            .price_units = "priceUnits",
            .resource_specification = "resourceSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const GrantEntitlementRequest = struct {
    data_transfer_subscriber_fee_percent: ?i64 = null,
    description: ?[]const u8 = null,
    encryption: ?Encryption = null,
    entitlement_status: ?[]const u8 = null,
    name: ?[]const u8 = null,
    subscribers: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_transfer_subscriber_fee_percent = "dataTransferSubscriberFeePercent",
            .description = "description",
            .encryption = "encryption",
            .entitlement_status = "entitlementStatus",
            .name = "name",
            .subscribers = "subscribers",
        };
        return @field(mappings, field_name);
    }
};

pub const Gateway = struct {
    egress_cidr_blocks: [][]const u8,
    gateway_arn: []const u8,
    gateway_messages: ?[]MessageDetail = null,
    gateway_state: ?[]const u8 = null,
    name: []const u8,
    networks: []GatewayNetwork,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .egress_cidr_blocks = "egressCidrBlocks",
            .gateway_arn = "gatewayArn",
            .gateway_messages = "gatewayMessages",
            .gateway_state = "gatewayState",
            .name = "name",
            .networks = "networks",
        };
        return @field(mappings, field_name);
    }
};

pub const GatewayNetwork = struct {
    cidr_block: []const u8,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_block = "cidrBlock",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcInterfaceRequest = struct {
    name: []const u8,
    network_interface_type: ?[]const u8 = null,
    role_arn: []const u8,
    security_group_ids: [][]const u8,
    subnet_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .network_interface_type = "networkInterfaceType",
            .role_arn = "roleArn",
            .security_group_ids = "securityGroupIds",
            .subnet_id = "subnetId",
        };
        return @field(mappings, field_name);
    }
};

pub const SetSourceRequest = struct {
    decryption: ?Encryption = null,
    description: ?[]const u8 = null,
    entitlement_arn: ?[]const u8 = null,
    ingest_port: ?i64 = null,
    max_bitrate: ?i64 = null,
    max_latency: ?i64 = null,
    max_sync_buffer: ?i64 = null,
    media_stream_source_configurations: ?[]MediaStreamSourceConfigurationRequest = null,
    min_latency: ?i64 = null,
    name: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    sender_control_port: ?i64 = null,
    sender_ip_address: ?[]const u8 = null,
    source_listener_address: ?[]const u8 = null,
    source_listener_port: ?i64 = null,
    stream_id: ?[]const u8 = null,
    vpc_interface_name: ?[]const u8 = null,
    whitelist_cidr: ?[]const u8 = null,
    gateway_bridge_source: ?SetGatewayBridgeSourceRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .decryption = "decryption",
            .description = "description",
            .entitlement_arn = "entitlementArn",
            .ingest_port = "ingestPort",
            .max_bitrate = "maxBitrate",
            .max_latency = "maxLatency",
            .max_sync_buffer = "maxSyncBuffer",
            .media_stream_source_configurations = "mediaStreamSourceConfigurations",
            .min_latency = "minLatency",
            .name = "name",
            .protocol = "protocol",
            .sender_control_port = "senderControlPort",
            .sender_ip_address = "senderIpAddress",
            .source_listener_address = "sourceListenerAddress",
            .source_listener_port = "sourceListenerPort",
            .stream_id = "streamId",
            .vpc_interface_name = "vpcInterfaceName",
            .whitelist_cidr = "whitelistCidr",
            .gateway_bridge_source = "gatewayBridgeSource",
        };
        return @field(mappings, field_name);
    }
};

pub const SetGatewayBridgeSourceRequest = struct {
    bridge_arn: []const u8,
    vpc_interface_attachment: ?VpcInterfaceAttachment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bridge_arn = "bridgeArn",
            .vpc_interface_attachment = "vpcInterfaceAttachment",
        };
        return @field(mappings, field_name);
    }
};

pub const AddOutputRequest = struct {
    cidr_allow_list: ?[][]const u8 = null,
    description: ?[]const u8 = null,
    destination: ?[]const u8 = null,
    encryption: ?Encryption = null,
    max_latency: ?i64 = null,
    media_stream_output_configurations: ?[]MediaStreamOutputConfigurationRequest = null,
    min_latency: ?i64 = null,
    name: ?[]const u8 = null,
    port: ?i64 = null,
    protocol: []const u8,
    remote_id: ?[]const u8 = null,
    sender_control_port: ?i64 = null,
    smoothing_latency: ?i64 = null,
    stream_id: ?[]const u8 = null,
    vpc_interface_attachment: ?VpcInterfaceAttachment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidr_allow_list = "cidrAllowList",
            .description = "description",
            .destination = "destination",
            .encryption = "encryption",
            .max_latency = "maxLatency",
            .media_stream_output_configurations = "mediaStreamOutputConfigurations",
            .min_latency = "minLatency",
            .name = "name",
            .port = "port",
            .protocol = "protocol",
            .remote_id = "remoteId",
            .sender_control_port = "senderControlPort",
            .smoothing_latency = "smoothingLatency",
            .stream_id = "streamId",
            .vpc_interface_attachment = "vpcInterfaceAttachment",
        };
        return @field(mappings, field_name);
    }
};

pub const AddMediaStreamRequest = struct {
    attributes: ?MediaStreamAttributesRequest = null,
    clock_rate: ?i64 = null,
    description: ?[]const u8 = null,
    media_stream_id: i64,
    media_stream_name: []const u8,
    media_stream_type: []const u8,
    video_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "attributes",
            .clock_rate = "clockRate",
            .description = "description",
            .media_stream_id = "mediaStreamId",
            .media_stream_name = "mediaStreamName",
            .media_stream_type = "mediaStreamType",
            .video_format = "videoFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const AddBridgeSourceRequest = struct {
    flow_source: ?AddBridgeFlowSourceRequest = null,
    network_source: ?AddBridgeNetworkSourceRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_source = "flowSource",
            .network_source = "networkSource",
        };
        return @field(mappings, field_name);
    }
};

pub const AddBridgeNetworkSourceRequest = struct {
    multicast_ip: []const u8,
    name: []const u8,
    network_name: []const u8,
    port: i64,
    protocol: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .multicast_ip = "multicastIp",
            .name = "name",
            .network_name = "networkName",
            .port = "port",
            .protocol = "protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const AddBridgeFlowSourceRequest = struct {
    flow_arn: []const u8,
    flow_vpc_interface_attachment: ?VpcInterfaceAttachment = null,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flow_arn = "flowArn",
            .flow_vpc_interface_attachment = "flowVpcInterfaceAttachment",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const AddBridgeOutputRequest = struct {
    network_output: ?AddBridgeNetworkOutputRequest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_output = "networkOutput",
        };
        return @field(mappings, field_name);
    }
};

pub const AddBridgeNetworkOutputRequest = struct {
    ip_address: []const u8,
    name: []const u8,
    network_name: []const u8,
    port: i64,
    protocol: []const u8,
    ttl: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address = "ipAddress",
            .name = "name",
            .network_name = "networkName",
            .port = "port",
            .protocol = "protocol",
            .ttl = "ttl",
        };
        return @field(mappings, field_name);
    }
};
