const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-08-29";
pub const sdk_id: []const u8 = "MediaConvert";
pub const arn_namespace: ?[]const u8 = "mediaconvert";
pub const endpoint_prefix: []const u8 = "mediaconvert";
pub const sigv4_name: []const u8 = "mediaconvert";
pub const name: []const u8 = "MediaConvert";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-08-29",
    sdk_id: []const u8 = "MediaConvert",
    arn_namespace: ?[]const u8 = "mediaconvert",
    endpoint_prefix: []const u8 = "mediaconvert",
    sigv4_name: []const u8 = "mediaconvert",
    name: []const u8 = "MediaConvert",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_certificate: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2017-08-29/certificates",
        .success_code = 201,
    };

    action_name: []const u8 = "AssociateCertificate",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_certificate) } {
            return .{ .service_metadata = service_metadata, .action = associate_certificate };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const cancel_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2017-08-29/jobs/{Id}",
        .success_code = 202,
    };

    action_name: []const u8 = "CancelJob",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2017-08-29/jobs",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateJob",
    Request: type = struct {
        acceleration_settings: ?AccelerationSettings = null,
        billing_tags_source: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        hop_destinations: ?[]HopDestination = null,
        job_template: ?[]const u8 = null,
        priority: ?i64 = null,
        queue: ?[]const u8 = null,
        role: []const u8,
        settings: JobSettings,
        simulate_reserved_queue: ?[]const u8 = null,
        status_update_interval: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        user_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acceleration_settings = "accelerationSettings",
                .billing_tags_source = "billingTagsSource",
                .client_request_token = "clientRequestToken",
                .hop_destinations = "hopDestinations",
                .job_template = "jobTemplate",
                .priority = "priority",
                .queue = "queue",
                .role = "role",
                .settings = "settings",
                .simulate_reserved_queue = "simulateReservedQueue",
                .status_update_interval = "statusUpdateInterval",
                .tags = "tags",
                .user_metadata = "userMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "user_metadata", field_name))
                return try serializeMap(self.user_metadata, self.fieldNameFor("user_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job) } {
            return .{ .service_metadata = service_metadata, .action = create_job };
        }
    },
    Response: type = struct {
        job: ?Job = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_job_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2017-08-29/jobTemplates",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateJobTemplate",
    Request: type = struct {
        acceleration_settings: ?AccelerationSettings = null,
        category: ?[]const u8 = null,
        description: ?[]const u8 = null,
        hop_destinations: ?[]HopDestination = null,
        name: []const u8,
        priority: ?i64 = null,
        queue: ?[]const u8 = null,
        settings: JobTemplateSettings,
        status_update_interval: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acceleration_settings = "accelerationSettings",
                .category = "category",
                .description = "description",
                .hop_destinations = "hopDestinations",
                .name = "name",
                .priority = "priority",
                .queue = "queue",
                .settings = "settings",
                .status_update_interval = "statusUpdateInterval",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job_template) } {
            return .{ .service_metadata = service_metadata, .action = create_job_template };
        }
    },
    Response: type = struct {
        job_template: ?JobTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_template = "jobTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_preset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2017-08-29/presets",
        .success_code = 201,
    };

    action_name: []const u8 = "CreatePreset",
    Request: type = struct {
        category: ?[]const u8 = null,
        description: ?[]const u8 = null,
        name: []const u8,
        settings: PresetSettings,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category = "category",
                .description = "description",
                .name = "name",
                .settings = "settings",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_preset) } {
            return .{ .service_metadata = service_metadata, .action = create_preset };
        }
    },
    Response: type = struct {
        preset: ?Preset = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .preset = "preset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_queue: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2017-08-29/queues",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateQueue",
    Request: type = struct {
        description: ?[]const u8 = null,
        name: []const u8,
        pricing_plan: ?[]const u8 = null,
        reservation_plan_settings: ?ReservationPlanSettings = null,
        status: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .name = "name",
                .pricing_plan = "pricingPlan",
                .reservation_plan_settings = "reservationPlanSettings",
                .status = "status",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_queue) } {
            return .{ .service_metadata = service_metadata, .action = create_queue };
        }
    },
    Response: type = struct {
        queue: ?Queue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue = "queue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_job_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2017-08-29/jobTemplates/{Name}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteJobTemplate",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_job_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2017-08-29/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePolicy",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_preset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2017-08-29/presets/{Name}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeletePreset",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_preset) } {
            return .{ .service_metadata = service_metadata, .action = delete_preset };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_queue: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2017-08-29/queues/{Name}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteQueue",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_queue) } {
            return .{ .service_metadata = service_metadata, .action = delete_queue };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_endpoints: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2017-08-29/endpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeEndpoints",
    Request: type = struct {
        max_results: ?i64 = null,
        mode: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .mode = "mode",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoints };
        }
    },
    Response: type = struct {
        endpoints: ?[]struct {
            url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .url = "url",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "endpoints",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const disassociate_certificate: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2017-08-29/certificates/{Arn}",
        .success_code = 202,
    };

    action_name: []const u8 = "DisassociateCertificate",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_certificate) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_certificate };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-08-29/jobs/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJob",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job) } {
            return .{ .service_metadata = service_metadata, .action = get_job };
        }
    },
    Response: type = struct {
        job: ?Job = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_job_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-08-29/jobTemplates/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJobTemplate",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_template) } {
            return .{ .service_metadata = service_metadata, .action = get_job_template };
        }
    },
    Response: type = struct {
        job_template: ?JobTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_template = "jobTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-08-29/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPolicy",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_policy };
        }
    },
    Response: type = struct {
        policy: ?Policy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_preset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-08-29/presets/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPreset",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_preset) } {
            return .{ .service_metadata = service_metadata, .action = get_preset };
        }
    },
    Response: type = struct {
        preset: ?Preset = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .preset = "preset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_queue: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-08-29/queues/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetQueue",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_queue) } {
            return .{ .service_metadata = service_metadata, .action = get_queue };
        }
    },
    Response: type = struct {
        queue: ?Queue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue = "queue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-08-29/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        order: ?[]const u8 = null,
        queue: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .order = "order",
            .queue = "queue",
            .status = "status",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .order = "Order",
                .queue = "Queue",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]Job = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_job_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-08-29/jobTemplates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobTemplates",
    Request: type = struct {
        category: ?[]const u8 = null,
        list_by: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        order: ?[]const u8 = null,

        pub const http_query = .{
            .category = "category",
            .list_by = "listBy",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .order = "order",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category = "Category",
                .list_by = "ListBy",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .order = "Order",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_job_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_job_templates };
        }
    },
    Response: type = struct {
        job_templates: ?[]JobTemplate = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_templates = "jobTemplates",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_presets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-08-29/presets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPresets",
    Request: type = struct {
        category: ?[]const u8 = null,
        list_by: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        order: ?[]const u8 = null,

        pub const http_query = .{
            .category = "category",
            .list_by = "listBy",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .order = "order",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category = "Category",
                .list_by = "ListBy",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .order = "Order",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_presets) } {
            return .{ .service_metadata = service_metadata, .action = list_presets };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        presets: ?[]Preset = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .presets = "presets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_queues: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-08-29/queues",
        .success_code = 200,
    };

    action_name: []const u8 = "ListQueues",
    Request: type = struct {
        list_by: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        order: ?[]const u8 = null,

        pub const http_query = .{
            .list_by = "listBy",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .order = "order",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .list_by = "ListBy",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .order = "Order",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_queues) } {
            return .{ .service_metadata = service_metadata, .action = list_queues };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        queues: ?[]Queue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .queues = "queues",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2017-08-29/tags/{Arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        resource_tags: ?struct {
            arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_tags = "resourceTags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2017-08-29/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutPolicy",
    Request: type = struct {
        policy: Policy,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_policy };
        }
    },
    Response: type = struct {
        policy: ?Policy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2017-08-29/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2017-08-29/tags/{Arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        arn: []const u8,
        tag_keys: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_job_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2017-08-29/jobTemplates/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJobTemplate",
    Request: type = struct {
        acceleration_settings: ?AccelerationSettings = null,
        category: ?[]const u8 = null,
        description: ?[]const u8 = null,
        hop_destinations: ?[]HopDestination = null,
        name: []const u8,
        priority: ?i64 = null,
        queue: ?[]const u8 = null,
        settings: ?JobTemplateSettings = null,
        status_update_interval: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acceleration_settings = "accelerationSettings",
                .category = "category",
                .description = "description",
                .hop_destinations = "hopDestinations",
                .name = "Name",
                .priority = "priority",
                .queue = "queue",
                .settings = "settings",
                .status_update_interval = "statusUpdateInterval",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job_template) } {
            return .{ .service_metadata = service_metadata, .action = update_job_template };
        }
    },
    Response: type = struct {
        job_template: ?JobTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_template = "jobTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_preset: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2017-08-29/presets/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePreset",
    Request: type = struct {
        category: ?[]const u8 = null,
        description: ?[]const u8 = null,
        name: []const u8,
        settings: ?PresetSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category = "category",
                .description = "description",
                .name = "Name",
                .settings = "settings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_preset) } {
            return .{ .service_metadata = service_metadata, .action = update_preset };
        }
    },
    Response: type = struct {
        preset: ?Preset = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .preset = "preset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_queue: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2017-08-29/queues/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueue",
    Request: type = struct {
        description: ?[]const u8 = null,
        name: []const u8,
        reservation_plan_settings: ?ReservationPlanSettings = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .name = "Name",
                .reservation_plan_settings = "reservationPlanSettings",
                .status = "status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue) } {
            return .{ .service_metadata = service_metadata, .action = update_queue };
        }
    },
    Response: type = struct {
        queue: ?Queue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue = "queue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const Queue = struct {
    arn: ?[]const u8 = null,
    created_at: ?i64 = null,
    description: ?[]const u8 = null,
    last_updated: ?i64 = null,
    name: []const u8,
    pricing_plan: ?[]const u8 = null,
    progressing_jobs_count: ?i64 = null,
    reservation_plan: ?ReservationPlan = null,
    status: ?[]const u8 = null,
    submitted_jobs_count: ?i64 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .created_at = "createdAt",
            .description = "description",
            .last_updated = "lastUpdated",
            .name = "name",
            .pricing_plan = "pricingPlan",
            .progressing_jobs_count = "progressingJobsCount",
            .reservation_plan = "reservationPlan",
            .status = "status",
            .submitted_jobs_count = "submittedJobsCount",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservationPlan = struct {
    commitment: ?[]const u8 = null,
    expires_at: ?i64 = null,
    purchased_at: ?i64 = null,
    renewal_type: ?[]const u8 = null,
    reserved_slots: ?i64 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .commitment = "commitment",
            .expires_at = "expiresAt",
            .purchased_at = "purchasedAt",
            .renewal_type = "renewalType",
            .reserved_slots = "reservedSlots",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservationPlanSettings = struct {
    commitment: []const u8,
    renewal_type: []const u8,
    reserved_slots: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .commitment = "commitment",
            .renewal_type = "renewalType",
            .reserved_slots = "reservedSlots",
        };
        return @field(mappings, field_name);
    }
};

pub const Preset = struct {
    arn: ?[]const u8 = null,
    category: ?[]const u8 = null,
    created_at: ?i64 = null,
    description: ?[]const u8 = null,
    last_updated: ?i64 = null,
    name: []const u8,
    settings: PresetSettings,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .category = "category",
            .created_at = "createdAt",
            .description = "description",
            .last_updated = "lastUpdated",
            .name = "name",
            .settings = "settings",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const PresetSettings = struct {
    audio_descriptions: ?[]AudioDescription = null,
    caption_descriptions: ?[]CaptionDescriptionPreset = null,
    container_settings: ?ContainerSettings = null,
    video_description: ?VideoDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_descriptions = "audioDescriptions",
            .caption_descriptions = "captionDescriptions",
            .container_settings = "containerSettings",
            .video_description = "videoDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoDescription = struct {
    afd_signaling: ?[]const u8 = null,
    anti_alias: ?[]const u8 = null,
    codec_settings: ?VideoCodecSettings = null,
    color_metadata: ?[]const u8 = null,
    crop: ?Rectangle = null,
    drop_frame_timecode: ?[]const u8 = null,
    fixed_afd: ?i64 = null,
    height: ?i64 = null,
    position: ?Rectangle = null,
    respond_to_afd: ?[]const u8 = null,
    scaling_behavior: ?[]const u8 = null,
    sharpness: ?i64 = null,
    timecode_insertion: ?[]const u8 = null,
    video_preprocessors: ?VideoPreprocessor = null,
    width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .afd_signaling = "afdSignaling",
            .anti_alias = "antiAlias",
            .codec_settings = "codecSettings",
            .color_metadata = "colorMetadata",
            .crop = "crop",
            .drop_frame_timecode = "dropFrameTimecode",
            .fixed_afd = "fixedAfd",
            .height = "height",
            .position = "position",
            .respond_to_afd = "respondToAfd",
            .scaling_behavior = "scalingBehavior",
            .sharpness = "sharpness",
            .timecode_insertion = "timecodeInsertion",
            .video_preprocessors = "videoPreprocessors",
            .width = "width",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoPreprocessor = struct {
    color_corrector: ?ColorCorrector = null,
    deinterlacer: ?Deinterlacer = null,
    dolby_vision: ?DolbyVision = null,
    hdr10_plus: ?Hdr10Plus = null,
    image_inserter: ?ImageInserter = null,
    noise_reducer: ?NoiseReducer = null,
    partner_watermarking: ?PartnerWatermarking = null,
    timecode_burnin: ?TimecodeBurnin = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .color_corrector = "colorCorrector",
            .deinterlacer = "deinterlacer",
            .dolby_vision = "dolbyVision",
            .hdr10_plus = "hdr10Plus",
            .image_inserter = "imageInserter",
            .noise_reducer = "noiseReducer",
            .partner_watermarking = "partnerWatermarking",
            .timecode_burnin = "timecodeBurnin",
        };
        return @field(mappings, field_name);
    }
};

pub const TimecodeBurnin = struct {
    font_size: ?i64 = null,
    position: ?[]const u8 = null,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .font_size = "fontSize",
            .position = "position",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const PartnerWatermarking = struct {
    nexguard_file_marker_settings: ?NexGuardFileMarkerSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nexguard_file_marker_settings = "nexguardFileMarkerSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const NexGuardFileMarkerSettings = struct {
    license: ?[]const u8 = null,
    payload: ?i64 = null,
    preset: ?[]const u8 = null,
    strength: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .license = "license",
            .payload = "payload",
            .preset = "preset",
            .strength = "strength",
        };
        return @field(mappings, field_name);
    }
};

pub const NoiseReducer = struct {
    filter: ?[]const u8 = null,
    filter_settings: ?NoiseReducerFilterSettings = null,
    spatial_filter_settings: ?NoiseReducerSpatialFilterSettings = null,
    temporal_filter_settings: ?NoiseReducerTemporalFilterSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter = "filter",
            .filter_settings = "filterSettings",
            .spatial_filter_settings = "spatialFilterSettings",
            .temporal_filter_settings = "temporalFilterSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const NoiseReducerTemporalFilterSettings = struct {
    aggressive_mode: ?i64 = null,
    post_temporal_sharpening: ?[]const u8 = null,
    post_temporal_sharpening_strength: ?[]const u8 = null,
    speed: ?i64 = null,
    strength: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aggressive_mode = "aggressiveMode",
            .post_temporal_sharpening = "postTemporalSharpening",
            .post_temporal_sharpening_strength = "postTemporalSharpeningStrength",
            .speed = "speed",
            .strength = "strength",
        };
        return @field(mappings, field_name);
    }
};

pub const NoiseReducerSpatialFilterSettings = struct {
    post_filter_sharpen_strength: ?i64 = null,
    speed: ?i64 = null,
    strength: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .post_filter_sharpen_strength = "postFilterSharpenStrength",
            .speed = "speed",
            .strength = "strength",
        };
        return @field(mappings, field_name);
    }
};

pub const NoiseReducerFilterSettings = struct {
    strength: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .strength = "strength",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageInserter = struct {
    insertable_images: ?[]InsertableImage = null,
    sdr_reference_white_level: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insertable_images = "insertableImages",
            .sdr_reference_white_level = "sdrReferenceWhiteLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const InsertableImage = struct {
    duration: ?i64 = null,
    fade_in: ?i64 = null,
    fade_out: ?i64 = null,
    height: ?i64 = null,
    image_inserter_input: ?[]const u8 = null,
    imagex: ?i64 = null,
    imagey: ?i64 = null,
    layer: ?i64 = null,
    opacity: ?i64 = null,
    start_time: ?[]const u8 = null,
    width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration = "duration",
            .fade_in = "fadeIn",
            .fade_out = "fadeOut",
            .height = "height",
            .image_inserter_input = "imageInserterInput",
            .imagex = "imageX",
            .imagey = "imageY",
            .layer = "layer",
            .opacity = "opacity",
            .start_time = "startTime",
            .width = "width",
        };
        return @field(mappings, field_name);
    }
};

pub const Hdr10Plus = struct {
    mastering_monitor_nits: ?i64 = null,
    target_monitor_nits: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mastering_monitor_nits = "masteringMonitorNits",
            .target_monitor_nits = "targetMonitorNits",
        };
        return @field(mappings, field_name);
    }
};

pub const DolbyVision = struct {
    l6_metadata: ?DolbyVisionLevel6Metadata = null,
    l6_mode: ?[]const u8 = null,
    mapping: ?[]const u8 = null,
    profile: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .l6_metadata = "l6Metadata",
            .l6_mode = "l6Mode",
            .mapping = "mapping",
            .profile = "profile",
        };
        return @field(mappings, field_name);
    }
};

pub const DolbyVisionLevel6Metadata = struct {
    max_cll: ?i64 = null,
    max_fall: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_cll = "maxCll",
            .max_fall = "maxFall",
        };
        return @field(mappings, field_name);
    }
};

pub const Deinterlacer = struct {
    algorithm: ?[]const u8 = null,
    control: ?[]const u8 = null,
    mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .algorithm = "algorithm",
            .control = "control",
            .mode = "mode",
        };
        return @field(mappings, field_name);
    }
};

pub const ColorCorrector = struct {
    brightness: ?i64 = null,
    clip_limits: ?ClipLimits = null,
    color_space_conversion: ?[]const u8 = null,
    contrast: ?i64 = null,
    hdr10_metadata: ?Hdr10Metadata = null,
    hdr_to_sdr_tone_mapper: ?[]const u8 = null,
    hue: ?i64 = null,
    max_luminance: ?i64 = null,
    sample_range_conversion: ?[]const u8 = null,
    saturation: ?i64 = null,
    sdr_reference_white_level: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .brightness = "brightness",
            .clip_limits = "clipLimits",
            .color_space_conversion = "colorSpaceConversion",
            .contrast = "contrast",
            .hdr10_metadata = "hdr10Metadata",
            .hdr_to_sdr_tone_mapper = "hdrToSdrToneMapper",
            .hue = "hue",
            .max_luminance = "maxLuminance",
            .sample_range_conversion = "sampleRangeConversion",
            .saturation = "saturation",
            .sdr_reference_white_level = "sdrReferenceWhiteLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const Hdr10Metadata = struct {
    blue_primaryx: ?i64 = null,
    blue_primaryy: ?i64 = null,
    green_primaryx: ?i64 = null,
    green_primaryy: ?i64 = null,
    max_content_light_level: ?i64 = null,
    max_frame_average_light_level: ?i64 = null,
    max_luminance: ?i64 = null,
    min_luminance: ?i64 = null,
    red_primaryx: ?i64 = null,
    red_primaryy: ?i64 = null,
    white_pointx: ?i64 = null,
    white_pointy: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .blue_primaryx = "bluePrimaryX",
            .blue_primaryy = "bluePrimaryY",
            .green_primaryx = "greenPrimaryX",
            .green_primaryy = "greenPrimaryY",
            .max_content_light_level = "maxContentLightLevel",
            .max_frame_average_light_level = "maxFrameAverageLightLevel",
            .max_luminance = "maxLuminance",
            .min_luminance = "minLuminance",
            .red_primaryx = "redPrimaryX",
            .red_primaryy = "redPrimaryY",
            .white_pointx = "whitePointX",
            .white_pointy = "whitePointY",
        };
        return @field(mappings, field_name);
    }
};

pub const ClipLimits = struct {
    maximum_rgb_tolerance: ?i64 = null,
    maximum_yuv: ?i64 = null,
    minimum_rgb_tolerance: ?i64 = null,
    minimum_yuv: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_rgb_tolerance = "maximumRGBTolerance",
            .maximum_yuv = "maximumYUV",
            .minimum_rgb_tolerance = "minimumRGBTolerance",
            .minimum_yuv = "minimumYUV",
        };
        return @field(mappings, field_name);
    }
};

pub const Rectangle = struct {
    height: ?i64 = null,
    width: ?i64 = null,
    x: ?i64 = null,
    y: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .height = "height",
            .width = "width",
            .x = "x",
            .y = "y",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoCodecSettings = struct {
    av1_settings: ?Av1Settings = null,
    avc_intra_settings: ?AvcIntraSettings = null,
    codec: ?[]const u8 = null,
    frame_capture_settings: ?FrameCaptureSettings = null,
    h264_settings: ?H264Settings = null,
    h265_settings: ?H265Settings = null,
    mpeg2_settings: ?Mpeg2Settings = null,
    prores_settings: ?ProresSettings = null,
    uncompressed_settings: ?UncompressedSettings = null,
    vc3_settings: ?Vc3Settings = null,
    vp8_settings: ?Vp8Settings = null,
    vp9_settings: ?Vp9Settings = null,
    xavc_settings: ?XavcSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .av1_settings = "av1Settings",
            .avc_intra_settings = "avcIntraSettings",
            .codec = "codec",
            .frame_capture_settings = "frameCaptureSettings",
            .h264_settings = "h264Settings",
            .h265_settings = "h265Settings",
            .mpeg2_settings = "mpeg2Settings",
            .prores_settings = "proresSettings",
            .uncompressed_settings = "uncompressedSettings",
            .vc3_settings = "vc3Settings",
            .vp8_settings = "vp8Settings",
            .vp9_settings = "vp9Settings",
            .xavc_settings = "xavcSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const XavcSettings = struct {
    adaptive_quantization: ?[]const u8 = null,
    entropy_encoding: ?[]const u8 = null,
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    profile: ?[]const u8 = null,
    slow_pal: ?[]const u8 = null,
    softness: ?i64 = null,
    spatial_adaptive_quantization: ?[]const u8 = null,
    temporal_adaptive_quantization: ?[]const u8 = null,
    xavc4k_intra_cbg_profile_settings: ?Xavc4kIntraCbgProfileSettings = null,
    xavc4k_intra_vbr_profile_settings: ?Xavc4kIntraVbrProfileSettings = null,
    xavc4k_profile_settings: ?Xavc4kProfileSettings = null,
    xavc_hd_intra_cbg_profile_settings: ?XavcHdIntraCbgProfileSettings = null,
    xavc_hd_profile_settings: ?XavcHdProfileSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adaptive_quantization = "adaptiveQuantization",
            .entropy_encoding = "entropyEncoding",
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .profile = "profile",
            .slow_pal = "slowPal",
            .softness = "softness",
            .spatial_adaptive_quantization = "spatialAdaptiveQuantization",
            .temporal_adaptive_quantization = "temporalAdaptiveQuantization",
            .xavc4k_intra_cbg_profile_settings = "xavc4kIntraCbgProfileSettings",
            .xavc4k_intra_vbr_profile_settings = "xavc4kIntraVbrProfileSettings",
            .xavc4k_profile_settings = "xavc4kProfileSettings",
            .xavc_hd_intra_cbg_profile_settings = "xavcHdIntraCbgProfileSettings",
            .xavc_hd_profile_settings = "xavcHdProfileSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const XavcHdProfileSettings = struct {
    bitrate_class: ?[]const u8 = null,
    flicker_adaptive_quantization: ?[]const u8 = null,
    gop_b_reference: ?[]const u8 = null,
    gop_closed_cadence: ?i64 = null,
    hrd_buffer_size: ?i64 = null,
    interlace_mode: ?[]const u8 = null,
    quality_tuning_level: ?[]const u8 = null,
    slices: ?i64 = null,
    telecine: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate_class = "bitrateClass",
            .flicker_adaptive_quantization = "flickerAdaptiveQuantization",
            .gop_b_reference = "gopBReference",
            .gop_closed_cadence = "gopClosedCadence",
            .hrd_buffer_size = "hrdBufferSize",
            .interlace_mode = "interlaceMode",
            .quality_tuning_level = "qualityTuningLevel",
            .slices = "slices",
            .telecine = "telecine",
        };
        return @field(mappings, field_name);
    }
};

pub const XavcHdIntraCbgProfileSettings = struct {
    xavc_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .xavc_class = "xavcClass",
        };
        return @field(mappings, field_name);
    }
};

pub const Xavc4kProfileSettings = struct {
    bitrate_class: ?[]const u8 = null,
    codec_profile: ?[]const u8 = null,
    flicker_adaptive_quantization: ?[]const u8 = null,
    gop_b_reference: ?[]const u8 = null,
    gop_closed_cadence: ?i64 = null,
    hrd_buffer_size: ?i64 = null,
    quality_tuning_level: ?[]const u8 = null,
    slices: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate_class = "bitrateClass",
            .codec_profile = "codecProfile",
            .flicker_adaptive_quantization = "flickerAdaptiveQuantization",
            .gop_b_reference = "gopBReference",
            .gop_closed_cadence = "gopClosedCadence",
            .hrd_buffer_size = "hrdBufferSize",
            .quality_tuning_level = "qualityTuningLevel",
            .slices = "slices",
        };
        return @field(mappings, field_name);
    }
};

pub const Xavc4kIntraVbrProfileSettings = struct {
    xavc_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .xavc_class = "xavcClass",
        };
        return @field(mappings, field_name);
    }
};

pub const Xavc4kIntraCbgProfileSettings = struct {
    xavc_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .xavc_class = "xavcClass",
        };
        return @field(mappings, field_name);
    }
};

pub const Vp9Settings = struct {
    bitrate: ?i64 = null,
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    gop_size: ?f64 = null,
    hrd_buffer_size: ?i64 = null,
    max_bitrate: ?i64 = null,
    par_control: ?[]const u8 = null,
    par_denominator: ?i64 = null,
    par_numerator: ?i64 = null,
    quality_tuning_level: ?[]const u8 = null,
    rate_control_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .gop_size = "gopSize",
            .hrd_buffer_size = "hrdBufferSize",
            .max_bitrate = "maxBitrate",
            .par_control = "parControl",
            .par_denominator = "parDenominator",
            .par_numerator = "parNumerator",
            .quality_tuning_level = "qualityTuningLevel",
            .rate_control_mode = "rateControlMode",
        };
        return @field(mappings, field_name);
    }
};

pub const Vp8Settings = struct {
    bitrate: ?i64 = null,
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    gop_size: ?f64 = null,
    hrd_buffer_size: ?i64 = null,
    max_bitrate: ?i64 = null,
    par_control: ?[]const u8 = null,
    par_denominator: ?i64 = null,
    par_numerator: ?i64 = null,
    quality_tuning_level: ?[]const u8 = null,
    rate_control_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .gop_size = "gopSize",
            .hrd_buffer_size = "hrdBufferSize",
            .max_bitrate = "maxBitrate",
            .par_control = "parControl",
            .par_denominator = "parDenominator",
            .par_numerator = "parNumerator",
            .quality_tuning_level = "qualityTuningLevel",
            .rate_control_mode = "rateControlMode",
        };
        return @field(mappings, field_name);
    }
};

pub const Vc3Settings = struct {
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    interlace_mode: ?[]const u8 = null,
    scan_type_conversion_mode: ?[]const u8 = null,
    slow_pal: ?[]const u8 = null,
    telecine: ?[]const u8 = null,
    vc3_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .interlace_mode = "interlaceMode",
            .scan_type_conversion_mode = "scanTypeConversionMode",
            .slow_pal = "slowPal",
            .telecine = "telecine",
            .vc3_class = "vc3Class",
        };
        return @field(mappings, field_name);
    }
};

pub const UncompressedSettings = struct {
    fourcc: ?[]const u8 = null,
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    interlace_mode: ?[]const u8 = null,
    scan_type_conversion_mode: ?[]const u8 = null,
    slow_pal: ?[]const u8 = null,
    telecine: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fourcc = "fourcc",
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .interlace_mode = "interlaceMode",
            .scan_type_conversion_mode = "scanTypeConversionMode",
            .slow_pal = "slowPal",
            .telecine = "telecine",
        };
        return @field(mappings, field_name);
    }
};

pub const ProresSettings = struct {
    chroma_sampling: ?[]const u8 = null,
    codec_profile: ?[]const u8 = null,
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    interlace_mode: ?[]const u8 = null,
    par_control: ?[]const u8 = null,
    par_denominator: ?i64 = null,
    par_numerator: ?i64 = null,
    scan_type_conversion_mode: ?[]const u8 = null,
    slow_pal: ?[]const u8 = null,
    telecine: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .chroma_sampling = "chromaSampling",
            .codec_profile = "codecProfile",
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .interlace_mode = "interlaceMode",
            .par_control = "parControl",
            .par_denominator = "parDenominator",
            .par_numerator = "parNumerator",
            .scan_type_conversion_mode = "scanTypeConversionMode",
            .slow_pal = "slowPal",
            .telecine = "telecine",
        };
        return @field(mappings, field_name);
    }
};

pub const Mpeg2Settings = struct {
    adaptive_quantization: ?[]const u8 = null,
    bitrate: ?i64 = null,
    codec_level: ?[]const u8 = null,
    codec_profile: ?[]const u8 = null,
    dynamic_sub_gop: ?[]const u8 = null,
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    gop_closed_cadence: ?i64 = null,
    gop_size: ?f64 = null,
    gop_size_units: ?[]const u8 = null,
    hrd_buffer_final_fill_percentage: ?i64 = null,
    hrd_buffer_initial_fill_percentage: ?i64 = null,
    hrd_buffer_size: ?i64 = null,
    interlace_mode: ?[]const u8 = null,
    intra_dc_precision: ?[]const u8 = null,
    max_bitrate: ?i64 = null,
    min_i_interval: ?i64 = null,
    number_b_frames_between_reference_frames: ?i64 = null,
    par_control: ?[]const u8 = null,
    par_denominator: ?i64 = null,
    par_numerator: ?i64 = null,
    quality_tuning_level: ?[]const u8 = null,
    rate_control_mode: ?[]const u8 = null,
    scan_type_conversion_mode: ?[]const u8 = null,
    scene_change_detect: ?[]const u8 = null,
    slow_pal: ?[]const u8 = null,
    softness: ?i64 = null,
    spatial_adaptive_quantization: ?[]const u8 = null,
    syntax: ?[]const u8 = null,
    telecine: ?[]const u8 = null,
    temporal_adaptive_quantization: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adaptive_quantization = "adaptiveQuantization",
            .bitrate = "bitrate",
            .codec_level = "codecLevel",
            .codec_profile = "codecProfile",
            .dynamic_sub_gop = "dynamicSubGop",
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .gop_closed_cadence = "gopClosedCadence",
            .gop_size = "gopSize",
            .gop_size_units = "gopSizeUnits",
            .hrd_buffer_final_fill_percentage = "hrdBufferFinalFillPercentage",
            .hrd_buffer_initial_fill_percentage = "hrdBufferInitialFillPercentage",
            .hrd_buffer_size = "hrdBufferSize",
            .interlace_mode = "interlaceMode",
            .intra_dc_precision = "intraDcPrecision",
            .max_bitrate = "maxBitrate",
            .min_i_interval = "minIInterval",
            .number_b_frames_between_reference_frames = "numberBFramesBetweenReferenceFrames",
            .par_control = "parControl",
            .par_denominator = "parDenominator",
            .par_numerator = "parNumerator",
            .quality_tuning_level = "qualityTuningLevel",
            .rate_control_mode = "rateControlMode",
            .scan_type_conversion_mode = "scanTypeConversionMode",
            .scene_change_detect = "sceneChangeDetect",
            .slow_pal = "slowPal",
            .softness = "softness",
            .spatial_adaptive_quantization = "spatialAdaptiveQuantization",
            .syntax = "syntax",
            .telecine = "telecine",
            .temporal_adaptive_quantization = "temporalAdaptiveQuantization",
        };
        return @field(mappings, field_name);
    }
};

pub const H265Settings = struct {
    adaptive_quantization: ?[]const u8 = null,
    alternate_transfer_function_sei: ?[]const u8 = null,
    bandwidth_reduction_filter: ?BandwidthReductionFilter = null,
    bitrate: ?i64 = null,
    codec_level: ?[]const u8 = null,
    codec_profile: ?[]const u8 = null,
    dynamic_sub_gop: ?[]const u8 = null,
    end_of_stream_markers: ?[]const u8 = null,
    flicker_adaptive_quantization: ?[]const u8 = null,
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    gop_b_reference: ?[]const u8 = null,
    gop_closed_cadence: ?i64 = null,
    gop_size: ?f64 = null,
    gop_size_units: ?[]const u8 = null,
    hrd_buffer_final_fill_percentage: ?i64 = null,
    hrd_buffer_initial_fill_percentage: ?i64 = null,
    hrd_buffer_size: ?i64 = null,
    interlace_mode: ?[]const u8 = null,
    max_bitrate: ?i64 = null,
    min_i_interval: ?i64 = null,
    number_b_frames_between_reference_frames: ?i64 = null,
    number_reference_frames: ?i64 = null,
    par_control: ?[]const u8 = null,
    par_denominator: ?i64 = null,
    par_numerator: ?i64 = null,
    quality_tuning_level: ?[]const u8 = null,
    qvbr_settings: ?H265QvbrSettings = null,
    rate_control_mode: ?[]const u8 = null,
    sample_adaptive_offset_filter_mode: ?[]const u8 = null,
    scan_type_conversion_mode: ?[]const u8 = null,
    scene_change_detect: ?[]const u8 = null,
    slices: ?i64 = null,
    slow_pal: ?[]const u8 = null,
    spatial_adaptive_quantization: ?[]const u8 = null,
    telecine: ?[]const u8 = null,
    temporal_adaptive_quantization: ?[]const u8 = null,
    temporal_ids: ?[]const u8 = null,
    tiles: ?[]const u8 = null,
    unregistered_sei_timecode: ?[]const u8 = null,
    write_mp4_packaging_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adaptive_quantization = "adaptiveQuantization",
            .alternate_transfer_function_sei = "alternateTransferFunctionSei",
            .bandwidth_reduction_filter = "bandwidthReductionFilter",
            .bitrate = "bitrate",
            .codec_level = "codecLevel",
            .codec_profile = "codecProfile",
            .dynamic_sub_gop = "dynamicSubGop",
            .end_of_stream_markers = "endOfStreamMarkers",
            .flicker_adaptive_quantization = "flickerAdaptiveQuantization",
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .gop_b_reference = "gopBReference",
            .gop_closed_cadence = "gopClosedCadence",
            .gop_size = "gopSize",
            .gop_size_units = "gopSizeUnits",
            .hrd_buffer_final_fill_percentage = "hrdBufferFinalFillPercentage",
            .hrd_buffer_initial_fill_percentage = "hrdBufferInitialFillPercentage",
            .hrd_buffer_size = "hrdBufferSize",
            .interlace_mode = "interlaceMode",
            .max_bitrate = "maxBitrate",
            .min_i_interval = "minIInterval",
            .number_b_frames_between_reference_frames = "numberBFramesBetweenReferenceFrames",
            .number_reference_frames = "numberReferenceFrames",
            .par_control = "parControl",
            .par_denominator = "parDenominator",
            .par_numerator = "parNumerator",
            .quality_tuning_level = "qualityTuningLevel",
            .qvbr_settings = "qvbrSettings",
            .rate_control_mode = "rateControlMode",
            .sample_adaptive_offset_filter_mode = "sampleAdaptiveOffsetFilterMode",
            .scan_type_conversion_mode = "scanTypeConversionMode",
            .scene_change_detect = "sceneChangeDetect",
            .slices = "slices",
            .slow_pal = "slowPal",
            .spatial_adaptive_quantization = "spatialAdaptiveQuantization",
            .telecine = "telecine",
            .temporal_adaptive_quantization = "temporalAdaptiveQuantization",
            .temporal_ids = "temporalIds",
            .tiles = "tiles",
            .unregistered_sei_timecode = "unregisteredSeiTimecode",
            .write_mp4_packaging_type = "writeMp4PackagingType",
        };
        return @field(mappings, field_name);
    }
};

pub const H265QvbrSettings = struct {
    max_average_bitrate: ?i64 = null,
    qvbr_quality_level: ?i64 = null,
    qvbr_quality_level_fine_tune: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_average_bitrate = "maxAverageBitrate",
            .qvbr_quality_level = "qvbrQualityLevel",
            .qvbr_quality_level_fine_tune = "qvbrQualityLevelFineTune",
        };
        return @field(mappings, field_name);
    }
};

pub const BandwidthReductionFilter = struct {
    sharpening: ?[]const u8 = null,
    strength: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sharpening = "sharpening",
            .strength = "strength",
        };
        return @field(mappings, field_name);
    }
};

pub const H264Settings = struct {
    adaptive_quantization: ?[]const u8 = null,
    bandwidth_reduction_filter: ?BandwidthReductionFilter = null,
    bitrate: ?i64 = null,
    codec_level: ?[]const u8 = null,
    codec_profile: ?[]const u8 = null,
    dynamic_sub_gop: ?[]const u8 = null,
    end_of_stream_markers: ?[]const u8 = null,
    entropy_encoding: ?[]const u8 = null,
    field_encoding: ?[]const u8 = null,
    flicker_adaptive_quantization: ?[]const u8 = null,
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    gop_b_reference: ?[]const u8 = null,
    gop_closed_cadence: ?i64 = null,
    gop_size: ?f64 = null,
    gop_size_units: ?[]const u8 = null,
    hrd_buffer_final_fill_percentage: ?i64 = null,
    hrd_buffer_initial_fill_percentage: ?i64 = null,
    hrd_buffer_size: ?i64 = null,
    interlace_mode: ?[]const u8 = null,
    max_bitrate: ?i64 = null,
    min_i_interval: ?i64 = null,
    number_b_frames_between_reference_frames: ?i64 = null,
    number_reference_frames: ?i64 = null,
    par_control: ?[]const u8 = null,
    par_denominator: ?i64 = null,
    par_numerator: ?i64 = null,
    quality_tuning_level: ?[]const u8 = null,
    qvbr_settings: ?H264QvbrSettings = null,
    rate_control_mode: ?[]const u8 = null,
    repeat_pps: ?[]const u8 = null,
    scan_type_conversion_mode: ?[]const u8 = null,
    scene_change_detect: ?[]const u8 = null,
    slices: ?i64 = null,
    slow_pal: ?[]const u8 = null,
    softness: ?i64 = null,
    spatial_adaptive_quantization: ?[]const u8 = null,
    syntax: ?[]const u8 = null,
    telecine: ?[]const u8 = null,
    temporal_adaptive_quantization: ?[]const u8 = null,
    unregistered_sei_timecode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adaptive_quantization = "adaptiveQuantization",
            .bandwidth_reduction_filter = "bandwidthReductionFilter",
            .bitrate = "bitrate",
            .codec_level = "codecLevel",
            .codec_profile = "codecProfile",
            .dynamic_sub_gop = "dynamicSubGop",
            .end_of_stream_markers = "endOfStreamMarkers",
            .entropy_encoding = "entropyEncoding",
            .field_encoding = "fieldEncoding",
            .flicker_adaptive_quantization = "flickerAdaptiveQuantization",
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .gop_b_reference = "gopBReference",
            .gop_closed_cadence = "gopClosedCadence",
            .gop_size = "gopSize",
            .gop_size_units = "gopSizeUnits",
            .hrd_buffer_final_fill_percentage = "hrdBufferFinalFillPercentage",
            .hrd_buffer_initial_fill_percentage = "hrdBufferInitialFillPercentage",
            .hrd_buffer_size = "hrdBufferSize",
            .interlace_mode = "interlaceMode",
            .max_bitrate = "maxBitrate",
            .min_i_interval = "minIInterval",
            .number_b_frames_between_reference_frames = "numberBFramesBetweenReferenceFrames",
            .number_reference_frames = "numberReferenceFrames",
            .par_control = "parControl",
            .par_denominator = "parDenominator",
            .par_numerator = "parNumerator",
            .quality_tuning_level = "qualityTuningLevel",
            .qvbr_settings = "qvbrSettings",
            .rate_control_mode = "rateControlMode",
            .repeat_pps = "repeatPps",
            .scan_type_conversion_mode = "scanTypeConversionMode",
            .scene_change_detect = "sceneChangeDetect",
            .slices = "slices",
            .slow_pal = "slowPal",
            .softness = "softness",
            .spatial_adaptive_quantization = "spatialAdaptiveQuantization",
            .syntax = "syntax",
            .telecine = "telecine",
            .temporal_adaptive_quantization = "temporalAdaptiveQuantization",
            .unregistered_sei_timecode = "unregisteredSeiTimecode",
        };
        return @field(mappings, field_name);
    }
};

pub const H264QvbrSettings = struct {
    max_average_bitrate: ?i64 = null,
    qvbr_quality_level: ?i64 = null,
    qvbr_quality_level_fine_tune: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_average_bitrate = "maxAverageBitrate",
            .qvbr_quality_level = "qvbrQualityLevel",
            .qvbr_quality_level_fine_tune = "qvbrQualityLevelFineTune",
        };
        return @field(mappings, field_name);
    }
};

pub const FrameCaptureSettings = struct {
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    max_captures: ?i64 = null,
    quality: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .max_captures = "maxCaptures",
            .quality = "quality",
        };
        return @field(mappings, field_name);
    }
};

pub const AvcIntraSettings = struct {
    avc_intra_class: ?[]const u8 = null,
    avc_intra_uhd_settings: ?AvcIntraUhdSettings = null,
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    interlace_mode: ?[]const u8 = null,
    scan_type_conversion_mode: ?[]const u8 = null,
    slow_pal: ?[]const u8 = null,
    telecine: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .avc_intra_class = "avcIntraClass",
            .avc_intra_uhd_settings = "avcIntraUhdSettings",
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .interlace_mode = "interlaceMode",
            .scan_type_conversion_mode = "scanTypeConversionMode",
            .slow_pal = "slowPal",
            .telecine = "telecine",
        };
        return @field(mappings, field_name);
    }
};

pub const AvcIntraUhdSettings = struct {
    quality_tuning_level: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quality_tuning_level = "qualityTuningLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const Av1Settings = struct {
    adaptive_quantization: ?[]const u8 = null,
    bit_depth: ?[]const u8 = null,
    film_grain_synthesis: ?[]const u8 = null,
    framerate_control: ?[]const u8 = null,
    framerate_conversion_algorithm: ?[]const u8 = null,
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,
    gop_size: ?f64 = null,
    max_bitrate: ?i64 = null,
    number_b_frames_between_reference_frames: ?i64 = null,
    qvbr_settings: ?Av1QvbrSettings = null,
    rate_control_mode: ?[]const u8 = null,
    slices: ?i64 = null,
    spatial_adaptive_quantization: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adaptive_quantization = "adaptiveQuantization",
            .bit_depth = "bitDepth",
            .film_grain_synthesis = "filmGrainSynthesis",
            .framerate_control = "framerateControl",
            .framerate_conversion_algorithm = "framerateConversionAlgorithm",
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
            .gop_size = "gopSize",
            .max_bitrate = "maxBitrate",
            .number_b_frames_between_reference_frames = "numberBFramesBetweenReferenceFrames",
            .qvbr_settings = "qvbrSettings",
            .rate_control_mode = "rateControlMode",
            .slices = "slices",
            .spatial_adaptive_quantization = "spatialAdaptiveQuantization",
        };
        return @field(mappings, field_name);
    }
};

pub const Av1QvbrSettings = struct {
    qvbr_quality_level: ?i64 = null,
    qvbr_quality_level_fine_tune: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .qvbr_quality_level = "qvbrQualityLevel",
            .qvbr_quality_level_fine_tune = "qvbrQualityLevelFineTune",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerSettings = struct {
    cmfc_settings: ?CmfcSettings = null,
    container: ?[]const u8 = null,
    f4v_settings: ?F4vSettings = null,
    m2ts_settings: ?M2tsSettings = null,
    m3u8_settings: ?M3u8Settings = null,
    mov_settings: ?MovSettings = null,
    mp4_settings: ?Mp4Settings = null,
    mpd_settings: ?MpdSettings = null,
    mxf_settings: ?MxfSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cmfc_settings = "cmfcSettings",
            .container = "container",
            .f4v_settings = "f4vSettings",
            .m2ts_settings = "m2tsSettings",
            .m3u8_settings = "m3u8Settings",
            .mov_settings = "movSettings",
            .mp4_settings = "mp4Settings",
            .mpd_settings = "mpdSettings",
            .mxf_settings = "mxfSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const MxfSettings = struct {
    afd_signaling: ?[]const u8 = null,
    profile: ?[]const u8 = null,
    xavc_profile_settings: ?MxfXavcProfileSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .afd_signaling = "afdSignaling",
            .profile = "profile",
            .xavc_profile_settings = "xavcProfileSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const MxfXavcProfileSettings = struct {
    duration_mode: ?[]const u8 = null,
    max_anc_data_size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration_mode = "durationMode",
            .max_anc_data_size = "maxAncDataSize",
        };
        return @field(mappings, field_name);
    }
};

pub const MpdSettings = struct {
    accessibility_caption_hints: ?[]const u8 = null,
    audio_duration: ?[]const u8 = null,
    caption_container_type: ?[]const u8 = null,
    klv_metadata: ?[]const u8 = null,
    manifest_metadata_signaling: ?[]const u8 = null,
    scte35_esam: ?[]const u8 = null,
    scte35_source: ?[]const u8 = null,
    timed_metadata: ?[]const u8 = null,
    timed_metadata_box_version: ?[]const u8 = null,
    timed_metadata_scheme_id_uri: ?[]const u8 = null,
    timed_metadata_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accessibility_caption_hints = "accessibilityCaptionHints",
            .audio_duration = "audioDuration",
            .caption_container_type = "captionContainerType",
            .klv_metadata = "klvMetadata",
            .manifest_metadata_signaling = "manifestMetadataSignaling",
            .scte35_esam = "scte35Esam",
            .scte35_source = "scte35Source",
            .timed_metadata = "timedMetadata",
            .timed_metadata_box_version = "timedMetadataBoxVersion",
            .timed_metadata_scheme_id_uri = "timedMetadataSchemeIdUri",
            .timed_metadata_value = "timedMetadataValue",
        };
        return @field(mappings, field_name);
    }
};

pub const Mp4Settings = struct {
    audio_duration: ?[]const u8 = null,
    cslg_atom: ?[]const u8 = null,
    ctts_version: ?i64 = null,
    free_space_box: ?[]const u8 = null,
    moov_placement: ?[]const u8 = null,
    mp4_major_brand: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_duration = "audioDuration",
            .cslg_atom = "cslgAtom",
            .ctts_version = "cttsVersion",
            .free_space_box = "freeSpaceBox",
            .moov_placement = "moovPlacement",
            .mp4_major_brand = "mp4MajorBrand",
        };
        return @field(mappings, field_name);
    }
};

pub const MovSettings = struct {
    clap_atom: ?[]const u8 = null,
    cslg_atom: ?[]const u8 = null,
    mpeg2_four_cc_control: ?[]const u8 = null,
    padding_control: ?[]const u8 = null,
    reference: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .clap_atom = "clapAtom",
            .cslg_atom = "cslgAtom",
            .mpeg2_four_cc_control = "mpeg2FourCCControl",
            .padding_control = "paddingControl",
            .reference = "reference",
        };
        return @field(mappings, field_name);
    }
};

pub const M3u8Settings = struct {
    audio_duration: ?[]const u8 = null,
    audio_frames_per_pes: ?i64 = null,
    audio_pids: ?[]i64 = null,
    data_pts_control: ?[]const u8 = null,
    max_pcr_interval: ?i64 = null,
    nielsen_id3: ?[]const u8 = null,
    pat_interval: ?i64 = null,
    pcr_control: ?[]const u8 = null,
    pcr_pid: ?i64 = null,
    pmt_interval: ?i64 = null,
    pmt_pid: ?i64 = null,
    private_metadata_pid: ?i64 = null,
    program_number: ?i64 = null,
    pts_offset: ?i64 = null,
    pts_offset_mode: ?[]const u8 = null,
    scte35_pid: ?i64 = null,
    scte35_source: ?[]const u8 = null,
    timed_metadata: ?[]const u8 = null,
    timed_metadata_pid: ?i64 = null,
    transport_stream_id: ?i64 = null,
    video_pid: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_duration = "audioDuration",
            .audio_frames_per_pes = "audioFramesPerPes",
            .audio_pids = "audioPids",
            .data_pts_control = "dataPTSControl",
            .max_pcr_interval = "maxPcrInterval",
            .nielsen_id3 = "nielsenId3",
            .pat_interval = "patInterval",
            .pcr_control = "pcrControl",
            .pcr_pid = "pcrPid",
            .pmt_interval = "pmtInterval",
            .pmt_pid = "pmtPid",
            .private_metadata_pid = "privateMetadataPid",
            .program_number = "programNumber",
            .pts_offset = "ptsOffset",
            .pts_offset_mode = "ptsOffsetMode",
            .scte35_pid = "scte35Pid",
            .scte35_source = "scte35Source",
            .timed_metadata = "timedMetadata",
            .timed_metadata_pid = "timedMetadataPid",
            .transport_stream_id = "transportStreamId",
            .video_pid = "videoPid",
        };
        return @field(mappings, field_name);
    }
};

pub const M2tsSettings = struct {
    audio_buffer_model: ?[]const u8 = null,
    audio_duration: ?[]const u8 = null,
    audio_frames_per_pes: ?i64 = null,
    audio_pids: ?[]i64 = null,
    bitrate: ?i64 = null,
    buffer_model: ?[]const u8 = null,
    data_pts_control: ?[]const u8 = null,
    dvb_nit_settings: ?DvbNitSettings = null,
    dvb_sdt_settings: ?DvbSdtSettings = null,
    dvb_sub_pids: ?[]i64 = null,
    dvb_tdt_settings: ?DvbTdtSettings = null,
    dvb_teletext_pid: ?i64 = null,
    ebp_audio_interval: ?[]const u8 = null,
    ebp_placement: ?[]const u8 = null,
    es_rate_in_pes: ?[]const u8 = null,
    force_ts_video_ebp_order: ?[]const u8 = null,
    fragment_time: ?f64 = null,
    klv_metadata: ?[]const u8 = null,
    max_pcr_interval: ?i64 = null,
    min_ebp_interval: ?i64 = null,
    nielsen_id3: ?[]const u8 = null,
    null_packet_bitrate: ?f64 = null,
    pat_interval: ?i64 = null,
    pcr_control: ?[]const u8 = null,
    pcr_pid: ?i64 = null,
    pmt_interval: ?i64 = null,
    pmt_pid: ?i64 = null,
    private_metadata_pid: ?i64 = null,
    program_number: ?i64 = null,
    pts_offset: ?i64 = null,
    pts_offset_mode: ?[]const u8 = null,
    rate_mode: ?[]const u8 = null,
    scte35_esam: ?M2tsScte35Esam = null,
    scte35_pid: ?i64 = null,
    scte35_source: ?[]const u8 = null,
    segmentation_markers: ?[]const u8 = null,
    segmentation_style: ?[]const u8 = null,
    segmentation_time: ?f64 = null,
    timed_metadata_pid: ?i64 = null,
    transport_stream_id: ?i64 = null,
    video_pid: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_buffer_model = "audioBufferModel",
            .audio_duration = "audioDuration",
            .audio_frames_per_pes = "audioFramesPerPes",
            .audio_pids = "audioPids",
            .bitrate = "bitrate",
            .buffer_model = "bufferModel",
            .data_pts_control = "dataPTSControl",
            .dvb_nit_settings = "dvbNitSettings",
            .dvb_sdt_settings = "dvbSdtSettings",
            .dvb_sub_pids = "dvbSubPids",
            .dvb_tdt_settings = "dvbTdtSettings",
            .dvb_teletext_pid = "dvbTeletextPid",
            .ebp_audio_interval = "ebpAudioInterval",
            .ebp_placement = "ebpPlacement",
            .es_rate_in_pes = "esRateInPes",
            .force_ts_video_ebp_order = "forceTsVideoEbpOrder",
            .fragment_time = "fragmentTime",
            .klv_metadata = "klvMetadata",
            .max_pcr_interval = "maxPcrInterval",
            .min_ebp_interval = "minEbpInterval",
            .nielsen_id3 = "nielsenId3",
            .null_packet_bitrate = "nullPacketBitrate",
            .pat_interval = "patInterval",
            .pcr_control = "pcrControl",
            .pcr_pid = "pcrPid",
            .pmt_interval = "pmtInterval",
            .pmt_pid = "pmtPid",
            .private_metadata_pid = "privateMetadataPid",
            .program_number = "programNumber",
            .pts_offset = "ptsOffset",
            .pts_offset_mode = "ptsOffsetMode",
            .rate_mode = "rateMode",
            .scte35_esam = "scte35Esam",
            .scte35_pid = "scte35Pid",
            .scte35_source = "scte35Source",
            .segmentation_markers = "segmentationMarkers",
            .segmentation_style = "segmentationStyle",
            .segmentation_time = "segmentationTime",
            .timed_metadata_pid = "timedMetadataPid",
            .transport_stream_id = "transportStreamId",
            .video_pid = "videoPid",
        };
        return @field(mappings, field_name);
    }
};

pub const M2tsScte35Esam = struct {
    scte35_esam_pid: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scte35_esam_pid = "scte35EsamPid",
        };
        return @field(mappings, field_name);
    }
};

pub const DvbTdtSettings = struct {
    tdt_interval: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tdt_interval = "tdtInterval",
        };
        return @field(mappings, field_name);
    }
};

pub const DvbSdtSettings = struct {
    output_sdt: ?[]const u8 = null,
    sdt_interval: ?i64 = null,
    service_name: ?[]const u8 = null,
    service_provider_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_sdt = "outputSdt",
            .sdt_interval = "sdtInterval",
            .service_name = "serviceName",
            .service_provider_name = "serviceProviderName",
        };
        return @field(mappings, field_name);
    }
};

pub const DvbNitSettings = struct {
    network_id: ?i64 = null,
    network_name: ?[]const u8 = null,
    nit_interval: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_id = "networkId",
            .network_name = "networkName",
            .nit_interval = "nitInterval",
        };
        return @field(mappings, field_name);
    }
};

pub const F4vSettings = struct {
    moov_placement: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .moov_placement = "moovPlacement",
        };
        return @field(mappings, field_name);
    }
};

pub const CmfcSettings = struct {
    audio_duration: ?[]const u8 = null,
    audio_group_id: ?[]const u8 = null,
    audio_rendition_sets: ?[]const u8 = null,
    audio_track_type: ?[]const u8 = null,
    descriptive_video_service_flag: ?[]const u8 = null,
    i_frame_only_manifest: ?[]const u8 = null,
    klv_metadata: ?[]const u8 = null,
    manifest_metadata_signaling: ?[]const u8 = null,
    scte35_esam: ?[]const u8 = null,
    scte35_source: ?[]const u8 = null,
    timed_metadata: ?[]const u8 = null,
    timed_metadata_box_version: ?[]const u8 = null,
    timed_metadata_scheme_id_uri: ?[]const u8 = null,
    timed_metadata_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_duration = "audioDuration",
            .audio_group_id = "audioGroupId",
            .audio_rendition_sets = "audioRenditionSets",
            .audio_track_type = "audioTrackType",
            .descriptive_video_service_flag = "descriptiveVideoServiceFlag",
            .i_frame_only_manifest = "iFrameOnlyManifest",
            .klv_metadata = "klvMetadata",
            .manifest_metadata_signaling = "manifestMetadataSignaling",
            .scte35_esam = "scte35Esam",
            .scte35_source = "scte35Source",
            .timed_metadata = "timedMetadata",
            .timed_metadata_box_version = "timedMetadataBoxVersion",
            .timed_metadata_scheme_id_uri = "timedMetadataSchemeIdUri",
            .timed_metadata_value = "timedMetadataValue",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionDescriptionPreset = struct {
    custom_language_code: ?[]const u8 = null,
    destination_settings: ?CaptionDestinationSettings = null,
    language_code: ?[]const u8 = null,
    language_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_language_code = "customLanguageCode",
            .destination_settings = "destinationSettings",
            .language_code = "languageCode",
            .language_description = "languageDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionDestinationSettings = struct {
    burnin_destination_settings: ?BurninDestinationSettings = null,
    destination_type: ?[]const u8 = null,
    dvb_sub_destination_settings: ?DvbSubDestinationSettings = null,
    embedded_destination_settings: ?EmbeddedDestinationSettings = null,
    imsc_destination_settings: ?ImscDestinationSettings = null,
    scc_destination_settings: ?SccDestinationSettings = null,
    srt_destination_settings: ?SrtDestinationSettings = null,
    teletext_destination_settings: ?TeletextDestinationSettings = null,
    ttml_destination_settings: ?TtmlDestinationSettings = null,
    webvtt_destination_settings: ?WebvttDestinationSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .burnin_destination_settings = "burninDestinationSettings",
            .destination_type = "destinationType",
            .dvb_sub_destination_settings = "dvbSubDestinationSettings",
            .embedded_destination_settings = "embeddedDestinationSettings",
            .imsc_destination_settings = "imscDestinationSettings",
            .scc_destination_settings = "sccDestinationSettings",
            .srt_destination_settings = "srtDestinationSettings",
            .teletext_destination_settings = "teletextDestinationSettings",
            .ttml_destination_settings = "ttmlDestinationSettings",
            .webvtt_destination_settings = "webvttDestinationSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const WebvttDestinationSettings = struct {
    accessibility: ?[]const u8 = null,
    style_passthrough: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accessibility = "accessibility",
            .style_passthrough = "stylePassthrough",
        };
        return @field(mappings, field_name);
    }
};

pub const TtmlDestinationSettings = struct {
    style_passthrough: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .style_passthrough = "stylePassthrough",
        };
        return @field(mappings, field_name);
    }
};

pub const TeletextDestinationSettings = struct {
    page_number: ?[]const u8 = null,
    page_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .page_number = "pageNumber",
            .page_types = "pageTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const SrtDestinationSettings = struct {
    style_passthrough: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .style_passthrough = "stylePassthrough",
        };
        return @field(mappings, field_name);
    }
};

pub const SccDestinationSettings = struct {
    framerate: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .framerate = "framerate",
        };
        return @field(mappings, field_name);
    }
};

pub const ImscDestinationSettings = struct {
    accessibility: ?[]const u8 = null,
    style_passthrough: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accessibility = "accessibility",
            .style_passthrough = "stylePassthrough",
        };
        return @field(mappings, field_name);
    }
};

pub const EmbeddedDestinationSettings = struct {
    destination608_channel_number: ?i64 = null,
    destination708_service_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination608_channel_number = "destination608ChannelNumber",
            .destination708_service_number = "destination708ServiceNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const DvbSubDestinationSettings = struct {
    alignment: ?[]const u8 = null,
    apply_font_color: ?[]const u8 = null,
    background_color: ?[]const u8 = null,
    background_opacity: ?i64 = null,
    dds_handling: ?[]const u8 = null,
    dds_x_coordinate: ?i64 = null,
    dds_y_coordinate: ?i64 = null,
    fallback_font: ?[]const u8 = null,
    font_color: ?[]const u8 = null,
    font_opacity: ?i64 = null,
    font_resolution: ?i64 = null,
    font_script: ?[]const u8 = null,
    font_size: ?i64 = null,
    height: ?i64 = null,
    hex_font_color: ?[]const u8 = null,
    outline_color: ?[]const u8 = null,
    outline_size: ?i64 = null,
    shadow_color: ?[]const u8 = null,
    shadow_opacity: ?i64 = null,
    shadow_x_offset: ?i64 = null,
    shadow_y_offset: ?i64 = null,
    style_passthrough: ?[]const u8 = null,
    subtitling_type: ?[]const u8 = null,
    teletext_spacing: ?[]const u8 = null,
    width: ?i64 = null,
    x_position: ?i64 = null,
    y_position: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alignment = "alignment",
            .apply_font_color = "applyFontColor",
            .background_color = "backgroundColor",
            .background_opacity = "backgroundOpacity",
            .dds_handling = "ddsHandling",
            .dds_x_coordinate = "ddsXCoordinate",
            .dds_y_coordinate = "ddsYCoordinate",
            .fallback_font = "fallbackFont",
            .font_color = "fontColor",
            .font_opacity = "fontOpacity",
            .font_resolution = "fontResolution",
            .font_script = "fontScript",
            .font_size = "fontSize",
            .height = "height",
            .hex_font_color = "hexFontColor",
            .outline_color = "outlineColor",
            .outline_size = "outlineSize",
            .shadow_color = "shadowColor",
            .shadow_opacity = "shadowOpacity",
            .shadow_x_offset = "shadowXOffset",
            .shadow_y_offset = "shadowYOffset",
            .style_passthrough = "stylePassthrough",
            .subtitling_type = "subtitlingType",
            .teletext_spacing = "teletextSpacing",
            .width = "width",
            .x_position = "xPosition",
            .y_position = "yPosition",
        };
        return @field(mappings, field_name);
    }
};

pub const BurninDestinationSettings = struct {
    alignment: ?[]const u8 = null,
    apply_font_color: ?[]const u8 = null,
    background_color: ?[]const u8 = null,
    background_opacity: ?i64 = null,
    fallback_font: ?[]const u8 = null,
    font_color: ?[]const u8 = null,
    font_opacity: ?i64 = null,
    font_resolution: ?i64 = null,
    font_script: ?[]const u8 = null,
    font_size: ?i64 = null,
    hex_font_color: ?[]const u8 = null,
    outline_color: ?[]const u8 = null,
    outline_size: ?i64 = null,
    shadow_color: ?[]const u8 = null,
    shadow_opacity: ?i64 = null,
    shadow_x_offset: ?i64 = null,
    shadow_y_offset: ?i64 = null,
    style_passthrough: ?[]const u8 = null,
    teletext_spacing: ?[]const u8 = null,
    x_position: ?i64 = null,
    y_position: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alignment = "alignment",
            .apply_font_color = "applyFontColor",
            .background_color = "backgroundColor",
            .background_opacity = "backgroundOpacity",
            .fallback_font = "fallbackFont",
            .font_color = "fontColor",
            .font_opacity = "fontOpacity",
            .font_resolution = "fontResolution",
            .font_script = "fontScript",
            .font_size = "fontSize",
            .hex_font_color = "hexFontColor",
            .outline_color = "outlineColor",
            .outline_size = "outlineSize",
            .shadow_color = "shadowColor",
            .shadow_opacity = "shadowOpacity",
            .shadow_x_offset = "shadowXOffset",
            .shadow_y_offset = "shadowYOffset",
            .style_passthrough = "stylePassthrough",
            .teletext_spacing = "teletextSpacing",
            .x_position = "xPosition",
            .y_position = "yPosition",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioDescription = struct {
    audio_channel_tagging_settings: ?AudioChannelTaggingSettings = null,
    audio_normalization_settings: ?AudioNormalizationSettings = null,
    audio_source_name: ?[]const u8 = null,
    audio_type: ?i64 = null,
    audio_type_control: ?[]const u8 = null,
    codec_settings: ?AudioCodecSettings = null,
    custom_language_code: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    language_code_control: ?[]const u8 = null,
    remix_settings: ?RemixSettings = null,
    stream_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_channel_tagging_settings = "audioChannelTaggingSettings",
            .audio_normalization_settings = "audioNormalizationSettings",
            .audio_source_name = "audioSourceName",
            .audio_type = "audioType",
            .audio_type_control = "audioTypeControl",
            .codec_settings = "codecSettings",
            .custom_language_code = "customLanguageCode",
            .language_code = "languageCode",
            .language_code_control = "languageCodeControl",
            .remix_settings = "remixSettings",
            .stream_name = "streamName",
        };
        return @field(mappings, field_name);
    }
};

pub const RemixSettings = struct {
    audio_description_audio_channel: ?i64 = null,
    audio_description_data_channel: ?i64 = null,
    channel_mapping: ?ChannelMapping = null,
    channels_in: ?i64 = null,
    channels_out: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_description_audio_channel = "audioDescriptionAudioChannel",
            .audio_description_data_channel = "audioDescriptionDataChannel",
            .channel_mapping = "channelMapping",
            .channels_in = "channelsIn",
            .channels_out = "channelsOut",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelMapping = struct {
    output_channels: ?[]OutputChannelMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_channels = "outputChannels",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputChannelMapping = struct {
    input_channels: ?[]i64 = null,
    input_channels_fine_tune: ?[]f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_channels = "inputChannels",
            .input_channels_fine_tune = "inputChannelsFineTune",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioCodecSettings = struct {
    aac_settings: ?AacSettings = null,
    ac3_settings: ?Ac3Settings = null,
    aiff_settings: ?AiffSettings = null,
    codec: ?[]const u8 = null,
    eac3_atmos_settings: ?Eac3AtmosSettings = null,
    eac3_settings: ?Eac3Settings = null,
    flac_settings: ?FlacSettings = null,
    mp2_settings: ?Mp2Settings = null,
    mp3_settings: ?Mp3Settings = null,
    opus_settings: ?OpusSettings = null,
    vorbis_settings: ?VorbisSettings = null,
    wav_settings: ?WavSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aac_settings = "aacSettings",
            .ac3_settings = "ac3Settings",
            .aiff_settings = "aiffSettings",
            .codec = "codec",
            .eac3_atmos_settings = "eac3AtmosSettings",
            .eac3_settings = "eac3Settings",
            .flac_settings = "flacSettings",
            .mp2_settings = "mp2Settings",
            .mp3_settings = "mp3Settings",
            .opus_settings = "opusSettings",
            .vorbis_settings = "vorbisSettings",
            .wav_settings = "wavSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const WavSettings = struct {
    bit_depth: ?i64 = null,
    channels: ?i64 = null,
    format: ?[]const u8 = null,
    sample_rate: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bit_depth = "bitDepth",
            .channels = "channels",
            .format = "format",
            .sample_rate = "sampleRate",
        };
        return @field(mappings, field_name);
    }
};

pub const VorbisSettings = struct {
    channels: ?i64 = null,
    sample_rate: ?i64 = null,
    vbr_quality: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channels = "channels",
            .sample_rate = "sampleRate",
            .vbr_quality = "vbrQuality",
        };
        return @field(mappings, field_name);
    }
};

pub const OpusSettings = struct {
    bitrate: ?i64 = null,
    channels: ?i64 = null,
    sample_rate: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .channels = "channels",
            .sample_rate = "sampleRate",
        };
        return @field(mappings, field_name);
    }
};

pub const Mp3Settings = struct {
    bitrate: ?i64 = null,
    channels: ?i64 = null,
    rate_control_mode: ?[]const u8 = null,
    sample_rate: ?i64 = null,
    vbr_quality: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .channels = "channels",
            .rate_control_mode = "rateControlMode",
            .sample_rate = "sampleRate",
            .vbr_quality = "vbrQuality",
        };
        return @field(mappings, field_name);
    }
};

pub const Mp2Settings = struct {
    bitrate: ?i64 = null,
    channels: ?i64 = null,
    sample_rate: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .channels = "channels",
            .sample_rate = "sampleRate",
        };
        return @field(mappings, field_name);
    }
};

pub const FlacSettings = struct {
    bit_depth: ?i64 = null,
    channels: ?i64 = null,
    sample_rate: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bit_depth = "bitDepth",
            .channels = "channels",
            .sample_rate = "sampleRate",
        };
        return @field(mappings, field_name);
    }
};

pub const Eac3Settings = struct {
    attenuation_control: ?[]const u8 = null,
    bitrate: ?i64 = null,
    bitstream_mode: ?[]const u8 = null,
    coding_mode: ?[]const u8 = null,
    dc_filter: ?[]const u8 = null,
    dialnorm: ?i64 = null,
    dynamic_range_compression_line: ?[]const u8 = null,
    dynamic_range_compression_rf: ?[]const u8 = null,
    lfe_control: ?[]const u8 = null,
    lfe_filter: ?[]const u8 = null,
    lo_ro_center_mix_level: ?f64 = null,
    lo_ro_surround_mix_level: ?f64 = null,
    lt_rt_center_mix_level: ?f64 = null,
    lt_rt_surround_mix_level: ?f64 = null,
    metadata_control: ?[]const u8 = null,
    passthrough_control: ?[]const u8 = null,
    phase_control: ?[]const u8 = null,
    sample_rate: ?i64 = null,
    stereo_downmix: ?[]const u8 = null,
    surround_ex_mode: ?[]const u8 = null,
    surround_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attenuation_control = "attenuationControl",
            .bitrate = "bitrate",
            .bitstream_mode = "bitstreamMode",
            .coding_mode = "codingMode",
            .dc_filter = "dcFilter",
            .dialnorm = "dialnorm",
            .dynamic_range_compression_line = "dynamicRangeCompressionLine",
            .dynamic_range_compression_rf = "dynamicRangeCompressionRf",
            .lfe_control = "lfeControl",
            .lfe_filter = "lfeFilter",
            .lo_ro_center_mix_level = "loRoCenterMixLevel",
            .lo_ro_surround_mix_level = "loRoSurroundMixLevel",
            .lt_rt_center_mix_level = "ltRtCenterMixLevel",
            .lt_rt_surround_mix_level = "ltRtSurroundMixLevel",
            .metadata_control = "metadataControl",
            .passthrough_control = "passthroughControl",
            .phase_control = "phaseControl",
            .sample_rate = "sampleRate",
            .stereo_downmix = "stereoDownmix",
            .surround_ex_mode = "surroundExMode",
            .surround_mode = "surroundMode",
        };
        return @field(mappings, field_name);
    }
};

pub const Eac3AtmosSettings = struct {
    bitrate: ?i64 = null,
    bitstream_mode: ?[]const u8 = null,
    coding_mode: ?[]const u8 = null,
    dialogue_intelligence: ?[]const u8 = null,
    downmix_control: ?[]const u8 = null,
    dynamic_range_compression_line: ?[]const u8 = null,
    dynamic_range_compression_rf: ?[]const u8 = null,
    dynamic_range_control: ?[]const u8 = null,
    lo_ro_center_mix_level: ?f64 = null,
    lo_ro_surround_mix_level: ?f64 = null,
    lt_rt_center_mix_level: ?f64 = null,
    lt_rt_surround_mix_level: ?f64 = null,
    metering_mode: ?[]const u8 = null,
    sample_rate: ?i64 = null,
    speech_threshold: ?i64 = null,
    stereo_downmix: ?[]const u8 = null,
    surround_ex_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .bitstream_mode = "bitstreamMode",
            .coding_mode = "codingMode",
            .dialogue_intelligence = "dialogueIntelligence",
            .downmix_control = "downmixControl",
            .dynamic_range_compression_line = "dynamicRangeCompressionLine",
            .dynamic_range_compression_rf = "dynamicRangeCompressionRf",
            .dynamic_range_control = "dynamicRangeControl",
            .lo_ro_center_mix_level = "loRoCenterMixLevel",
            .lo_ro_surround_mix_level = "loRoSurroundMixLevel",
            .lt_rt_center_mix_level = "ltRtCenterMixLevel",
            .lt_rt_surround_mix_level = "ltRtSurroundMixLevel",
            .metering_mode = "meteringMode",
            .sample_rate = "sampleRate",
            .speech_threshold = "speechThreshold",
            .stereo_downmix = "stereoDownmix",
            .surround_ex_mode = "surroundExMode",
        };
        return @field(mappings, field_name);
    }
};

pub const AiffSettings = struct {
    bit_depth: ?i64 = null,
    channels: ?i64 = null,
    sample_rate: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bit_depth = "bitDepth",
            .channels = "channels",
            .sample_rate = "sampleRate",
        };
        return @field(mappings, field_name);
    }
};

pub const Ac3Settings = struct {
    bitrate: ?i64 = null,
    bitstream_mode: ?[]const u8 = null,
    coding_mode: ?[]const u8 = null,
    dialnorm: ?i64 = null,
    dynamic_range_compression_line: ?[]const u8 = null,
    dynamic_range_compression_profile: ?[]const u8 = null,
    dynamic_range_compression_rf: ?[]const u8 = null,
    lfe_filter: ?[]const u8 = null,
    metadata_control: ?[]const u8 = null,
    sample_rate: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bitrate = "bitrate",
            .bitstream_mode = "bitstreamMode",
            .coding_mode = "codingMode",
            .dialnorm = "dialnorm",
            .dynamic_range_compression_line = "dynamicRangeCompressionLine",
            .dynamic_range_compression_profile = "dynamicRangeCompressionProfile",
            .dynamic_range_compression_rf = "dynamicRangeCompressionRf",
            .lfe_filter = "lfeFilter",
            .metadata_control = "metadataControl",
            .sample_rate = "sampleRate",
        };
        return @field(mappings, field_name);
    }
};

pub const AacSettings = struct {
    audio_description_broadcaster_mix: ?[]const u8 = null,
    bitrate: ?i64 = null,
    codec_profile: ?[]const u8 = null,
    coding_mode: ?[]const u8 = null,
    rate_control_mode: ?[]const u8 = null,
    raw_format: ?[]const u8 = null,
    sample_rate: ?i64 = null,
    specification: ?[]const u8 = null,
    vbr_quality: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_description_broadcaster_mix = "audioDescriptionBroadcasterMix",
            .bitrate = "bitrate",
            .codec_profile = "codecProfile",
            .coding_mode = "codingMode",
            .rate_control_mode = "rateControlMode",
            .raw_format = "rawFormat",
            .sample_rate = "sampleRate",
            .specification = "specification",
            .vbr_quality = "vbrQuality",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioNormalizationSettings = struct {
    algorithm: ?[]const u8 = null,
    algorithm_control: ?[]const u8 = null,
    correction_gate_level: ?i64 = null,
    loudness_logging: ?[]const u8 = null,
    peak_calculation: ?[]const u8 = null,
    target_lkfs: ?f64 = null,
    true_peak_limiter_threshold: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .algorithm = "algorithm",
            .algorithm_control = "algorithmControl",
            .correction_gate_level = "correctionGateLevel",
            .loudness_logging = "loudnessLogging",
            .peak_calculation = "peakCalculation",
            .target_lkfs = "targetLkfs",
            .true_peak_limiter_threshold = "truePeakLimiterThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioChannelTaggingSettings = struct {
    channel_tag: ?[]const u8 = null,
    channel_tags: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_tag = "channelTag",
            .channel_tags = "channelTags",
        };
        return @field(mappings, field_name);
    }
};

pub const JobTemplate = struct {
    acceleration_settings: ?AccelerationSettings = null,
    arn: ?[]const u8 = null,
    category: ?[]const u8 = null,
    created_at: ?i64 = null,
    description: ?[]const u8 = null,
    hop_destinations: ?[]HopDestination = null,
    last_updated: ?i64 = null,
    name: []const u8,
    priority: ?i64 = null,
    queue: ?[]const u8 = null,
    settings: JobTemplateSettings,
    status_update_interval: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .acceleration_settings = "accelerationSettings",
            .arn = "arn",
            .category = "category",
            .created_at = "createdAt",
            .description = "description",
            .hop_destinations = "hopDestinations",
            .last_updated = "lastUpdated",
            .name = "name",
            .priority = "priority",
            .queue = "queue",
            .settings = "settings",
            .status_update_interval = "statusUpdateInterval",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const JobTemplateSettings = struct {
    ad_avail_offset: ?i64 = null,
    avail_blanking: ?AvailBlanking = null,
    color_conversion3dlut_settings: ?[]ColorConversion3DLUTSetting = null,
    esam: ?EsamSettings = null,
    extended_data_services: ?ExtendedDataServices = null,
    follow_source: ?i64 = null,
    inputs: ?[]InputTemplate = null,
    kantar_watermark: ?KantarWatermarkSettings = null,
    motion_image_inserter: ?MotionImageInserter = null,
    nielsen_configuration: ?NielsenConfiguration = null,
    nielsen_non_linear_watermark: ?NielsenNonLinearWatermarkSettings = null,
    output_groups: ?[]OutputGroup = null,
    timecode_config: ?TimecodeConfig = null,
    timed_metadata_insertion: ?TimedMetadataInsertion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_avail_offset = "adAvailOffset",
            .avail_blanking = "availBlanking",
            .color_conversion3dlut_settings = "colorConversion3DLUTSettings",
            .esam = "esam",
            .extended_data_services = "extendedDataServices",
            .follow_source = "followSource",
            .inputs = "inputs",
            .kantar_watermark = "kantarWatermark",
            .motion_image_inserter = "motionImageInserter",
            .nielsen_configuration = "nielsenConfiguration",
            .nielsen_non_linear_watermark = "nielsenNonLinearWatermark",
            .output_groups = "outputGroups",
            .timecode_config = "timecodeConfig",
            .timed_metadata_insertion = "timedMetadataInsertion",
        };
        return @field(mappings, field_name);
    }
};

pub const TimedMetadataInsertion = struct {
    id3_insertions: ?[]Id3Insertion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id3_insertions = "id3Insertions",
        };
        return @field(mappings, field_name);
    }
};

pub const Id3Insertion = struct {
    id3: ?[]const u8 = null,
    timecode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id3 = "id3",
            .timecode = "timecode",
        };
        return @field(mappings, field_name);
    }
};

pub const TimecodeConfig = struct {
    anchor: ?[]const u8 = null,
    source: ?[]const u8 = null,
    start: ?[]const u8 = null,
    timestamp_offset: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .anchor = "anchor",
            .source = "source",
            .start = "start",
            .timestamp_offset = "timestampOffset",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputGroup = struct {
    automated_encoding_settings: ?AutomatedEncodingSettings = null,
    custom_name: ?[]const u8 = null,
    name: ?[]const u8 = null,
    output_group_settings: ?OutputGroupSettings = null,
    outputs: ?[]Output = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automated_encoding_settings = "automatedEncodingSettings",
            .custom_name = "customName",
            .name = "name",
            .output_group_settings = "outputGroupSettings",
            .outputs = "outputs",
        };
        return @field(mappings, field_name);
    }
};

pub const Output = struct {
    audio_descriptions: ?[]AudioDescription = null,
    caption_descriptions: ?[]CaptionDescription = null,
    container_settings: ?ContainerSettings = null,
    extension: ?[]const u8 = null,
    name_modifier: ?[]const u8 = null,
    output_settings: ?OutputSettings = null,
    preset: ?[]const u8 = null,
    video_description: ?VideoDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_descriptions = "audioDescriptions",
            .caption_descriptions = "captionDescriptions",
            .container_settings = "containerSettings",
            .extension = "extension",
            .name_modifier = "nameModifier",
            .output_settings = "outputSettings",
            .preset = "preset",
            .video_description = "videoDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputSettings = struct {
    hls_settings: ?HlsSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hls_settings = "hlsSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsSettings = struct {
    audio_group_id: ?[]const u8 = null,
    audio_only_container: ?[]const u8 = null,
    audio_rendition_sets: ?[]const u8 = null,
    audio_track_type: ?[]const u8 = null,
    descriptive_video_service_flag: ?[]const u8 = null,
    i_frame_only_manifest: ?[]const u8 = null,
    segment_modifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_group_id = "audioGroupId",
            .audio_only_container = "audioOnlyContainer",
            .audio_rendition_sets = "audioRenditionSets",
            .audio_track_type = "audioTrackType",
            .descriptive_video_service_flag = "descriptiveVideoServiceFlag",
            .i_frame_only_manifest = "iFrameOnlyManifest",
            .segment_modifier = "segmentModifier",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionDescription = struct {
    caption_selector_name: ?[]const u8 = null,
    custom_language_code: ?[]const u8 = null,
    destination_settings: ?CaptionDestinationSettings = null,
    language_code: ?[]const u8 = null,
    language_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .caption_selector_name = "captionSelectorName",
            .custom_language_code = "customLanguageCode",
            .destination_settings = "destinationSettings",
            .language_code = "languageCode",
            .language_description = "languageDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputGroupSettings = struct {
    cmaf_group_settings: ?CmafGroupSettings = null,
    dash_iso_group_settings: ?DashIsoGroupSettings = null,
    file_group_settings: ?FileGroupSettings = null,
    hls_group_settings: ?HlsGroupSettings = null,
    ms_smooth_group_settings: ?MsSmoothGroupSettings = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cmaf_group_settings = "cmafGroupSettings",
            .dash_iso_group_settings = "dashIsoGroupSettings",
            .file_group_settings = "fileGroupSettings",
            .hls_group_settings = "hlsGroupSettings",
            .ms_smooth_group_settings = "msSmoothGroupSettings",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const MsSmoothGroupSettings = struct {
    additional_manifests: ?[]MsSmoothAdditionalManifest = null,
    audio_deduplication: ?[]const u8 = null,
    destination: ?[]const u8 = null,
    destination_settings: ?DestinationSettings = null,
    encryption: ?MsSmoothEncryptionSettings = null,
    fragment_length: ?i64 = null,
    fragment_length_control: ?[]const u8 = null,
    manifest_encoding: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_manifests = "additionalManifests",
            .audio_deduplication = "audioDeduplication",
            .destination = "destination",
            .destination_settings = "destinationSettings",
            .encryption = "encryption",
            .fragment_length = "fragmentLength",
            .fragment_length_control = "fragmentLengthControl",
            .manifest_encoding = "manifestEncoding",
        };
        return @field(mappings, field_name);
    }
};

pub const MsSmoothEncryptionSettings = struct {
    speke_key_provider: ?SpekeKeyProvider = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .speke_key_provider = "spekeKeyProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const SpekeKeyProvider = struct {
    certificate_arn: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    system_ids: ?[][]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "certificateArn",
            .resource_id = "resourceId",
            .system_ids = "systemIds",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};

pub const DestinationSettings = struct {
    s3_settings: ?S3DestinationSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_settings = "s3Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DestinationSettings = struct {
    access_control: ?S3DestinationAccessControl = null,
    encryption: ?S3EncryptionSettings = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_control = "accessControl",
            .encryption = "encryption",
            .storage_class = "storageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const S3EncryptionSettings = struct {
    encryption_type: ?[]const u8 = null,
    kms_encryption_context: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_type = "encryptionType",
            .kms_encryption_context = "kmsEncryptionContext",
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DestinationAccessControl = struct {
    canned_acl: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .canned_acl = "cannedAcl",
        };
        return @field(mappings, field_name);
    }
};

pub const MsSmoothAdditionalManifest = struct {
    manifest_name_modifier: ?[]const u8 = null,
    selected_outputs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_name_modifier = "manifestNameModifier",
            .selected_outputs = "selectedOutputs",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsGroupSettings = struct {
    ad_markers: ?[][]const u8 = null,
    additional_manifests: ?[]HlsAdditionalManifest = null,
    audio_only_header: ?[]const u8 = null,
    base_url: ?[]const u8 = null,
    caption_language_mappings: ?[]HlsCaptionLanguageMapping = null,
    caption_language_setting: ?[]const u8 = null,
    caption_segment_length_control: ?[]const u8 = null,
    client_cache: ?[]const u8 = null,
    codec_specification: ?[]const u8 = null,
    destination: ?[]const u8 = null,
    destination_settings: ?DestinationSettings = null,
    directory_structure: ?[]const u8 = null,
    encryption: ?HlsEncryptionSettings = null,
    image_based_trick_play: ?[]const u8 = null,
    image_based_trick_play_settings: ?HlsImageBasedTrickPlaySettings = null,
    manifest_compression: ?[]const u8 = null,
    manifest_duration_format: ?[]const u8 = null,
    min_final_segment_length: ?f64 = null,
    min_segment_length: ?i64 = null,
    output_selection: ?[]const u8 = null,
    program_date_time: ?[]const u8 = null,
    program_date_time_period: ?i64 = null,
    progressive_write_hls_manifest: ?[]const u8 = null,
    segment_control: ?[]const u8 = null,
    segment_length: ?i64 = null,
    segment_length_control: ?[]const u8 = null,
    segments_per_subdirectory: ?i64 = null,
    stream_inf_resolution: ?[]const u8 = null,
    target_duration_compatibility_mode: ?[]const u8 = null,
    timed_metadata_id3_frame: ?[]const u8 = null,
    timed_metadata_id3_period: ?i64 = null,
    timestamp_delta_milliseconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_markers = "adMarkers",
            .additional_manifests = "additionalManifests",
            .audio_only_header = "audioOnlyHeader",
            .base_url = "baseUrl",
            .caption_language_mappings = "captionLanguageMappings",
            .caption_language_setting = "captionLanguageSetting",
            .caption_segment_length_control = "captionSegmentLengthControl",
            .client_cache = "clientCache",
            .codec_specification = "codecSpecification",
            .destination = "destination",
            .destination_settings = "destinationSettings",
            .directory_structure = "directoryStructure",
            .encryption = "encryption",
            .image_based_trick_play = "imageBasedTrickPlay",
            .image_based_trick_play_settings = "imageBasedTrickPlaySettings",
            .manifest_compression = "manifestCompression",
            .manifest_duration_format = "manifestDurationFormat",
            .min_final_segment_length = "minFinalSegmentLength",
            .min_segment_length = "minSegmentLength",
            .output_selection = "outputSelection",
            .program_date_time = "programDateTime",
            .program_date_time_period = "programDateTimePeriod",
            .progressive_write_hls_manifest = "progressiveWriteHlsManifest",
            .segment_control = "segmentControl",
            .segment_length = "segmentLength",
            .segment_length_control = "segmentLengthControl",
            .segments_per_subdirectory = "segmentsPerSubdirectory",
            .stream_inf_resolution = "streamInfResolution",
            .target_duration_compatibility_mode = "targetDurationCompatibilityMode",
            .timed_metadata_id3_frame = "timedMetadataId3Frame",
            .timed_metadata_id3_period = "timedMetadataId3Period",
            .timestamp_delta_milliseconds = "timestampDeltaMilliseconds",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsImageBasedTrickPlaySettings = struct {
    interval_cadence: ?[]const u8 = null,
    thumbnail_height: ?i64 = null,
    thumbnail_interval: ?f64 = null,
    thumbnail_width: ?i64 = null,
    tile_height: ?i64 = null,
    tile_width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interval_cadence = "intervalCadence",
            .thumbnail_height = "thumbnailHeight",
            .thumbnail_interval = "thumbnailInterval",
            .thumbnail_width = "thumbnailWidth",
            .tile_height = "tileHeight",
            .tile_width = "tileWidth",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsEncryptionSettings = struct {
    constant_initialization_vector: ?[]const u8 = null,
    encryption_method: ?[]const u8 = null,
    initialization_vector_in_manifest: ?[]const u8 = null,
    offline_encrypted: ?[]const u8 = null,
    speke_key_provider: ?SpekeKeyProvider = null,
    static_key_provider: ?StaticKeyProvider = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant_initialization_vector = "constantInitializationVector",
            .encryption_method = "encryptionMethod",
            .initialization_vector_in_manifest = "initializationVectorInManifest",
            .offline_encrypted = "offlineEncrypted",
            .speke_key_provider = "spekeKeyProvider",
            .static_key_provider = "staticKeyProvider",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const StaticKeyProvider = struct {
    key_format: ?[]const u8 = null,
    key_format_versions: ?[]const u8 = null,
    static_key_value: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_format = "keyFormat",
            .key_format_versions = "keyFormatVersions",
            .static_key_value = "staticKeyValue",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsCaptionLanguageMapping = struct {
    caption_channel: ?i64 = null,
    custom_language_code: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    language_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .caption_channel = "captionChannel",
            .custom_language_code = "customLanguageCode",
            .language_code = "languageCode",
            .language_description = "languageDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsAdditionalManifest = struct {
    manifest_name_modifier: ?[]const u8 = null,
    selected_outputs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_name_modifier = "manifestNameModifier",
            .selected_outputs = "selectedOutputs",
        };
        return @field(mappings, field_name);
    }
};

pub const FileGroupSettings = struct {
    destination: ?[]const u8 = null,
    destination_settings: ?DestinationSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination = "destination",
            .destination_settings = "destinationSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const DashIsoGroupSettings = struct {
    additional_manifests: ?[]DashAdditionalManifest = null,
    audio_channel_config_scheme_id_uri: ?[]const u8 = null,
    base_url: ?[]const u8 = null,
    dash_manifest_style: ?[]const u8 = null,
    destination: ?[]const u8 = null,
    destination_settings: ?DestinationSettings = null,
    encryption: ?DashIsoEncryptionSettings = null,
    fragment_length: ?i64 = null,
    hbbtv_compliance: ?[]const u8 = null,
    image_based_trick_play: ?[]const u8 = null,
    image_based_trick_play_settings: ?DashIsoImageBasedTrickPlaySettings = null,
    min_buffer_time: ?i64 = null,
    min_final_segment_length: ?f64 = null,
    mpd_manifest_bandwidth_type: ?[]const u8 = null,
    mpd_profile: ?[]const u8 = null,
    pts_offset_handling_for_b_frames: ?[]const u8 = null,
    segment_control: ?[]const u8 = null,
    segment_length: ?i64 = null,
    segment_length_control: ?[]const u8 = null,
    video_composition_offsets: ?[]const u8 = null,
    write_segment_timeline_in_representation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_manifests = "additionalManifests",
            .audio_channel_config_scheme_id_uri = "audioChannelConfigSchemeIdUri",
            .base_url = "baseUrl",
            .dash_manifest_style = "dashManifestStyle",
            .destination = "destination",
            .destination_settings = "destinationSettings",
            .encryption = "encryption",
            .fragment_length = "fragmentLength",
            .hbbtv_compliance = "hbbtvCompliance",
            .image_based_trick_play = "imageBasedTrickPlay",
            .image_based_trick_play_settings = "imageBasedTrickPlaySettings",
            .min_buffer_time = "minBufferTime",
            .min_final_segment_length = "minFinalSegmentLength",
            .mpd_manifest_bandwidth_type = "mpdManifestBandwidthType",
            .mpd_profile = "mpdProfile",
            .pts_offset_handling_for_b_frames = "ptsOffsetHandlingForBFrames",
            .segment_control = "segmentControl",
            .segment_length = "segmentLength",
            .segment_length_control = "segmentLengthControl",
            .video_composition_offsets = "videoCompositionOffsets",
            .write_segment_timeline_in_representation = "writeSegmentTimelineInRepresentation",
        };
        return @field(mappings, field_name);
    }
};

pub const DashIsoImageBasedTrickPlaySettings = struct {
    interval_cadence: ?[]const u8 = null,
    thumbnail_height: ?i64 = null,
    thumbnail_interval: ?f64 = null,
    thumbnail_width: ?i64 = null,
    tile_height: ?i64 = null,
    tile_width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interval_cadence = "intervalCadence",
            .thumbnail_height = "thumbnailHeight",
            .thumbnail_interval = "thumbnailInterval",
            .thumbnail_width = "thumbnailWidth",
            .tile_height = "tileHeight",
            .tile_width = "tileWidth",
        };
        return @field(mappings, field_name);
    }
};

pub const DashIsoEncryptionSettings = struct {
    playback_device_compatibility: ?[]const u8 = null,
    speke_key_provider: ?SpekeKeyProvider = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .playback_device_compatibility = "playbackDeviceCompatibility",
            .speke_key_provider = "spekeKeyProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const DashAdditionalManifest = struct {
    manifest_name_modifier: ?[]const u8 = null,
    selected_outputs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_name_modifier = "manifestNameModifier",
            .selected_outputs = "selectedOutputs",
        };
        return @field(mappings, field_name);
    }
};

pub const CmafGroupSettings = struct {
    additional_manifests: ?[]CmafAdditionalManifest = null,
    base_url: ?[]const u8 = null,
    client_cache: ?[]const u8 = null,
    codec_specification: ?[]const u8 = null,
    dash_manifest_style: ?[]const u8 = null,
    destination: ?[]const u8 = null,
    destination_settings: ?DestinationSettings = null,
    encryption: ?CmafEncryptionSettings = null,
    fragment_length: ?i64 = null,
    image_based_trick_play: ?[]const u8 = null,
    image_based_trick_play_settings: ?CmafImageBasedTrickPlaySettings = null,
    manifest_compression: ?[]const u8 = null,
    manifest_duration_format: ?[]const u8 = null,
    min_buffer_time: ?i64 = null,
    min_final_segment_length: ?f64 = null,
    mpd_manifest_bandwidth_type: ?[]const u8 = null,
    mpd_profile: ?[]const u8 = null,
    pts_offset_handling_for_b_frames: ?[]const u8 = null,
    segment_control: ?[]const u8 = null,
    segment_length: ?i64 = null,
    segment_length_control: ?[]const u8 = null,
    stream_inf_resolution: ?[]const u8 = null,
    target_duration_compatibility_mode: ?[]const u8 = null,
    video_composition_offsets: ?[]const u8 = null,
    write_dash_manifest: ?[]const u8 = null,
    write_hls_manifest: ?[]const u8 = null,
    write_segment_timeline_in_representation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .additional_manifests = "additionalManifests",
            .base_url = "baseUrl",
            .client_cache = "clientCache",
            .codec_specification = "codecSpecification",
            .dash_manifest_style = "dashManifestStyle",
            .destination = "destination",
            .destination_settings = "destinationSettings",
            .encryption = "encryption",
            .fragment_length = "fragmentLength",
            .image_based_trick_play = "imageBasedTrickPlay",
            .image_based_trick_play_settings = "imageBasedTrickPlaySettings",
            .manifest_compression = "manifestCompression",
            .manifest_duration_format = "manifestDurationFormat",
            .min_buffer_time = "minBufferTime",
            .min_final_segment_length = "minFinalSegmentLength",
            .mpd_manifest_bandwidth_type = "mpdManifestBandwidthType",
            .mpd_profile = "mpdProfile",
            .pts_offset_handling_for_b_frames = "ptsOffsetHandlingForBFrames",
            .segment_control = "segmentControl",
            .segment_length = "segmentLength",
            .segment_length_control = "segmentLengthControl",
            .stream_inf_resolution = "streamInfResolution",
            .target_duration_compatibility_mode = "targetDurationCompatibilityMode",
            .video_composition_offsets = "videoCompositionOffsets",
            .write_dash_manifest = "writeDashManifest",
            .write_hls_manifest = "writeHlsManifest",
            .write_segment_timeline_in_representation = "writeSegmentTimelineInRepresentation",
        };
        return @field(mappings, field_name);
    }
};

pub const CmafImageBasedTrickPlaySettings = struct {
    interval_cadence: ?[]const u8 = null,
    thumbnail_height: ?i64 = null,
    thumbnail_interval: ?f64 = null,
    thumbnail_width: ?i64 = null,
    tile_height: ?i64 = null,
    tile_width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interval_cadence = "intervalCadence",
            .thumbnail_height = "thumbnailHeight",
            .thumbnail_interval = "thumbnailInterval",
            .thumbnail_width = "thumbnailWidth",
            .tile_height = "tileHeight",
            .tile_width = "tileWidth",
        };
        return @field(mappings, field_name);
    }
};

pub const CmafEncryptionSettings = struct {
    constant_initialization_vector: ?[]const u8 = null,
    encryption_method: ?[]const u8 = null,
    initialization_vector_in_manifest: ?[]const u8 = null,
    speke_key_provider: ?SpekeKeyProviderCmaf = null,
    static_key_provider: ?StaticKeyProvider = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant_initialization_vector = "constantInitializationVector",
            .encryption_method = "encryptionMethod",
            .initialization_vector_in_manifest = "initializationVectorInManifest",
            .speke_key_provider = "spekeKeyProvider",
            .static_key_provider = "staticKeyProvider",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const SpekeKeyProviderCmaf = struct {
    certificate_arn: ?[]const u8 = null,
    dash_signaled_system_ids: ?[][]const u8 = null,
    hls_signaled_system_ids: ?[][]const u8 = null,
    resource_id: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "certificateArn",
            .dash_signaled_system_ids = "dashSignaledSystemIds",
            .hls_signaled_system_ids = "hlsSignaledSystemIds",
            .resource_id = "resourceId",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};

pub const CmafAdditionalManifest = struct {
    manifest_name_modifier: ?[]const u8 = null,
    selected_outputs: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_name_modifier = "manifestNameModifier",
            .selected_outputs = "selectedOutputs",
        };
        return @field(mappings, field_name);
    }
};

pub const AutomatedEncodingSettings = struct {
    abr_settings: ?AutomatedAbrSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .abr_settings = "abrSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const AutomatedAbrSettings = struct {
    max_abr_bitrate: ?i64 = null,
    max_renditions: ?i64 = null,
    min_abr_bitrate: ?i64 = null,
    rules: ?[]AutomatedAbrRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_abr_bitrate = "maxAbrBitrate",
            .max_renditions = "maxRenditions",
            .min_abr_bitrate = "minAbrBitrate",
            .rules = "rules",
        };
        return @field(mappings, field_name);
    }
};

pub const AutomatedAbrRule = struct {
    allowed_renditions: ?[]AllowedRenditionSize = null,
    force_include_renditions: ?[]ForceIncludeRenditionSize = null,
    min_bottom_rendition_size: ?MinBottomRenditionSize = null,
    min_top_rendition_size: ?MinTopRenditionSize = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allowed_renditions = "allowedRenditions",
            .force_include_renditions = "forceIncludeRenditions",
            .min_bottom_rendition_size = "minBottomRenditionSize",
            .min_top_rendition_size = "minTopRenditionSize",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const MinTopRenditionSize = struct {
    height: ?i64 = null,
    width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .height = "height",
            .width = "width",
        };
        return @field(mappings, field_name);
    }
};

pub const MinBottomRenditionSize = struct {
    height: ?i64 = null,
    width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .height = "height",
            .width = "width",
        };
        return @field(mappings, field_name);
    }
};

pub const ForceIncludeRenditionSize = struct {
    height: ?i64 = null,
    width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .height = "height",
            .width = "width",
        };
        return @field(mappings, field_name);
    }
};

pub const AllowedRenditionSize = struct {
    height: ?i64 = null,
    required: ?[]const u8 = null,
    width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .height = "height",
            .required = "required",
            .width = "width",
        };
        return @field(mappings, field_name);
    }
};

pub const NielsenNonLinearWatermarkSettings = struct {
    active_watermark_process: ?[]const u8 = null,
    adi_filename: ?[]const u8 = null,
    asset_id: ?[]const u8 = null,
    asset_name: ?[]const u8 = null,
    cbet_source_id: ?[]const u8 = null,
    episode_id: ?[]const u8 = null,
    metadata_destination: ?[]const u8 = null,
    source_id: ?i64 = null,
    source_watermark_status: ?[]const u8 = null,
    tic_server_url: ?[]const u8 = null,
    unique_tic_per_audio_track: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_watermark_process = "activeWatermarkProcess",
            .adi_filename = "adiFilename",
            .asset_id = "assetId",
            .asset_name = "assetName",
            .cbet_source_id = "cbetSourceId",
            .episode_id = "episodeId",
            .metadata_destination = "metadataDestination",
            .source_id = "sourceId",
            .source_watermark_status = "sourceWatermarkStatus",
            .tic_server_url = "ticServerUrl",
            .unique_tic_per_audio_track = "uniqueTicPerAudioTrack",
        };
        return @field(mappings, field_name);
    }
};

pub const NielsenConfiguration = struct {
    breakout_code: ?i64 = null,
    distributor_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .breakout_code = "breakoutCode",
            .distributor_id = "distributorId",
        };
        return @field(mappings, field_name);
    }
};

pub const MotionImageInserter = struct {
    framerate: ?MotionImageInsertionFramerate = null,
    input: ?[]const u8 = null,
    insertion_mode: ?[]const u8 = null,
    offset: ?MotionImageInsertionOffset = null,
    playback: ?[]const u8 = null,
    start_time: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .framerate = "framerate",
            .input = "input",
            .insertion_mode = "insertionMode",
            .offset = "offset",
            .playback = "playback",
            .start_time = "startTime",
        };
        return @field(mappings, field_name);
    }
};

pub const MotionImageInsertionOffset = struct {
    imagex: ?i64 = null,
    imagey: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .imagex = "imageX",
            .imagey = "imageY",
        };
        return @field(mappings, field_name);
    }
};

pub const MotionImageInsertionFramerate = struct {
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
        };
        return @field(mappings, field_name);
    }
};

pub const KantarWatermarkSettings = struct {
    channel_name: ?[]const u8 = null,
    content_reference: ?[]const u8 = null,
    credentials_secret_name: ?[]const u8 = null,
    file_offset: ?f64 = null,
    kantar_license_id: ?i64 = null,
    kantar_server_url: ?[]const u8 = null,
    log_destination: ?[]const u8 = null,
    metadata3: ?[]const u8 = null,
    metadata4: ?[]const u8 = null,
    metadata5: ?[]const u8 = null,
    metadata6: ?[]const u8 = null,
    metadata7: ?[]const u8 = null,
    metadata8: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_name = "channelName",
            .content_reference = "contentReference",
            .credentials_secret_name = "credentialsSecretName",
            .file_offset = "fileOffset",
            .kantar_license_id = "kantarLicenseId",
            .kantar_server_url = "kantarServerUrl",
            .log_destination = "logDestination",
            .metadata3 = "metadata3",
            .metadata4 = "metadata4",
            .metadata5 = "metadata5",
            .metadata6 = "metadata6",
            .metadata7 = "metadata7",
            .metadata8 = "metadata8",
        };
        return @field(mappings, field_name);
    }
};

pub const InputTemplate = struct {
    advanced_input_filter: ?[]const u8 = null,
    advanced_input_filter_settings: ?AdvancedInputFilterSettings = null,
    audio_selector_groups: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AudioSelectorGroup = null,
    } = null,
    audio_selectors: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AudioSelector = null,
    } = null,
    caption_selectors: ?[]struct {
        key: ?[]const u8 = null,
        value: ?CaptionSelector = null,
    } = null,
    crop: ?Rectangle = null,
    deblock_filter: ?[]const u8 = null,
    denoise_filter: ?[]const u8 = null,
    dolby_vision_metadata_xml: ?[]const u8 = null,
    filter_enable: ?[]const u8 = null,
    filter_strength: ?i64 = null,
    image_inserter: ?ImageInserter = null,
    input_clippings: ?[]InputClipping = null,
    input_scan_type: ?[]const u8 = null,
    position: ?Rectangle = null,
    program_number: ?i64 = null,
    psi_control: ?[]const u8 = null,
    timecode_source: ?[]const u8 = null,
    timecode_start: ?[]const u8 = null,
    video_overlays: ?[]VideoOverlay = null,
    video_selector: ?VideoSelector = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .advanced_input_filter = "advancedInputFilter",
            .advanced_input_filter_settings = "advancedInputFilterSettings",
            .audio_selector_groups = "audioSelectorGroups",
            .audio_selectors = "audioSelectors",
            .caption_selectors = "captionSelectors",
            .crop = "crop",
            .deblock_filter = "deblockFilter",
            .denoise_filter = "denoiseFilter",
            .dolby_vision_metadata_xml = "dolbyVisionMetadataXml",
            .filter_enable = "filterEnable",
            .filter_strength = "filterStrength",
            .image_inserter = "imageInserter",
            .input_clippings = "inputClippings",
            .input_scan_type = "inputScanType",
            .position = "position",
            .program_number = "programNumber",
            .psi_control = "psiControl",
            .timecode_source = "timecodeSource",
            .timecode_start = "timecodeStart",
            .video_overlays = "videoOverlays",
            .video_selector = "videoSelector",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "audio_selector_groups", field_name))
            return try serializeMap(self.audio_selector_groups, self.fieldNameFor("audio_selector_groups"), options, out_stream);
        if (std.mem.eql(u8, "audio_selectors", field_name))
            return try serializeMap(self.audio_selectors, self.fieldNameFor("audio_selectors"), options, out_stream);
        if (std.mem.eql(u8, "caption_selectors", field_name))
            return try serializeMap(self.caption_selectors, self.fieldNameFor("caption_selectors"), options, out_stream);
        return false;
    }
};

pub const VideoSelector = struct {
    alpha_behavior: ?[]const u8 = null,
    color_space: ?[]const u8 = null,
    color_space_usage: ?[]const u8 = null,
    embedded_timecode_override: ?[]const u8 = null,
    hdr10_metadata: ?Hdr10Metadata = null,
    max_luminance: ?i64 = null,
    pad_video: ?[]const u8 = null,
    pid: ?i64 = null,
    program_number: ?i64 = null,
    rotate: ?[]const u8 = null,
    sample_range: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alpha_behavior = "alphaBehavior",
            .color_space = "colorSpace",
            .color_space_usage = "colorSpaceUsage",
            .embedded_timecode_override = "embeddedTimecodeOverride",
            .hdr10_metadata = "hdr10Metadata",
            .max_luminance = "maxLuminance",
            .pad_video = "padVideo",
            .pid = "pid",
            .program_number = "programNumber",
            .rotate = "rotate",
            .sample_range = "sampleRange",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoOverlay = struct {
    end_timecode: ?[]const u8 = null,
    input: ?VideoOverlayInput = null,
    start_timecode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .end_timecode = "endTimecode",
            .input = "input",
            .start_timecode = "startTimecode",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoOverlayInput = struct {
    file_input: ?[]const u8 = null,
    input_clippings: ?[]VideoOverlayInputClipping = null,
    timecode_source: ?[]const u8 = null,
    timecode_start: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_input = "fileInput",
            .input_clippings = "inputClippings",
            .timecode_source = "timecodeSource",
            .timecode_start = "timecodeStart",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoOverlayInputClipping = struct {
    end_timecode: ?[]const u8 = null,
    start_timecode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .end_timecode = "endTimecode",
            .start_timecode = "startTimecode",
        };
        return @field(mappings, field_name);
    }
};

pub const InputClipping = struct {
    end_timecode: ?[]const u8 = null,
    start_timecode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .end_timecode = "endTimecode",
            .start_timecode = "startTimecode",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionSelector = struct {
    custom_language_code: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    source_settings: ?CaptionSourceSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_language_code = "customLanguageCode",
            .language_code = "languageCode",
            .source_settings = "sourceSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionSourceSettings = struct {
    ancillary_source_settings: ?AncillarySourceSettings = null,
    dvb_sub_source_settings: ?DvbSubSourceSettings = null,
    embedded_source_settings: ?EmbeddedSourceSettings = null,
    file_source_settings: ?FileSourceSettings = null,
    source_type: ?[]const u8 = null,
    teletext_source_settings: ?TeletextSourceSettings = null,
    track_source_settings: ?TrackSourceSettings = null,
    webvtt_hls_source_settings: ?WebvttHlsSourceSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ancillary_source_settings = "ancillarySourceSettings",
            .dvb_sub_source_settings = "dvbSubSourceSettings",
            .embedded_source_settings = "embeddedSourceSettings",
            .file_source_settings = "fileSourceSettings",
            .source_type = "sourceType",
            .teletext_source_settings = "teletextSourceSettings",
            .track_source_settings = "trackSourceSettings",
            .webvtt_hls_source_settings = "webvttHlsSourceSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const WebvttHlsSourceSettings = struct {
    rendition_group_id: ?[]const u8 = null,
    rendition_language_code: ?[]const u8 = null,
    rendition_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rendition_group_id = "renditionGroupId",
            .rendition_language_code = "renditionLanguageCode",
            .rendition_name = "renditionName",
        };
        return @field(mappings, field_name);
    }
};

pub const TrackSourceSettings = struct {
    track_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .track_number = "trackNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const TeletextSourceSettings = struct {
    page_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .page_number = "pageNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSourceSettings = struct {
    convert608_to708: ?[]const u8 = null,
    convert_paint_to_pop: ?[]const u8 = null,
    framerate: ?CaptionSourceFramerate = null,
    source_file: ?[]const u8 = null,
    time_delta: ?i64 = null,
    time_delta_units: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .convert608_to708 = "convert608To708",
            .convert_paint_to_pop = "convertPaintToPop",
            .framerate = "framerate",
            .source_file = "sourceFile",
            .time_delta = "timeDelta",
            .time_delta_units = "timeDeltaUnits",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptionSourceFramerate = struct {
    framerate_denominator: ?i64 = null,
    framerate_numerator: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .framerate_denominator = "framerateDenominator",
            .framerate_numerator = "framerateNumerator",
        };
        return @field(mappings, field_name);
    }
};

pub const EmbeddedSourceSettings = struct {
    convert608_to708: ?[]const u8 = null,
    source608_channel_number: ?i64 = null,
    source608_track_number: ?i64 = null,
    terminate_captions: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .convert608_to708 = "convert608To708",
            .source608_channel_number = "source608ChannelNumber",
            .source608_track_number = "source608TrackNumber",
            .terminate_captions = "terminateCaptions",
        };
        return @field(mappings, field_name);
    }
};

pub const DvbSubSourceSettings = struct {
    pid: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pid = "pid",
        };
        return @field(mappings, field_name);
    }
};

pub const AncillarySourceSettings = struct {
    convert608_to708: ?[]const u8 = null,
    source_ancillary_channel_number: ?i64 = null,
    terminate_captions: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .convert608_to708 = "convert608To708",
            .source_ancillary_channel_number = "sourceAncillaryChannelNumber",
            .terminate_captions = "terminateCaptions",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioSelector = struct {
    audio_duration_correction: ?[]const u8 = null,
    custom_language_code: ?[]const u8 = null,
    default_selection: ?[]const u8 = null,
    external_audio_file_input: ?[]const u8 = null,
    hls_rendition_group_settings: ?HlsRenditionGroupSettings = null,
    language_code: ?[]const u8 = null,
    offset: ?i64 = null,
    pids: ?[]i64 = null,
    program_selection: ?i64 = null,
    remix_settings: ?RemixSettings = null,
    selector_type: ?[]const u8 = null,
    tracks: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_duration_correction = "audioDurationCorrection",
            .custom_language_code = "customLanguageCode",
            .default_selection = "defaultSelection",
            .external_audio_file_input = "externalAudioFileInput",
            .hls_rendition_group_settings = "hlsRenditionGroupSettings",
            .language_code = "languageCode",
            .offset = "offset",
            .pids = "pids",
            .program_selection = "programSelection",
            .remix_settings = "remixSettings",
            .selector_type = "selectorType",
            .tracks = "tracks",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsRenditionGroupSettings = struct {
    rendition_group_id: ?[]const u8 = null,
    rendition_language_code: ?[]const u8 = null,
    rendition_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rendition_group_id = "renditionGroupId",
            .rendition_language_code = "renditionLanguageCode",
            .rendition_name = "renditionName",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioSelectorGroup = struct {
    audio_selector_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_selector_names = "audioSelectorNames",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedInputFilterSettings = struct {
    add_texture: ?[]const u8 = null,
    sharpening: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .add_texture = "addTexture",
            .sharpening = "sharpening",
        };
        return @field(mappings, field_name);
    }
};

pub const ExtendedDataServices = struct {
    copy_protection_action: ?[]const u8 = null,
    vchip_action: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .copy_protection_action = "copyProtectionAction",
            .vchip_action = "vchipAction",
        };
        return @field(mappings, field_name);
    }
};

pub const EsamSettings = struct {
    manifest_confirm_condition_notification: ?EsamManifestConfirmConditionNotification = null,
    response_signal_preroll: ?i64 = null,
    signal_processing_notification: ?EsamSignalProcessingNotification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_confirm_condition_notification = "manifestConfirmConditionNotification",
            .response_signal_preroll = "responseSignalPreroll",
            .signal_processing_notification = "signalProcessingNotification",
        };
        return @field(mappings, field_name);
    }
};

pub const EsamSignalProcessingNotification = struct {
    scc_xml: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scc_xml = "sccXml",
        };
        return @field(mappings, field_name);
    }
};

pub const EsamManifestConfirmConditionNotification = struct {
    mcc_xml: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mcc_xml = "mccXml",
        };
        return @field(mappings, field_name);
    }
};

pub const ColorConversion3DLUTSetting = struct {
    file_input: ?[]const u8 = null,
    input_color_space: ?[]const u8 = null,
    input_mastering_luminance: ?i64 = null,
    output_color_space: ?[]const u8 = null,
    output_mastering_luminance: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_input = "fileInput",
            .input_color_space = "inputColorSpace",
            .input_mastering_luminance = "inputMasteringLuminance",
            .output_color_space = "outputColorSpace",
            .output_mastering_luminance = "outputMasteringLuminance",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailBlanking = struct {
    avail_blanking_image: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .avail_blanking_image = "availBlankingImage",
        };
        return @field(mappings, field_name);
    }
};

pub const HopDestination = struct {
    priority: ?i64 = null,
    queue: ?[]const u8 = null,
    wait_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .priority = "priority",
            .queue = "queue",
            .wait_minutes = "waitMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const AccelerationSettings = struct {
    mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "mode",
        };
        return @field(mappings, field_name);
    }
};

pub const Policy = struct {
    http_inputs: ?[]const u8 = null,
    https_inputs: ?[]const u8 = null,
    s3_inputs: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_inputs = "httpInputs",
            .https_inputs = "httpsInputs",
            .s3_inputs = "s3Inputs",
        };
        return @field(mappings, field_name);
    }
};

pub const Job = struct {
    acceleration_settings: ?AccelerationSettings = null,
    acceleration_status: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    billing_tags_source: ?[]const u8 = null,
    client_request_token: ?[]const u8 = null,
    created_at: ?i64 = null,
    current_phase: ?[]const u8 = null,
    error_code: ?i64 = null,
    error_message: ?[]const u8 = null,
    hop_destinations: ?[]HopDestination = null,
    id: ?[]const u8 = null,
    job_percent_complete: ?i64 = null,
    job_template: ?[]const u8 = null,
    messages: ?JobMessages = null,
    output_group_details: ?[]OutputGroupDetail = null,
    priority: ?i64 = null,
    queue: ?[]const u8 = null,
    queue_transitions: ?[]QueueTransition = null,
    retry_count: ?i64 = null,
    role: []const u8,
    settings: JobSettings,
    simulate_reserved_queue: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_update_interval: ?[]const u8 = null,
    timing: ?Timing = null,
    user_metadata: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    warnings: ?[]WarningGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .acceleration_settings = "accelerationSettings",
            .acceleration_status = "accelerationStatus",
            .arn = "arn",
            .billing_tags_source = "billingTagsSource",
            .client_request_token = "clientRequestToken",
            .created_at = "createdAt",
            .current_phase = "currentPhase",
            .error_code = "errorCode",
            .error_message = "errorMessage",
            .hop_destinations = "hopDestinations",
            .id = "id",
            .job_percent_complete = "jobPercentComplete",
            .job_template = "jobTemplate",
            .messages = "messages",
            .output_group_details = "outputGroupDetails",
            .priority = "priority",
            .queue = "queue",
            .queue_transitions = "queueTransitions",
            .retry_count = "retryCount",
            .role = "role",
            .settings = "settings",
            .simulate_reserved_queue = "simulateReservedQueue",
            .status = "status",
            .status_update_interval = "statusUpdateInterval",
            .timing = "timing",
            .user_metadata = "userMetadata",
            .warnings = "warnings",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "user_metadata", field_name))
            return try serializeMap(self.user_metadata, self.fieldNameFor("user_metadata"), options, out_stream);
        return false;
    }
};

pub const WarningGroup = struct {
    code: i64,
    count: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .count = "count",
        };
        return @field(mappings, field_name);
    }
};

pub const Timing = struct {
    finish_time: ?i64 = null,
    start_time: ?i64 = null,
    submit_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .finish_time = "finishTime",
            .start_time = "startTime",
            .submit_time = "submitTime",
        };
        return @field(mappings, field_name);
    }
};

pub const JobSettings = struct {
    ad_avail_offset: ?i64 = null,
    avail_blanking: ?AvailBlanking = null,
    color_conversion3dlut_settings: ?[]ColorConversion3DLUTSetting = null,
    esam: ?EsamSettings = null,
    extended_data_services: ?ExtendedDataServices = null,
    follow_source: ?i64 = null,
    inputs: ?[]Input = null,
    kantar_watermark: ?KantarWatermarkSettings = null,
    motion_image_inserter: ?MotionImageInserter = null,
    nielsen_configuration: ?NielsenConfiguration = null,
    nielsen_non_linear_watermark: ?NielsenNonLinearWatermarkSettings = null,
    output_groups: ?[]OutputGroup = null,
    timecode_config: ?TimecodeConfig = null,
    timed_metadata_insertion: ?TimedMetadataInsertion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_avail_offset = "adAvailOffset",
            .avail_blanking = "availBlanking",
            .color_conversion3dlut_settings = "colorConversion3DLUTSettings",
            .esam = "esam",
            .extended_data_services = "extendedDataServices",
            .follow_source = "followSource",
            .inputs = "inputs",
            .kantar_watermark = "kantarWatermark",
            .motion_image_inserter = "motionImageInserter",
            .nielsen_configuration = "nielsenConfiguration",
            .nielsen_non_linear_watermark = "nielsenNonLinearWatermark",
            .output_groups = "outputGroups",
            .timecode_config = "timecodeConfig",
            .timed_metadata_insertion = "timedMetadataInsertion",
        };
        return @field(mappings, field_name);
    }
};

pub const Input = struct {
    advanced_input_filter: ?[]const u8 = null,
    advanced_input_filter_settings: ?AdvancedInputFilterSettings = null,
    audio_selector_groups: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AudioSelectorGroup = null,
    } = null,
    audio_selectors: ?[]struct {
        key: ?[]const u8 = null,
        value: ?AudioSelector = null,
    } = null,
    caption_selectors: ?[]struct {
        key: ?[]const u8 = null,
        value: ?CaptionSelector = null,
    } = null,
    crop: ?Rectangle = null,
    deblock_filter: ?[]const u8 = null,
    decryption_settings: ?InputDecryptionSettings = null,
    denoise_filter: ?[]const u8 = null,
    dolby_vision_metadata_xml: ?[]const u8 = null,
    file_input: ?[]const u8 = null,
    filter_enable: ?[]const u8 = null,
    filter_strength: ?i64 = null,
    image_inserter: ?ImageInserter = null,
    input_clippings: ?[]InputClipping = null,
    input_scan_type: ?[]const u8 = null,
    position: ?Rectangle = null,
    program_number: ?i64 = null,
    psi_control: ?[]const u8 = null,
    supplemental_imps: ?[][]const u8 = null,
    timecode_source: ?[]const u8 = null,
    timecode_start: ?[]const u8 = null,
    video_generator: ?InputVideoGenerator = null,
    video_overlays: ?[]VideoOverlay = null,
    video_selector: ?VideoSelector = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .advanced_input_filter = "advancedInputFilter",
            .advanced_input_filter_settings = "advancedInputFilterSettings",
            .audio_selector_groups = "audioSelectorGroups",
            .audio_selectors = "audioSelectors",
            .caption_selectors = "captionSelectors",
            .crop = "crop",
            .deblock_filter = "deblockFilter",
            .decryption_settings = "decryptionSettings",
            .denoise_filter = "denoiseFilter",
            .dolby_vision_metadata_xml = "dolbyVisionMetadataXml",
            .file_input = "fileInput",
            .filter_enable = "filterEnable",
            .filter_strength = "filterStrength",
            .image_inserter = "imageInserter",
            .input_clippings = "inputClippings",
            .input_scan_type = "inputScanType",
            .position = "position",
            .program_number = "programNumber",
            .psi_control = "psiControl",
            .supplemental_imps = "supplementalImps",
            .timecode_source = "timecodeSource",
            .timecode_start = "timecodeStart",
            .video_generator = "videoGenerator",
            .video_overlays = "videoOverlays",
            .video_selector = "videoSelector",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "audio_selector_groups", field_name))
            return try serializeMap(self.audio_selector_groups, self.fieldNameFor("audio_selector_groups"), options, out_stream);
        if (std.mem.eql(u8, "audio_selectors", field_name))
            return try serializeMap(self.audio_selectors, self.fieldNameFor("audio_selectors"), options, out_stream);
        if (std.mem.eql(u8, "caption_selectors", field_name))
            return try serializeMap(self.caption_selectors, self.fieldNameFor("caption_selectors"), options, out_stream);
        return false;
    }
};

pub const InputVideoGenerator = struct {
    duration: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration = "duration",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDecryptionSettings = struct {
    decryption_mode: ?[]const u8 = null,
    encrypted_decryption_key: ?[]const u8 = null,
    initialization_vector: ?[]const u8 = null,
    kms_key_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .decryption_mode = "decryptionMode",
            .encrypted_decryption_key = "encryptedDecryptionKey",
            .initialization_vector = "initializationVector",
            .kms_key_region = "kmsKeyRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const QueueTransition = struct {
    destination_queue: ?[]const u8 = null,
    source_queue: ?[]const u8 = null,
    timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_queue = "destinationQueue",
            .source_queue = "sourceQueue",
            .timestamp = "timestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputGroupDetail = struct {
    output_details: ?[]OutputDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_details = "outputDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputDetail = struct {
    duration_in_ms: ?i64 = null,
    video_details: ?VideoDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duration_in_ms = "durationInMs",
            .video_details = "videoDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoDetail = struct {
    height_in_px: ?i64 = null,
    width_in_px: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .height_in_px = "heightInPx",
            .width_in_px = "widthInPx",
        };
        return @field(mappings, field_name);
    }
};

pub const JobMessages = struct {
    info: ?[][]const u8 = null,
    warning: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .info = "info",
            .warning = "warning",
        };
        return @field(mappings, field_name);
    }
};
