const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-10-12";
pub const sdk_id: []const u8 = "MediaPackage";
pub const arn_namespace: ?[]const u8 = "mediapackage";
pub const endpoint_prefix: []const u8 = "mediapackage";
pub const sigv4_name: []const u8 = "mediapackage";
pub const name: []const u8 = "MediaPackage";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-10-12",
    sdk_id: []const u8 = "MediaPackage",
    arn_namespace: ?[]const u8 = "mediapackage",
    endpoint_prefix: []const u8 = "mediapackage",
    sigv4_name: []const u8 = "mediapackage",
    name: []const u8 = "MediaPackage",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const configure_logs: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{Id}/configure_logs",
        .success_code = 200,
    };

    action_name: []const u8 = "ConfigureLogs",
    Request: type = struct {
        egress_access_logs: ?EgressAccessLogs = null,
        id: []const u8,
        ingress_access_logs: ?IngressAccessLogs = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .egress_access_logs = "egressAccessLogs",
                .id = "Id",
                .ingress_access_logs = "ingressAccessLogs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(configure_logs) } {
            return .{ .service_metadata = service_metadata, .action = configure_logs };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        description: ?[]const u8 = null,
        egress_access_logs: ?EgressAccessLogs = null,
        hls_ingest: ?HlsIngest = null,
        id: ?[]const u8 = null,
        ingress_access_logs: ?IngressAccessLogs = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created_at = "createdAt",
                .description = "description",
                .egress_access_logs = "egressAccessLogs",
                .hls_ingest = "hlsIngest",
                .id = "id",
                .ingress_access_logs = "ingressAccessLogs",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const create_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateChannel",
    Request: type = struct {
        description: ?[]const u8 = null,
        id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .id = "id",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel) } {
            return .{ .service_metadata = service_metadata, .action = create_channel };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        description: ?[]const u8 = null,
        egress_access_logs: ?EgressAccessLogs = null,
        hls_ingest: ?HlsIngest = null,
        id: ?[]const u8 = null,
        ingress_access_logs: ?IngressAccessLogs = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created_at = "createdAt",
                .description = "description",
                .egress_access_logs = "egressAccessLogs",
                .hls_ingest = "hlsIngest",
                .id = "id",
                .ingress_access_logs = "ingressAccessLogs",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const create_harvest_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/harvest_jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateHarvestJob",
    Request: type = struct {
        end_time: []const u8,
        id: []const u8,
        origin_endpoint_id: []const u8,
        s3_destination: S3Destination,
        start_time: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .end_time = "endTime",
                .id = "id",
                .origin_endpoint_id = "originEndpointId",
                .s3_destination = "s3Destination",
                .start_time = "startTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_harvest_job) } {
            return .{ .service_metadata = service_metadata, .action = create_harvest_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        channel_id: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        end_time: ?[]const u8 = null,
        id: ?[]const u8 = null,
        origin_endpoint_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,
        start_time: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .channel_id = "channelId",
                .created_at = "createdAt",
                .end_time = "endTime",
                .id = "id",
                .origin_endpoint_id = "originEndpointId",
                .s3_destination = "s3Destination",
                .start_time = "startTime",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const create_origin_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/origin_endpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateOriginEndpoint",
    Request: type = struct {
        authorization: ?Authorization = null,
        channel_id: []const u8,
        cmaf_package: ?CmafPackageCreateOrUpdateParameters = null,
        dash_package: ?DashPackage = null,
        description: ?[]const u8 = null,
        hls_package: ?HlsPackage = null,
        id: []const u8,
        manifest_name: ?[]const u8 = null,
        mss_package: ?MssPackage = null,
        origination: ?[]const u8 = null,
        startover_window_seconds: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        time_delay_seconds: ?i64 = null,
        whitelist: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorization = "authorization",
                .channel_id = "channelId",
                .cmaf_package = "cmafPackage",
                .dash_package = "dashPackage",
                .description = "description",
                .hls_package = "hlsPackage",
                .id = "id",
                .manifest_name = "manifestName",
                .mss_package = "mssPackage",
                .origination = "origination",
                .startover_window_seconds = "startoverWindowSeconds",
                .tags = "tags",
                .time_delay_seconds = "timeDelaySeconds",
                .whitelist = "whitelist",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_origin_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_origin_endpoint };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        authorization: ?Authorization = null,
        channel_id: ?[]const u8 = null,
        cmaf_package: ?CmafPackage = null,
        created_at: ?[]const u8 = null,
        dash_package: ?DashPackage = null,
        description: ?[]const u8 = null,
        hls_package: ?HlsPackage = null,
        id: ?[]const u8 = null,
        manifest_name: ?[]const u8 = null,
        mss_package: ?MssPackage = null,
        origination: ?[]const u8 = null,
        startover_window_seconds: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        time_delay_seconds: ?i64 = null,
        url: ?[]const u8 = null,
        whitelist: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .authorization = "authorization",
                .channel_id = "channelId",
                .cmaf_package = "cmafPackage",
                .created_at = "createdAt",
                .dash_package = "dashPackage",
                .description = "description",
                .hls_package = "hlsPackage",
                .id = "id",
                .manifest_name = "manifestName",
                .mss_package = "mssPackage",
                .origination = "origination",
                .startover_window_seconds = "startoverWindowSeconds",
                .tags = "tags",
                .time_delay_seconds = "timeDelaySeconds",
                .url = "url",
                .whitelist = "whitelist",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const delete_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{Id}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteChannel",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const delete_origin_endpoint: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/origin_endpoints/{Id}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteOriginEndpoint",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_origin_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_origin_endpoint };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const describe_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannel",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        description: ?[]const u8 = null,
        egress_access_logs: ?EgressAccessLogs = null,
        hls_ingest: ?HlsIngest = null,
        id: ?[]const u8 = null,
        ingress_access_logs: ?IngressAccessLogs = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created_at = "createdAt",
                .description = "description",
                .egress_access_logs = "egressAccessLogs",
                .hls_ingest = "hlsIngest",
                .id = "id",
                .ingress_access_logs = "ingressAccessLogs",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const describe_harvest_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/harvest_jobs/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeHarvestJob",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_harvest_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_harvest_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        channel_id: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        end_time: ?[]const u8 = null,
        id: ?[]const u8 = null,
        origin_endpoint_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,
        start_time: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .channel_id = "channelId",
                .created_at = "createdAt",
                .end_time = "endTime",
                .id = "id",
                .origin_endpoint_id = "originEndpointId",
                .s3_destination = "s3Destination",
                .start_time = "startTime",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const describe_origin_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/origin_endpoints/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOriginEndpoint",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_origin_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = describe_origin_endpoint };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        authorization: ?Authorization = null,
        channel_id: ?[]const u8 = null,
        cmaf_package: ?CmafPackage = null,
        created_at: ?[]const u8 = null,
        dash_package: ?DashPackage = null,
        description: ?[]const u8 = null,
        hls_package: ?HlsPackage = null,
        id: ?[]const u8 = null,
        manifest_name: ?[]const u8 = null,
        mss_package: ?MssPackage = null,
        origination: ?[]const u8 = null,
        startover_window_seconds: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        time_delay_seconds: ?i64 = null,
        url: ?[]const u8 = null,
        whitelist: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .authorization = "authorization",
                .channel_id = "channelId",
                .cmaf_package = "cmafPackage",
                .created_at = "createdAt",
                .dash_package = "dashPackage",
                .description = "description",
                .hls_package = "hlsPackage",
                .id = "id",
                .manifest_name = "manifestName",
                .mss_package = "mssPackage",
                .origination = "origination",
                .startover_window_seconds = "startoverWindowSeconds",
                .tags = "tags",
                .time_delay_seconds = "timeDelaySeconds",
                .url = "url",
                .whitelist = "whitelist",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const list_channels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannels",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_channels };
        }
    },
    Response: type = struct {
        channels: ?[]struct {
            arn: ?[]const u8 = null,
            created_at: ?[]const u8 = null,
            description: ?[]const u8 = null,
            egress_access_logs: ?EgressAccessLogs = null,
            hls_ingest: ?HlsIngest = null,
            id: ?[]const u8 = null,
            ingress_access_logs: ?IngressAccessLogs = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .created_at = "createdAt",
                    .description = "description",
                    .egress_access_logs = "egressAccessLogs",
                    .hls_ingest = "hlsIngest",
                    .id = "id",
                    .ingress_access_logs = "ingressAccessLogs",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "channels",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const list_harvest_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/harvest_jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListHarvestJobs",
    Request: type = struct {
        include_channel_id: ?[]const u8 = null,
        include_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .include_channel_id = "includeChannelId",
            .include_status = "includeStatus",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .include_channel_id = "IncludeChannelId",
                .include_status = "IncludeStatus",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_harvest_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_harvest_jobs };
        }
    },
    Response: type = struct {
        harvest_jobs: ?[]struct {
            arn: ?[]const u8 = null,
            channel_id: ?[]const u8 = null,
            created_at: ?[]const u8 = null,
            end_time: ?[]const u8 = null,
            id: ?[]const u8 = null,
            origin_endpoint_id: ?[]const u8 = null,
            s3_destination: ?S3Destination = null,
            start_time: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .channel_id = "channelId",
                    .created_at = "createdAt",
                    .end_time = "endTime",
                    .id = "id",
                    .origin_endpoint_id = "originEndpointId",
                    .s3_destination = "s3Destination",
                    .start_time = "startTime",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .harvest_jobs = "harvestJobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const list_origin_endpoints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/origin_endpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOriginEndpoints",
    Request: type = struct {
        channel_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .channel_id = "channelId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_id = "ChannelId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_origin_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_origin_endpoints };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        origin_endpoints: ?[]struct {
            arn: ?[]const u8 = null,
            authorization: ?Authorization = null,
            channel_id: ?[]const u8 = null,
            cmaf_package: ?CmafPackage = null,
            created_at: ?[]const u8 = null,
            dash_package: ?DashPackage = null,
            description: ?[]const u8 = null,
            hls_package: ?HlsPackage = null,
            id: ?[]const u8 = null,
            manifest_name: ?[]const u8 = null,
            mss_package: ?MssPackage = null,
            origination: ?[]const u8 = null,
            startover_window_seconds: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            time_delay_seconds: ?i64 = null,
            url: ?[]const u8 = null,
            whitelist: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .authorization = "authorization",
                    .channel_id = "channelId",
                    .cmaf_package = "cmafPackage",
                    .created_at = "createdAt",
                    .dash_package = "dashPackage",
                    .description = "description",
                    .hls_package = "hlsPackage",
                    .id = "id",
                    .manifest_name = "manifestName",
                    .mss_package = "mssPackage",
                    .origination = "origination",
                    .startover_window_seconds = "startoverWindowSeconds",
                    .tags = "tags",
                    .time_delay_seconds = "timeDelaySeconds",
                    .url = "url",
                    .whitelist = "whitelist",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .origin_endpoints = "originEndpoints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const rotate_channel_credentials: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{Id}/credentials",
        .success_code = 200,
    };

    action_name: []const u8 = "RotateChannelCredentials",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rotate_channel_credentials) } {
            return .{ .service_metadata = service_metadata, .action = rotate_channel_credentials };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        description: ?[]const u8 = null,
        egress_access_logs: ?EgressAccessLogs = null,
        hls_ingest: ?HlsIngest = null,
        id: ?[]const u8 = null,
        ingress_access_logs: ?IngressAccessLogs = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created_at = "createdAt",
                .description = "description",
                .egress_access_logs = "egressAccessLogs",
                .hls_ingest = "hlsIngest",
                .id = "id",
                .ingress_access_logs = "ingressAccessLogs",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const rotate_ingest_endpoint_credentials: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{Id}/ingest_endpoints/{IngestEndpointId}/credentials",
        .success_code = 200,
    };

    action_name: []const u8 = "RotateIngestEndpointCredentials",
    Request: type = struct {
        id: []const u8,
        ingest_endpoint_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .ingest_endpoint_id = "IngestEndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rotate_ingest_endpoint_credentials) } {
            return .{ .service_metadata = service_metadata, .action = rotate_ingest_endpoint_credentials };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        description: ?[]const u8 = null,
        egress_access_logs: ?EgressAccessLogs = null,
        hls_ingest: ?HlsIngest = null,
        id: ?[]const u8 = null,
        ingress_access_logs: ?IngressAccessLogs = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created_at = "createdAt",
                .description = "description",
                .egress_access_logs = "egressAccessLogs",
                .hls_ingest = "hlsIngest",
                .id = "id",
                .ingress_access_logs = "ingressAccessLogs",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
} = .{};
pub const update_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannel",
    Request: type = struct {
        description: ?[]const u8 = null,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_channel };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        description: ?[]const u8 = null,
        egress_access_logs: ?EgressAccessLogs = null,
        hls_ingest: ?HlsIngest = null,
        id: ?[]const u8 = null,
        ingress_access_logs: ?IngressAccessLogs = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created_at = "createdAt",
                .description = "description",
                .egress_access_logs = "egressAccessLogs",
                .hls_ingest = "hlsIngest",
                .id = "id",
                .ingress_access_logs = "ingressAccessLogs",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const update_origin_endpoint: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/origin_endpoints/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOriginEndpoint",
    Request: type = struct {
        authorization: ?Authorization = null,
        cmaf_package: ?CmafPackageCreateOrUpdateParameters = null,
        dash_package: ?DashPackage = null,
        description: ?[]const u8 = null,
        hls_package: ?HlsPackage = null,
        id: []const u8,
        manifest_name: ?[]const u8 = null,
        mss_package: ?MssPackage = null,
        origination: ?[]const u8 = null,
        startover_window_seconds: ?i64 = null,
        time_delay_seconds: ?i64 = null,
        whitelist: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorization = "authorization",
                .cmaf_package = "cmafPackage",
                .dash_package = "dashPackage",
                .description = "description",
                .hls_package = "hlsPackage",
                .id = "Id",
                .manifest_name = "manifestName",
                .mss_package = "mssPackage",
                .origination = "origination",
                .startover_window_seconds = "startoverWindowSeconds",
                .time_delay_seconds = "timeDelaySeconds",
                .whitelist = "whitelist",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_origin_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = update_origin_endpoint };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        authorization: ?Authorization = null,
        channel_id: ?[]const u8 = null,
        cmaf_package: ?CmafPackage = null,
        created_at: ?[]const u8 = null,
        dash_package: ?DashPackage = null,
        description: ?[]const u8 = null,
        hls_package: ?HlsPackage = null,
        id: ?[]const u8 = null,
        manifest_name: ?[]const u8 = null,
        mss_package: ?MssPackage = null,
        origination: ?[]const u8 = null,
        startover_window_seconds: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        time_delay_seconds: ?i64 = null,
        url: ?[]const u8 = null,
        whitelist: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .authorization = "authorization",
                .channel_id = "channelId",
                .cmaf_package = "cmafPackage",
                .created_at = "createdAt",
                .dash_package = "dashPackage",
                .description = "description",
                .hls_package = "hlsPackage",
                .id = "id",
                .manifest_name = "manifestName",
                .mss_package = "mssPackage",
                .origination = "origination",
                .startover_window_seconds = "startoverWindowSeconds",
                .tags = "tags",
                .time_delay_seconds = "timeDelaySeconds",
                .url = "url",
                .whitelist = "whitelist",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};

pub const MssPackage = struct {
    encryption: ?MssEncryption = null,
    manifest_window_seconds: ?i64 = null,
    segment_duration_seconds: ?i64 = null,
    stream_selection: ?StreamSelection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption = "encryption",
            .manifest_window_seconds = "manifestWindowSeconds",
            .segment_duration_seconds = "segmentDurationSeconds",
            .stream_selection = "streamSelection",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamSelection = struct {
    max_video_bits_per_second: ?i64 = null,
    min_video_bits_per_second: ?i64 = null,
    stream_order: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_video_bits_per_second = "maxVideoBitsPerSecond",
            .min_video_bits_per_second = "minVideoBitsPerSecond",
            .stream_order = "streamOrder",
        };
        return @field(mappings, field_name);
    }
};

pub const MssEncryption = struct {
    speke_key_provider: SpekeKeyProvider,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .speke_key_provider = "spekeKeyProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const SpekeKeyProvider = struct {
    certificate_arn: ?[]const u8 = null,
    encryption_contract_configuration: ?EncryptionContractConfiguration = null,
    resource_id: []const u8,
    role_arn: []const u8,
    system_ids: [][]const u8,
    url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "certificateArn",
            .encryption_contract_configuration = "encryptionContractConfiguration",
            .resource_id = "resourceId",
            .role_arn = "roleArn",
            .system_ids = "systemIds",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionContractConfiguration = struct {
    preset_speke20_audio: []const u8,
    preset_speke20_video: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .preset_speke20_audio = "presetSpeke20Audio",
            .preset_speke20_video = "presetSpeke20Video",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsPackage = struct {
    ad_markers: ?[]const u8 = null,
    ad_triggers: ?[][]const u8 = null,
    ads_on_delivery_restrictions: ?[]const u8 = null,
    encryption: ?HlsEncryption = null,
    include_dvb_subtitles: ?bool = null,
    include_iframe_only_stream: ?bool = null,
    playlist_type: ?[]const u8 = null,
    playlist_window_seconds: ?i64 = null,
    program_date_time_interval_seconds: ?i64 = null,
    segment_duration_seconds: ?i64 = null,
    stream_selection: ?StreamSelection = null,
    use_audio_rendition_group: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_markers = "adMarkers",
            .ad_triggers = "adTriggers",
            .ads_on_delivery_restrictions = "adsOnDeliveryRestrictions",
            .encryption = "encryption",
            .include_dvb_subtitles = "includeDvbSubtitles",
            .include_iframe_only_stream = "includeIframeOnlyStream",
            .playlist_type = "playlistType",
            .playlist_window_seconds = "playlistWindowSeconds",
            .program_date_time_interval_seconds = "programDateTimeIntervalSeconds",
            .segment_duration_seconds = "segmentDurationSeconds",
            .stream_selection = "streamSelection",
            .use_audio_rendition_group = "useAudioRenditionGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsEncryption = struct {
    constant_initialization_vector: ?[]const u8 = null,
    encryption_method: ?[]const u8 = null,
    key_rotation_interval_seconds: ?i64 = null,
    repeat_ext_x_key: ?bool = null,
    speke_key_provider: SpekeKeyProvider,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant_initialization_vector = "constantInitializationVector",
            .encryption_method = "encryptionMethod",
            .key_rotation_interval_seconds = "keyRotationIntervalSeconds",
            .repeat_ext_x_key = "repeatExtXKey",
            .speke_key_provider = "spekeKeyProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const DashPackage = struct {
    ad_triggers: ?[][]const u8 = null,
    ads_on_delivery_restrictions: ?[]const u8 = null,
    encryption: ?DashEncryption = null,
    include_iframe_only_stream: ?bool = null,
    manifest_layout: ?[]const u8 = null,
    manifest_window_seconds: ?i64 = null,
    min_buffer_time_seconds: ?i64 = null,
    min_update_period_seconds: ?i64 = null,
    period_triggers: ?[][]const u8 = null,
    profile: ?[]const u8 = null,
    segment_duration_seconds: ?i64 = null,
    segment_template_format: ?[]const u8 = null,
    stream_selection: ?StreamSelection = null,
    suggested_presentation_delay_seconds: ?i64 = null,
    utc_timing: ?[]const u8 = null,
    utc_timing_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_triggers = "adTriggers",
            .ads_on_delivery_restrictions = "adsOnDeliveryRestrictions",
            .encryption = "encryption",
            .include_iframe_only_stream = "includeIframeOnlyStream",
            .manifest_layout = "manifestLayout",
            .manifest_window_seconds = "manifestWindowSeconds",
            .min_buffer_time_seconds = "minBufferTimeSeconds",
            .min_update_period_seconds = "minUpdatePeriodSeconds",
            .period_triggers = "periodTriggers",
            .profile = "profile",
            .segment_duration_seconds = "segmentDurationSeconds",
            .segment_template_format = "segmentTemplateFormat",
            .stream_selection = "streamSelection",
            .suggested_presentation_delay_seconds = "suggestedPresentationDelaySeconds",
            .utc_timing = "utcTiming",
            .utc_timing_uri = "utcTimingUri",
        };
        return @field(mappings, field_name);
    }
};

pub const DashEncryption = struct {
    key_rotation_interval_seconds: ?i64 = null,
    speke_key_provider: SpekeKeyProvider,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_rotation_interval_seconds = "keyRotationIntervalSeconds",
            .speke_key_provider = "spekeKeyProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const CmafPackage = struct {
    encryption: ?CmafEncryption = null,
    hls_manifests: ?[]HlsManifest = null,
    segment_duration_seconds: ?i64 = null,
    segment_prefix: ?[]const u8 = null,
    stream_selection: ?StreamSelection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption = "encryption",
            .hls_manifests = "hlsManifests",
            .segment_duration_seconds = "segmentDurationSeconds",
            .segment_prefix = "segmentPrefix",
            .stream_selection = "streamSelection",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsManifest = struct {
    ad_markers: ?[]const u8 = null,
    id: []const u8,
    include_iframe_only_stream: ?bool = null,
    manifest_name: ?[]const u8 = null,
    playlist_type: ?[]const u8 = null,
    playlist_window_seconds: ?i64 = null,
    program_date_time_interval_seconds: ?i64 = null,
    url: ?[]const u8 = null,
    ad_triggers: ?[][]const u8 = null,
    ads_on_delivery_restrictions: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_markers = "adMarkers",
            .id = "id",
            .include_iframe_only_stream = "includeIframeOnlyStream",
            .manifest_name = "manifestName",
            .playlist_type = "playlistType",
            .playlist_window_seconds = "playlistWindowSeconds",
            .program_date_time_interval_seconds = "programDateTimeIntervalSeconds",
            .url = "url",
            .ad_triggers = "adTriggers",
            .ads_on_delivery_restrictions = "adsOnDeliveryRestrictions",
        };
        return @field(mappings, field_name);
    }
};

pub const CmafEncryption = struct {
    constant_initialization_vector: ?[]const u8 = null,
    encryption_method: ?[]const u8 = null,
    key_rotation_interval_seconds: ?i64 = null,
    speke_key_provider: SpekeKeyProvider,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant_initialization_vector = "constantInitializationVector",
            .encryption_method = "encryptionMethod",
            .key_rotation_interval_seconds = "keyRotationIntervalSeconds",
            .speke_key_provider = "spekeKeyProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const Authorization = struct {
    cdn_identifier_secret: []const u8,
    secrets_role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cdn_identifier_secret = "cdnIdentifierSecret",
            .secrets_role_arn = "secretsRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CmafPackageCreateOrUpdateParameters = struct {
    encryption: ?CmafEncryption = null,
    hls_manifests: ?[]HlsManifestCreateOrUpdateParameters = null,
    segment_duration_seconds: ?i64 = null,
    segment_prefix: ?[]const u8 = null,
    stream_selection: ?StreamSelection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption = "encryption",
            .hls_manifests = "hlsManifests",
            .segment_duration_seconds = "segmentDurationSeconds",
            .segment_prefix = "segmentPrefix",
            .stream_selection = "streamSelection",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsManifestCreateOrUpdateParameters = struct {
    ad_markers: ?[]const u8 = null,
    ad_triggers: ?[][]const u8 = null,
    ads_on_delivery_restrictions: ?[]const u8 = null,
    id: []const u8,
    include_iframe_only_stream: ?bool = null,
    manifest_name: ?[]const u8 = null,
    playlist_type: ?[]const u8 = null,
    playlist_window_seconds: ?i64 = null,
    program_date_time_interval_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_markers = "adMarkers",
            .ad_triggers = "adTriggers",
            .ads_on_delivery_restrictions = "adsOnDeliveryRestrictions",
            .id = "id",
            .include_iframe_only_stream = "includeIframeOnlyStream",
            .manifest_name = "manifestName",
            .playlist_type = "playlistType",
            .playlist_window_seconds = "playlistWindowSeconds",
            .program_date_time_interval_seconds = "programDateTimeIntervalSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const IngressAccessLogs = struct {
    log_group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group_name = "logGroupName",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsIngest = struct {
    ingest_endpoints: ?[]IngestEndpoint = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ingest_endpoints = "ingestEndpoints",
        };
        return @field(mappings, field_name);
    }
};

pub const IngestEndpoint = struct {
    id: ?[]const u8 = null,
    password: ?[]const u8 = null,
    url: ?[]const u8 = null,
    username: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .password = "password",
            .url = "url",
            .username = "username",
        };
        return @field(mappings, field_name);
    }
};

pub const EgressAccessLogs = struct {
    log_group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group_name = "logGroupName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Destination = struct {
    bucket_name: []const u8,
    manifest_key: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .manifest_key = "manifestKey",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};
