const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-07";
pub const sdk_id: []const u8 = "MediaPackage Vod";
pub const arn_namespace: ?[]const u8 = "mediapackage-vod";
pub const endpoint_prefix: []const u8 = "mediapackage-vod";
pub const sigv4_name: []const u8 = "mediapackage-vod";
pub const name: []const u8 = "MediaPackageVod";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-07",
    sdk_id: []const u8 = "MediaPackage Vod",
    arn_namespace: ?[]const u8 = "mediapackage-vod",
    endpoint_prefix: []const u8 = "mediapackage-vod",
    sigv4_name: []const u8 = "mediapackage-vod",
    name: []const u8 = "MediaPackageVod",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const configure_logs: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/packaging_groups/{Id}/configure_logs",
        .success_code = 200,
    };

    action_name: []const u8 = "ConfigureLogs",
    Request: type = struct {
        egress_access_logs: ?EgressAccessLogs = null,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .egress_access_logs = "egressAccessLogs",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(configure_logs) } {
            return .{ .service_metadata = service_metadata, .action = configure_logs };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        authorization: ?Authorization = null,
        created_at: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        egress_access_logs: ?EgressAccessLogs = null,
        id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .authorization = "authorization",
                .created_at = "createdAt",
                .domain_name = "domainName",
                .egress_access_logs = "egressAccessLogs",
                .id = "id",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const create_asset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/assets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAsset",
    Request: type = struct {
        id: []const u8,
        packaging_group_id: []const u8,
        resource_id: ?[]const u8 = null,
        source_arn: []const u8,
        source_role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .packaging_group_id = "packagingGroupId",
                .resource_id = "resourceId",
                .source_arn = "sourceArn",
                .source_role_arn = "sourceRoleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_asset) } {
            return .{ .service_metadata = service_metadata, .action = create_asset };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        egress_endpoints: ?[]EgressEndpoint = null,
        id: ?[]const u8 = null,
        packaging_group_id: ?[]const u8 = null,
        resource_id: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        source_role_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created_at = "createdAt",
                .egress_endpoints = "egressEndpoints",
                .id = "id",
                .packaging_group_id = "packagingGroupId",
                .resource_id = "resourceId",
                .source_arn = "sourceArn",
                .source_role_arn = "sourceRoleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const create_packaging_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/packaging_configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePackagingConfiguration",
    Request: type = struct {
        cmaf_package: ?CmafPackage = null,
        dash_package: ?DashPackage = null,
        hls_package: ?HlsPackage = null,
        id: []const u8,
        mss_package: ?MssPackage = null,
        packaging_group_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cmaf_package = "cmafPackage",
                .dash_package = "dashPackage",
                .hls_package = "hlsPackage",
                .id = "id",
                .mss_package = "mssPackage",
                .packaging_group_id = "packagingGroupId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_packaging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_packaging_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        cmaf_package: ?CmafPackage = null,
        created_at: ?[]const u8 = null,
        dash_package: ?DashPackage = null,
        hls_package: ?HlsPackage = null,
        id: ?[]const u8 = null,
        mss_package: ?MssPackage = null,
        packaging_group_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .cmaf_package = "cmafPackage",
                .created_at = "createdAt",
                .dash_package = "dashPackage",
                .hls_package = "hlsPackage",
                .id = "id",
                .mss_package = "mssPackage",
                .packaging_group_id = "packagingGroupId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const create_packaging_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/packaging_groups",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePackagingGroup",
    Request: type = struct {
        authorization: ?Authorization = null,
        egress_access_logs: ?EgressAccessLogs = null,
        id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorization = "authorization",
                .egress_access_logs = "egressAccessLogs",
                .id = "id",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_packaging_group) } {
            return .{ .service_metadata = service_metadata, .action = create_packaging_group };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        authorization: ?Authorization = null,
        created_at: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        egress_access_logs: ?EgressAccessLogs = null,
        id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .authorization = "authorization",
                .created_at = "createdAt",
                .domain_name = "domainName",
                .egress_access_logs = "egressAccessLogs",
                .id = "id",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const delete_asset: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/assets/{Id}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteAsset",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_asset) } {
            return .{ .service_metadata = service_metadata, .action = delete_asset };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const delete_packaging_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/packaging_configurations/{Id}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeletePackagingConfiguration",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_packaging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_packaging_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const delete_packaging_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/packaging_groups/{Id}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeletePackagingGroup",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_packaging_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_packaging_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const describe_asset: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assets/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAsset",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_asset) } {
            return .{ .service_metadata = service_metadata, .action = describe_asset };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created_at: ?[]const u8 = null,
        egress_endpoints: ?[]EgressEndpoint = null,
        id: ?[]const u8 = null,
        packaging_group_id: ?[]const u8 = null,
        resource_id: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        source_role_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created_at = "createdAt",
                .egress_endpoints = "egressEndpoints",
                .id = "id",
                .packaging_group_id = "packagingGroupId",
                .resource_id = "resourceId",
                .source_arn = "sourceArn",
                .source_role_arn = "sourceRoleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const describe_packaging_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packaging_configurations/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePackagingConfiguration",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_packaging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_packaging_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        cmaf_package: ?CmafPackage = null,
        created_at: ?[]const u8 = null,
        dash_package: ?DashPackage = null,
        hls_package: ?HlsPackage = null,
        id: ?[]const u8 = null,
        mss_package: ?MssPackage = null,
        packaging_group_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .cmaf_package = "cmafPackage",
                .created_at = "createdAt",
                .dash_package = "dashPackage",
                .hls_package = "hlsPackage",
                .id = "id",
                .mss_package = "mssPackage",
                .packaging_group_id = "packagingGroupId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const describe_packaging_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packaging_groups/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePackagingGroup",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_packaging_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_packaging_group };
        }
    },
    Response: type = struct {
        approximate_asset_count: ?i64 = null,
        arn: ?[]const u8 = null,
        authorization: ?Authorization = null,
        created_at: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        egress_access_logs: ?EgressAccessLogs = null,
        id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approximate_asset_count = "approximateAssetCount",
                .arn = "arn",
                .authorization = "authorization",
                .created_at = "createdAt",
                .domain_name = "domainName",
                .egress_access_logs = "egressAccessLogs",
                .id = "id",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const list_assets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssets",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        packaging_group_id: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .packaging_group_id = "packagingGroupId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .packaging_group_id = "PackagingGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assets) } {
            return .{ .service_metadata = service_metadata, .action = list_assets };
        }
    },
    Response: type = struct {
        assets: ?[]struct {
            arn: ?[]const u8 = null,
            created_at: ?[]const u8 = null,
            id: ?[]const u8 = null,
            packaging_group_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            source_arn: ?[]const u8 = null,
            source_role_arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .created_at = "createdAt",
                    .id = "id",
                    .packaging_group_id = "packagingGroupId",
                    .resource_id = "resourceId",
                    .source_arn = "sourceArn",
                    .source_role_arn = "sourceRoleArn",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assets = "assets",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const list_packaging_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packaging_configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackagingConfigurations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        packaging_group_id: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .packaging_group_id = "packagingGroupId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .packaging_group_id = "PackagingGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_packaging_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_packaging_configurations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        packaging_configurations: ?[]struct {
            arn: ?[]const u8 = null,
            cmaf_package: ?CmafPackage = null,
            created_at: ?[]const u8 = null,
            dash_package: ?DashPackage = null,
            hls_package: ?HlsPackage = null,
            id: ?[]const u8 = null,
            mss_package: ?MssPackage = null,
            packaging_group_id: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .cmaf_package = "cmafPackage",
                    .created_at = "createdAt",
                    .dash_package = "dashPackage",
                    .hls_package = "hlsPackage",
                    .id = "id",
                    .mss_package = "mssPackage",
                    .packaging_group_id = "packagingGroupId",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .packaging_configurations = "packagingConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const list_packaging_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packaging_groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackagingGroups",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_packaging_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_packaging_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        packaging_groups: ?[]struct {
            approximate_asset_count: ?i64 = null,
            arn: ?[]const u8 = null,
            authorization: ?Authorization = null,
            created_at: ?[]const u8 = null,
            domain_name: ?[]const u8 = null,
            egress_access_logs: ?EgressAccessLogs = null,
            id: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .approximate_asset_count = "approximateAssetCount",
                    .arn = "arn",
                    .authorization = "authorization",
                    .created_at = "createdAt",
                    .domain_name = "domainName",
                    .egress_access_logs = "egressAccessLogs",
                    .id = "id",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .packaging_groups = "packagingGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
} = .{};
pub const update_packaging_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/packaging_groups/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePackagingGroup",
    Request: type = struct {
        authorization: ?Authorization = null,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorization = "authorization",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_packaging_group) } {
            return .{ .service_metadata = service_metadata, .action = update_packaging_group };
        }
    },
    Response: type = struct {
        approximate_asset_count: ?i64 = null,
        arn: ?[]const u8 = null,
        authorization: ?Authorization = null,
        created_at: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        egress_access_logs: ?EgressAccessLogs = null,
        id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approximate_asset_count = "approximateAssetCount",
                .arn = "arn",
                .authorization = "authorization",
                .created_at = "createdAt",
                .domain_name = "domainName",
                .egress_access_logs = "egressAccessLogs",
                .id = "id",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        UnprocessableEntity,
    },
} = .{};

pub const EgressAccessLogs = struct {
    log_group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group_name = "logGroupName",
        };
        return @field(mappings, field_name);
    }
};

pub const Authorization = struct {
    cdn_identifier_secret: []const u8,
    secrets_role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cdn_identifier_secret = "cdnIdentifierSecret",
            .secrets_role_arn = "secretsRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MssPackage = struct {
    encryption: ?MssEncryption = null,
    mss_manifests: []MssManifest,
    segment_duration_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption = "encryption",
            .mss_manifests = "mssManifests",
            .segment_duration_seconds = "segmentDurationSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const MssManifest = struct {
    manifest_name: ?[]const u8 = null,
    stream_selection: ?StreamSelection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_name = "manifestName",
            .stream_selection = "streamSelection",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamSelection = struct {
    max_video_bits_per_second: ?i64 = null,
    min_video_bits_per_second: ?i64 = null,
    stream_order: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_video_bits_per_second = "maxVideoBitsPerSecond",
            .min_video_bits_per_second = "minVideoBitsPerSecond",
            .stream_order = "streamOrder",
        };
        return @field(mappings, field_name);
    }
};

pub const MssEncryption = struct {
    speke_key_provider: SpekeKeyProvider,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .speke_key_provider = "spekeKeyProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const SpekeKeyProvider = struct {
    encryption_contract_configuration: ?EncryptionContractConfiguration = null,
    role_arn: []const u8,
    system_ids: [][]const u8,
    url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_contract_configuration = "encryptionContractConfiguration",
            .role_arn = "roleArn",
            .system_ids = "systemIds",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionContractConfiguration = struct {
    preset_speke20_audio: []const u8,
    preset_speke20_video: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .preset_speke20_audio = "presetSpeke20Audio",
            .preset_speke20_video = "presetSpeke20Video",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsPackage = struct {
    encryption: ?HlsEncryption = null,
    hls_manifests: []HlsManifest,
    include_dvb_subtitles: ?bool = null,
    segment_duration_seconds: ?i64 = null,
    use_audio_rendition_group: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption = "encryption",
            .hls_manifests = "hlsManifests",
            .include_dvb_subtitles = "includeDvbSubtitles",
            .segment_duration_seconds = "segmentDurationSeconds",
            .use_audio_rendition_group = "useAudioRenditionGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsManifest = struct {
    ad_markers: ?[]const u8 = null,
    include_iframe_only_stream: ?bool = null,
    manifest_name: ?[]const u8 = null,
    program_date_time_interval_seconds: ?i64 = null,
    repeat_ext_x_key: ?bool = null,
    stream_selection: ?StreamSelection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_markers = "adMarkers",
            .include_iframe_only_stream = "includeIframeOnlyStream",
            .manifest_name = "manifestName",
            .program_date_time_interval_seconds = "programDateTimeIntervalSeconds",
            .repeat_ext_x_key = "repeatExtXKey",
            .stream_selection = "streamSelection",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsEncryption = struct {
    constant_initialization_vector: ?[]const u8 = null,
    encryption_method: ?[]const u8 = null,
    speke_key_provider: SpekeKeyProvider,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant_initialization_vector = "constantInitializationVector",
            .encryption_method = "encryptionMethod",
            .speke_key_provider = "spekeKeyProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const DashPackage = struct {
    dash_manifests: []DashManifest,
    encryption: ?DashEncryption = null,
    include_encoder_configuration_in_segments: ?bool = null,
    include_iframe_only_stream: ?bool = null,
    period_triggers: ?[][]const u8 = null,
    segment_duration_seconds: ?i64 = null,
    segment_template_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dash_manifests = "dashManifests",
            .encryption = "encryption",
            .include_encoder_configuration_in_segments = "includeEncoderConfigurationInSegments",
            .include_iframe_only_stream = "includeIframeOnlyStream",
            .period_triggers = "periodTriggers",
            .segment_duration_seconds = "segmentDurationSeconds",
            .segment_template_format = "segmentTemplateFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const DashEncryption = struct {
    speke_key_provider: SpekeKeyProvider,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .speke_key_provider = "spekeKeyProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const DashManifest = struct {
    manifest_layout: ?[]const u8 = null,
    manifest_name: ?[]const u8 = null,
    min_buffer_time_seconds: ?i64 = null,
    profile: ?[]const u8 = null,
    scte_markers_source: ?[]const u8 = null,
    stream_selection: ?StreamSelection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_layout = "manifestLayout",
            .manifest_name = "manifestName",
            .min_buffer_time_seconds = "minBufferTimeSeconds",
            .profile = "profile",
            .scte_markers_source = "scteMarkersSource",
            .stream_selection = "streamSelection",
        };
        return @field(mappings, field_name);
    }
};

pub const CmafPackage = struct {
    encryption: ?CmafEncryption = null,
    hls_manifests: []HlsManifest,
    include_encoder_configuration_in_segments: ?bool = null,
    segment_duration_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption = "encryption",
            .hls_manifests = "hlsManifests",
            .include_encoder_configuration_in_segments = "includeEncoderConfigurationInSegments",
            .segment_duration_seconds = "segmentDurationSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const CmafEncryption = struct {
    constant_initialization_vector: ?[]const u8 = null,
    speke_key_provider: SpekeKeyProvider,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constant_initialization_vector = "constantInitializationVector",
            .speke_key_provider = "spekeKeyProvider",
        };
        return @field(mappings, field_name);
    }
};

pub const EgressEndpoint = struct {
    packaging_configuration_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .packaging_configuration_id = "packagingConfigurationId",
            .status = "status",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};
