const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-09-01";
pub const sdk_id: []const u8 = "MediaStore Data";
pub const arn_namespace: ?[]const u8 = "mediastore";
pub const endpoint_prefix: []const u8 = "data.mediastore";
pub const sigv4_name: []const u8 = "mediastore";
pub const name: []const u8 = "MediaStoreObject_20170901";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-09-01",
    sdk_id: []const u8 = "MediaStore Data",
    arn_namespace: ?[]const u8 = "mediastore",
    endpoint_prefix: []const u8 = "data.mediastore",
    sigv4_name: []const u8 = "mediastore",
    name: []const u8 = "MediaStoreObject_20170901",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_object: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/{Path+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteObject",
    Request: type = struct {
        path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .path = "Path",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_object) } {
            return .{ .service_metadata = service_metadata, .action = delete_object };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ContainerNotFound,
        InternalServerError,
        ObjectNotFound,
    },
} = .{};
pub const describe_object: struct {
    pub const http_config = .{
        .method = "HEAD",
        .uri = "/{Path+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeObject",
    Request: type = struct {
        path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .path = "Path",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_object) } {
            return .{ .service_metadata = service_metadata, .action = describe_object };
        }
    },
    Response: type = struct {
        e_tag: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        content_length: ?i64 = null,
        cache_control: ?[]const u8 = null,
        last_modified: ?i64 = null,
        pub const http_header = .{
            .e_tag = "ETag",
            .content_type = "Content-Type",
            .content_length = "Content-Length",
            .cache_control = "Cache-Control",
            .last_modified = "Last-Modified",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .e_tag = "ETag",
                .content_type = "ContentType",
                .content_length = "ContentLength",
                .cache_control = "CacheControl",
                .last_modified = "LastModified",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ContainerNotFound,
        InternalServerError,
        ObjectNotFound,
    },
} = .{};
pub const get_object: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/{Path+}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetObject",
    Request: type = struct {
        path: []const u8,
        range: ?[]const u8 = null,
        pub const http_header = .{
            .range = "Range",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .path = "Path",
                .range = "Range",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_object) } {
            return .{ .service_metadata = service_metadata, .action = get_object };
        }
    },
    Response: type = struct {
        body: ?[]const u8 = null,
        cache_control: ?[]const u8 = null,
        content_range: ?[]const u8 = null,
        content_length: ?i64 = null,
        content_type: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        last_modified: ?i64 = null,
        status_code: i64,
        pub const http_header = .{
            .cache_control = "Cache-Control",
            .content_range = "Content-Range",
            .content_length = "Content-Length",
            .content_type = "Content-Type",
            .e_tag = "ETag",
            .last_modified = "Last-Modified",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "Body",
                .cache_control = "CacheControl",
                .content_range = "ContentRange",
                .content_length = "ContentLength",
                .content_type = "ContentType",
                .e_tag = "ETag",
                .last_modified = "LastModified",
                .status_code = "StatusCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ContainerNotFound,
        InternalServerError,
        ObjectNotFound,
        RequestedRangeNotSatisfiable,
    },
} = .{};
pub const list_items: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/",
        .success_code = 200,
    };

    action_name: []const u8 = "ListItems",
    Request: type = struct {
        path: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .path = "Path",
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .path = "Path",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_items) } {
            return .{ .service_metadata = service_metadata, .action = list_items };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            e_tag: ?[]const u8 = null,
            last_modified: ?i64 = null,
            content_type: ?[]const u8 = null,
            content_length: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .type = "Type",
                    .e_tag = "ETag",
                    .last_modified = "LastModified",
                    .content_type = "ContentType",
                    .content_length = "ContentLength",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ContainerNotFound,
        InternalServerError,
    },
} = .{};
pub const put_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/{Path+}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutObject",
    Request: type = struct {
        body: []const u8,
        path: []const u8,
        content_type: ?[]const u8 = null,
        cache_control: ?[]const u8 = null,
        storage_class: ?[]const u8 = null,
        upload_availability: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .cache_control = "Cache-Control",
            .storage_class = "x-amz-storage-class",
            .upload_availability = "x-amz-upload-availability",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "Body",
                .path = "Path",
                .content_type = "ContentType",
                .cache_control = "CacheControl",
                .storage_class = "StorageClass",
                .upload_availability = "UploadAvailability",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_object) } {
            return .{ .service_metadata = service_metadata, .action = put_object };
        }
    },
    Response: type = struct {
        content_sha256: ?[]const u8 = null,
        e_tag: ?[]const u8 = null,
        storage_class: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_sha256 = "ContentSHA256",
                .e_tag = "ETag",
                .storage_class = "StorageClass",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ContainerNotFound,
        InternalServerError,
    },
} = .{};
