const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-04-23";
pub const sdk_id: []const u8 = "MediaTailor";
pub const arn_namespace: ?[]const u8 = "mediatailor";
pub const endpoint_prefix: []const u8 = "api.mediatailor";
pub const sigv4_name: []const u8 = "mediatailor";
pub const name: []const u8 = "MediaTailor";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-04-23",
    sdk_id: []const u8 = "MediaTailor",
    arn_namespace: ?[]const u8 = "mediatailor",
    endpoint_prefix: []const u8 = "api.mediatailor",
    sigv4_name: []const u8 = "mediatailor",
    name: []const u8 = "MediaTailor",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const configure_logs_for_playback_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/configureLogs/playbackConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "ConfigureLogsForPlaybackConfiguration",
    Request: type = struct {
        percent_enabled: i64,
        playback_configuration_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .percent_enabled = "PercentEnabled",
                .playback_configuration_name = "PlaybackConfigurationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(configure_logs_for_playback_configuration) } {
            return .{ .service_metadata = service_metadata, .action = configure_logs_for_playback_configuration };
        }
    },
    Response: type = struct {
        percent_enabled: i64,
        playback_configuration_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .percent_enabled = "PercentEnabled",
                .playback_configuration_name = "PlaybackConfigurationName",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_alerts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/alerts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAlerts",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        resource_arn: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_alerts) } {
            return .{ .service_metadata = service_metadata, .action = list_alerts };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            alert_code: []const u8,
            alert_message: []const u8,
            last_modified_time: i64,
            related_resource_arns: [][]const u8,
            resource_arn: []const u8,
            category: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .alert_code = "AlertCode",
                    .alert_message = "AlertMessage",
                    .last_modified_time = "LastModifiedTime",
                    .related_resource_arns = "RelatedResourceArns",
                    .resource_arn = "ResourceArn",
                    .category = "Category",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
