const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2023-07-19";
pub const sdk_id: []const u8 = "Medical Imaging";
pub const arn_namespace: ?[]const u8 = "medical-imaging";
pub const endpoint_prefix: []const u8 = "medical-imaging";
pub const sigv4_name: []const u8 = "medical-imaging";
pub const name: []const u8 = "AHIGatewayService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2023-07-19",
    sdk_id: []const u8 = "Medical Imaging",
    arn_namespace: ?[]const u8 = "medical-imaging",
    endpoint_prefix: []const u8 = "medical-imaging",
    sigv4_name: []const u8 = "medical-imaging",
    name: []const u8 = "AHIGatewayService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const copy_image_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datastore/{datastoreId}/imageSet/{sourceImageSetId}/copyImageSet",
        .success_code = 200,
    };

    action_name: []const u8 = "CopyImageSet",
    Request: type = struct {
        datastore_id: []const u8,
        source_image_set_id: []const u8,
        copy_image_set_information: struct {
            source_image_set: struct {
                latest_version_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .latest_version_id = "latestVersionId",
                    };
                    return @field(mappings, field_name);
                }
            },
            destination_image_set: ?struct {
                image_set_id: []const u8,
                latest_version_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .image_set_id = "imageSetId",
                        .latest_version_id = "latestVersionId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_image_set = "sourceImageSet",
                    .destination_image_set = "destinationImageSet",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "copy_image_set_information";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .source_image_set_id = "sourceImageSetId",
                .copy_image_set_information = "copyImageSetInformation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_image_set) } {
            return .{ .service_metadata = service_metadata, .action = copy_image_set };
        }
    },
    Response: type = struct {
        datastore_id: []const u8,
        source_image_set_properties: struct {
            image_set_id: []const u8,
            latest_version_id: []const u8,
            image_set_state: ?[]const u8 = null,
            image_set_workflow_status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            image_set_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_set_id = "imageSetId",
                    .latest_version_id = "latestVersionId",
                    .image_set_state = "imageSetState",
                    .image_set_workflow_status = "imageSetWorkflowStatus",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .image_set_arn = "imageSetArn",
                };
                return @field(mappings, field_name);
            }
        },
        destination_image_set_properties: struct {
            image_set_id: []const u8,
            latest_version_id: []const u8,
            image_set_state: ?[]const u8 = null,
            image_set_workflow_status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            image_set_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_set_id = "imageSetId",
                    .latest_version_id = "latestVersionId",
                    .image_set_state = "imageSetState",
                    .image_set_workflow_status = "imageSetWorkflowStatus",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .image_set_arn = "imageSetArn",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .source_image_set_properties = "sourceImageSetProperties",
                .destination_image_set_properties = "destinationImageSetProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_image_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datastore/{datastoreId}/imageSet/{imageSetId}/deleteImageSet",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteImageSet",
    Request: type = struct {
        datastore_id: []const u8,
        image_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .image_set_id = "imageSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_image_set };
        }
    },
    Response: type = struct {
        datastore_id: []const u8,
        image_set_id: []const u8,
        image_set_state: []const u8,
        image_set_workflow_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .image_set_id = "imageSetId",
                .image_set_state = "imageSetState",
                .image_set_workflow_status = "imageSetWorkflowStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_dicom_import_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/getDICOMImportJob/datastore/{datastoreId}/job/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDICOMImportJob",
    Request: type = struct {
        datastore_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dicom_import_job) } {
            return .{ .service_metadata = service_metadata, .action = get_dicom_import_job };
        }
    },
    Response: type = struct {
        job_properties: struct {
            job_id: []const u8,
            job_name: []const u8,
            job_status: []const u8,
            datastore_id: []const u8,
            data_access_role_arn: []const u8,
            ended_at: ?i64 = null,
            submitted_at: ?i64 = null,
            input_s3_uri: []const u8,
            output_s3_uri: []const u8,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "jobId",
                    .job_name = "jobName",
                    .job_status = "jobStatus",
                    .datastore_id = "datastoreId",
                    .data_access_role_arn = "dataAccessRoleArn",
                    .ended_at = "endedAt",
                    .submitted_at = "submittedAt",
                    .input_s3_uri = "inputS3Uri",
                    .output_s3_uri = "outputS3Uri",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_properties = "jobProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_image_frame: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datastore/{datastoreId}/imageSet/{imageSetId}/getImageFrame",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImageFrame",
    Request: type = struct {
        datastore_id: []const u8,
        image_set_id: []const u8,
        image_frame_information: struct {
            image_frame_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_frame_id = "imageFrameId",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_payload: []const u8 = "image_frame_information";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .image_set_id = "imageSetId",
                .image_frame_information = "imageFrameInformation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_frame) } {
            return .{ .service_metadata = service_metadata, .action = get_image_frame };
        }
    },
    Response: type = struct {
        image_frame_blob: []const u8,
        content_type: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "image_frame_blob";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_frame_blob = "imageFrameBlob",
                .content_type = "contentType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_image_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datastore/{datastoreId}/imageSet/{imageSetId}/getImageSet",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImageSet",
    Request: type = struct {
        datastore_id: []const u8,
        image_set_id: []const u8,
        version_id: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .image_set_id = "imageSetId",
                .version_id = "versionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_set) } {
            return .{ .service_metadata = service_metadata, .action = get_image_set };
        }
    },
    Response: type = struct {
        datastore_id: []const u8,
        image_set_id: []const u8,
        version_id: []const u8,
        image_set_state: []const u8,
        image_set_workflow_status: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        deleted_at: ?i64 = null,
        message: ?[]const u8 = null,
        image_set_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .image_set_id = "imageSetId",
                .version_id = "versionId",
                .image_set_state = "imageSetState",
                .image_set_workflow_status = "imageSetWorkflowStatus",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .deleted_at = "deletedAt",
                .message = "message",
                .image_set_arn = "imageSetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_image_set_metadata: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datastore/{datastoreId}/imageSet/{imageSetId}/getImageSetMetadata",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImageSetMetadata",
    Request: type = struct {
        datastore_id: []const u8,
        image_set_id: []const u8,
        version_id: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .image_set_id = "imageSetId",
                .version_id = "versionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_set_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_image_set_metadata };
        }
    },
    Response: type = struct {
        image_set_metadata_blob: []const u8,
        content_type: ?[]const u8 = null,
        content_encoding: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .content_encoding = "Content-Encoding",
        };

        pub const http_payload: []const u8 = "image_set_metadata_blob";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_set_metadata_blob = "imageSetMetadataBlob",
                .content_type = "contentType",
                .content_encoding = "contentEncoding",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_dicom_import_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/listDICOMImportJobs/datastore/{datastoreId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDICOMImportJobs",
    Request: type = struct {
        datastore_id: []const u8,
        job_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .job_status = "jobStatus",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .job_status = "jobStatus",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dicom_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_dicom_import_jobs };
        }
    },
    Response: type = struct {
        job_summaries: []struct {
            job_id: []const u8,
            job_name: []const u8,
            job_status: []const u8,
            datastore_id: []const u8,
            data_access_role_arn: ?[]const u8 = null,
            ended_at: ?i64 = null,
            submitted_at: ?i64 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "jobId",
                    .job_name = "jobName",
                    .job_status = "jobStatus",
                    .datastore_id = "datastoreId",
                    .data_access_role_arn = "dataAccessRoleArn",
                    .ended_at = "endedAt",
                    .submitted_at = "submittedAt",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summaries = "jobSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_image_set_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datastore/{datastoreId}/imageSet/{imageSetId}/listImageSetVersions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImageSetVersions",
    Request: type = struct {
        datastore_id: []const u8,
        image_set_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .image_set_id = "imageSetId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_set_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_image_set_versions };
        }
    },
    Response: type = struct {
        image_set_properties_list: []struct {
            image_set_id: []const u8,
            version_id: []const u8,
            image_set_state: []const u8,
            image_set_workflow_status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            deleted_at: ?i64 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_set_id = "imageSetId",
                    .version_id = "versionId",
                    .image_set_state = "imageSetState",
                    .image_set_workflow_status = "ImageSetWorkflowStatus",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .deleted_at = "deletedAt",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_set_properties_list = "imageSetPropertiesList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const search_image_sets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datastore/{datastoreId}/searchImageSets",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchImageSets",
    Request: type = struct {
        datastore_id: []const u8,
        search_criteria: ?struct {
            filters: ?[]struct {
                values: []union {
                    dicom_patient_id: ?[]const u8,
                    dicom_accession_number: ?[]const u8,
                    dicom_study_id: ?[]const u8,
                    dicom_study_instance_uid: ?[]const u8,
                    created_at: ?i64,
                    dicom_study_date_and_time: ?struct {
                        dicom_study_date: []const u8,
                        dicom_study_time: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .dicom_study_date = "DICOMStudyDate",
                                .dicom_study_time = "DICOMStudyTime",
                            };
                            return @field(mappings, field_name);
                        }
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .dicom_patient_id = "DICOMPatientId",
                            .dicom_accession_number = "DICOMAccessionNumber",
                            .dicom_study_id = "DICOMStudyId",
                            .dicom_study_instance_uid = "DICOMStudyInstanceUID",
                            .created_at = "createdAt",
                            .dicom_study_date_and_time = "DICOMStudyDateAndTime",
                        };
                        return @field(mappings, field_name);
                    }
                },
                operator: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .values = "values",
                        .operator = "operator",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .filters = "filters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub const http_payload: []const u8 = "search_criteria";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .search_criteria = "searchCriteria",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_image_sets) } {
            return .{ .service_metadata = service_metadata, .action = search_image_sets };
        }
    },
    Response: type = struct {
        image_sets_metadata_summaries: []struct {
            image_set_id: []const u8,
            version: ?i64 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            dicom_tags: ?struct {
                dicom_patient_id: ?[]const u8 = null,
                dicom_patient_name: ?[]const u8 = null,
                dicom_patient_birth_date: ?[]const u8 = null,
                dicom_patient_sex: ?[]const u8 = null,
                dicom_study_instance_uid: ?[]const u8 = null,
                dicom_study_id: ?[]const u8 = null,
                dicom_study_description: ?[]const u8 = null,
                dicom_number_of_study_related_series: ?i64 = null,
                dicom_number_of_study_related_instances: ?i64 = null,
                dicom_accession_number: ?[]const u8 = null,
                dicom_study_date: ?[]const u8 = null,
                dicom_study_time: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .dicom_patient_id = "DICOMPatientId",
                        .dicom_patient_name = "DICOMPatientName",
                        .dicom_patient_birth_date = "DICOMPatientBirthDate",
                        .dicom_patient_sex = "DICOMPatientSex",
                        .dicom_study_instance_uid = "DICOMStudyInstanceUID",
                        .dicom_study_id = "DICOMStudyId",
                        .dicom_study_description = "DICOMStudyDescription",
                        .dicom_number_of_study_related_series = "DICOMNumberOfStudyRelatedSeries",
                        .dicom_number_of_study_related_instances = "DICOMNumberOfStudyRelatedInstances",
                        .dicom_accession_number = "DICOMAccessionNumber",
                        .dicom_study_date = "DICOMStudyDate",
                        .dicom_study_time = "DICOMStudyTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_set_id = "imageSetId",
                    .version = "version",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .dicom_tags = "DICOMTags",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_sets_metadata_summaries = "imageSetsMetadataSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_dicom_import_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/startDICOMImportJob/datastore/{datastoreId}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartDICOMImportJob",
    Request: type = struct {
        job_name: ?[]const u8 = null,
        data_access_role_arn: []const u8,
        client_token: []const u8,
        datastore_id: []const u8,
        input_s3_uri: []const u8,
        output_s3_uri: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "jobName",
                .data_access_role_arn = "dataAccessRoleArn",
                .client_token = "clientToken",
                .datastore_id = "datastoreId",
                .input_s3_uri = "inputS3Uri",
                .output_s3_uri = "outputS3Uri",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_dicom_import_job) } {
            return .{ .service_metadata = service_metadata, .action = start_dicom_import_job };
        }
    },
    Response: type = struct {
        datastore_id: []const u8,
        job_id: []const u8,
        job_status: []const u8,
        submitted_at: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .job_id = "jobId",
                .job_status = "jobStatus",
                .submitted_at = "submittedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_image_set_metadata: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/datastore/{datastoreId}/imageSet/{imageSetId}/updateImageSetMetadata",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateImageSetMetadata",
    Request: type = struct {
        datastore_id: []const u8,
        image_set_id: []const u8,
        latest_version_id: []const u8,
        update_image_set_metadata_updates: union {
            dicom_updates: ?struct {
                removable_attributes: ?[]const u8 = null,
                updatable_attributes: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .removable_attributes = "removableAttributes",
                        .updatable_attributes = "updatableAttributes",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dicom_updates = "DICOMUpdates",
                };
                return @field(mappings, field_name);
            }
        },

        pub const http_query = .{
            .latest_version_id = "latestVersion",
        };

        pub const http_payload: []const u8 = "update_image_set_metadata_updates";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .image_set_id = "imageSetId",
                .latest_version_id = "latestVersionId",
                .update_image_set_metadata_updates = "updateImageSetMetadataUpdates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_image_set_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_image_set_metadata };
        }
    },
    Response: type = struct {
        datastore_id: []const u8,
        image_set_id: []const u8,
        latest_version_id: []const u8,
        image_set_state: []const u8,
        image_set_workflow_status: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datastore_id = "datastoreId",
                .image_set_id = "imageSetId",
                .latest_version_id = "latestVersionId",
                .image_set_state = "imageSetState",
                .image_set_workflow_status = "imageSetWorkflowStatus",
                .created_at = "createdAt",
                .updated_at = "updatedAt",
                .message = "message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
