const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-01-01";
pub const sdk_id: []const u8 = "MemoryDB";
pub const arn_namespace: ?[]const u8 = "memorydb";
pub const endpoint_prefix: []const u8 = "memory-db";
pub const sigv4_name: []const u8 = "memorydb";
pub const name: []const u8 = "AmazonMemoryDB";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-01-01",
    sdk_id: []const u8 = "MemoryDB",
    arn_namespace: ?[]const u8 = "memorydb",
    endpoint_prefix: []const u8 = "memory-db",
    sigv4_name: []const u8 = "memorydb",
    name: []const u8 = "AmazonMemoryDB",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_update_cluster: struct {
    action_name: []const u8 = "BatchUpdateCluster",
    Request: type = struct {
        cluster_names: [][]const u8,
        service_update: ?struct {
            service_update_name_to_apply: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_update_name_to_apply = "ServiceUpdateNameToApply",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_names = "ClusterNames",
                .service_update = "ServiceUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_cluster) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_cluster };
        }
    },
    Response: type = struct {
        processed_clusters: ?[]Cluster = null,
        unprocessed_clusters: ?[]struct {
            cluster_name: ?[]const u8 = null,
            error_type: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cluster_name = "ClusterName",
                    .error_type = "ErrorType",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processed_clusters = "ProcessedClusters",
                .unprocessed_clusters = "UnprocessedClusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUpdateNotFound,
    },
} = .{};
pub const copy_snapshot: struct {
    action_name: []const u8 = "CopySnapshot",
    Request: type = struct {
        source_snapshot_name: []const u8,
        target_snapshot_name: []const u8,
        target_bucket: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_snapshot_name = "SourceSnapshotName",
                .target_snapshot_name = "TargetSnapshotName",
                .target_bucket = "TargetBucket",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = copy_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidSnapshotState,
        ServiceLinkedRoleNotFound,
        SnapshotAlreadyExists,
        SnapshotNotFound,
        SnapshotQuotaExceeded,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_acl: struct {
    action_name: []const u8 = "CreateACL",
    Request: type = struct {
        acl_name: []const u8,
        user_names: ?[][]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl_name = "ACLName",
                .user_names = "UserNames",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_acl) } {
            return .{ .service_metadata = service_metadata, .action = create_acl };
        }
    },
    Response: type = struct {
        acl: ?ACL = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ACLAlreadyExists,
        ACLQuotaExceeded,
        DefaultUserRequired,
        DuplicateUserName,
        InvalidParameterValue,
        TagQuotaPerResourceExceeded,
        UserNotFound,
    },
} = .{};
pub const create_cluster: struct {
    action_name: []const u8 = "CreateCluster",
    Request: type = struct {
        cluster_name: []const u8,
        node_type: []const u8,
        parameter_group_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        num_shards: ?i64 = null,
        num_replicas_per_shard: ?i64 = null,
        subnet_group_name: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        maintenance_window: ?[]const u8 = null,
        port: ?i64 = null,
        sns_topic_arn: ?[]const u8 = null,
        tls_enabled: ?bool = null,
        kms_key_id: ?[]const u8 = null,
        snapshot_arns: ?[][]const u8 = null,
        snapshot_name: ?[]const u8 = null,
        snapshot_retention_limit: ?i64 = null,
        tags: ?[]Tag = null,
        snapshot_window: ?[]const u8 = null,
        acl_name: []const u8,
        engine_version: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        data_tiering: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .node_type = "NodeType",
                .parameter_group_name = "ParameterGroupName",
                .description = "Description",
                .num_shards = "NumShards",
                .num_replicas_per_shard = "NumReplicasPerShard",
                .subnet_group_name = "SubnetGroupName",
                .security_group_ids = "SecurityGroupIds",
                .maintenance_window = "MaintenanceWindow",
                .port = "Port",
                .sns_topic_arn = "SnsTopicArn",
                .tls_enabled = "TLSEnabled",
                .kms_key_id = "KmsKeyId",
                .snapshot_arns = "SnapshotArns",
                .snapshot_name = "SnapshotName",
                .snapshot_retention_limit = "SnapshotRetentionLimit",
                .tags = "Tags",
                .snapshot_window = "SnapshotWindow",
                .acl_name = "ACLName",
                .engine_version = "EngineVersion",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .data_tiering = "DataTiering",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ACLNotFound,
        ClusterAlreadyExists,
        ClusterQuotaForCustomerExceeded,
        InsufficientClusterCapacity,
        InvalidACLState,
        InvalidCredentials,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidVPCNetworkState,
        NodeQuotaForClusterExceeded,
        NodeQuotaForCustomerExceeded,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
        ShardsPerClusterQuotaExceeded,
        SubnetGroupNotFound,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_parameter_group: struct {
    action_name: []const u8 = "CreateParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,
        family: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .family = "Family",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = create_parameter_group };
        }
    },
    Response: type = struct {
        parameter_group: ?ParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group = "ParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterGroupState,
        InvalidParameterValue,
        ParameterGroupAlreadyExists,
        ParameterGroupQuotaExceeded,
        ServiceLinkedRoleNotFound,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_snapshot: struct {
    action_name: []const u8 = "CreateSnapshot",
    Request: type = struct {
        cluster_name: []const u8,
        snapshot_name: []const u8,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .snapshot_name = "SnapshotName",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
        SnapshotAlreadyExists,
        SnapshotQuotaExceeded,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_subnet_group: struct {
    action_name: []const u8 = "CreateSubnetGroup",
    Request: type = struct {
        subnet_group_name: []const u8,
        description: ?[]const u8 = null,
        subnet_ids: [][]const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group_name = "SubnetGroupName",
                .description = "Description",
                .subnet_ids = "SubnetIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = create_subnet_group };
        }
    },
    Response: type = struct {
        subnet_group: ?SubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group = "SubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidSubnet,
        ServiceLinkedRoleNotFound,
        SubnetGroupAlreadyExists,
        SubnetGroupQuotaExceeded,
        SubnetNotAllowed,
        SubnetQuotaExceeded,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const create_user: struct {
    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        user_name: []const u8,
        authentication_mode: AuthenticationMode,
        access_string: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .authentication_mode = "AuthenticationMode",
                .access_string = "AccessString",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateUserName,
        InvalidParameterCombination,
        InvalidParameterValue,
        TagQuotaPerResourceExceeded,
        UserAlreadyExists,
        UserQuotaExceeded,
    },
} = .{};
pub const delete_acl: struct {
    action_name: []const u8 = "DeleteACL",
    Request: type = struct {
        acl_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl_name = "ACLName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_acl) } {
            return .{ .service_metadata = service_metadata, .action = delete_acl };
        }
    },
    Response: type = struct {
        acl: ?ACL = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ACLNotFound,
        InvalidACLState,
        InvalidParameterValue,
    },
} = .{};
pub const delete_cluster: struct {
    action_name: []const u8 = "DeleteCluster",
    Request: type = struct {
        cluster_name: []const u8,
        final_snapshot_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .final_snapshot_name = "FinalSnapshotName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidClusterState,
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
        SnapshotAlreadyExists,
    },
} = .{};
pub const delete_parameter_group: struct {
    action_name: []const u8 = "DeleteParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_parameter_group };
        }
    },
    Response: type = struct {
        parameter_group: ?ParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group = "ParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterGroupState,
        InvalidParameterValue,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const delete_snapshot: struct {
    action_name: []const u8 = "DeleteSnapshot",
    Request: type = struct {
        snapshot_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_name = "SnapshotName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = delete_snapshot };
        }
    },
    Response: type = struct {
        snapshot: ?Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot = "Snapshot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidSnapshotState,
        ServiceLinkedRoleNotFound,
        SnapshotNotFound,
    },
} = .{};
pub const delete_subnet_group: struct {
    action_name: []const u8 = "DeleteSubnetGroup",
    Request: type = struct {
        subnet_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group_name = "SubnetGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_subnet_group };
        }
    },
    Response: type = struct {
        subnet_group: ?SubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group = "SubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ServiceLinkedRoleNotFound,
        SubnetGroupInUse,
        SubnetGroupNotFound,
    },
} = .{};
pub const delete_user: struct {
    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidUserState,
        UserNotFound,
    },
} = .{};
pub const describe_ac_ls: struct {
    action_name: []const u8 = "DescribeACLs",
    Request: type = struct {
        acl_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl_name = "ACLName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ac_ls) } {
            return .{ .service_metadata = service_metadata, .action = describe_ac_ls };
        }
    },
    Response: type = struct {
        ac_ls: ?[]ACL = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ac_ls = "ACLs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ACLNotFound,
        InvalidParameterCombination,
    },
} = .{};
pub const describe_clusters: struct {
    action_name: []const u8 = "DescribeClusters",
    Request: type = struct {
        cluster_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        show_shard_details: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .show_shard_details = "ShowShardDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_clusters) } {
            return .{ .service_metadata = service_metadata, .action = describe_clusters };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        clusters: ?[]Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .clusters = "Clusters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_engine_versions: struct {
    action_name: []const u8 = "DescribeEngineVersions",
    Request: type = struct {
        engine_version: ?[]const u8 = null,
        parameter_group_family: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        default_only: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_version = "EngineVersion",
                .parameter_group_family = "ParameterGroupFamily",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .default_only = "DefaultOnly",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_engine_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_engine_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        engine_versions: ?[]struct {
            engine_version: ?[]const u8 = null,
            engine_patch_version: ?[]const u8 = null,
            parameter_group_family: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine_version = "EngineVersion",
                    .engine_patch_version = "EnginePatchVersion",
                    .parameter_group_family = "ParameterGroupFamily",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .engine_versions = "EngineVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        source_name: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        duration: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_name = "SourceName",
                .source_type = "SourceType",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .duration = "Duration",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        events: ?[]struct {
            source_name: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            message: ?[]const u8 = null,
            date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_name = "SourceName",
                    .source_type = "SourceType",
                    .message = "Message",
                    .date = "Date",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .events = "Events",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_parameter_groups: struct {
    action_name: []const u8 = "DescribeParameterGroups",
    Request: type = struct {
        parameter_group_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_parameter_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_parameter_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        parameter_groups: ?[]ParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .parameter_groups = "ParameterGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_parameters: struct {
    action_name: []const u8 = "DescribeParameters",
    Request: type = struct {
        parameter_group_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_parameters };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        parameters: ?[]struct {
            name: ?[]const u8 = null,
            value: ?[]const u8 = null,
            description: ?[]const u8 = null,
            data_type: ?[]const u8 = null,
            allowed_values: ?[]const u8 = null,
            minimum_engine_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .value = "Value",
                    .description = "Description",
                    .data_type = "DataType",
                    .allowed_values = "AllowedValues",
                    .minimum_engine_version = "MinimumEngineVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_reserved_nodes: struct {
    action_name: []const u8 = "DescribeReservedNodes",
    Request: type = struct {
        reservation_id: ?[]const u8 = null,
        reserved_nodes_offering_id: ?[]const u8 = null,
        node_type: ?[]const u8 = null,
        duration: ?[]const u8 = null,
        offering_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reservation_id = "ReservationId",
                .reserved_nodes_offering_id = "ReservedNodesOfferingId",
                .node_type = "NodeType",
                .duration = "Duration",
                .offering_type = "OfferingType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_nodes) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_nodes };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        reserved_nodes: ?[]ReservedNode = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .reserved_nodes = "ReservedNodes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ReservedNodeNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_reserved_nodes_offerings: struct {
    action_name: []const u8 = "DescribeReservedNodesOfferings",
    Request: type = struct {
        reserved_nodes_offering_id: ?[]const u8 = null,
        node_type: ?[]const u8 = null,
        duration: ?[]const u8 = null,
        offering_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_nodes_offering_id = "ReservedNodesOfferingId",
                .node_type = "NodeType",
                .duration = "Duration",
                .offering_type = "OfferingType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_nodes_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_nodes_offerings };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        reserved_nodes_offerings: ?[]struct {
            reserved_nodes_offering_id: ?[]const u8 = null,
            node_type: ?[]const u8 = null,
            duration: ?i64 = null,
            fixed_price: ?f64 = null,
            offering_type: ?[]const u8 = null,
            recurring_charges: ?[]RecurringCharge = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reserved_nodes_offering_id = "ReservedNodesOfferingId",
                    .node_type = "NodeType",
                    .duration = "Duration",
                    .fixed_price = "FixedPrice",
                    .offering_type = "OfferingType",
                    .recurring_charges = "RecurringCharges",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .reserved_nodes_offerings = "ReservedNodesOfferings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ReservedNodesOfferingNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const describe_service_updates: struct {
    action_name: []const u8 = "DescribeServiceUpdates",
    Request: type = struct {
        service_update_name: ?[]const u8 = null,
        cluster_names: ?[][]const u8 = null,
        status: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_update_name = "ServiceUpdateName",
                .cluster_names = "ClusterNames",
                .status = "Status",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_service_updates) } {
            return .{ .service_metadata = service_metadata, .action = describe_service_updates };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        service_updates: ?[]struct {
            cluster_name: ?[]const u8 = null,
            service_update_name: ?[]const u8 = null,
            release_date: ?i64 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            type: ?[]const u8 = null,
            nodes_updated: ?[]const u8 = null,
            auto_update_start_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cluster_name = "ClusterName",
                    .service_update_name = "ServiceUpdateName",
                    .release_date = "ReleaseDate",
                    .description = "Description",
                    .status = "Status",
                    .type = "Type",
                    .nodes_updated = "NodesUpdated",
                    .auto_update_start_date = "AutoUpdateStartDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .service_updates = "ServiceUpdates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
    },
} = .{};
pub const describe_snapshots: struct {
    action_name: []const u8 = "DescribeSnapshots",
    Request: type = struct {
        cluster_name: ?[]const u8 = null,
        snapshot_name: ?[]const u8 = null,
        source: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        show_detail: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .snapshot_name = "SnapshotName",
                .source = "Source",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .show_detail = "ShowDetail",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_snapshots };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        snapshots: ?[]Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .snapshots = "Snapshots",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
        SnapshotNotFound,
    },
} = .{};
pub const describe_subnet_groups: struct {
    action_name: []const u8 = "DescribeSubnetGroups",
    Request: type = struct {
        subnet_group_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group_name = "SubnetGroupName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_subnet_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_subnet_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        subnet_groups: ?[]SubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .subnet_groups = "SubnetGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ServiceLinkedRoleNotFound,
        SubnetGroupNotFound,
    },
} = .{};
pub const describe_users: struct {
    action_name: []const u8 = "DescribeUsers",
    Request: type = struct {
        user_name: ?[]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_users) } {
            return .{ .service_metadata = service_metadata, .action = describe_users };
        }
    },
    Response: type = struct {
        users: ?[]User = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        UserNotFound,
    },
} = .{};
pub const failover_shard: struct {
    action_name: []const u8 = "FailoverShard",
    Request: type = struct {
        cluster_name: []const u8,
        shard_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .shard_name = "ShardName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(failover_shard) } {
            return .{ .service_metadata = service_metadata, .action = failover_shard };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        APICallRateForCustomerExceeded,
        ClusterNotFound,
        InvalidClusterState,
        InvalidKMSKey,
        InvalidParameterCombination,
        InvalidParameterValue,
        ShardNotFound,
        TestFailoverNotAvailable,
    },
} = .{};
pub const list_allowed_node_type_updates: struct {
    action_name: []const u8 = "ListAllowedNodeTypeUpdates",
    Request: type = struct {
        cluster_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_allowed_node_type_updates) } {
            return .{ .service_metadata = service_metadata, .action = list_allowed_node_type_updates };
        }
    },
    Response: type = struct {
        scale_up_node_types: ?[][]const u8 = null,
        scale_down_node_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scale_up_node_types = "ScaleUpNodeTypes",
                .scale_down_node_types = "ScaleDownNodeTypes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterNotFound,
        InvalidParameterCombination,
        InvalidParameterValue,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const list_tags: struct {
    action_name: []const u8 = "ListTags",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ACLNotFound,
        ClusterNotFound,
        InvalidARN,
        InvalidClusterState,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
        SnapshotNotFound,
        SubnetGroupNotFound,
        UserNotFound,
    },
} = .{};
pub const purchase_reserved_nodes_offering: struct {
    action_name: []const u8 = "PurchaseReservedNodesOffering",
    Request: type = struct {
        reserved_nodes_offering_id: []const u8,
        reservation_id: ?[]const u8 = null,
        node_count: ?i64 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_nodes_offering_id = "ReservedNodesOfferingId",
                .reservation_id = "ReservationId",
                .node_count = "NodeCount",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_reserved_nodes_offering) } {
            return .{ .service_metadata = service_metadata, .action = purchase_reserved_nodes_offering };
        }
    },
    Response: type = struct {
        reserved_node: ?ReservedNode = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_node = "ReservedNode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        ReservedNodeAlreadyExists,
        ReservedNodeQuotaExceeded,
        ReservedNodesOfferingNotFound,
        ServiceLinkedRoleNotFound,
        TagQuotaPerResourceExceeded,
    },
} = .{};
pub const reset_parameter_group: struct {
    action_name: []const u8 = "ResetParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,
        all_parameters: ?bool = null,
        parameter_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .all_parameters = "AllParameters",
                .parameter_names = "ParameterNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = reset_parameter_group };
        }
    },
    Response: type = struct {
        parameter_group: ?ParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group = "ParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterGroupState,
        InvalidParameterValue,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ACLNotFound,
        ClusterNotFound,
        InvalidARN,
        InvalidClusterState,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
        SnapshotNotFound,
        SubnetGroupNotFound,
        TagQuotaPerResourceExceeded,
        UserNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ACLNotFound,
        ClusterNotFound,
        InvalidARN,
        InvalidClusterState,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
        SnapshotNotFound,
        SubnetGroupNotFound,
        TagNotFound,
        UserNotFound,
    },
} = .{};
pub const update_acl: struct {
    action_name: []const u8 = "UpdateACL",
    Request: type = struct {
        acl_name: []const u8,
        user_names_to_add: ?[][]const u8 = null,
        user_names_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl_name = "ACLName",
                .user_names_to_add = "UserNamesToAdd",
                .user_names_to_remove = "UserNamesToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_acl) } {
            return .{ .service_metadata = service_metadata, .action = update_acl };
        }
    },
    Response: type = struct {
        acl: ?ACL = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ACLNotFound,
        DefaultUserRequired,
        DuplicateUserName,
        InvalidACLState,
        InvalidParameterCombination,
        InvalidParameterValue,
        UserNotFound,
    },
} = .{};
pub const update_cluster: struct {
    action_name: []const u8 = "UpdateCluster",
    Request: type = struct {
        cluster_name: []const u8,
        description: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        maintenance_window: ?[]const u8 = null,
        sns_topic_arn: ?[]const u8 = null,
        sns_topic_status: ?[]const u8 = null,
        parameter_group_name: ?[]const u8 = null,
        snapshot_window: ?[]const u8 = null,
        snapshot_retention_limit: ?i64 = null,
        node_type: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        replica_configuration: ?struct {
            replica_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replica_count = "ReplicaCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        shard_configuration: ?struct {
            shard_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .shard_count = "ShardCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        acl_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name = "ClusterName",
                .description = "Description",
                .security_group_ids = "SecurityGroupIds",
                .maintenance_window = "MaintenanceWindow",
                .sns_topic_arn = "SnsTopicArn",
                .sns_topic_status = "SnsTopicStatus",
                .parameter_group_name = "ParameterGroupName",
                .snapshot_window = "SnapshotWindow",
                .snapshot_retention_limit = "SnapshotRetentionLimit",
                .node_type = "NodeType",
                .engine_version = "EngineVersion",
                .replica_configuration = "ReplicaConfiguration",
                .shard_configuration = "ShardConfiguration",
                .acl_name = "ACLName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cluster) } {
            return .{ .service_metadata = service_metadata, .action = update_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ACLNotFound,
        ClusterNotFound,
        ClusterQuotaForCustomerExceeded,
        InvalidACLState,
        InvalidClusterState,
        InvalidKMSKey,
        InvalidNodeState,
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidVPCNetworkState,
        NodeQuotaForClusterExceeded,
        NodeQuotaForCustomerExceeded,
        NoOperation,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
        ShardsPerClusterQuotaExceeded,
    },
} = .{};
pub const update_parameter_group: struct {
    action_name: []const u8 = "UpdateParameterGroup",
    Request: type = struct {
        parameter_group_name: []const u8,
        parameter_name_values: []struct {
            parameter_name: ?[]const u8 = null,
            parameter_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .parameter_name = "ParameterName",
                    .parameter_value = "ParameterValue",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group_name = "ParameterGroupName",
                .parameter_name_values = "ParameterNameValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_parameter_group) } {
            return .{ .service_metadata = service_metadata, .action = update_parameter_group };
        }
    },
    Response: type = struct {
        parameter_group: ?ParameterGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parameter_group = "ParameterGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterGroupState,
        InvalidParameterValue,
        ParameterGroupNotFound,
        ServiceLinkedRoleNotFound,
    },
} = .{};
pub const update_subnet_group: struct {
    action_name: []const u8 = "UpdateSubnetGroup",
    Request: type = struct {
        subnet_group_name: []const u8,
        description: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group_name = "SubnetGroupName",
                .description = "Description",
                .subnet_ids = "SubnetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = update_subnet_group };
        }
    },
    Response: type = struct {
        subnet_group: ?SubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subnet_group = "SubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidSubnet,
        ServiceLinkedRoleNotFound,
        SubnetGroupNotFound,
        SubnetInUse,
        SubnetNotAllowed,
        SubnetQuotaExceeded,
    },
} = .{};
pub const update_user: struct {
    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        user_name: []const u8,
        authentication_mode: ?AuthenticationMode = null,
        access_string: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .authentication_mode = "AuthenticationMode",
                .access_string = "AccessString",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterCombination,
        InvalidParameterValue,
        InvalidUserState,
        UserNotFound,
    },
} = .{};

pub const User = struct {
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    access_string: ?[]const u8 = null,
    acl_names: ?[][]const u8 = null,
    minimum_engine_version: ?[]const u8 = null,
    authentication: ?Authentication = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .status = "Status",
            .access_string = "AccessString",
            .acl_names = "ACLNames",
            .minimum_engine_version = "MinimumEngineVersion",
            .authentication = "Authentication",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const Authentication = struct {
    type: ?[]const u8 = null,
    password_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .password_count = "PasswordCount",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthenticationMode = struct {
    type: ?[]const u8 = null,
    passwords: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .passwords = "Passwords",
        };
        return @field(mappings, field_name);
    }
};

pub const SubnetGroup = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnets: ?[]Subnet = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .vpc_id = "VpcId",
            .subnets = "Subnets",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const Subnet = struct {
    identifier: ?[]const u8 = null,
    availability_zone: ?AvailabilityZone = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
            .availability_zone = "AvailabilityZone",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailabilityZone = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterGroup = struct {
    name: ?[]const u8 = null,
    family: ?[]const u8 = null,
    description: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .family = "Family",
            .description = "Description",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const Cluster = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    status: ?[]const u8 = null,
    pending_updates: ?ClusterPendingUpdates = null,
    number_of_shards: ?i64 = null,
    shards: ?[]Shard = null,
    availability_mode: ?[]const u8 = null,
    cluster_endpoint: ?Endpoint = null,
    node_type: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    engine_patch_version: ?[]const u8 = null,
    parameter_group_name: ?[]const u8 = null,
    parameter_group_status: ?[]const u8 = null,
    security_groups: ?[]SecurityGroupMembership = null,
    subnet_group_name: ?[]const u8 = null,
    tls_enabled: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    sns_topic_status: ?[]const u8 = null,
    snapshot_retention_limit: ?i64 = null,
    maintenance_window: ?[]const u8 = null,
    snapshot_window: ?[]const u8 = null,
    acl_name: ?[]const u8 = null,
    auto_minor_version_upgrade: ?bool = null,
    data_tiering: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .status = "Status",
            .pending_updates = "PendingUpdates",
            .number_of_shards = "NumberOfShards",
            .shards = "Shards",
            .availability_mode = "AvailabilityMode",
            .cluster_endpoint = "ClusterEndpoint",
            .node_type = "NodeType",
            .engine_version = "EngineVersion",
            .engine_patch_version = "EnginePatchVersion",
            .parameter_group_name = "ParameterGroupName",
            .parameter_group_status = "ParameterGroupStatus",
            .security_groups = "SecurityGroups",
            .subnet_group_name = "SubnetGroupName",
            .tls_enabled = "TLSEnabled",
            .kms_key_id = "KmsKeyId",
            .arn = "ARN",
            .sns_topic_arn = "SnsTopicArn",
            .sns_topic_status = "SnsTopicStatus",
            .snapshot_retention_limit = "SnapshotRetentionLimit",
            .maintenance_window = "MaintenanceWindow",
            .snapshot_window = "SnapshotWindow",
            .acl_name = "ACLName",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .data_tiering = "DataTiering",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityGroupMembership = struct {
    security_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_id = "SecurityGroupId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const Endpoint = struct {
    address: ?[]const u8 = null,
    port: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const Shard = struct {
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    slots: ?[]const u8 = null,
    nodes: ?[]Node = null,
    number_of_nodes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .status = "Status",
            .slots = "Slots",
            .nodes = "Nodes",
            .number_of_nodes = "NumberOfNodes",
        };
        return @field(mappings, field_name);
    }
};

pub const Node = struct {
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    create_time: ?i64 = null,
    endpoint: ?Endpoint = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .status = "Status",
            .availability_zone = "AvailabilityZone",
            .create_time = "CreateTime",
            .endpoint = "Endpoint",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterPendingUpdates = struct {
    resharding: ?ReshardingStatus = null,
    ac_ls: ?ACLsUpdateStatus = null,
    service_updates: ?[]PendingModifiedServiceUpdate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resharding = "Resharding",
            .ac_ls = "ACLs",
            .service_updates = "ServiceUpdates",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingModifiedServiceUpdate = struct {
    service_update_name: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_update_name = "ServiceUpdateName",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ACLsUpdateStatus = struct {
    acl_to_apply: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .acl_to_apply = "ACLToApply",
        };
        return @field(mappings, field_name);
    }
};

pub const ReshardingStatus = struct {
    slot_migration: ?SlotMigration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .slot_migration = "SlotMigration",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotMigration = struct {
    progress_percentage: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .progress_percentage = "ProgressPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const ACL = struct {
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    user_names: ?[][]const u8 = null,
    minimum_engine_version: ?[]const u8 = null,
    pending_changes: ?ACLPendingChanges = null,
    clusters: ?[][]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .status = "Status",
            .user_names = "UserNames",
            .minimum_engine_version = "MinimumEngineVersion",
            .pending_changes = "PendingChanges",
            .clusters = "Clusters",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const ACLPendingChanges = struct {
    user_names_to_remove: ?[][]const u8 = null,
    user_names_to_add: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_names_to_remove = "UserNamesToRemove",
            .user_names_to_add = "UserNamesToAdd",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ReservedNode = struct {
    reservation_id: ?[]const u8 = null,
    reserved_nodes_offering_id: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    start_time: ?i64 = null,
    duration: ?i64 = null,
    fixed_price: ?f64 = null,
    node_count: ?i64 = null,
    offering_type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    recurring_charges: ?[]RecurringCharge = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reservation_id = "ReservationId",
            .reserved_nodes_offering_id = "ReservedNodesOfferingId",
            .node_type = "NodeType",
            .start_time = "StartTime",
            .duration = "Duration",
            .fixed_price = "FixedPrice",
            .node_count = "NodeCount",
            .offering_type = "OfferingType",
            .state = "State",
            .recurring_charges = "RecurringCharges",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const RecurringCharge = struct {
    recurring_charge_amount: ?f64 = null,
    recurring_charge_frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recurring_charge_amount = "RecurringChargeAmount",
            .recurring_charge_frequency = "RecurringChargeFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const Snapshot = struct {
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    source: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    cluster_configuration: ?ClusterConfiguration = null,
    data_tiering: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .status = "Status",
            .source = "Source",
            .kms_key_id = "KmsKeyId",
            .arn = "ARN",
            .cluster_configuration = "ClusterConfiguration",
            .data_tiering = "DataTiering",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterConfiguration = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    node_type: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    maintenance_window: ?[]const u8 = null,
    topic_arn: ?[]const u8 = null,
    port: ?i64 = null,
    parameter_group_name: ?[]const u8 = null,
    subnet_group_name: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    snapshot_retention_limit: ?i64 = null,
    snapshot_window: ?[]const u8 = null,
    num_shards: ?i64 = null,
    shards: ?[]ShardDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .node_type = "NodeType",
            .engine_version = "EngineVersion",
            .maintenance_window = "MaintenanceWindow",
            .topic_arn = "TopicArn",
            .port = "Port",
            .parameter_group_name = "ParameterGroupName",
            .subnet_group_name = "SubnetGroupName",
            .vpc_id = "VpcId",
            .snapshot_retention_limit = "SnapshotRetentionLimit",
            .snapshot_window = "SnapshotWindow",
            .num_shards = "NumShards",
            .shards = "Shards",
        };
        return @field(mappings, field_name);
    }
};

pub const ShardDetail = struct {
    name: ?[]const u8 = null,
    configuration: ?ShardConfiguration = null,
    size: ?[]const u8 = null,
    snapshot_creation_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .configuration = "Configuration",
            .size = "Size",
            .snapshot_creation_time = "SnapshotCreationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ShardConfiguration = struct {
    slots: ?[]const u8 = null,
    replica_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .slots = "Slots",
            .replica_count = "ReplicaCount",
        };
        return @field(mappings, field_name);
    }
};
