const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-05-31";
pub const sdk_id: []const u8 = "Migration Hub";
pub const arn_namespace: ?[]const u8 = "mgh";
pub const endpoint_prefix: []const u8 = "mgh";
pub const sigv4_name: []const u8 = "mgh";
pub const name: []const u8 = "AWSMigrationHub";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-05-31",
    sdk_id: []const u8 = "Migration Hub",
    arn_namespace: ?[]const u8 = "mgh",
    endpoint_prefix: []const u8 = "mgh",
    sigv4_name: []const u8 = "mgh",
    name: []const u8 = "AWSMigrationHub",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_created_artifact: struct {
    action_name: []const u8 = "AssociateCreatedArtifact",
    Request: type = struct {
        progress_update_stream: []const u8,
        migration_task_name: []const u8,
        created_artifact: CreatedArtifact,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream = "ProgressUpdateStream",
                .migration_task_name = "MigrationTaskName",
                .created_artifact = "CreatedArtifact",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_created_artifact) } {
            return .{ .service_metadata = service_metadata, .action = associate_created_artifact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        UnauthorizedOperation,
    },
} = .{};
pub const associate_discovered_resource: struct {
    action_name: []const u8 = "AssociateDiscoveredResource",
    Request: type = struct {
        progress_update_stream: []const u8,
        migration_task_name: []const u8,
        discovered_resource: DiscoveredResource,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream = "ProgressUpdateStream",
                .migration_task_name = "MigrationTaskName",
                .discovered_resource = "DiscoveredResource",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_discovered_resource) } {
            return .{ .service_metadata = service_metadata, .action = associate_discovered_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        PolicyError,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        UnauthorizedOperation,
    },
} = .{};
pub const create_progress_update_stream: struct {
    action_name: []const u8 = "CreateProgressUpdateStream",
    Request: type = struct {
        progress_update_stream_name: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream_name = "ProgressUpdateStreamName",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_progress_update_stream) } {
            return .{ .service_metadata = service_metadata, .action = create_progress_update_stream };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ServiceUnavailable,
        Throttling,
        UnauthorizedOperation,
    },
} = .{};
pub const delete_progress_update_stream: struct {
    action_name: []const u8 = "DeleteProgressUpdateStream",
    Request: type = struct {
        progress_update_stream_name: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream_name = "ProgressUpdateStreamName",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_progress_update_stream) } {
            return .{ .service_metadata = service_metadata, .action = delete_progress_update_stream };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        UnauthorizedOperation,
    },
} = .{};
pub const describe_application_state: struct {
    action_name: []const u8 = "DescribeApplicationState",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application_state) } {
            return .{ .service_metadata = service_metadata, .action = describe_application_state };
        }
    },
    Response: type = struct {
        application_status: ?[]const u8 = null,
        last_updated_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_status = "ApplicationStatus",
                .last_updated_time = "LastUpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        PolicyError,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_migration_task: struct {
    action_name: []const u8 = "DescribeMigrationTask",
    Request: type = struct {
        progress_update_stream: []const u8,
        migration_task_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream = "ProgressUpdateStream",
                .migration_task_name = "MigrationTaskName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_migration_task) } {
            return .{ .service_metadata = service_metadata, .action = describe_migration_task };
        }
    },
    Response: type = struct {
        migration_task: ?struct {
            progress_update_stream: ?[]const u8 = null,
            migration_task_name: ?[]const u8 = null,
            task: ?Task = null,
            update_date_time: ?i64 = null,
            resource_attribute_list: ?[]ResourceAttribute = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .progress_update_stream = "ProgressUpdateStream",
                    .migration_task_name = "MigrationTaskName",
                    .task = "Task",
                    .update_date_time = "UpdateDateTime",
                    .resource_attribute_list = "ResourceAttributeList",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_task = "MigrationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const disassociate_created_artifact: struct {
    action_name: []const u8 = "DisassociateCreatedArtifact",
    Request: type = struct {
        progress_update_stream: []const u8,
        migration_task_name: []const u8,
        created_artifact_name: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream = "ProgressUpdateStream",
                .migration_task_name = "MigrationTaskName",
                .created_artifact_name = "CreatedArtifactName",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_created_artifact) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_created_artifact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        UnauthorizedOperation,
    },
} = .{};
pub const disassociate_discovered_resource: struct {
    action_name: []const u8 = "DisassociateDiscoveredResource",
    Request: type = struct {
        progress_update_stream: []const u8,
        migration_task_name: []const u8,
        configuration_id: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream = "ProgressUpdateStream",
                .migration_task_name = "MigrationTaskName",
                .configuration_id = "ConfigurationId",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_discovered_resource) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_discovered_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        UnauthorizedOperation,
    },
} = .{};
pub const import_migration_task: struct {
    action_name: []const u8 = "ImportMigrationTask",
    Request: type = struct {
        progress_update_stream: []const u8,
        migration_task_name: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream = "ProgressUpdateStream",
                .migration_task_name = "MigrationTaskName",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_migration_task) } {
            return .{ .service_metadata = service_metadata, .action = import_migration_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        UnauthorizedOperation,
    },
} = .{};
pub const list_application_states: struct {
    action_name: []const u8 = "ListApplicationStates",
    Request: type = struct {
        application_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_ids = "ApplicationIds",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_states) } {
            return .{ .service_metadata = service_metadata, .action = list_application_states };
        }
    },
    Response: type = struct {
        application_state_list: ?[]struct {
            application_id: ?[]const u8 = null,
            application_status: ?[]const u8 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .application_status = "ApplicationStatus",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_state_list = "ApplicationStateList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_created_artifacts: struct {
    action_name: []const u8 = "ListCreatedArtifacts",
    Request: type = struct {
        progress_update_stream: []const u8,
        migration_task_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream = "ProgressUpdateStream",
                .migration_task_name = "MigrationTaskName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_created_artifacts) } {
            return .{ .service_metadata = service_metadata, .action = list_created_artifacts };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        created_artifact_list: ?[]CreatedArtifact = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .created_artifact_list = "CreatedArtifactList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_discovered_resources: struct {
    action_name: []const u8 = "ListDiscoveredResources",
    Request: type = struct {
        progress_update_stream: []const u8,
        migration_task_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream = "ProgressUpdateStream",
                .migration_task_name = "MigrationTaskName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_discovered_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_discovered_resources };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        discovered_resource_list: ?[]DiscoveredResource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .discovered_resource_list = "DiscoveredResourceList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_migration_tasks: struct {
    action_name: []const u8 = "ListMigrationTasks",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        resource_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .resource_name = "ResourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_migration_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_migration_tasks };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        migration_task_summary_list: ?[]struct {
            progress_update_stream: ?[]const u8 = null,
            migration_task_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            progress_percent: ?i64 = null,
            status_detail: ?[]const u8 = null,
            update_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .progress_update_stream = "ProgressUpdateStream",
                    .migration_task_name = "MigrationTaskName",
                    .status = "Status",
                    .progress_percent = "ProgressPercent",
                    .status_detail = "StatusDetail",
                    .update_date_time = "UpdateDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .migration_task_summary_list = "MigrationTaskSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        PolicyError,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_progress_update_streams: struct {
    action_name: []const u8 = "ListProgressUpdateStreams",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_progress_update_streams) } {
            return .{ .service_metadata = service_metadata, .action = list_progress_update_streams };
        }
    },
    Response: type = struct {
        progress_update_stream_summary_list: ?[]struct {
            progress_update_stream_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .progress_update_stream_name = "ProgressUpdateStreamName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream_summary_list = "ProgressUpdateStreamSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const notify_application_state: struct {
    action_name: []const u8 = "NotifyApplicationState",
    Request: type = struct {
        application_id: []const u8,
        status: []const u8,
        update_date_time: ?i64 = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .status = "Status",
                .update_date_time = "UpdateDateTime",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(notify_application_state) } {
            return .{ .service_metadata = service_metadata, .action = notify_application_state };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        PolicyError,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        UnauthorizedOperation,
    },
} = .{};
pub const notify_migration_task_state: struct {
    action_name: []const u8 = "NotifyMigrationTaskState",
    Request: type = struct {
        progress_update_stream: []const u8,
        migration_task_name: []const u8,
        task: Task,
        update_date_time: i64,
        next_update_seconds: i64,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream = "ProgressUpdateStream",
                .migration_task_name = "MigrationTaskName",
                .task = "Task",
                .update_date_time = "UpdateDateTime",
                .next_update_seconds = "NextUpdateSeconds",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(notify_migration_task_state) } {
            return .{ .service_metadata = service_metadata, .action = notify_migration_task_state };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        UnauthorizedOperation,
    },
} = .{};
pub const put_resource_attributes: struct {
    action_name: []const u8 = "PutResourceAttributes",
    Request: type = struct {
        progress_update_stream: []const u8,
        migration_task_name: []const u8,
        resource_attribute_list: []ResourceAttribute,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .progress_update_stream = "ProgressUpdateStream",
                .migration_task_name = "MigrationTaskName",
                .resource_attribute_list = "ResourceAttributeList",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        HomeRegionNotSet,
        InternalServerError,
        InvalidInput,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        UnauthorizedOperation,
    },
} = .{};

pub const ResourceAttribute = struct {
    type: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Task = struct {
    status: []const u8,
    status_detail: ?[]const u8 = null,
    progress_percent: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .status_detail = "StatusDetail",
            .progress_percent = "ProgressPercent",
        };
        return @field(mappings, field_name);
    }
};

pub const DiscoveredResource = struct {
    configuration_id: []const u8,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration_id = "ConfigurationId",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const CreatedArtifact = struct {
    name: []const u8,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};
