const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-06-30";
pub const sdk_id: []const u8 = "MigrationHub Config";
pub const arn_namespace: ?[]const u8 = "mgh";
pub const endpoint_prefix: []const u8 = "migrationhub-config";
pub const sigv4_name: []const u8 = "mgh";
pub const name: []const u8 = "AWSMigrationHubMultiAccountService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-06-30",
    sdk_id: []const u8 = "MigrationHub Config",
    arn_namespace: ?[]const u8 = "mgh",
    endpoint_prefix: []const u8 = "migrationhub-config",
    sigv4_name: []const u8 = "mgh",
    name: []const u8 = "AWSMigrationHubMultiAccountService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_home_region_control: struct {
    action_name: []const u8 = "CreateHomeRegionControl",
    Request: type = struct {
        home_region: []const u8,
        target: Target,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_region = "HomeRegion",
                .target = "Target",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_home_region_control) } {
            return .{ .service_metadata = service_metadata, .action = create_home_region_control };
        }
    },
    Response: type = struct {
        home_region_control: ?HomeRegionControl = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_region_control = "HomeRegionControl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DryRunOperation,
        InternalServerError,
        InvalidInput,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_home_region_control: struct {
    action_name: []const u8 = "DeleteHomeRegionControl",
    Request: type = struct {
        control_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_id = "ControlId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_home_region_control) } {
            return .{ .service_metadata = service_metadata, .action = delete_home_region_control };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidInput,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_home_region_controls: struct {
    action_name: []const u8 = "DescribeHomeRegionControls",
    Request: type = struct {
        control_id: ?[]const u8 = null,
        home_region: ?[]const u8 = null,
        target: ?Target = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_id = "ControlId",
                .home_region = "HomeRegion",
                .target = "Target",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_home_region_controls) } {
            return .{ .service_metadata = service_metadata, .action = describe_home_region_controls };
        }
    },
    Response: type = struct {
        home_region_controls: ?[]HomeRegionControl = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_region_controls = "HomeRegionControls",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidInput,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_home_region: struct {
    action_name: []const u8 = "GetHomeRegion",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_home_region) } {
            return .{ .service_metadata = service_metadata, .action = get_home_region };
        }
    },
    Response: type = struct {
        home_region: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_region = "HomeRegion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidInput,
        ServiceUnavailable,
        Throttling,
    },
} = .{};

pub const HomeRegionControl = struct {
    control_id: ?[]const u8 = null,
    home_region: ?[]const u8 = null,
    target: ?Target = null,
    requested_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .control_id = "ControlId",
            .home_region = "HomeRegion",
            .target = "Target",
            .requested_time = "RequestedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const Target = struct {
    type: []const u8,
    id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};
