const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-10-26";
pub const sdk_id: []const u8 = "Migration Hub Refactor Spaces";
pub const arn_namespace: ?[]const u8 = "refactor-spaces";
pub const endpoint_prefix: []const u8 = "refactor-spaces";
pub const sigv4_name: []const u8 = "refactor-spaces";
pub const name: []const u8 = "RefactorSpaces";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-10-26",
    sdk_id: []const u8 = "Migration Hub Refactor Spaces",
    arn_namespace: ?[]const u8 = "refactor-spaces",
    endpoint_prefix: []const u8 = "refactor-spaces",
    sigv4_name: []const u8 = "refactor-spaces",
    name: []const u8 = "RefactorSpaces",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/environments/{EnvironmentIdentifier}/applications",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateApplication",
    Request: type = struct {
        name: []const u8,
        environment_identifier: []const u8,
        vpc_id: []const u8,
        proxy_type: []const u8,
        api_gateway_proxy: ?ApiGatewayProxyInput = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .environment_identifier = "EnvironmentIdentifier",
                .vpc_id = "VpcId",
                .proxy_type = "ProxyType",
                .api_gateway_proxy = "ApiGatewayProxy",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application) } {
            return .{ .service_metadata = service_metadata, .action = create_application };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        owner_account_id: ?[]const u8 = null,
        created_by_account_id: ?[]const u8 = null,
        application_id: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        vpc_id: ?[]const u8 = null,
        proxy_type: ?[]const u8 = null,
        api_gateway_proxy: ?ApiGatewayProxyInput = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        last_updated_time: ?i64 = null,
        created_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .owner_account_id = "OwnerAccountId",
                .created_by_account_id = "CreatedByAccountId",
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .vpc_id = "VpcId",
                .proxy_type = "ProxyType",
                .api_gateway_proxy = "ApiGatewayProxy",
                .state = "State",
                .tags = "Tags",
                .last_updated_time = "LastUpdatedTime",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/environments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEnvironment",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        network_fabric_type: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .network_fabric_type = "NetworkFabricType",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_environment };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        network_fabric_type: ?[]const u8 = null,
        owner_account_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        last_updated_time: ?i64 = null,
        created_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .description = "Description",
                .environment_id = "EnvironmentId",
                .network_fabric_type = "NetworkFabricType",
                .owner_account_id = "OwnerAccountId",
                .state = "State",
                .tags = "Tags",
                .last_updated_time = "LastUpdatedTime",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_route: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}/routes",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRoute",
    Request: type = struct {
        environment_identifier: []const u8,
        application_identifier: []const u8,
        service_identifier: []const u8,
        route_type: []const u8,
        default_route: ?struct {
            activation_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .activation_state = "ActivationState",
                };
                return @field(mappings, field_name);
            }
        } = null,
        uri_path_route: ?UriPathRouteInput = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
                .service_identifier = "ServiceIdentifier",
                .route_type = "RouteType",
                .default_route = "DefaultRoute",
                .uri_path_route = "UriPathRoute",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_route) } {
            return .{ .service_metadata = service_metadata, .action = create_route };
        }
    },
    Response: type = struct {
        route_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        owner_account_id: ?[]const u8 = null,
        created_by_account_id: ?[]const u8 = null,
        route_type: ?[]const u8 = null,
        service_id: ?[]const u8 = null,
        application_id: ?[]const u8 = null,
        uri_path_route: ?UriPathRouteInput = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        last_updated_time: ?i64 = null,
        created_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route_id = "RouteId",
                .arn = "Arn",
                .owner_account_id = "OwnerAccountId",
                .created_by_account_id = "CreatedByAccountId",
                .route_type = "RouteType",
                .service_id = "ServiceId",
                .application_id = "ApplicationId",
                .uri_path_route = "UriPathRoute",
                .state = "State",
                .tags = "Tags",
                .last_updated_time = "LastUpdatedTime",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_service: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}/services",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateService",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        environment_identifier: []const u8,
        application_identifier: []const u8,
        vpc_id: ?[]const u8 = null,
        endpoint_type: []const u8,
        url_endpoint: ?UrlEndpointInput = null,
        lambda_endpoint: ?LambdaEndpointInput = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
                .vpc_id = "VpcId",
                .endpoint_type = "EndpointType",
                .url_endpoint = "UrlEndpoint",
                .lambda_endpoint = "LambdaEndpoint",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_service) } {
            return .{ .service_metadata = service_metadata, .action = create_service };
        }
    },
    Response: type = struct {
        service_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        owner_account_id: ?[]const u8 = null,
        created_by_account_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        application_id: ?[]const u8 = null,
        vpc_id: ?[]const u8 = null,
        endpoint_type: ?[]const u8 = null,
        url_endpoint: ?UrlEndpointInput = null,
        lambda_endpoint: ?LambdaEndpointInput = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        last_updated_time: ?i64 = null,
        created_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_id = "ServiceId",
                .name = "Name",
                .arn = "Arn",
                .owner_account_id = "OwnerAccountId",
                .created_by_account_id = "CreatedByAccountId",
                .description = "Description",
                .environment_id = "EnvironmentId",
                .application_id = "ApplicationId",
                .vpc_id = "VpcId",
                .endpoint_type = "EndpointType",
                .url_endpoint = "UrlEndpoint",
                .lambda_endpoint = "LambdaEndpoint",
                .state = "State",
                .tags = "Tags",
                .last_updated_time = "LastUpdatedTime",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_application: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApplication",
    Request: type = struct {
        environment_identifier: []const u8,
        application_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_application };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        application_id: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        last_updated_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .state = "State",
                .last_updated_time = "LastUpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_environment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/environments/{EnvironmentIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEnvironment",
    Request: type = struct {
        environment_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        last_updated_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .environment_id = "EnvironmentId",
                .state = "State",
                .last_updated_time = "LastUpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resource_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/resourcepolicy/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_route: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}/routes/{RouteIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRoute",
    Request: type = struct {
        environment_identifier: []const u8,
        application_identifier: []const u8,
        route_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
                .route_identifier = "RouteIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_route) } {
            return .{ .service_metadata = service_metadata, .action = delete_route };
        }
    },
    Response: type = struct {
        route_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        service_id: ?[]const u8 = null,
        application_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        last_updated_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route_id = "RouteId",
                .arn = "Arn",
                .service_id = "ServiceId",
                .application_id = "ApplicationId",
                .state = "State",
                .last_updated_time = "LastUpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_service: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}/services/{ServiceIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteService",
    Request: type = struct {
        environment_identifier: []const u8,
        application_identifier: []const u8,
        service_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
                .service_identifier = "ServiceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_service) } {
            return .{ .service_metadata = service_metadata, .action = delete_service };
        }
    },
    Response: type = struct {
        service_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        application_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        last_updated_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_id = "ServiceId",
                .name = "Name",
                .arn = "Arn",
                .environment_id = "EnvironmentId",
                .application_id = "ApplicationId",
                .state = "State",
                .last_updated_time = "LastUpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_application: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplication",
    Request: type = struct {
        environment_identifier: []const u8,
        application_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application) } {
            return .{ .service_metadata = service_metadata, .action = get_application };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        owner_account_id: ?[]const u8 = null,
        created_by_account_id: ?[]const u8 = null,
        application_id: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        vpc_id: ?[]const u8 = null,
        proxy_type: ?[]const u8 = null,
        api_gateway_proxy: ?struct {
            proxy_url: ?[]const u8 = null,
            api_gateway_id: ?[]const u8 = null,
            vpc_link_id: ?[]const u8 = null,
            nlb_arn: ?[]const u8 = null,
            nlb_name: ?[]const u8 = null,
            endpoint_type: ?[]const u8 = null,
            stage_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .proxy_url = "ProxyUrl",
                    .api_gateway_id = "ApiGatewayId",
                    .vpc_link_id = "VpcLinkId",
                    .nlb_arn = "NlbArn",
                    .nlb_name = "NlbName",
                    .endpoint_type = "EndpointType",
                    .stage_name = "StageName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        @"error": ?ErrorResponse = null,
        last_updated_time: ?i64 = null,
        created_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .owner_account_id = "OwnerAccountId",
                .created_by_account_id = "CreatedByAccountId",
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .vpc_id = "VpcId",
                .proxy_type = "ProxyType",
                .api_gateway_proxy = "ApiGatewayProxy",
                .state = "State",
                .tags = "Tags",
                .@"error" = "Error",
                .last_updated_time = "LastUpdatedTime",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_environment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments/{EnvironmentIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnvironment",
    Request: type = struct {
        environment_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_environment) } {
            return .{ .service_metadata = service_metadata, .action = get_environment };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        network_fabric_type: ?[]const u8 = null,
        owner_account_id: ?[]const u8 = null,
        transit_gateway_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        @"error": ?ErrorResponse = null,
        last_updated_time: ?i64 = null,
        created_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .description = "Description",
                .environment_id = "EnvironmentId",
                .network_fabric_type = "NetworkFabricType",
                .owner_account_id = "OwnerAccountId",
                .transit_gateway_id = "TransitGatewayId",
                .state = "State",
                .tags = "Tags",
                .@"error" = "Error",
                .last_updated_time = "LastUpdatedTime",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resourcepolicy/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_route: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}/routes/{RouteIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRoute",
    Request: type = struct {
        environment_identifier: []const u8,
        application_identifier: []const u8,
        route_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
                .route_identifier = "RouteIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_route) } {
            return .{ .service_metadata = service_metadata, .action = get_route };
        }
    },
    Response: type = struct {
        route_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        owner_account_id: ?[]const u8 = null,
        created_by_account_id: ?[]const u8 = null,
        route_type: ?[]const u8 = null,
        service_id: ?[]const u8 = null,
        application_id: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        source_path: ?[]const u8 = null,
        methods: ?[][]const u8 = null,
        include_child_paths: ?bool = null,
        path_resource_to_id: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        @"error": ?ErrorResponse = null,
        last_updated_time: ?i64 = null,
        created_time: ?i64 = null,
        append_source_path: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route_id = "RouteId",
                .arn = "Arn",
                .owner_account_id = "OwnerAccountId",
                .created_by_account_id = "CreatedByAccountId",
                .route_type = "RouteType",
                .service_id = "ServiceId",
                .application_id = "ApplicationId",
                .environment_id = "EnvironmentId",
                .source_path = "SourcePath",
                .methods = "Methods",
                .include_child_paths = "IncludeChildPaths",
                .path_resource_to_id = "PathResourceToId",
                .state = "State",
                .tags = "Tags",
                .@"error" = "Error",
                .last_updated_time = "LastUpdatedTime",
                .created_time = "CreatedTime",
                .append_source_path = "AppendSourcePath",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "path_resource_to_id", field_name))
                return try serializeMap(self.path_resource_to_id, self.fieldNameFor("path_resource_to_id"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_service: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}/services/{ServiceIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetService",
    Request: type = struct {
        environment_identifier: []const u8,
        application_identifier: []const u8,
        service_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
                .service_identifier = "ServiceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service) } {
            return .{ .service_metadata = service_metadata, .action = get_service };
        }
    },
    Response: type = struct {
        service_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        owner_account_id: ?[]const u8 = null,
        created_by_account_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment_id: ?[]const u8 = null,
        application_id: ?[]const u8 = null,
        vpc_id: ?[]const u8 = null,
        endpoint_type: ?[]const u8 = null,
        url_endpoint: ?struct {
            url: ?[]const u8 = null,
            health_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .url = "Url",
                    .health_url = "HealthUrl",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lambda_endpoint: ?struct {
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        state: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        @"error": ?ErrorResponse = null,
        last_updated_time: ?i64 = null,
        created_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_id = "ServiceId",
                .name = "Name",
                .arn = "Arn",
                .owner_account_id = "OwnerAccountId",
                .created_by_account_id = "CreatedByAccountId",
                .description = "Description",
                .environment_id = "EnvironmentId",
                .application_id = "ApplicationId",
                .vpc_id = "VpcId",
                .endpoint_type = "EndpointType",
                .url_endpoint = "UrlEndpoint",
                .lambda_endpoint = "LambdaEndpoint",
                .state = "State",
                .tags = "Tags",
                .@"error" = "Error",
                .last_updated_time = "LastUpdatedTime",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_applications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments/{EnvironmentIdentifier}/applications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplications",
    Request: type = struct {
        environment_identifier: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_applications };
        }
    },
    Response: type = struct {
        application_summary_list: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            owner_account_id: ?[]const u8 = null,
            created_by_account_id: ?[]const u8 = null,
            application_id: ?[]const u8 = null,
            environment_id: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            proxy_type: ?[]const u8 = null,
            api_gateway_proxy: ?struct {
                proxy_url: ?[]const u8 = null,
                api_gateway_id: ?[]const u8 = null,
                vpc_link_id: ?[]const u8 = null,
                nlb_arn: ?[]const u8 = null,
                nlb_name: ?[]const u8 = null,
                endpoint_type: ?[]const u8 = null,
                stage_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .proxy_url = "ProxyUrl",
                        .api_gateway_id = "ApiGatewayId",
                        .vpc_link_id = "VpcLinkId",
                        .nlb_arn = "NlbArn",
                        .nlb_name = "NlbName",
                        .endpoint_type = "EndpointType",
                        .stage_name = "StageName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            state: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            @"error": ?ErrorResponse = null,
            last_updated_time: ?i64 = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "Arn",
                    .owner_account_id = "OwnerAccountId",
                    .created_by_account_id = "CreatedByAccountId",
                    .application_id = "ApplicationId",
                    .environment_id = "EnvironmentId",
                    .vpc_id = "VpcId",
                    .proxy_type = "ProxyType",
                    .api_gateway_proxy = "ApiGatewayProxy",
                    .state = "State",
                    .tags = "Tags",
                    .@"error" = "Error",
                    .last_updated_time = "LastUpdatedTime",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_summary_list = "ApplicationSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_environments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnvironments",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environments) } {
            return .{ .service_metadata = service_metadata, .action = list_environments };
        }
    },
    Response: type = struct {
        environment_summary_list: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            environment_id: ?[]const u8 = null,
            network_fabric_type: ?[]const u8 = null,
            owner_account_id: ?[]const u8 = null,
            transit_gateway_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            @"error": ?ErrorResponse = null,
            last_updated_time: ?i64 = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "Arn",
                    .description = "Description",
                    .environment_id = "EnvironmentId",
                    .network_fabric_type = "NetworkFabricType",
                    .owner_account_id = "OwnerAccountId",
                    .transit_gateway_id = "TransitGatewayId",
                    .state = "State",
                    .tags = "Tags",
                    .@"error" = "Error",
                    .last_updated_time = "LastUpdatedTime",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_summary_list = "EnvironmentSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_environment_vpcs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments/{EnvironmentIdentifier}/vpcs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnvironmentVpcs",
    Request: type = struct {
        environment_identifier: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environment_vpcs) } {
            return .{ .service_metadata = service_metadata, .action = list_environment_vpcs };
        }
    },
    Response: type = struct {
        environment_vpc_list: ?[]struct {
            environment_id: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            cidr_blocks: ?[][]const u8 = null,
            vpc_name: ?[]const u8 = null,
            last_updated_time: ?i64 = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .environment_id = "EnvironmentId",
                    .vpc_id = "VpcId",
                    .account_id = "AccountId",
                    .cidr_blocks = "CidrBlocks",
                    .vpc_name = "VpcName",
                    .last_updated_time = "LastUpdatedTime",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_vpc_list = "EnvironmentVpcList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_routes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}/routes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRoutes",
    Request: type = struct {
        environment_identifier: []const u8,
        application_identifier: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_routes) } {
            return .{ .service_metadata = service_metadata, .action = list_routes };
        }
    },
    Response: type = struct {
        route_summary_list: ?[]struct {
            route_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            owner_account_id: ?[]const u8 = null,
            created_by_account_id: ?[]const u8 = null,
            route_type: ?[]const u8 = null,
            service_id: ?[]const u8 = null,
            application_id: ?[]const u8 = null,
            environment_id: ?[]const u8 = null,
            source_path: ?[]const u8 = null,
            methods: ?[][]const u8 = null,
            include_child_paths: ?bool = null,
            path_resource_to_id: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            state: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            @"error": ?ErrorResponse = null,
            last_updated_time: ?i64 = null,
            created_time: ?i64 = null,
            append_source_path: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .route_id = "RouteId",
                    .arn = "Arn",
                    .owner_account_id = "OwnerAccountId",
                    .created_by_account_id = "CreatedByAccountId",
                    .route_type = "RouteType",
                    .service_id = "ServiceId",
                    .application_id = "ApplicationId",
                    .environment_id = "EnvironmentId",
                    .source_path = "SourcePath",
                    .methods = "Methods",
                    .include_child_paths = "IncludeChildPaths",
                    .path_resource_to_id = "PathResourceToId",
                    .state = "State",
                    .tags = "Tags",
                    .@"error" = "Error",
                    .last_updated_time = "LastUpdatedTime",
                    .created_time = "CreatedTime",
                    .append_source_path = "AppendSourcePath",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "path_resource_to_id", field_name))
                    return try serializeMap(self.path_resource_to_id, self.fieldNameFor("path_resource_to_id"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route_summary_list = "RouteSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_services: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}/services",
        .success_code = 200,
    };

    action_name: []const u8 = "ListServices",
    Request: type = struct {
        environment_identifier: []const u8,
        application_identifier: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_services) } {
            return .{ .service_metadata = service_metadata, .action = list_services };
        }
    },
    Response: type = struct {
        service_summary_list: ?[]struct {
            service_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            owner_account_id: ?[]const u8 = null,
            created_by_account_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            environment_id: ?[]const u8 = null,
            application_id: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            endpoint_type: ?[]const u8 = null,
            url_endpoint: ?struct {
                url: ?[]const u8 = null,
                health_url: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .url = "Url",
                        .health_url = "HealthUrl",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lambda_endpoint: ?struct {
                arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .arn = "Arn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            state: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            @"error": ?ErrorResponse = null,
            last_updated_time: ?i64 = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_id = "ServiceId",
                    .name = "Name",
                    .arn = "Arn",
                    .owner_account_id = "OwnerAccountId",
                    .created_by_account_id = "CreatedByAccountId",
                    .description = "Description",
                    .environment_id = "EnvironmentId",
                    .application_id = "ApplicationId",
                    .vpc_id = "VpcId",
                    .endpoint_type = "EndpointType",
                    .url_endpoint = "UrlEndpoint",
                    .lambda_endpoint = "LambdaEndpoint",
                    .state = "State",
                    .tags = "Tags",
                    .@"error" = "Error",
                    .last_updated_time = "LastUpdatedTime",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_summary_list = "ServiceSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_resource_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/resourcepolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidResourcePolicy,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_route: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/environments/{EnvironmentIdentifier}/applications/{ApplicationIdentifier}/routes/{RouteIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoute",
    Request: type = struct {
        environment_identifier: []const u8,
        application_identifier: []const u8,
        route_identifier: []const u8,
        activation_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_identifier = "EnvironmentIdentifier",
                .application_identifier = "ApplicationIdentifier",
                .route_identifier = "RouteIdentifier",
                .activation_state = "ActivationState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_route) } {
            return .{ .service_metadata = service_metadata, .action = update_route };
        }
    },
    Response: type = struct {
        route_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        service_id: ?[]const u8 = null,
        application_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        last_updated_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route_id = "RouteId",
                .arn = "Arn",
                .service_id = "ServiceId",
                .application_id = "ApplicationId",
                .state = "State",
                .last_updated_time = "LastUpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const ErrorResponse = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    resource_identifier: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    additional_details: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
            .account_id = "AccountId",
            .resource_identifier = "ResourceIdentifier",
            .resource_type = "ResourceType",
            .additional_details = "AdditionalDetails",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_details", field_name))
            return try serializeMap(self.additional_details, self.fieldNameFor("additional_details"), options, out_stream);
        return false;
    }
};

pub const LambdaEndpointInput = struct {
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const UrlEndpointInput = struct {
    url: []const u8,
    health_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .url = "Url",
            .health_url = "HealthUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const UriPathRouteInput = struct {
    source_path: []const u8,
    activation_state: []const u8,
    methods: ?[][]const u8 = null,
    include_child_paths: ?bool = null,
    append_source_path: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_path = "SourcePath",
            .activation_state = "ActivationState",
            .methods = "Methods",
            .include_child_paths = "IncludeChildPaths",
            .append_source_path = "AppendSourcePath",
        };
        return @field(mappings, field_name);
    }
};

pub const ApiGatewayProxyInput = struct {
    endpoint_type: ?[]const u8 = null,
    stage_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_type = "EndpointType",
            .stage_name = "StageName",
        };
        return @field(mappings, field_name);
    }
};
