const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-02-19";
pub const sdk_id: []const u8 = "MigrationHubStrategy";
pub const arn_namespace: ?[]const u8 = null;
pub const endpoint_prefix: []const u8 = "migrationhub-strategy";
pub const sigv4_name: []const u8 = "migrationhub-strategy";
pub const name: []const u8 = "AWSMigrationHubStrategyRecommendation";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-02-19",
    sdk_id: []const u8 = "MigrationHubStrategy",
    arn_namespace: ?[]const u8 = null,
    endpoint_prefix: []const u8 = "migrationhub-strategy",
    sigv4_name: []const u8 = "migrationhub-strategy",
    name: []const u8 = "AWSMigrationHubStrategyRecommendation",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const get_application_component_details: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/get-applicationcomponent-details/{applicationComponentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplicationComponentDetails",
    Request: type = struct {
        application_component_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_component_id = "applicationComponentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application_component_details) } {
            return .{ .service_metadata = service_metadata, .action = get_application_component_details };
        }
    },
    Response: type = struct {
        application_component_detail: ?ApplicationComponentDetail = null,
        associated_applications: ?[]AssociatedApplication = null,
        more_application_resource: ?bool = null,
        associated_server_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_component_detail = "applicationComponentDetail",
                .associated_applications = "associatedApplications",
                .more_application_resource = "moreApplicationResource",
                .associated_server_ids = "associatedServerIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_application_component_strategies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/get-applicationcomponent-strategies/{applicationComponentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplicationComponentStrategies",
    Request: type = struct {
        application_component_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_component_id = "applicationComponentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application_component_strategies) } {
            return .{ .service_metadata = service_metadata, .action = get_application_component_strategies };
        }
    },
    Response: type = struct {
        application_component_strategies: ?[]struct {
            recommendation: ?RecommendationSet = null,
            status: ?[]const u8 = null,
            is_preferred: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation = "recommendation",
                    .status = "status",
                    .is_preferred = "isPreferred",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_component_strategies = "applicationComponentStrategies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_assessment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/get-assessment/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAssessment",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_assessment) } {
            return .{ .service_metadata = service_metadata, .action = get_assessment };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        data_collection_details: ?struct {
            status: ?[]const u8 = null,
            servers: ?i64 = null,
            failed: ?i64 = null,
            success: ?i64 = null,
            in_progress: ?i64 = null,
            start_time: ?i64 = null,
            completion_time: ?i64 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "status",
                    .servers = "servers",
                    .failed = "failed",
                    .success = "success",
                    .in_progress = "inProgress",
                    .start_time = "startTime",
                    .completion_time = "completionTime",
                    .status_message = "statusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        assessment_targets: ?[]AssessmentTarget = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .data_collection_details = "dataCollectionDetails",
                .assessment_targets = "assessmentTargets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_import_file_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/get-import-file-task/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImportFileTask",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_import_file_task) } {
            return .{ .service_metadata = service_metadata, .action = get_import_file_task };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        start_time: ?i64 = null,
        input_s3_bucket: ?[]const u8 = null,
        input_s3_key: ?[]const u8 = null,
        status_report_s3_bucket: ?[]const u8 = null,
        status_report_s3_key: ?[]const u8 = null,
        completion_time: ?i64 = null,
        number_of_records_success: ?i64 = null,
        number_of_records_failed: ?i64 = null,
        import_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .status = "status",
                .start_time = "startTime",
                .input_s3_bucket = "inputS3Bucket",
                .input_s3_key = "inputS3Key",
                .status_report_s3_bucket = "statusReportS3Bucket",
                .status_report_s3_key = "statusReportS3Key",
                .completion_time = "completionTime",
                .number_of_records_success = "numberOfRecordsSuccess",
                .number_of_records_failed = "numberOfRecordsFailed",
                .import_name = "importName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_latest_assessment_id: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/get-latest-assessment-id",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLatestAssessmentId",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_latest_assessment_id) } {
            return .{ .service_metadata = service_metadata, .action = get_latest_assessment_id };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Dependency,
        InternalServer,
        Validation,
    },
} = .{};
pub const get_portfolio_preferences: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/get-portfolio-preferences",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPortfolioPreferences",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_portfolio_preferences) } {
            return .{ .service_metadata = service_metadata, .action = get_portfolio_preferences };
        }
    },
    Response: type = struct {
        prioritize_business_goals: ?PrioritizeBusinessGoals = null,
        application_preferences: ?ApplicationPreferences = null,
        database_preferences: ?DatabasePreferences = null,
        application_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prioritize_business_goals = "prioritizeBusinessGoals",
                .application_preferences = "applicationPreferences",
                .database_preferences = "databasePreferences",
                .application_mode = "applicationMode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_portfolio_summary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/get-portfolio-summary",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPortfolioSummary",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_portfolio_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_portfolio_summary };
        }
    },
    Response: type = struct {
        assessment_summary: ?struct {
            list_server_strategy_summary: ?[]StrategySummary = null,
            list_application_component_strategy_summary: ?[]StrategySummary = null,
            list_antipattern_severity_summary: ?[]AntipatternSeveritySummary = null,
            list_application_component_summary: ?[]struct {
                app_type: ?[]const u8 = null,
                count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .app_type = "appType",
                        .count = "count",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_server_summary: ?[]struct {
                server_os_type: ?[]const u8 = null,
                count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .server_os_type = "ServerOsType",
                        .count = "count",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            antipattern_report_s3_object: ?S3Object = null,
            antipattern_report_status: ?[]const u8 = null,
            antipattern_report_status_message: ?[]const u8 = null,
            last_analyzed_timestamp: ?i64 = null,
            list_application_component_status_summary: ?[]struct {
                src_code_or_db_analysis_status: ?[]const u8 = null,
                count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .src_code_or_db_analysis_status = "srcCodeOrDbAnalysisStatus",
                        .count = "count",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            list_server_status_summary: ?[]struct {
                run_time_assessment_status: ?[]const u8 = null,
                count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .run_time_assessment_status = "runTimeAssessmentStatus",
                        .count = "count",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .list_server_strategy_summary = "listServerStrategySummary",
                    .list_application_component_strategy_summary = "listApplicationComponentStrategySummary",
                    .list_antipattern_severity_summary = "listAntipatternSeveritySummary",
                    .list_application_component_summary = "listApplicationComponentSummary",
                    .list_server_summary = "listServerSummary",
                    .antipattern_report_s3_object = "antipatternReportS3Object",
                    .antipattern_report_status = "antipatternReportStatus",
                    .antipattern_report_status_message = "antipatternReportStatusMessage",
                    .last_analyzed_timestamp = "lastAnalyzedTimestamp",
                    .list_application_component_status_summary = "listApplicationComponentStatusSummary",
                    .list_server_status_summary = "listServerStatusSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_summary = "assessmentSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
    },
} = .{};
pub const get_recommendation_report_details: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/get-recommendation-report-details/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecommendationReportDetails",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recommendation_report_details) } {
            return .{ .service_metadata = service_metadata, .action = get_recommendation_report_details };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        recommendation_report_details: ?struct {
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            start_time: ?i64 = null,
            completion_time: ?i64 = null,
            s3_bucket: ?[]const u8 = null,
            s3_keys: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "status",
                    .status_message = "statusMessage",
                    .start_time = "startTime",
                    .completion_time = "completionTime",
                    .s3_bucket = "s3Bucket",
                    .s3_keys = "s3Keys",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .recommendation_report_details = "recommendationReportDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_server_details: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/get-server-details/{serverId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetServerDetails",
    Request: type = struct {
        server_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "serverId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_server_details) } {
            return .{ .service_metadata = service_metadata, .action = get_server_details };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        server_detail: ?ServerDetail = null,
        associated_applications: ?[]AssociatedApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .server_detail = "serverDetail",
                .associated_applications = "associatedApplications",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_server_strategies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/get-server-strategies/{serverId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetServerStrategies",
    Request: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "serverId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_server_strategies) } {
            return .{ .service_metadata = service_metadata, .action = get_server_strategies };
        }
    },
    Response: type = struct {
        server_strategies: ?[]struct {
            recommendation: ?RecommendationSet = null,
            status: ?[]const u8 = null,
            number_of_application_components: ?i64 = null,
            is_preferred: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation = "recommendation",
                    .status = "status",
                    .number_of_application_components = "numberOfApplicationComponents",
                    .is_preferred = "isPreferred",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_strategies = "serverStrategies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_analyzable_servers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-analyzable-servers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnalyzableServers",
    Request: type = struct {
        sort: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort = "sort",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_analyzable_servers) } {
            return .{ .service_metadata = service_metadata, .action = list_analyzable_servers };
        }
    },
    Response: type = struct {
        analyzable_servers: ?[]struct {
            hostname: ?[]const u8 = null,
            ip_address: ?[]const u8 = null,
            source: ?[]const u8 = null,
            vm_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .hostname = "hostname",
                    .ip_address = "ipAddress",
                    .source = "source",
                    .vm_id = "vmId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analyzable_servers = "analyzableServers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_application_components: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-applicationcomponents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplicationComponents",
    Request: type = struct {
        application_component_criteria: ?[]const u8 = null,
        filter_value: ?[]const u8 = null,
        sort: ?[]const u8 = null,
        group_id_filter: ?[]Group = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_component_criteria = "applicationComponentCriteria",
                .filter_value = "filterValue",
                .sort = "sort",
                .group_id_filter = "groupIdFilter",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_components) } {
            return .{ .service_metadata = service_metadata, .action = list_application_components };
        }
    },
    Response: type = struct {
        application_component_infos: ?[]ApplicationComponentDetail = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_component_infos = "applicationComponentInfos",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceLinkedRoleLockClient,
        Validation,
    },
} = .{};
pub const list_collectors: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/list-collectors",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCollectors",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_collectors) } {
            return .{ .service_metadata = service_metadata, .action = list_collectors };
        }
    },
    Response: type = struct {
        collectors: ?[]struct {
            collector_id: ?[]const u8 = null,
            ip_address: ?[]const u8 = null,
            host_name: ?[]const u8 = null,
            collector_health: ?[]const u8 = null,
            collector_version: ?[]const u8 = null,
            registered_time_stamp: ?[]const u8 = null,
            last_activity_time_stamp: ?[]const u8 = null,
            configuration_summary: ?struct {
                vcenter_based_remote_info_list: ?[]struct {
                    vcenter_configuration_time_stamp: ?[]const u8 = null,
                    os_type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .vcenter_configuration_time_stamp = "vcenterConfigurationTimeStamp",
                            .os_type = "osType",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                ip_address_based_remote_info_list: ?[]struct {
                    ip_address_configuration_time_stamp: ?[]const u8 = null,
                    auth_type: ?[]const u8 = null,
                    os_type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .ip_address_configuration_time_stamp = "ipAddressConfigurationTimeStamp",
                            .auth_type = "authType",
                            .os_type = "osType",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                version_control_info_list: ?[]struct {
                    version_control_type: ?[]const u8 = null,
                    version_control_configuration_time_stamp: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .version_control_type = "versionControlType",
                            .version_control_configuration_time_stamp = "versionControlConfigurationTimeStamp",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                pipeline_info_list: ?[]struct {
                    pipeline_type: ?[]const u8 = null,
                    pipeline_configuration_time_stamp: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .pipeline_type = "pipelineType",
                            .pipeline_configuration_time_stamp = "pipelineConfigurationTimeStamp",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                remote_source_code_analysis_server_info: ?struct {
                    remote_source_code_analysis_server_configuration_timestamp: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .remote_source_code_analysis_server_configuration_timestamp = "remoteSourceCodeAnalysisServerConfigurationTimestamp",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .vcenter_based_remote_info_list = "vcenterBasedRemoteInfoList",
                        .ip_address_based_remote_info_list = "ipAddressBasedRemoteInfoList",
                        .version_control_info_list = "versionControlInfoList",
                        .pipeline_info_list = "pipelineInfoList",
                        .remote_source_code_analysis_server_info = "remoteSourceCodeAnalysisServerInfo",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .collector_id = "collectorId",
                    .ip_address = "ipAddress",
                    .host_name = "hostName",
                    .collector_health = "collectorHealth",
                    .collector_version = "collectorVersion",
                    .registered_time_stamp = "registeredTimeStamp",
                    .last_activity_time_stamp = "lastActivityTimeStamp",
                    .configuration_summary = "configurationSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collectors = "Collectors",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_import_file_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/list-import-file-task",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImportFileTask",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_import_file_task) } {
            return .{ .service_metadata = service_metadata, .action = list_import_file_task };
        }
    },
    Response: type = struct {
        task_infos: ?[]struct {
            id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            start_time: ?i64 = null,
            input_s3_bucket: ?[]const u8 = null,
            input_s3_key: ?[]const u8 = null,
            status_report_s3_bucket: ?[]const u8 = null,
            status_report_s3_key: ?[]const u8 = null,
            completion_time: ?i64 = null,
            number_of_records_success: ?i64 = null,
            number_of_records_failed: ?i64 = null,
            import_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .status = "status",
                    .start_time = "startTime",
                    .input_s3_bucket = "inputS3Bucket",
                    .input_s3_key = "inputS3Key",
                    .status_report_s3_bucket = "statusReportS3Bucket",
                    .status_report_s3_key = "statusReportS3Key",
                    .completion_time = "completionTime",
                    .number_of_records_success = "numberOfRecordsSuccess",
                    .number_of_records_failed = "numberOfRecordsFailed",
                    .import_name = "importName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_infos = "taskInfos",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_servers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-servers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListServers",
    Request: type = struct {
        server_criteria: ?[]const u8 = null,
        filter_value: ?[]const u8 = null,
        sort: ?[]const u8 = null,
        group_id_filter: ?[]Group = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_criteria = "serverCriteria",
                .filter_value = "filterValue",
                .sort = "sort",
                .group_id_filter = "groupIdFilter",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_servers) } {
            return .{ .service_metadata = service_metadata, .action = list_servers };
        }
    },
    Response: type = struct {
        server_infos: ?[]ServerDetail = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_infos = "serverInfos",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const put_portfolio_preferences: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/put-portfolio-preferences",
        .success_code = 200,
    };

    action_name: []const u8 = "PutPortfolioPreferences",
    Request: type = struct {
        prioritize_business_goals: ?PrioritizeBusinessGoals = null,
        application_preferences: ?ApplicationPreferences = null,
        database_preferences: ?DatabasePreferences = null,
        application_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prioritize_business_goals = "prioritizeBusinessGoals",
                .application_preferences = "applicationPreferences",
                .database_preferences = "databasePreferences",
                .application_mode = "applicationMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_portfolio_preferences) } {
            return .{ .service_metadata = service_metadata, .action = put_portfolio_preferences };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const start_assessment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/start-assessment",
        .success_code = 200,
    };

    action_name: []const u8 = "StartAssessment",
    Request: type = struct {
        s3bucket_for_analysis_data: ?[]const u8 = null,
        s3bucket_for_report_data: ?[]const u8 = null,
        assessment_targets: ?[]AssessmentTarget = null,
        assessment_data_source_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3bucket_for_analysis_data = "s3bucketForAnalysisData",
                .s3bucket_for_report_data = "s3bucketForReportData",
                .assessment_targets = "assessmentTargets",
                .assessment_data_source_type = "assessmentDataSourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_assessment) } {
            return .{ .service_metadata = service_metadata, .action = start_assessment };
        }
    },
    Response: type = struct {
        assessment_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const start_import_file_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/start-import-file-task",
        .success_code = 200,
    };

    action_name: []const u8 = "StartImportFileTask",
    Request: type = struct {
        name: []const u8,
        s3_bucket: []const u8,
        s3key: []const u8,
        data_source_type: ?[]const u8 = null,
        group_id: ?[]Group = null,
        s3bucket_for_report_data: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .s3_bucket = "S3Bucket",
                .s3key = "s3key",
                .data_source_type = "dataSourceType",
                .group_id = "groupId",
                .s3bucket_for_report_data = "s3bucketForReportData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_import_file_task) } {
            return .{ .service_metadata = service_metadata, .action = start_import_file_task };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_recommendation_report_generation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/start-recommendation-report-generation",
        .success_code = 200,
    };

    action_name: []const u8 = "StartRecommendationReportGeneration",
    Request: type = struct {
        output_format: ?[]const u8 = null,
        group_id_filter: ?[]Group = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .output_format = "outputFormat",
                .group_id_filter = "groupIdFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_recommendation_report_generation) } {
            return .{ .service_metadata = service_metadata, .action = start_recommendation_report_generation };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_assessment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/stop-assessment",
        .success_code = 200,
    };

    action_name: []const u8 = "StopAssessment",
    Request: type = struct {
        assessment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_id = "assessmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_assessment) } {
            return .{ .service_metadata = service_metadata, .action = stop_assessment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_application_component_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-applicationcomponent-config/",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApplicationComponentConfig",
    Request: type = struct {
        application_component_id: []const u8,
        inclusion_status: ?[]const u8 = null,
        strategy_option: ?StrategyOption = null,
        source_code_list: ?[]struct {
            version_control: ?[]const u8 = null,
            source_version: ?[]const u8 = null,
            location: ?[]const u8 = null,
            project_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version_control = "versionControl",
                    .source_version = "sourceVersion",
                    .location = "location",
                    .project_name = "projectName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        secrets_manager_key: ?[]const u8 = null,
        configure_only: ?bool = null,
        app_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_component_id = "applicationComponentId",
                .inclusion_status = "inclusionStatus",
                .strategy_option = "strategyOption",
                .source_code_list = "sourceCodeList",
                .secrets_manager_key = "secretsManagerKey",
                .configure_only = "configureOnly",
                .app_type = "appType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application_component_config) } {
            return .{ .service_metadata = service_metadata, .action = update_application_component_config };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_server_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-server-config/",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateServerConfig",
    Request: type = struct {
        server_id: []const u8,
        strategy_option: ?StrategyOption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "serverId",
                .strategy_option = "strategyOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_server_config) } {
            return .{ .service_metadata = service_metadata, .action = update_server_config };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const StrategyOption = struct {
    strategy: ?[]const u8 = null,
    tool_name: ?[]const u8 = null,
    target_destination: ?[]const u8 = null,
    is_preferred: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .strategy = "strategy",
            .tool_name = "toolName",
            .target_destination = "targetDestination",
            .is_preferred = "isPreferred",
        };
        return @field(mappings, field_name);
    }
};

pub const Group = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const AssessmentTarget = struct {
    condition: []const u8,
    name: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition = "condition",
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabasePreferences = struct {
    database_management_preference: ?[]const u8 = null,
    database_migration_preference: ?DatabaseMigrationPreference = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_management_preference = "databaseManagementPreference",
            .database_migration_preference = "databaseMigrationPreference",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseMigrationPreference = union {
    heterogeneous: ?Heterogeneous,
    homogeneous: ?Homogeneous,
    no_preference: ?NoDatabaseMigrationPreference,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .heterogeneous = "heterogeneous",
            .homogeneous = "homogeneous",
            .no_preference = "noPreference",
        };
        return @field(mappings, field_name);
    }
};

pub const NoDatabaseMigrationPreference = struct {
    target_database_engine: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_database_engine = "targetDatabaseEngine",
        };
        return @field(mappings, field_name);
    }
};

pub const Homogeneous = struct {
    target_database_engine: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_database_engine = "targetDatabaseEngine",
        };
        return @field(mappings, field_name);
    }
};

pub const Heterogeneous = struct {
    target_database_engine: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_database_engine = "targetDatabaseEngine",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationPreferences = struct {
    management_preference: ?ManagementPreference = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .management_preference = "managementPreference",
        };
        return @field(mappings, field_name);
    }
};

pub const ManagementPreference = union {
    aws_managed_resources: ?AwsManagedResources,
    self_manage_resources: ?SelfManageResources,
    no_preference: ?NoManagementPreference,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_managed_resources = "awsManagedResources",
            .self_manage_resources = "selfManageResources",
            .no_preference = "noPreference",
        };
        return @field(mappings, field_name);
    }
};

pub const NoManagementPreference = struct {
    target_destination: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_destination = "targetDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const SelfManageResources = struct {
    target_destination: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_destination = "targetDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsManagedResources = struct {
    target_destination: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_destination = "targetDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const PrioritizeBusinessGoals = struct {
    business_goals: ?BusinessGoals = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .business_goals = "businessGoals",
        };
        return @field(mappings, field_name);
    }
};

pub const BusinessGoals = struct {
    speed_of_migration: ?i64 = null,
    reduce_operational_overhead_with_managed_services: ?i64 = null,
    modernize_infrastructure_with_cloud_native_technologies: ?i64 = null,
    license_cost_reduction: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .speed_of_migration = "speedOfMigration",
            .reduce_operational_overhead_with_managed_services = "reduceOperationalOverheadWithManagedServices",
            .modernize_infrastructure_with_cloud_native_technologies = "modernizeInfrastructureWithCloudNativeTechnologies",
            .license_cost_reduction = "licenseCostReduction",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerDetail = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    recommendation_set: ?RecommendationSet = null,
    data_collection_status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    list_antipattern_severity_summary: ?[]AntipatternSeveritySummary = null,
    system_info: ?SystemInfo = null,
    application_component_strategy_summary: ?[]StrategySummary = null,
    antipattern_report_s3_object: ?S3Object = null,
    antipattern_report_status: ?[]const u8 = null,
    antipattern_report_status_message: ?[]const u8 = null,
    server_type: ?[]const u8 = null,
    last_analyzed_timestamp: ?i64 = null,
    server_error: ?ServerError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .recommendation_set = "recommendationSet",
            .data_collection_status = "dataCollectionStatus",
            .status_message = "statusMessage",
            .list_antipattern_severity_summary = "listAntipatternSeveritySummary",
            .system_info = "systemInfo",
            .application_component_strategy_summary = "applicationComponentStrategySummary",
            .antipattern_report_s3_object = "antipatternReportS3Object",
            .antipattern_report_status = "antipatternReportStatus",
            .antipattern_report_status_message = "antipatternReportStatusMessage",
            .server_type = "serverType",
            .last_analyzed_timestamp = "lastAnalyzedTimestamp",
            .server_error = "serverError",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerError = struct {
    server_error_category: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_error_category = "serverErrorCategory",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Object = struct {
    s3_bucket: ?[]const u8 = null,
    s3key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
            .s3key = "s3key",
        };
        return @field(mappings, field_name);
    }
};

pub const StrategySummary = struct {
    strategy: ?[]const u8 = null,
    count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .strategy = "strategy",
            .count = "count",
        };
        return @field(mappings, field_name);
    }
};

pub const SystemInfo = struct {
    os_info: ?OSInfo = null,
    file_system_type: ?[]const u8 = null,
    network_info_list: ?[]NetworkInfo = null,
    cpu_architecture: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .os_info = "osInfo",
            .file_system_type = "fileSystemType",
            .network_info_list = "networkInfoList",
            .cpu_architecture = "cpuArchitecture",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInfo = struct {
    interface_name: []const u8,
    ip_address: []const u8,
    mac_address: []const u8,
    net_mask: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .interface_name = "interfaceName",
            .ip_address = "ipAddress",
            .mac_address = "macAddress",
            .net_mask = "netMask",
        };
        return @field(mappings, field_name);
    }
};

pub const OSInfo = struct {
    type: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const AntipatternSeveritySummary = struct {
    severity: ?[]const u8 = null,
    count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .severity = "severity",
            .count = "count",
        };
        return @field(mappings, field_name);
    }
};

pub const RecommendationSet = struct {
    transformation_tool: ?TransformationTool = null,
    target_destination: ?[]const u8 = null,
    strategy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transformation_tool = "transformationTool",
            .target_destination = "targetDestination",
            .strategy = "strategy",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformationTool = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    tranformation_tool_installation_link: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .tranformation_tool_installation_link = "tranformationToolInstallationLink",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationComponentDetail = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    recommendation_set: ?RecommendationSet = null,
    analysis_status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    list_antipattern_severity_summary: ?[]AntipatternSeveritySummary = null,
    database_config_detail: ?DatabaseConfigDetail = null,
    source_code_repositories: ?[]SourceCodeRepository = null,
    app_type: ?[]const u8 = null,
    resource_sub_type: ?[]const u8 = null,
    inclusion_status: ?[]const u8 = null,
    antipattern_report_s3_object: ?S3Object = null,
    antipattern_report_status: ?[]const u8 = null,
    antipattern_report_status_message: ?[]const u8 = null,
    os_version: ?[]const u8 = null,
    os_driver: ?[]const u8 = null,
    last_analyzed_timestamp: ?i64 = null,
    associated_server_id: ?[]const u8 = null,
    more_server_association_exists: ?bool = null,
    runtime_status: ?[]const u8 = null,
    runtime_status_message: ?[]const u8 = null,
    app_unit_error: ?AppUnitError = null,
    result_list: ?[]Result = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .recommendation_set = "recommendationSet",
            .analysis_status = "analysisStatus",
            .status_message = "statusMessage",
            .list_antipattern_severity_summary = "listAntipatternSeveritySummary",
            .database_config_detail = "databaseConfigDetail",
            .source_code_repositories = "sourceCodeRepositories",
            .app_type = "appType",
            .resource_sub_type = "resourceSubType",
            .inclusion_status = "inclusionStatus",
            .antipattern_report_s3_object = "antipatternReportS3Object",
            .antipattern_report_status = "antipatternReportStatus",
            .antipattern_report_status_message = "antipatternReportStatusMessage",
            .os_version = "osVersion",
            .os_driver = "osDriver",
            .last_analyzed_timestamp = "lastAnalyzedTimestamp",
            .associated_server_id = "associatedServerId",
            .more_server_association_exists = "moreServerAssociationExists",
            .runtime_status = "runtimeStatus",
            .runtime_status_message = "runtimeStatusMessage",
            .app_unit_error = "appUnitError",
            .result_list = "resultList",
        };
        return @field(mappings, field_name);
    }
};

pub const Result = struct {
    analysis_type: ?[]const u8 = null,
    analysis_status: ?AnalysisStatusUnion = null,
    status_message: ?[]const u8 = null,
    antipattern_report_result_list: ?[]AntipatternReportResult = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .analysis_type = "analysisType",
            .analysis_status = "analysisStatus",
            .status_message = "statusMessage",
            .antipattern_report_result_list = "antipatternReportResultList",
        };
        return @field(mappings, field_name);
    }
};

pub const AntipatternReportResult = struct {
    analyzer_name: ?AnalyzerNameUnion = null,
    anti_pattern_report_s3_object: ?S3Object = null,
    antipattern_report_status: ?[]const u8 = null,
    antipattern_report_status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .analyzer_name = "analyzerName",
            .anti_pattern_report_s3_object = "antiPatternReportS3Object",
            .antipattern_report_status = "antipatternReportStatus",
            .antipattern_report_status_message = "antipatternReportStatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyzerNameUnion = union {
    binary_analyzer_name: ?[]const u8,
    run_time_analyzer_name: ?[]const u8,
    source_code_analyzer_name: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .binary_analyzer_name = "binaryAnalyzerName",
            .run_time_analyzer_name = "runTimeAnalyzerName",
            .source_code_analyzer_name = "sourceCodeAnalyzerName",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisStatusUnion = union {
    runtime_analysis_status: ?[]const u8,
    src_code_or_db_analysis_status: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .runtime_analysis_status = "runtimeAnalysisStatus",
            .src_code_or_db_analysis_status = "srcCodeOrDbAnalysisStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AppUnitError = struct {
    app_unit_error_category: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_unit_error_category = "appUnitErrorCategory",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceCodeRepository = struct {
    repository: ?[]const u8 = null,
    branch: ?[]const u8 = null,
    version_control_type: ?[]const u8 = null,
    project_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository = "repository",
            .branch = "branch",
            .version_control_type = "versionControlType",
            .project_name = "projectName",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseConfigDetail = struct {
    secret_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .secret_name = "secretName",
        };
        return @field(mappings, field_name);
    }
};

pub const AssociatedApplication = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .id = "id",
        };
        return @field(mappings, field_name);
    }
};
