const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-01";
pub const sdk_id: []const u8 = "Mobile";
pub const arn_namespace: ?[]const u8 = "awsmobilehubservice";
pub const endpoint_prefix: []const u8 = "mobile";
pub const sigv4_name: []const u8 = "AWSMobileHubService";
pub const name: []const u8 = "AWSMobileService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-01",
    sdk_id: []const u8 = "Mobile",
    arn_namespace: ?[]const u8 = "awsmobilehubservice",
    endpoint_prefix: []const u8 = "mobile",
    sigv4_name: []const u8 = "AWSMobileHubService",
    name: []const u8 = "AWSMobileService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_project: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/projects",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        name: ?[]const u8 = null,
        region: ?[]const u8 = null,
        contents: ?[]const u8 = null,
        snapshot_id: ?[]const u8 = null,

        pub const http_query = .{
            .name = "name",
            .region = "region",
            .snapshot_id = "snapshotId",
        };

        pub const http_payload: []const u8 = "contents";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .region = "region",
                .contents = "contents",
                .snapshot_id = "snapshotId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {
        details: ?ProjectDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .details = "details",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_project: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/projects/{projectId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        project_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {
        deleted_resources: ?[]Resource = null,
        orphaned_resources: ?[]Resource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deleted_resources = "deletedResources",
                .orphaned_resources = "orphanedResources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_bundle: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bundles/{bundleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBundle",
    Request: type = struct {
        bundle_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_id = "bundleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bundle) } {
            return .{ .service_metadata = service_metadata, .action = describe_bundle };
        }
    },
    Response: type = struct {
        details: ?BundleDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .details = "details",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_project: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/project",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProject",
    Request: type = struct {
        project_id: []const u8,
        sync_from_resources: ?bool = null,

        pub const http_query = .{
            .project_id = "projectId",
            .sync_from_resources = "syncFromResources",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
                .sync_from_resources = "syncFromResources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_project) } {
            return .{ .service_metadata = service_metadata, .action = describe_project };
        }
    },
    Response: type = struct {
        details: ?ProjectDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .details = "details",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const export_bundle: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bundles/{bundleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ExportBundle",
    Request: type = struct {
        bundle_id: []const u8,
        project_id: ?[]const u8 = null,
        platform: ?[]const u8 = null,

        pub const http_query = .{
            .project_id = "projectId",
            .platform = "platform",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_id = "bundleId",
                .project_id = "projectId",
                .platform = "platform",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_bundle) } {
            return .{ .service_metadata = service_metadata, .action = export_bundle };
        }
    },
    Response: type = struct {
        download_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .download_url = "downloadUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const export_project: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/exports/{projectId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ExportProject",
    Request: type = struct {
        project_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_id = "projectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_project) } {
            return .{ .service_metadata = service_metadata, .action = export_project };
        }
    },
    Response: type = struct {
        download_url: ?[]const u8 = null,
        share_url: ?[]const u8 = null,
        snapshot_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .download_url = "downloadUrl",
                .share_url = "shareUrl",
                .snapshot_id = "snapshotId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_bundles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bundles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBundles",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bundles) } {
            return .{ .service_metadata = service_metadata, .action = list_bundles };
        }
    },
    Response: type = struct {
        bundle_list: ?[]BundleDetails = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_list = "bundleList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_projects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/projects",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProjects",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_projects) } {
            return .{ .service_metadata = service_metadata, .action = list_projects };
        }
    },
    Response: type = struct {
        projects: ?[]struct {
            name: ?[]const u8 = null,
            project_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .project_id = "projectId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .projects = "projects",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_project: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateProject",
    Request: type = struct {
        contents: ?[]const u8 = null,
        project_id: []const u8,

        pub const http_query = .{
            .project_id = "projectId",
        };

        pub const http_payload: []const u8 = "contents";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contents = "contents",
                .project_id = "projectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_project) } {
            return .{ .service_metadata = service_metadata, .action = update_project };
        }
    },
    Response: type = struct {
        details: ?ProjectDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .details = "details",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountActionRequired,
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};

pub const ProjectDetails = struct {
    name: ?[]const u8 = null,
    project_id: ?[]const u8 = null,
    region: ?[]const u8 = null,
    state: ?[]const u8 = null,
    created_date: ?i64 = null,
    last_updated_date: ?i64 = null,
    console_url: ?[]const u8 = null,
    resources: ?[]Resource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .project_id = "projectId",
            .region = "region",
            .state = "state",
            .created_date = "createdDate",
            .last_updated_date = "lastUpdatedDate",
            .console_url = "consoleUrl",
            .resources = "resources",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    feature: ?[]const u8 = null,
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .name = "name",
            .arn = "arn",
            .feature = "feature",
            .attributes = "attributes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const BundleDetails = struct {
    bundle_id: ?[]const u8 = null,
    title: ?[]const u8 = null,
    version: ?[]const u8 = null,
    description: ?[]const u8 = null,
    icon_url: ?[]const u8 = null,
    available_platforms: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bundle_id = "bundleId",
            .title = "title",
            .version = "version",
            .description = "description",
            .icon_url = "iconUrl",
            .available_platforms = "availablePlatforms",
        };
        return @field(mappings, field_name);
    }
};
