const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-11-27";
pub const sdk_id: []const u8 = "mq";
pub const arn_namespace: ?[]const u8 = "mq";
pub const endpoint_prefix: []const u8 = "mq";
pub const sigv4_name: []const u8 = "mq";
pub const name: []const u8 = "mq";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-11-27",
    sdk_id: []const u8 = "mq",
    arn_namespace: ?[]const u8 = "mq",
    endpoint_prefix: []const u8 = "mq",
    sigv4_name: []const u8 = "mq",
    name: []const u8 = "mq",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_broker: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/brokers",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBroker",
    Request: type = struct {
        authentication_strategy: ?[]const u8 = null,
        auto_minor_version_upgrade: bool,
        broker_name: []const u8,
        configuration: ?ConfigurationId = null,
        creator_request_id: ?[]const u8 = null,
        deployment_mode: []const u8,
        encryption_options: ?EncryptionOptions = null,
        engine_type: []const u8,
        engine_version: []const u8,
        host_instance_type: []const u8,
        ldap_server_metadata: ?LdapServerMetadataInput = null,
        logs: ?Logs = null,
        maintenance_window_start_time: ?WeeklyStartTime = null,
        publicly_accessible: bool,
        security_groups: ?[][]const u8 = null,
        storage_type: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        users: []struct {
            console_access: ?bool = null,
            groups: ?[][]const u8 = null,
            password: []const u8,
            username: []const u8,
            replication_user: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .console_access = "consoleAccess",
                    .groups = "groups",
                    .password = "password",
                    .username = "username",
                    .replication_user = "replicationUser",
                };
                return @field(mappings, field_name);
            }
        },
        data_replication_mode: ?[]const u8 = null,
        data_replication_primary_broker_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_strategy = "authenticationStrategy",
                .auto_minor_version_upgrade = "autoMinorVersionUpgrade",
                .broker_name = "brokerName",
                .configuration = "configuration",
                .creator_request_id = "creatorRequestId",
                .deployment_mode = "deploymentMode",
                .encryption_options = "encryptionOptions",
                .engine_type = "engineType",
                .engine_version = "engineVersion",
                .host_instance_type = "hostInstanceType",
                .ldap_server_metadata = "ldapServerMetadata",
                .logs = "logs",
                .maintenance_window_start_time = "maintenanceWindowStartTime",
                .publicly_accessible = "publiclyAccessible",
                .security_groups = "securityGroups",
                .storage_type = "storageType",
                .subnet_ids = "subnetIds",
                .tags = "tags",
                .users = "users",
                .data_replication_mode = "dataReplicationMode",
                .data_replication_primary_broker_arn = "dataReplicationPrimaryBrokerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_broker) } {
            return .{ .service_metadata = service_metadata, .action = create_broker };
        }
    },
    Response: type = struct {
        broker_arn: ?[]const u8 = null,
        broker_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_arn = "brokerArn",
                .broker_id = "brokerId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        Unauthorized,
    },
} = .{};
pub const create_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConfiguration",
    Request: type = struct {
        authentication_strategy: ?[]const u8 = null,
        engine_type: []const u8,
        engine_version: []const u8,
        name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_strategy = "authenticationStrategy",
                .engine_type = "engineType",
                .engine_version = "engineVersion",
                .name = "name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        authentication_strategy: ?[]const u8 = null,
        created: ?i64 = null,
        id: ?[]const u8 = null,
        latest_revision: ?ConfigurationRevision = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .authentication_strategy = "authenticationStrategy",
                .created = "created",
                .id = "id",
                .latest_revision = "latestRevision",
                .name = "name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
    },
} = .{};
pub const create_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "CreateTags",
    Request: type = struct {
        resource_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tags) } {
            return .{ .service_metadata = service_metadata, .action = create_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const create_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/brokers/{BrokerId}/users/{Username}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        broker_id: []const u8,
        console_access: ?bool = null,
        groups: ?[][]const u8 = null,
        password: []const u8,
        username: []const u8,
        replication_user: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "BrokerId",
                .console_access = "consoleAccess",
                .groups = "groups",
                .password = "password",
                .username = "Username",
                .replication_user = "replicationUser",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const delete_broker: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/brokers/{BrokerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBroker",
    Request: type = struct {
        broker_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "BrokerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_broker) } {
            return .{ .service_metadata = service_metadata, .action = delete_broker };
        }
    },
    Response: type = struct {
        broker_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "brokerId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const delete_tags: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteTags",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tags) } {
            return .{ .service_metadata = service_metadata, .action = delete_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const delete_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/brokers/{BrokerId}/users/{Username}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        broker_id: []const u8,
        username: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "BrokerId",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const describe_broker: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/brokers/{BrokerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBroker",
    Request: type = struct {
        broker_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "BrokerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_broker) } {
            return .{ .service_metadata = service_metadata, .action = describe_broker };
        }
    },
    Response: type = struct {
        actions_required: ?[]struct {
            action_required_code: ?[]const u8 = null,
            action_required_info: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_required_code = "actionRequiredCode",
                    .action_required_info = "actionRequiredInfo",
                };
                return @field(mappings, field_name);
            }
        } = null,
        authentication_strategy: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        broker_arn: ?[]const u8 = null,
        broker_id: ?[]const u8 = null,
        broker_instances: ?[]struct {
            console_url: ?[]const u8 = null,
            endpoints: ?[][]const u8 = null,
            ip_address: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .console_url = "consoleURL",
                    .endpoints = "endpoints",
                    .ip_address = "ipAddress",
                };
                return @field(mappings, field_name);
            }
        } = null,
        broker_name: ?[]const u8 = null,
        broker_state: ?[]const u8 = null,
        configurations: ?struct {
            current: ?ConfigurationId = null,
            history: ?[]ConfigurationId = null,
            pending: ?ConfigurationId = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .current = "current",
                    .history = "history",
                    .pending = "pending",
                };
                return @field(mappings, field_name);
            }
        } = null,
        created: ?i64 = null,
        deployment_mode: ?[]const u8 = null,
        encryption_options: ?EncryptionOptions = null,
        engine_type: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        host_instance_type: ?[]const u8 = null,
        ldap_server_metadata: ?LdapServerMetadataOutput = null,
        logs: ?struct {
            audit: ?bool = null,
            audit_log_group: ?[]const u8 = null,
            general: bool,
            general_log_group: []const u8,
            pending: ?struct {
                audit: ?bool = null,
                general: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .audit = "audit",
                        .general = "general",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .audit = "audit",
                    .audit_log_group = "auditLogGroup",
                    .general = "general",
                    .general_log_group = "generalLogGroup",
                    .pending = "pending",
                };
                return @field(mappings, field_name);
            }
        } = null,
        maintenance_window_start_time: ?WeeklyStartTime = null,
        pending_authentication_strategy: ?[]const u8 = null,
        pending_engine_version: ?[]const u8 = null,
        pending_host_instance_type: ?[]const u8 = null,
        pending_ldap_server_metadata: ?LdapServerMetadataOutput = null,
        pending_security_groups: ?[][]const u8 = null,
        publicly_accessible: ?bool = null,
        security_groups: ?[][]const u8 = null,
        storage_type: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        users: ?[]UserSummary = null,
        data_replication_metadata: ?DataReplicationMetadataOutput = null,
        data_replication_mode: ?[]const u8 = null,
        pending_data_replication_metadata: ?DataReplicationMetadataOutput = null,
        pending_data_replication_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .actions_required = "actionsRequired",
                .authentication_strategy = "authenticationStrategy",
                .auto_minor_version_upgrade = "autoMinorVersionUpgrade",
                .broker_arn = "brokerArn",
                .broker_id = "brokerId",
                .broker_instances = "brokerInstances",
                .broker_name = "brokerName",
                .broker_state = "brokerState",
                .configurations = "configurations",
                .created = "created",
                .deployment_mode = "deploymentMode",
                .encryption_options = "encryptionOptions",
                .engine_type = "engineType",
                .engine_version = "engineVersion",
                .host_instance_type = "hostInstanceType",
                .ldap_server_metadata = "ldapServerMetadata",
                .logs = "logs",
                .maintenance_window_start_time = "maintenanceWindowStartTime",
                .pending_authentication_strategy = "pendingAuthenticationStrategy",
                .pending_engine_version = "pendingEngineVersion",
                .pending_host_instance_type = "pendingHostInstanceType",
                .pending_ldap_server_metadata = "pendingLdapServerMetadata",
                .pending_security_groups = "pendingSecurityGroups",
                .publicly_accessible = "publiclyAccessible",
                .security_groups = "securityGroups",
                .storage_type = "storageType",
                .subnet_ids = "subnetIds",
                .tags = "tags",
                .users = "users",
                .data_replication_metadata = "dataReplicationMetadata",
                .data_replication_mode = "dataReplicationMode",
                .pending_data_replication_metadata = "pendingDataReplicationMetadata",
                .pending_data_replication_mode = "pendingDataReplicationMode",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const describe_broker_engine_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/broker-engine-types",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBrokerEngineTypes",
    Request: type = struct {
        engine_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .engine_type = "engineType",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_type = "EngineType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_broker_engine_types) } {
            return .{ .service_metadata = service_metadata, .action = describe_broker_engine_types };
        }
    },
    Response: type = struct {
        broker_engine_types: ?[]struct {
            engine_type: ?[]const u8 = null,
            engine_versions: ?[]struct {
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine_type = "engineType",
                    .engine_versions = "engineVersions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_engine_types = "brokerEngineTypes",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
    },
} = .{};
pub const describe_broker_instance_options: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/broker-instance-options",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBrokerInstanceOptions",
    Request: type = struct {
        engine_type: ?[]const u8 = null,
        host_instance_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        storage_type: ?[]const u8 = null,

        pub const http_query = .{
            .engine_type = "engineType",
            .host_instance_type = "hostInstanceType",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .storage_type = "storageType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_type = "EngineType",
                .host_instance_type = "HostInstanceType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .storage_type = "StorageType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_broker_instance_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_broker_instance_options };
        }
    },
    Response: type = struct {
        broker_instance_options: ?[]struct {
            availability_zones: ?[]struct {
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            engine_type: ?[]const u8 = null,
            host_instance_type: ?[]const u8 = null,
            storage_type: ?[]const u8 = null,
            supported_deployment_modes: ?[][]const u8 = null,
            supported_engine_versions: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .availability_zones = "availabilityZones",
                    .engine_type = "engineType",
                    .host_instance_type = "hostInstanceType",
                    .storage_type = "storageType",
                    .supported_deployment_modes = "supportedDeploymentModes",
                    .supported_engine_versions = "supportedEngineVersions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_instance_options = "brokerInstanceOptions",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
    },
} = .{};
pub const describe_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/configurations/{ConfigurationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeConfiguration",
    Request: type = struct {
        configuration_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_id = "ConfigurationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        authentication_strategy: ?[]const u8 = null,
        created: ?i64 = null,
        description: ?[]const u8 = null,
        engine_type: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        id: ?[]const u8 = null,
        latest_revision: ?ConfigurationRevision = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .authentication_strategy = "authenticationStrategy",
                .created = "created",
                .description = "description",
                .engine_type = "engineType",
                .engine_version = "engineVersion",
                .id = "id",
                .latest_revision = "latestRevision",
                .name = "name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const describe_configuration_revision: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/configurations/{ConfigurationId}/revisions/{ConfigurationRevision}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeConfigurationRevision",
    Request: type = struct {
        configuration_id: []const u8,
        configuration_revision: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_id = "ConfigurationId",
                .configuration_revision = "ConfigurationRevision",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration_revision) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration_revision };
        }
    },
    Response: type = struct {
        configuration_id: ?[]const u8 = null,
        created: ?i64 = null,
        data: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_id = "configurationId",
                .created = "created",
                .data = "data",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const describe_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/brokers/{BrokerId}/users/{Username}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUser",
    Request: type = struct {
        broker_id: []const u8,
        username: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "BrokerId",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_user };
        }
    },
    Response: type = struct {
        broker_id: ?[]const u8 = null,
        console_access: ?bool = null,
        groups: ?[][]const u8 = null,
        pending: ?struct {
            console_access: ?bool = null,
            groups: ?[][]const u8 = null,
            pending_change: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .console_access = "consoleAccess",
                    .groups = "groups",
                    .pending_change = "pendingChange",
                };
                return @field(mappings, field_name);
            }
        } = null,
        username: ?[]const u8 = null,
        replication_user: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "brokerId",
                .console_access = "consoleAccess",
                .groups = "groups",
                .pending = "pending",
                .username = "username",
                .replication_user = "replicationUser",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const list_brokers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/brokers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBrokers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_brokers) } {
            return .{ .service_metadata = service_metadata, .action = list_brokers };
        }
    },
    Response: type = struct {
        broker_summaries: ?[]struct {
            broker_arn: ?[]const u8 = null,
            broker_id: ?[]const u8 = null,
            broker_name: ?[]const u8 = null,
            broker_state: ?[]const u8 = null,
            created: ?i64 = null,
            deployment_mode: []const u8,
            engine_type: []const u8,
            host_instance_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .broker_arn = "brokerArn",
                    .broker_id = "brokerId",
                    .broker_name = "brokerName",
                    .broker_state = "brokerState",
                    .created = "created",
                    .deployment_mode = "deploymentMode",
                    .engine_type = "engineType",
                    .host_instance_type = "hostInstanceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_summaries = "brokerSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
    },
} = .{};
pub const list_configuration_revisions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/configurations/{ConfigurationId}/revisions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConfigurationRevisions",
    Request: type = struct {
        configuration_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_id = "ConfigurationId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configuration_revisions) } {
            return .{ .service_metadata = service_metadata, .action = list_configuration_revisions };
        }
    },
    Response: type = struct {
        configuration_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        revisions: ?[]ConfigurationRevision = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_id = "configurationId",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .revisions = "revisions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const list_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConfigurations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_configurations };
        }
    },
    Response: type = struct {
        configurations: ?[]struct {
            arn: []const u8,
            authentication_strategy: []const u8,
            created: i64,
            description: []const u8,
            engine_type: []const u8,
            engine_version: []const u8,
            id: []const u8,
            latest_revision: ConfigurationRevision,
            name: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .authentication_strategy = "authenticationStrategy",
                    .created = "created",
                    .description = "description",
                    .engine_type = "engineType",
                    .engine_version = "engineVersion",
                    .id = "id",
                    .latest_revision = "latestRevision",
                    .name = "name",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configurations = "configurations",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
    },
} = .{};
pub const list_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTags",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const list_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/brokers/{BrokerId}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        broker_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "BrokerId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        broker_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        users: ?[]UserSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "brokerId",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .users = "users",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const promote: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/brokers/{BrokerId}/promote",
        .success_code = 200,
    };

    action_name: []const u8 = "Promote",
    Request: type = struct {
        broker_id: []const u8,
        mode: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "BrokerId",
                .mode = "mode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(promote) } {
            return .{ .service_metadata = service_metadata, .action = promote };
        }
    },
    Response: type = struct {
        broker_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "brokerId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const reboot_broker: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/brokers/{BrokerId}/reboot",
        .success_code = 200,
    };

    action_name: []const u8 = "RebootBroker",
    Request: type = struct {
        broker_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "BrokerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_broker) } {
            return .{ .service_metadata = service_metadata, .action = reboot_broker };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const update_broker: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/brokers/{BrokerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBroker",
    Request: type = struct {
        authentication_strategy: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        broker_id: []const u8,
        configuration: ?ConfigurationId = null,
        engine_version: ?[]const u8 = null,
        host_instance_type: ?[]const u8 = null,
        ldap_server_metadata: ?LdapServerMetadataInput = null,
        logs: ?Logs = null,
        maintenance_window_start_time: ?WeeklyStartTime = null,
        security_groups: ?[][]const u8 = null,
        data_replication_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_strategy = "authenticationStrategy",
                .auto_minor_version_upgrade = "autoMinorVersionUpgrade",
                .broker_id = "BrokerId",
                .configuration = "configuration",
                .engine_version = "engineVersion",
                .host_instance_type = "hostInstanceType",
                .ldap_server_metadata = "ldapServerMetadata",
                .logs = "logs",
                .maintenance_window_start_time = "maintenanceWindowStartTime",
                .security_groups = "securityGroups",
                .data_replication_mode = "dataReplicationMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_broker) } {
            return .{ .service_metadata = service_metadata, .action = update_broker };
        }
    },
    Response: type = struct {
        authentication_strategy: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        broker_id: ?[]const u8 = null,
        configuration: ?ConfigurationId = null,
        engine_version: ?[]const u8 = null,
        host_instance_type: ?[]const u8 = null,
        ldap_server_metadata: ?LdapServerMetadataOutput = null,
        logs: ?Logs = null,
        maintenance_window_start_time: ?WeeklyStartTime = null,
        security_groups: ?[][]const u8 = null,
        data_replication_metadata: ?DataReplicationMetadataOutput = null,
        data_replication_mode: ?[]const u8 = null,
        pending_data_replication_metadata: ?DataReplicationMetadataOutput = null,
        pending_data_replication_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_strategy = "authenticationStrategy",
                .auto_minor_version_upgrade = "autoMinorVersionUpgrade",
                .broker_id = "brokerId",
                .configuration = "configuration",
                .engine_version = "engineVersion",
                .host_instance_type = "hostInstanceType",
                .ldap_server_metadata = "ldapServerMetadata",
                .logs = "logs",
                .maintenance_window_start_time = "maintenanceWindowStartTime",
                .security_groups = "securityGroups",
                .data_replication_metadata = "dataReplicationMetadata",
                .data_replication_mode = "dataReplicationMode",
                .pending_data_replication_metadata = "pendingDataReplicationMetadata",
                .pending_data_replication_mode = "pendingDataReplicationMode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const update_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/configurations/{ConfigurationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConfiguration",
    Request: type = struct {
        configuration_id: []const u8,
        data: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_id = "ConfigurationId",
                .data = "data",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        created: ?i64 = null,
        id: ?[]const u8 = null,
        latest_revision: ?ConfigurationRevision = null,
        name: ?[]const u8 = null,
        warnings: ?[]struct {
            attribute_name: ?[]const u8 = null,
            element_name: ?[]const u8 = null,
            reason: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_name = "attributeName",
                    .element_name = "elementName",
                    .reason = "reason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .created = "created",
                .id = "id",
                .latest_revision = "latestRevision",
                .name = "name",
                .warnings = "warnings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const update_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/brokers/{BrokerId}/users/{Username}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        broker_id: []const u8,
        console_access: ?bool = null,
        groups: ?[][]const u8 = null,
        password: ?[]const u8 = null,
        username: []const u8,
        replication_user: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_id = "BrokerId",
                .console_access = "consoleAccess",
                .groups = "groups",
                .password = "password",
                .username = "Username",
                .replication_user = "replicationUser",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};

pub const ConfigurationRevision = struct {
    created: i64,
    description: ?[]const u8 = null,
    revision: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .created = "created",
            .description = "description",
            .revision = "revision",
        };
        return @field(mappings, field_name);
    }
};

pub const DataReplicationMetadataOutput = struct {
    data_replication_counterpart: ?DataReplicationCounterpart = null,
    data_replication_role: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_replication_counterpart = "dataReplicationCounterpart",
            .data_replication_role = "dataReplicationRole",
        };
        return @field(mappings, field_name);
    }
};

pub const DataReplicationCounterpart = struct {
    broker_id: []const u8,
    region: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .broker_id = "brokerId",
            .region = "region",
        };
        return @field(mappings, field_name);
    }
};

pub const WeeklyStartTime = struct {
    day_of_week: []const u8,
    time_of_day: []const u8,
    time_zone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .day_of_week = "dayOfWeek",
            .time_of_day = "timeOfDay",
            .time_zone = "timeZone",
        };
        return @field(mappings, field_name);
    }
};

pub const Logs = struct {
    audit: ?bool = null,
    general: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audit = "audit",
            .general = "general",
        };
        return @field(mappings, field_name);
    }
};

pub const LdapServerMetadataOutput = struct {
    hosts: [][]const u8,
    role_base: []const u8,
    role_name: ?[]const u8 = null,
    role_search_matching: []const u8,
    role_search_subtree: ?bool = null,
    service_account_username: []const u8,
    user_base: []const u8,
    user_role_name: ?[]const u8 = null,
    user_search_matching: []const u8,
    user_search_subtree: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hosts = "hosts",
            .role_base = "roleBase",
            .role_name = "roleName",
            .role_search_matching = "roleSearchMatching",
            .role_search_subtree = "roleSearchSubtree",
            .service_account_username = "serviceAccountUsername",
            .user_base = "userBase",
            .user_role_name = "userRoleName",
            .user_search_matching = "userSearchMatching",
            .user_search_subtree = "userSearchSubtree",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationId = struct {
    id: []const u8,
    revision: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .revision = "revision",
        };
        return @field(mappings, field_name);
    }
};

pub const LdapServerMetadataInput = struct {
    hosts: [][]const u8,
    role_base: []const u8,
    role_name: ?[]const u8 = null,
    role_search_matching: []const u8,
    role_search_subtree: ?bool = null,
    service_account_password: []const u8,
    service_account_username: []const u8,
    user_base: []const u8,
    user_role_name: ?[]const u8 = null,
    user_search_matching: []const u8,
    user_search_subtree: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hosts = "hosts",
            .role_base = "roleBase",
            .role_name = "roleName",
            .role_search_matching = "roleSearchMatching",
            .role_search_subtree = "roleSearchSubtree",
            .service_account_password = "serviceAccountPassword",
            .service_account_username = "serviceAccountUsername",
            .user_base = "userBase",
            .user_role_name = "userRoleName",
            .user_search_matching = "userSearchMatching",
            .user_search_subtree = "userSearchSubtree",
        };
        return @field(mappings, field_name);
    }
};

pub const UserSummary = struct {
    pending_change: ?[]const u8 = null,
    username: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pending_change = "pendingChange",
            .username = "username",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionOptions = struct {
    kms_key_id: ?[]const u8 = null,
    use_aws_owned_key: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "kmsKeyId",
            .use_aws_owned_key = "useAwsOwnedKey",
        };
        return @field(mappings, field_name);
    }
};
