const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-01";
pub const sdk_id: []const u8 = "MWAA";
pub const arn_namespace: ?[]const u8 = "airflow";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "airflow";
pub const name: []const u8 = "AmazonMWAA";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-01",
    sdk_id: []const u8 = "MWAA",
    arn_namespace: ?[]const u8 = "airflow",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "airflow",
    name: []const u8 = "AmazonMWAA",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_cli_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clitoken/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCliToken",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cli_token) } {
            return .{ .service_metadata = service_metadata, .action = create_cli_token };
        }
    },
    Response: type = struct {
        cli_token: ?[]const u8 = null,
        web_server_hostname: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cli_token = "CliToken",
                .web_server_hostname = "WebServerHostname",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const create_environment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/environments/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEnvironment",
    Request: type = struct {
        name: []const u8,
        execution_role_arn: []const u8,
        source_bucket_arn: []const u8,
        dag_s3_path: []const u8,
        network_configuration: NetworkConfiguration,
        plugins_s3_path: ?[]const u8 = null,
        plugins_s3_object_version: ?[]const u8 = null,
        requirements_s3_path: ?[]const u8 = null,
        requirements_s3_object_version: ?[]const u8 = null,
        startup_script_s3_path: ?[]const u8 = null,
        startup_script_s3_object_version: ?[]const u8 = null,
        airflow_configuration_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        environment_class: ?[]const u8 = null,
        max_workers: ?i64 = null,
        kms_key: ?[]const u8 = null,
        airflow_version: ?[]const u8 = null,
        logging_configuration: ?LoggingConfigurationInput = null,
        weekly_maintenance_window_start: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        webserver_access_mode: ?[]const u8 = null,
        min_workers: ?i64 = null,
        schedulers: ?i64 = null,
        endpoint_management: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .execution_role_arn = "ExecutionRoleArn",
                .source_bucket_arn = "SourceBucketArn",
                .dag_s3_path = "DagS3Path",
                .network_configuration = "NetworkConfiguration",
                .plugins_s3_path = "PluginsS3Path",
                .plugins_s3_object_version = "PluginsS3ObjectVersion",
                .requirements_s3_path = "RequirementsS3Path",
                .requirements_s3_object_version = "RequirementsS3ObjectVersion",
                .startup_script_s3_path = "StartupScriptS3Path",
                .startup_script_s3_object_version = "StartupScriptS3ObjectVersion",
                .airflow_configuration_options = "AirflowConfigurationOptions",
                .environment_class = "EnvironmentClass",
                .max_workers = "MaxWorkers",
                .kms_key = "KmsKey",
                .airflow_version = "AirflowVersion",
                .logging_configuration = "LoggingConfiguration",
                .weekly_maintenance_window_start = "WeeklyMaintenanceWindowStart",
                .tags = "Tags",
                .webserver_access_mode = "WebserverAccessMode",
                .min_workers = "MinWorkers",
                .schedulers = "Schedulers",
                .endpoint_management = "EndpointManagement",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "airflow_configuration_options", field_name))
                return try serializeMap(self.airflow_configuration_options, self.fieldNameFor("airflow_configuration_options"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_environment };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const create_web_login_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/webtoken/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWebLoginToken",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_web_login_token) } {
            return .{ .service_metadata = service_metadata, .action = create_web_login_token };
        }
    },
    Response: type = struct {
        web_token: ?[]const u8 = null,
        web_server_hostname: ?[]const u8 = null,
        iam_identity: ?[]const u8 = null,
        airflow_identity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_token = "WebToken",
                .web_server_hostname = "WebServerHostname",
                .iam_identity = "IamIdentity",
                .airflow_identity = "AirflowIdentity",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_environment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/environments/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEnvironment",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_environment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnvironment",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_environment) } {
            return .{ .service_metadata = service_metadata, .action = get_environment };
        }
    },
    Response: type = struct {
        environment: ?struct {
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            webserver_url: ?[]const u8 = null,
            execution_role_arn: ?[]const u8 = null,
            service_role_arn: ?[]const u8 = null,
            kms_key: ?[]const u8 = null,
            airflow_version: ?[]const u8 = null,
            source_bucket_arn: ?[]const u8 = null,
            dag_s3_path: ?[]const u8 = null,
            plugins_s3_path: ?[]const u8 = null,
            plugins_s3_object_version: ?[]const u8 = null,
            requirements_s3_path: ?[]const u8 = null,
            requirements_s3_object_version: ?[]const u8 = null,
            startup_script_s3_path: ?[]const u8 = null,
            startup_script_s3_object_version: ?[]const u8 = null,
            airflow_configuration_options: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            environment_class: ?[]const u8 = null,
            max_workers: ?i64 = null,
            network_configuration: ?NetworkConfiguration = null,
            logging_configuration: ?struct {
                dag_processing_logs: ?ModuleLoggingConfiguration = null,
                scheduler_logs: ?ModuleLoggingConfiguration = null,
                webserver_logs: ?ModuleLoggingConfiguration = null,
                worker_logs: ?ModuleLoggingConfiguration = null,
                task_logs: ?ModuleLoggingConfiguration = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .dag_processing_logs = "DagProcessingLogs",
                        .scheduler_logs = "SchedulerLogs",
                        .webserver_logs = "WebserverLogs",
                        .worker_logs = "WorkerLogs",
                        .task_logs = "TaskLogs",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_update: ?struct {
                status: ?[]const u8 = null,
                created_at: ?i64 = null,
                @"error": ?struct {
                    error_code: ?[]const u8 = null,
                    error_message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .error_code = "ErrorCode",
                            .error_message = "ErrorMessage",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                source: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "Status",
                        .created_at = "CreatedAt",
                        .@"error" = "Error",
                        .source = "Source",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            weekly_maintenance_window_start: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            webserver_access_mode: ?[]const u8 = null,
            min_workers: ?i64 = null,
            schedulers: ?i64 = null,
            webserver_vpc_endpoint_service: ?[]const u8 = null,
            database_vpc_endpoint_service: ?[]const u8 = null,
            celery_executor_queue: ?[]const u8 = null,
            endpoint_management: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .status = "Status",
                    .arn = "Arn",
                    .created_at = "CreatedAt",
                    .webserver_url = "WebserverUrl",
                    .execution_role_arn = "ExecutionRoleArn",
                    .service_role_arn = "ServiceRoleArn",
                    .kms_key = "KmsKey",
                    .airflow_version = "AirflowVersion",
                    .source_bucket_arn = "SourceBucketArn",
                    .dag_s3_path = "DagS3Path",
                    .plugins_s3_path = "PluginsS3Path",
                    .plugins_s3_object_version = "PluginsS3ObjectVersion",
                    .requirements_s3_path = "RequirementsS3Path",
                    .requirements_s3_object_version = "RequirementsS3ObjectVersion",
                    .startup_script_s3_path = "StartupScriptS3Path",
                    .startup_script_s3_object_version = "StartupScriptS3ObjectVersion",
                    .airflow_configuration_options = "AirflowConfigurationOptions",
                    .environment_class = "EnvironmentClass",
                    .max_workers = "MaxWorkers",
                    .network_configuration = "NetworkConfiguration",
                    .logging_configuration = "LoggingConfiguration",
                    .last_update = "LastUpdate",
                    .weekly_maintenance_window_start = "WeeklyMaintenanceWindowStart",
                    .tags = "Tags",
                    .webserver_access_mode = "WebserverAccessMode",
                    .min_workers = "MinWorkers",
                    .schedulers = "Schedulers",
                    .webserver_vpc_endpoint_service = "WebserverVpcEndpointService",
                    .database_vpc_endpoint_service = "DatabaseVpcEndpointService",
                    .celery_executor_queue = "CeleryExecutorQueue",
                    .endpoint_management = "EndpointManagement",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "airflow_configuration_options", field_name))
                    return try serializeMap(self.airflow_configuration_options, self.fieldNameFor("airflow_configuration_options"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment = "Environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_environments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnvironments",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environments) } {
            return .{ .service_metadata = service_metadata, .action = list_environments };
        }
    },
    Response: type = struct {
        environments: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environments = "Environments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const publish_metrics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/metrics/environments/{EnvironmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "PublishMetrics",
    Request: type = struct {
        environment_name: []const u8,
        metric_data: []struct {
            metric_name: []const u8,
            timestamp: i64,
            dimensions: ?[]struct {
                name: []const u8,
                value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            value: ?f64 = null,
            unit: ?[]const u8 = null,
            statistic_values: ?struct {
                sample_count: ?i64 = null,
                sum: ?f64 = null,
                minimum: ?f64 = null,
                maximum: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .sample_count = "SampleCount",
                        .sum = "Sum",
                        .minimum = "Minimum",
                        .maximum = "Maximum",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .metric_name = "MetricName",
                    .timestamp = "Timestamp",
                    .dimensions = "Dimensions",
                    .value = "Value",
                    .unit = "Unit",
                    .statistic_values = "StatisticValues",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "EnvironmentName",
                .metric_data = "MetricData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish_metrics) } {
            return .{ .service_metadata = service_metadata, .action = publish_metrics };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_environment: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/environments/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEnvironment",
    Request: type = struct {
        name: []const u8,
        execution_role_arn: ?[]const u8 = null,
        airflow_version: ?[]const u8 = null,
        source_bucket_arn: ?[]const u8 = null,
        dag_s3_path: ?[]const u8 = null,
        plugins_s3_path: ?[]const u8 = null,
        plugins_s3_object_version: ?[]const u8 = null,
        requirements_s3_path: ?[]const u8 = null,
        requirements_s3_object_version: ?[]const u8 = null,
        startup_script_s3_path: ?[]const u8 = null,
        startup_script_s3_object_version: ?[]const u8 = null,
        airflow_configuration_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        environment_class: ?[]const u8 = null,
        max_workers: ?i64 = null,
        network_configuration: ?struct {
            security_group_ids: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .security_group_ids = "SecurityGroupIds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        logging_configuration: ?LoggingConfigurationInput = null,
        weekly_maintenance_window_start: ?[]const u8 = null,
        webserver_access_mode: ?[]const u8 = null,
        min_workers: ?i64 = null,
        schedulers: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .execution_role_arn = "ExecutionRoleArn",
                .airflow_version = "AirflowVersion",
                .source_bucket_arn = "SourceBucketArn",
                .dag_s3_path = "DagS3Path",
                .plugins_s3_path = "PluginsS3Path",
                .plugins_s3_object_version = "PluginsS3ObjectVersion",
                .requirements_s3_path = "RequirementsS3Path",
                .requirements_s3_object_version = "RequirementsS3ObjectVersion",
                .startup_script_s3_path = "StartupScriptS3Path",
                .startup_script_s3_object_version = "StartupScriptS3ObjectVersion",
                .airflow_configuration_options = "AirflowConfigurationOptions",
                .environment_class = "EnvironmentClass",
                .max_workers = "MaxWorkers",
                .network_configuration = "NetworkConfiguration",
                .logging_configuration = "LoggingConfiguration",
                .weekly_maintenance_window_start = "WeeklyMaintenanceWindowStart",
                .webserver_access_mode = "WebserverAccessMode",
                .min_workers = "MinWorkers",
                .schedulers = "Schedulers",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "airflow_configuration_options", field_name))
                return try serializeMap(self.airflow_configuration_options, self.fieldNameFor("airflow_configuration_options"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_environment };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const LoggingConfigurationInput = struct {
    dag_processing_logs: ?ModuleLoggingConfigurationInput = null,
    scheduler_logs: ?ModuleLoggingConfigurationInput = null,
    webserver_logs: ?ModuleLoggingConfigurationInput = null,
    worker_logs: ?ModuleLoggingConfigurationInput = null,
    task_logs: ?ModuleLoggingConfigurationInput = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dag_processing_logs = "DagProcessingLogs",
            .scheduler_logs = "SchedulerLogs",
            .webserver_logs = "WebserverLogs",
            .worker_logs = "WorkerLogs",
            .task_logs = "TaskLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const ModuleLoggingConfigurationInput = struct {
    enabled: bool,
    log_level: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .log_level = "LogLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const ModuleLoggingConfiguration = struct {
    enabled: ?bool = null,
    log_level: ?[]const u8 = null,
    cloud_watch_log_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .log_level = "LogLevel",
            .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkConfiguration = struct {
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};
