const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2023-11-29";
pub const sdk_id: []const u8 = "Neptune Graph";
pub const arn_namespace: ?[]const u8 = "neptune-graph";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "neptune-graph";
pub const name: []const u8 = "AmazonNeptuneGraph";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2023-11-29",
    sdk_id: []const u8 = "Neptune Graph",
    arn_namespace: ?[]const u8 = "neptune-graph",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "neptune-graph",
    name: []const u8 = "AmazonNeptuneGraph",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_query: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/queries/{queryId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelQuery",
    Request: type = struct {
        graph_identifier: []const u8,
        query_id: []const u8,
        pub const http_header = .{
            .graph_identifier = "graphIdentifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_identifier = "graphIdentifier",
                .query_id = "queryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_query) } {
            return .{ .service_metadata = service_metadata, .action = cancel_query };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const execute_query: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queries",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteQuery",
    Request: type = struct {
        graph_identifier: []const u8,
        query_string: []const u8,
        language: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        plan_cache: ?[]const u8 = null,
        explain_mode: ?[]const u8 = null,
        query_timeout_milliseconds: ?i64 = null,
        pub const http_header = .{
            .graph_identifier = "graphIdentifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_identifier = "graphIdentifier",
                .query_string = "query",
                .language = "language",
                .parameters = "parameters",
                .plan_cache = "planCache",
                .explain_mode = "explain",
                .query_timeout_milliseconds = "queryTimeoutMilliseconds",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_query) } {
            return .{ .service_metadata = service_metadata, .action = execute_query };
        }
    },
    Response: type = struct {
        payload: []const u8,

        pub const http_payload: []const u8 = "payload";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Unprocessable,
        Validation,
    },
} = .{};
pub const get_graph_summary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/summary",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGraphSummary",
    Request: type = struct {
        graph_identifier: []const u8,
        mode: ?[]const u8 = null,

        pub const http_query = .{
            .mode = "mode",
        };

        pub const http_header = .{
            .graph_identifier = "graphIdentifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_identifier = "graphIdentifier",
                .mode = "mode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_graph_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_graph_summary };
        }
    },
    Response: type = struct {
        version: ?[]const u8 = null,
        last_statistics_computation_time: ?i64 = null,
        graph_summary: ?struct {
            num_nodes: ?i64 = null,
            num_edges: ?i64 = null,
            num_node_labels: ?i64 = null,
            num_edge_labels: ?i64 = null,
            node_labels: ?[][]const u8 = null,
            edge_labels: ?[][]const u8 = null,
            num_node_properties: ?i64 = null,
            num_edge_properties: ?i64 = null,
            node_properties: ?[][]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            edge_properties: ?[][]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            total_node_property_values: ?i64 = null,
            total_edge_property_values: ?i64 = null,
            node_structures: ?[]struct {
                count: ?i64 = null,
                node_properties: ?[][]const u8 = null,
                distinct_outgoing_edge_labels: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .count = "count",
                        .node_properties = "nodeProperties",
                        .distinct_outgoing_edge_labels = "distinctOutgoingEdgeLabels",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            edge_structures: ?[]struct {
                count: ?i64 = null,
                edge_properties: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .count = "count",
                        .edge_properties = "edgeProperties",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .num_nodes = "numNodes",
                    .num_edges = "numEdges",
                    .num_node_labels = "numNodeLabels",
                    .num_edge_labels = "numEdgeLabels",
                    .node_labels = "nodeLabels",
                    .edge_labels = "edgeLabels",
                    .num_node_properties = "numNodeProperties",
                    .num_edge_properties = "numEdgeProperties",
                    .node_properties = "nodeProperties",
                    .edge_properties = "edgeProperties",
                    .total_node_property_values = "totalNodePropertyValues",
                    .total_edge_property_values = "totalEdgePropertyValues",
                    .node_structures = "nodeStructures",
                    .edge_structures = "edgeStructures",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "node_properties", field_name))
                    return try serializeMap(self.node_properties, self.fieldNameFor("node_properties"), options, out_stream);
                if (std.mem.eql(u8, "edge_properties", field_name))
                    return try serializeMap(self.edge_properties, self.fieldNameFor("edge_properties"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version = "version",
                .last_statistics_computation_time = "lastStatisticsComputationTime",
                .graph_summary = "graphSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_query: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/queries/{queryId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetQuery",
    Request: type = struct {
        graph_identifier: []const u8,
        query_id: []const u8,
        pub const http_header = .{
            .graph_identifier = "graphIdentifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_identifier = "graphIdentifier",
                .query_id = "queryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query) } {
            return .{ .service_metadata = service_metadata, .action = get_query };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        query_string: ?[]const u8 = null,
        waited: ?i64 = null,
        elapsed: ?i64 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .query_string = "queryString",
                .waited = "waited",
                .elapsed = "elapsed",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_queries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/queries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListQueries",
    Request: type = struct {
        graph_identifier: []const u8,
        max_results: i64,
        state: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .state = "state",
        };

        pub const http_header = .{
            .graph_identifier = "graphIdentifier",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graph_identifier = "graphIdentifier",
                .max_results = "maxResults",
                .state = "state",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_queries) } {
            return .{ .service_metadata = service_metadata, .action = list_queries };
        }
    },
    Response: type = struct {
        queries: []struct {
            id: ?[]const u8 = null,
            query_string: ?[]const u8 = null,
            waited: ?i64 = null,
            elapsed: ?i64 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .query_string = "queryString",
                    .waited = "waited",
                    .elapsed = "elapsed",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queries = "queries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
