const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2023-08-01";
pub const sdk_id: []const u8 = "neptunedata";
pub const arn_namespace: ?[]const u8 = "neptune-db";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "neptune-db";
pub const name: []const u8 = "AmazonNeptuneDataplane";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2023-08-01",
    sdk_id: []const u8 = "neptunedata",
    arn_namespace: ?[]const u8 = "neptune-db",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "neptune-db",
    name: []const u8 = "AmazonNeptuneDataplane",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_gremlin_query: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/gremlin/status/{queryId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelGremlinQuery",
    Request: type = struct {
        query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "queryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_gremlin_query) } {
            return .{ .service_metadata = service_metadata, .action = cancel_gremlin_query };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const cancel_loader_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/loader/{loadId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelLoaderJob",
    Request: type = struct {
        load_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_id = "loadId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_loader_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_loader_job };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        BulkLoadIdNotFound,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InternalFailure,
        InvalidArgument,
        InvalidParameter,
        LoadUrlAccessDenied,
        MissingParameter,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const cancel_ml_data_processing_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/ml/dataprocessing/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelMLDataProcessingJob",
    Request: type = struct {
        id: []const u8,
        neptune_iam_role_arn: ?[]const u8 = null,
        clean: ?bool = null,

        pub const http_query = .{
            .neptune_iam_role_arn = "neptuneIamRoleArn",
            .clean = "clean",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
                .clean = "clean",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_ml_data_processing_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_ml_data_processing_job };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const cancel_ml_model_training_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/ml/modeltraining/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelMLModelTrainingJob",
    Request: type = struct {
        id: []const u8,
        neptune_iam_role_arn: ?[]const u8 = null,
        clean: ?bool = null,

        pub const http_query = .{
            .neptune_iam_role_arn = "neptuneIamRoleArn",
            .clean = "clean",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
                .clean = "clean",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_ml_model_training_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_ml_model_training_job };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const cancel_ml_model_transform_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/ml/modeltransform/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelMLModelTransformJob",
    Request: type = struct {
        id: []const u8,
        neptune_iam_role_arn: ?[]const u8 = null,
        clean: ?bool = null,

        pub const http_query = .{
            .neptune_iam_role_arn = "neptuneIamRoleArn",
            .clean = "clean",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
                .clean = "clean",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_ml_model_transform_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_ml_model_transform_job };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const cancel_open_cypher_query: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/opencypher/status/{queryId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelOpenCypherQuery",
    Request: type = struct {
        query_id: []const u8,
        silent: ?bool = null,

        pub const http_query = .{
            .silent = "silent",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "queryId",
                .silent = "silent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_open_cypher_query) } {
            return .{ .service_metadata = service_metadata, .action = cancel_open_cypher_query };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        payload: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidNumericData,
        InvalidParameter,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const create_ml_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ml/endpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMLEndpoint",
    Request: type = struct {
        id: ?[]const u8 = null,
        ml_model_training_job_id: ?[]const u8 = null,
        ml_model_transform_job_id: ?[]const u8 = null,
        update: ?bool = null,
        neptune_iam_role_arn: ?[]const u8 = null,
        model_name: ?[]const u8 = null,
        instance_type: ?[]const u8 = null,
        instance_count: ?i64 = null,
        volume_encryption_kms_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .ml_model_training_job_id = "mlModelTrainingJobId",
                .ml_model_transform_job_id = "mlModelTransformJobId",
                .update = "update",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
                .model_name = "modelName",
                .instance_type = "instanceType",
                .instance_count = "instanceCount",
                .volume_encryption_kms_key = "volumeEncryptionKMSKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ml_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_ml_endpoint };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        creation_time_in_millis: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .creation_time_in_millis = "creationTimeInMillis",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const delete_ml_endpoint: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/ml/endpoints/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMLEndpoint",
    Request: type = struct {
        id: []const u8,
        neptune_iam_role_arn: ?[]const u8 = null,
        clean: ?bool = null,

        pub const http_query = .{
            .neptune_iam_role_arn = "neptuneIamRoleArn",
            .clean = "clean",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
                .clean = "clean",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ml_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_ml_endpoint };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const delete_propertygraph_statistics: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/propertygraph/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePropertygraphStatistics",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_propertygraph_statistics) } {
            return .{ .service_metadata = service_metadata, .action = delete_propertygraph_statistics };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,
        status: ?[]const u8 = null,
        payload: ?DeleteStatisticsValueMap = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        PreconditionsFailed,
        ReadOnlyViolation,
        StatisticsNotAvailable,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const delete_sparql_statistics: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sparql/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSparqlStatistics",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sparql_statistics) } {
            return .{ .service_metadata = service_metadata, .action = delete_sparql_statistics };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,
        status: ?[]const u8 = null,
        payload: ?DeleteStatisticsValueMap = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        PreconditionsFailed,
        ReadOnlyViolation,
        StatisticsNotAvailable,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const execute_fast_reset: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/system",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteFastReset",
    Request: type = struct {
        action: []const u8,
        token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "action",
                .token = "token",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_fast_reset) } {
            return .{ .service_metadata = service_metadata, .action = execute_fast_reset };
        }
    },
    Response: type = struct {
        status: []const u8,
        payload: ?struct {
            token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .token = "token",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MethodNotAllowed,
        MissingParameter,
        PreconditionsFailed,
        ReadOnlyViolation,
        ServerShutdown,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const execute_gremlin_explain_query: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/gremlin/explain",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteGremlinExplainQuery",
    Request: type = struct {
        gremlin_query: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gremlin_query = "gremlin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_gremlin_explain_query) } {
            return .{ .service_metadata = service_metadata, .action = execute_gremlin_explain_query };
        }
    },
    Response: type = struct {
        output: ?[]const u8 = null,

        pub const http_payload: []const u8 = "output";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .output = "output",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        CancelledByUser,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MalformedQuery,
        MemoryLimitExceeded,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        QueryLimitExceeded,
        QueryLimit,
        QueryTooLarge,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const execute_gremlin_profile_query: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/gremlin/profile",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteGremlinProfileQuery",
    Request: type = struct {
        gremlin_query: []const u8,
        results: ?bool = null,
        chop: ?i64 = null,
        serializer: ?[]const u8 = null,
        index_ops: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gremlin_query = "gremlin",
                .results = "profile.results",
                .chop = "profile.chop",
                .serializer = "profile.serializer",
                .index_ops = "profile.indexOps",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_gremlin_profile_query) } {
            return .{ .service_metadata = service_metadata, .action = execute_gremlin_profile_query };
        }
    },
    Response: type = struct {
        output: ?[]const u8 = null,

        pub const http_payload: []const u8 = "output";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .output = "output",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        CancelledByUser,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MalformedQuery,
        MemoryLimitExceeded,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        QueryLimitExceeded,
        QueryLimit,
        QueryTooLarge,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const execute_gremlin_query: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/gremlin",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteGremlinQuery",
    Request: type = struct {
        gremlin_query: []const u8,
        serializer: ?[]const u8 = null,
        pub const http_header = .{
            .serializer = "accept",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gremlin_query = "gremlin",
                .serializer = "serializer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_gremlin_query) } {
            return .{ .service_metadata = service_metadata, .action = execute_gremlin_query };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?struct {
            message: ?[]const u8 = null,
            code: ?i64 = null,
            attributes: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message = "message",
                    .code = "code",
                    .attributes = "attributes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        result: ?[]const u8 = null,
        meta: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .status = "status",
                .result = "result",
                .meta = "meta",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        CancelledByUser,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MalformedQuery,
        MemoryLimitExceeded,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        QueryLimitExceeded,
        QueryLimit,
        QueryTooLarge,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const execute_open_cypher_explain_query: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/opencypher/explain",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteOpenCypherExplainQuery",
    Request: type = struct {
        open_cypher_query: []const u8,
        parameters: ?[]const u8 = null,
        explain_mode: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .open_cypher_query = "query",
                .parameters = "parameters",
                .explain_mode = "explain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_open_cypher_explain_query) } {
            return .{ .service_metadata = service_metadata, .action = execute_open_cypher_explain_query };
        }
    },
    Response: type = struct {
        results: []const u8,

        pub const http_payload: []const u8 = "results";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "results",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        CancelledByUser,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidNumericData,
        InvalidParameter,
        MalformedQuery,
        MemoryLimitExceeded,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        QueryLimitExceeded,
        QueryLimit,
        QueryTooLarge,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const execute_open_cypher_query: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/opencypher",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteOpenCypherQuery",
    Request: type = struct {
        open_cypher_query: []const u8,
        parameters: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .open_cypher_query = "query",
                .parameters = "parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_open_cypher_query) } {
            return .{ .service_metadata = service_metadata, .action = execute_open_cypher_query };
        }
    },
    Response: type = struct {
        results: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "results",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        CancelledByUser,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidNumericData,
        InvalidParameter,
        MalformedQuery,
        MemoryLimitExceeded,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        QueryLimitExceeded,
        QueryLimit,
        QueryTooLarge,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_engine_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEngineStatus",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_engine_status) } {
            return .{ .service_metadata = service_metadata, .action = get_engine_status };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        start_time: ?[]const u8 = null,
        db_engine_version: ?[]const u8 = null,
        role: ?[]const u8 = null,
        dfe_query_engine: ?[]const u8 = null,
        gremlin: ?QueryLanguageVersion = null,
        sparql: ?QueryLanguageVersion = null,
        opencypher: ?QueryLanguageVersion = null,
        lab_mode: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        rolling_back_trx_count: ?i64 = null,
        rolling_back_trx_earliest_start_time: ?[]const u8 = null,
        features: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .start_time = "startTime",
                .db_engine_version = "dbEngineVersion",
                .role = "role",
                .dfe_query_engine = "dfeQueryEngine",
                .gremlin = "gremlin",
                .sparql = "sparql",
                .opencypher = "opencypher",
                .lab_mode = "labMode",
                .rolling_back_trx_count = "rollingBackTrxCount",
                .rolling_back_trx_earliest_start_time = "rollingBackTrxEarliestStartTime",
                .features = "features",
                .settings = "settings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "lab_mode", field_name))
                return try serializeMap(self.lab_mode, self.fieldNameFor("lab_mode"), options, out_stream);
            if (std.mem.eql(u8, "features", field_name))
                return try serializeMap(self.features, self.fieldNameFor("features"), options, out_stream);
            if (std.mem.eql(u8, "settings", field_name))
                return try serializeMap(self.settings, self.fieldNameFor("settings"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InternalFailure,
        InvalidArgument,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_gremlin_query_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/gremlin/status/{queryId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGremlinQueryStatus",
    Request: type = struct {
        query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "queryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_gremlin_query_status) } {
            return .{ .service_metadata = service_metadata, .action = get_gremlin_query_status };
        }
    },
    Response: type = struct {
        query_id: ?[]const u8 = null,
        query_string: ?[]const u8 = null,
        query_eval_stats: ?QueryEvalStats = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "queryId",
                .query_string = "queryString",
                .query_eval_stats = "queryEvalStats",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        ReadOnlyViolation,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_loader_job_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/loader/{loadId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLoaderJobStatus",
    Request: type = struct {
        load_id: []const u8,
        details: ?bool = null,
        errors: ?bool = null,
        page: ?i64 = null,
        errors_per_page: ?i64 = null,

        pub const http_query = .{
            .details = "details",
            .errors = "errors",
            .page = "page",
            .errors_per_page = "errorsPerPage",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .load_id = "loadId",
                .details = "details",
                .errors = "errors",
                .page = "page",
                .errors_per_page = "errorsPerPage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_loader_job_status) } {
            return .{ .service_metadata = service_metadata, .action = get_loader_job_status };
        }
    },
    Response: type = struct {
        status: []const u8,
        payload: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        BulkLoadIdNotFound,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InternalFailure,
        InvalidArgument,
        InvalidParameter,
        LoadUrlAccessDenied,
        MissingParameter,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_ml_data_processing_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ml/dataprocessing/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMLDataProcessingJob",
    Request: type = struct {
        id: []const u8,
        neptune_iam_role_arn: ?[]const u8 = null,

        pub const http_query = .{
            .neptune_iam_role_arn = "neptuneIamRoleArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_data_processing_job) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_data_processing_job };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        id: ?[]const u8 = null,
        processing_job: ?MlResourceDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .id = "id",
                .processing_job = "processingJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_ml_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ml/endpoints/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMLEndpoint",
    Request: type = struct {
        id: []const u8,
        neptune_iam_role_arn: ?[]const u8 = null,

        pub const http_query = .{
            .neptune_iam_role_arn = "neptuneIamRoleArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_endpoint };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        id: ?[]const u8 = null,
        endpoint: ?MlResourceDefinition = null,
        endpoint_config: ?MlConfigDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .id = "id",
                .endpoint = "endpoint",
                .endpoint_config = "endpointConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_ml_model_training_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ml/modeltraining/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMLModelTrainingJob",
    Request: type = struct {
        id: []const u8,
        neptune_iam_role_arn: ?[]const u8 = null,

        pub const http_query = .{
            .neptune_iam_role_arn = "neptuneIamRoleArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_model_training_job) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_model_training_job };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        id: ?[]const u8 = null,
        processing_job: ?MlResourceDefinition = null,
        hpo_job: ?MlResourceDefinition = null,
        model_transform_job: ?MlResourceDefinition = null,
        ml_models: ?[]MlConfigDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .id = "id",
                .processing_job = "processingJob",
                .hpo_job = "hpoJob",
                .model_transform_job = "modelTransformJob",
                .ml_models = "mlModels",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_ml_model_transform_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ml/modeltransform/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMLModelTransformJob",
    Request: type = struct {
        id: []const u8,
        neptune_iam_role_arn: ?[]const u8 = null,

        pub const http_query = .{
            .neptune_iam_role_arn = "neptuneIamRoleArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_model_transform_job) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_model_transform_job };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        id: ?[]const u8 = null,
        base_processing_job: ?MlResourceDefinition = null,
        remote_model_transform_job: ?MlResourceDefinition = null,
        models: ?[]MlConfigDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .id = "id",
                .base_processing_job = "baseProcessingJob",
                .remote_model_transform_job = "remoteModelTransformJob",
                .models = "models",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_open_cypher_query_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/opencypher/status/{queryId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOpenCypherQueryStatus",
    Request: type = struct {
        query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "queryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_open_cypher_query_status) } {
            return .{ .service_metadata = service_metadata, .action = get_open_cypher_query_status };
        }
    },
    Response: type = struct {
        query_id: ?[]const u8 = null,
        query_string: ?[]const u8 = null,
        query_eval_stats: ?QueryEvalStats = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "queryId",
                .query_string = "queryString",
                .query_eval_stats = "queryEvalStats",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidNumericData,
        InvalidParameter,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        ReadOnlyViolation,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_propertygraph_statistics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/propertygraph/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPropertygraphStatistics",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_propertygraph_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_propertygraph_statistics };
        }
    },
    Response: type = struct {
        status: []const u8,
        payload: Statistics,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        PreconditionsFailed,
        ReadOnlyViolation,
        StatisticsNotAvailable,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_propertygraph_stream: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/propertygraph/stream",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPropertygraphStream",
    Request: type = struct {
        limit: ?i64 = null,
        iterator_type: ?[]const u8 = null,
        commit_num: ?i64 = null,
        op_num: ?i64 = null,
        encoding: ?[]const u8 = null,

        pub const http_query = .{
            .limit = "limit",
            .iterator_type = "iteratorType",
            .commit_num = "commitNum",
            .op_num = "opNum",
        };

        pub const http_header = .{
            .encoding = "Accept-Encoding",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "limit",
                .iterator_type = "iteratorType",
                .commit_num = "commitNum",
                .op_num = "opNum",
                .encoding = "encoding",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_propertygraph_stream) } {
            return .{ .service_metadata = service_metadata, .action = get_propertygraph_stream };
        }
    },
    Response: type = struct {
        last_event_id: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        last_trx_timestamp_in_millis: i64,
        format: []const u8,
        records: []struct {
            commit_timestamp_in_millis: i64,
            event_id: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },
            data: struct {
                id: []const u8,
                type: []const u8,
                key: []const u8,
                value: []const u8,
                from: ?[]const u8 = null,
                to: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "id",
                        .type = "type",
                        .key = "key",
                        .value = "value",
                        .from = "from",
                        .to = "to",
                    };
                    return @field(mappings, field_name);
                }
            },
            op: []const u8,
            is_last_op: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .commit_timestamp_in_millis = "commitTimestamp",
                    .event_id = "eventId",
                    .data = "data",
                    .op = "op",
                    .is_last_op = "isLastOp",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "event_id", field_name))
                    return try serializeMap(self.event_id, self.fieldNameFor("event_id"), options, out_stream);
                return false;
            }
        },
        total_records: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .last_event_id = "lastEventId",
                .last_trx_timestamp_in_millis = "lastTrxTimestamp",
                .format = "format",
                .records = "records",
                .total_records = "totalRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "last_event_id", field_name))
                return try serializeMap(self.last_event_id, self.fieldNameFor("last_event_id"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ClientTimeout,
        ConstraintViolation,
        ExpiredStream,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MemoryLimitExceeded,
        PreconditionsFailed,
        StreamRecordsNotFound,
        Throttling,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_propertygraph_summary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/propertygraph/statistics/summary",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPropertygraphSummary",
    Request: type = struct {
        mode: ?[]const u8 = null,

        pub const http_query = .{
            .mode = "mode",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mode = "mode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_propertygraph_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_propertygraph_summary };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,
        payload: ?struct {
            version: ?[]const u8 = null,
            last_statistics_computation_time: ?i64 = null,
            graph_summary: ?struct {
                num_nodes: ?i64 = null,
                num_edges: ?i64 = null,
                num_node_labels: ?i64 = null,
                num_edge_labels: ?i64 = null,
                node_labels: ?[][]const u8 = null,
                edge_labels: ?[][]const u8 = null,
                num_node_properties: ?i64 = null,
                num_edge_properties: ?i64 = null,
                node_properties: ?[][]struct {
                    key: ?[]const u8 = null,
                    value: ?i64 = null,
                } = null,
                edge_properties: ?[][]struct {
                    key: ?[]const u8 = null,
                    value: ?i64 = null,
                } = null,
                total_node_property_values: ?i64 = null,
                total_edge_property_values: ?i64 = null,
                node_structures: ?[]struct {
                    count: ?i64 = null,
                    node_properties: ?[][]const u8 = null,
                    distinct_outgoing_edge_labels: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .count = "count",
                            .node_properties = "nodeProperties",
                            .distinct_outgoing_edge_labels = "distinctOutgoingEdgeLabels",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                edge_structures: ?[]struct {
                    count: ?i64 = null,
                    edge_properties: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .count = "count",
                            .edge_properties = "edgeProperties",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .num_nodes = "numNodes",
                        .num_edges = "numEdges",
                        .num_node_labels = "numNodeLabels",
                        .num_edge_labels = "numEdgeLabels",
                        .node_labels = "nodeLabels",
                        .edge_labels = "edgeLabels",
                        .num_node_properties = "numNodeProperties",
                        .num_edge_properties = "numEdgeProperties",
                        .node_properties = "nodeProperties",
                        .edge_properties = "edgeProperties",
                        .total_node_property_values = "totalNodePropertyValues",
                        .total_edge_property_values = "totalEdgePropertyValues",
                        .node_structures = "nodeStructures",
                        .edge_structures = "edgeStructures",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "node_properties", field_name))
                        return try serializeMap(self.node_properties, self.fieldNameFor("node_properties"), options, out_stream);
                    if (std.mem.eql(u8, "edge_properties", field_name))
                        return try serializeMap(self.edge_properties, self.fieldNameFor("edge_properties"), options, out_stream);
                    return false;
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version = "version",
                    .last_statistics_computation_time = "lastStatisticsComputationTime",
                    .graph_summary = "graphSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        PreconditionsFailed,
        ReadOnlyViolation,
        StatisticsNotAvailable,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_rdf_graph_summary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rdf/statistics/summary",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRDFGraphSummary",
    Request: type = struct {
        mode: ?[]const u8 = null,

        pub const http_query = .{
            .mode = "mode",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mode = "mode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rdf_graph_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_rdf_graph_summary };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,
        payload: ?struct {
            version: ?[]const u8 = null,
            last_statistics_computation_time: ?i64 = null,
            graph_summary: ?struct {
                num_distinct_subjects: ?i64 = null,
                num_distinct_predicates: ?i64 = null,
                num_quads: ?i64 = null,
                num_classes: ?i64 = null,
                classes: ?[][]const u8 = null,
                predicates: ?[][]struct {
                    key: ?[]const u8 = null,
                    value: ?i64 = null,
                } = null,
                subject_structures: ?[]struct {
                    count: ?i64 = null,
                    predicates: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .count = "count",
                            .predicates = "predicates",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .num_distinct_subjects = "numDistinctSubjects",
                        .num_distinct_predicates = "numDistinctPredicates",
                        .num_quads = "numQuads",
                        .num_classes = "numClasses",
                        .classes = "classes",
                        .predicates = "predicates",
                        .subject_structures = "subjectStructures",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "predicates", field_name))
                        return try serializeMap(self.predicates, self.fieldNameFor("predicates"), options, out_stream);
                    return false;
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version = "version",
                    .last_statistics_computation_time = "lastStatisticsComputationTime",
                    .graph_summary = "graphSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        PreconditionsFailed,
        ReadOnlyViolation,
        StatisticsNotAvailable,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_sparql_statistics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sparql/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSparqlStatistics",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sparql_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_sparql_statistics };
        }
    },
    Response: type = struct {
        status: []const u8,
        payload: Statistics,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        PreconditionsFailed,
        ReadOnlyViolation,
        StatisticsNotAvailable,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const get_sparql_stream: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sparql/stream",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSparqlStream",
    Request: type = struct {
        limit: ?i64 = null,
        iterator_type: ?[]const u8 = null,
        commit_num: ?i64 = null,
        op_num: ?i64 = null,
        encoding: ?[]const u8 = null,

        pub const http_query = .{
            .limit = "limit",
            .iterator_type = "iteratorType",
            .commit_num = "commitNum",
            .op_num = "opNum",
        };

        pub const http_header = .{
            .encoding = "Accept-Encoding",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "limit",
                .iterator_type = "iteratorType",
                .commit_num = "commitNum",
                .op_num = "opNum",
                .encoding = "encoding",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sparql_stream) } {
            return .{ .service_metadata = service_metadata, .action = get_sparql_stream };
        }
    },
    Response: type = struct {
        last_event_id: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        last_trx_timestamp_in_millis: i64,
        format: []const u8,
        records: []struct {
            commit_timestamp_in_millis: i64,
            event_id: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },
            data: struct {
                stmt: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .stmt = "stmt",
                    };
                    return @field(mappings, field_name);
                }
            },
            op: []const u8,
            is_last_op: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .commit_timestamp_in_millis = "commitTimestamp",
                    .event_id = "eventId",
                    .data = "data",
                    .op = "op",
                    .is_last_op = "isLastOp",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "event_id", field_name))
                    return try serializeMap(self.event_id, self.fieldNameFor("event_id"), options, out_stream);
                return false;
            }
        },
        total_records: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .last_event_id = "lastEventId",
                .last_trx_timestamp_in_millis = "lastTrxTimestamp",
                .format = "format",
                .records = "records",
                .total_records = "totalRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "last_event_id", field_name))
                return try serializeMap(self.last_event_id, self.fieldNameFor("last_event_id"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ClientTimeout,
        ConstraintViolation,
        ExpiredStream,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MemoryLimitExceeded,
        PreconditionsFailed,
        StreamRecordsNotFound,
        Throttling,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const list_gremlin_queries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/gremlin/status",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGremlinQueries",
    Request: type = struct {
        include_waiting: ?bool = null,

        pub const http_query = .{
            .include_waiting = "includeWaiting",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .include_waiting = "includeWaiting",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_gremlin_queries) } {
            return .{ .service_metadata = service_metadata, .action = list_gremlin_queries };
        }
    },
    Response: type = struct {
        accepted_query_count: ?i64 = null,
        running_query_count: ?i64 = null,
        queries: ?[]GremlinQueryStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accepted_query_count = "acceptedQueryCount",
                .running_query_count = "runningQueryCount",
                .queries = "queries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        ReadOnlyViolation,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const list_loader_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/loader",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLoaderJobs",
    Request: type = struct {
        limit: ?i64 = null,
        include_queued_loads: ?bool = null,

        pub const http_query = .{
            .limit = "limit",
            .include_queued_loads = "includeQueuedLoads",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "limit",
                .include_queued_loads = "includeQueuedLoads",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_loader_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_loader_jobs };
        }
    },
    Response: type = struct {
        status: []const u8,
        payload: struct {
            load_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .load_ids = "loadIds",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        BulkLoadIdNotFound,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InternalFailure,
        InvalidArgument,
        InvalidParameter,
        LoadUrlAccessDenied,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const list_ml_data_processing_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ml/dataprocessing",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMLDataProcessingJobs",
    Request: type = struct {
        max_items: ?i64 = null,
        neptune_iam_role_arn: ?[]const u8 = null,

        pub const http_query = .{
            .max_items = "maxItems",
            .neptune_iam_role_arn = "neptuneIamRoleArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_items = "maxItems",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ml_data_processing_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_ml_data_processing_jobs };
        }
    },
    Response: type = struct {
        ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const list_ml_endpoints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ml/endpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMLEndpoints",
    Request: type = struct {
        max_items: ?i64 = null,
        neptune_iam_role_arn: ?[]const u8 = null,

        pub const http_query = .{
            .max_items = "maxItems",
            .neptune_iam_role_arn = "neptuneIamRoleArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_items = "maxItems",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ml_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_ml_endpoints };
        }
    },
    Response: type = struct {
        ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const list_ml_model_training_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ml/modeltraining",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMLModelTrainingJobs",
    Request: type = struct {
        max_items: ?i64 = null,
        neptune_iam_role_arn: ?[]const u8 = null,

        pub const http_query = .{
            .max_items = "maxItems",
            .neptune_iam_role_arn = "neptuneIamRoleArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_items = "maxItems",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ml_model_training_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_ml_model_training_jobs };
        }
    },
    Response: type = struct {
        ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const list_ml_model_transform_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ml/modeltransform",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMLModelTransformJobs",
    Request: type = struct {
        max_items: ?i64 = null,
        neptune_iam_role_arn: ?[]const u8 = null,

        pub const http_query = .{
            .max_items = "maxItems",
            .neptune_iam_role_arn = "neptuneIamRoleArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_items = "maxItems",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ml_model_transform_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_ml_model_transform_jobs };
        }
    },
    Response: type = struct {
        ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const list_open_cypher_queries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/opencypher/status",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOpenCypherQueries",
    Request: type = struct {
        include_waiting: ?bool = null,

        pub const http_query = .{
            .include_waiting = "includeWaiting",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .include_waiting = "includeWaiting",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_open_cypher_queries) } {
            return .{ .service_metadata = service_metadata, .action = list_open_cypher_queries };
        }
    },
    Response: type = struct {
        accepted_query_count: ?i64 = null,
        running_query_count: ?i64 = null,
        queries: ?[]GremlinQueryStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accepted_query_count = "acceptedQueryCount",
                .running_query_count = "runningQueryCount",
                .queries = "queries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConcurrentModification,
        ConstraintViolation,
        FailureByQuery,
        IllegalArgument,
        InvalidArgument,
        InvalidNumericData,
        InvalidParameter,
        MissingParameter,
        Parsing,
        PreconditionsFailed,
        ReadOnlyViolation,
        TimeLimitExceeded,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const manage_propertygraph_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/propertygraph/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "ManagePropertygraphStatistics",
    Request: type = struct {
        mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mode = "mode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(manage_propertygraph_statistics) } {
            return .{ .service_metadata = service_metadata, .action = manage_propertygraph_statistics };
        }
    },
    Response: type = struct {
        status: []const u8,
        payload: ?RefreshStatisticsIdMap = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        PreconditionsFailed,
        ReadOnlyViolation,
        StatisticsNotAvailable,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const manage_sparql_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sparql/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "ManageSparqlStatistics",
    Request: type = struct {
        mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mode = "mode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(manage_sparql_statistics) } {
            return .{ .service_metadata = service_metadata, .action = manage_sparql_statistics };
        }
    },
    Response: type = struct {
        status: []const u8,
        payload: ?RefreshStatisticsIdMap = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        PreconditionsFailed,
        ReadOnlyViolation,
        StatisticsNotAvailable,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const start_loader_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/loader",
        .success_code = 200,
    };

    action_name: []const u8 = "StartLoaderJob",
    Request: type = struct {
        source: []const u8,
        format: []const u8,
        s3_bucket_region: []const u8,
        iam_role_arn: []const u8,
        mode: ?[]const u8 = null,
        fail_on_error: ?bool = null,
        parallelism: ?[]const u8 = null,
        parser_configuration: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        update_single_cardinality_properties: ?bool = null,
        queue_request: ?bool = null,
        dependencies: ?[][]const u8 = null,
        user_provided_edge_ids: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "source",
                .format = "format",
                .s3_bucket_region = "region",
                .iam_role_arn = "iamRoleArn",
                .mode = "mode",
                .fail_on_error = "failOnError",
                .parallelism = "parallelism",
                .parser_configuration = "parserConfiguration",
                .update_single_cardinality_properties = "updateSingleCardinalityProperties",
                .queue_request = "queueRequest",
                .dependencies = "dependencies",
                .user_provided_edge_ids = "userProvidedEdgeIds",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parser_configuration", field_name))
                return try serializeMap(self.parser_configuration, self.fieldNameFor("parser_configuration"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_loader_job) } {
            return .{ .service_metadata = service_metadata, .action = start_loader_job };
        }
    },
    Response: type = struct {
        status: []const u8,
        payload: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .payload = "payload",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "payload", field_name))
                return try serializeMap(self.payload, self.fieldNameFor("payload"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        BulkLoadIdNotFound,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InternalFailure,
        InvalidArgument,
        InvalidParameter,
        LoadUrlAccessDenied,
        MissingParameter,
        PreconditionsFailed,
        S3,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const start_ml_data_processing_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ml/dataprocessing",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMLDataProcessingJob",
    Request: type = struct {
        id: ?[]const u8 = null,
        previous_data_processing_job_id: ?[]const u8 = null,
        input_data_s3_location: []const u8,
        processed_data_s3_location: []const u8,
        sagemaker_iam_role_arn: ?[]const u8 = null,
        neptune_iam_role_arn: ?[]const u8 = null,
        processing_instance_type: ?[]const u8 = null,
        processing_instance_volume_size_in_gb: ?i64 = null,
        processing_time_out_in_seconds: ?i64 = null,
        model_type: ?[]const u8 = null,
        config_file_name: ?[]const u8 = null,
        subnets: ?[][]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        volume_encryption_kms_key: ?[]const u8 = null,
        s3_output_encryption_kms_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .previous_data_processing_job_id = "previousDataProcessingJobId",
                .input_data_s3_location = "inputDataS3Location",
                .processed_data_s3_location = "processedDataS3Location",
                .sagemaker_iam_role_arn = "sagemakerIamRoleArn",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
                .processing_instance_type = "processingInstanceType",
                .processing_instance_volume_size_in_gb = "processingInstanceVolumeSizeInGB",
                .processing_time_out_in_seconds = "processingTimeOutInSeconds",
                .model_type = "modelType",
                .config_file_name = "configFileName",
                .subnets = "subnets",
                .security_group_ids = "securityGroupIds",
                .volume_encryption_kms_key = "volumeEncryptionKMSKey",
                .s3_output_encryption_kms_key = "s3OutputEncryptionKMSKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_ml_data_processing_job) } {
            return .{ .service_metadata = service_metadata, .action = start_ml_data_processing_job };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        creation_time_in_millis: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .creation_time_in_millis = "creationTimeInMillis",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const start_ml_model_training_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ml/modeltraining",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMLModelTrainingJob",
    Request: type = struct {
        id: ?[]const u8 = null,
        previous_model_training_job_id: ?[]const u8 = null,
        data_processing_job_id: []const u8,
        train_model_s3_location: []const u8,
        sagemaker_iam_role_arn: ?[]const u8 = null,
        neptune_iam_role_arn: ?[]const u8 = null,
        base_processing_instance_type: ?[]const u8 = null,
        training_instance_type: ?[]const u8 = null,
        training_instance_volume_size_in_gb: ?i64 = null,
        training_time_out_in_seconds: ?i64 = null,
        max_hpo_number_of_training_jobs: ?i64 = null,
        max_hpo_parallel_training_jobs: ?i64 = null,
        subnets: ?[][]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        volume_encryption_kms_key: ?[]const u8 = null,
        s3_output_encryption_kms_key: ?[]const u8 = null,
        enable_managed_spot_training: ?bool = null,
        custom_model_training_parameters: ?struct {
            source_s3_directory_path: []const u8,
            training_entry_point_script: ?[]const u8 = null,
            transform_entry_point_script: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_s3_directory_path = "sourceS3DirectoryPath",
                    .training_entry_point_script = "trainingEntryPointScript",
                    .transform_entry_point_script = "transformEntryPointScript",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .previous_model_training_job_id = "previousModelTrainingJobId",
                .data_processing_job_id = "dataProcessingJobId",
                .train_model_s3_location = "trainModelS3Location",
                .sagemaker_iam_role_arn = "sagemakerIamRoleArn",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
                .base_processing_instance_type = "baseProcessingInstanceType",
                .training_instance_type = "trainingInstanceType",
                .training_instance_volume_size_in_gb = "trainingInstanceVolumeSizeInGB",
                .training_time_out_in_seconds = "trainingTimeOutInSeconds",
                .max_hpo_number_of_training_jobs = "maxHPONumberOfTrainingJobs",
                .max_hpo_parallel_training_jobs = "maxHPOParallelTrainingJobs",
                .subnets = "subnets",
                .security_group_ids = "securityGroupIds",
                .volume_encryption_kms_key = "volumeEncryptionKMSKey",
                .s3_output_encryption_kms_key = "s3OutputEncryptionKMSKey",
                .enable_managed_spot_training = "enableManagedSpotTraining",
                .custom_model_training_parameters = "customModelTrainingParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_ml_model_training_job) } {
            return .{ .service_metadata = service_metadata, .action = start_ml_model_training_job };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        creation_time_in_millis: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .creation_time_in_millis = "creationTimeInMillis",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};
pub const start_ml_model_transform_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ml/modeltransform",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMLModelTransformJob",
    Request: type = struct {
        id: ?[]const u8 = null,
        data_processing_job_id: ?[]const u8 = null,
        ml_model_training_job_id: ?[]const u8 = null,
        training_job_name: ?[]const u8 = null,
        model_transform_output_s3_location: []const u8,
        sagemaker_iam_role_arn: ?[]const u8 = null,
        neptune_iam_role_arn: ?[]const u8 = null,
        custom_model_transform_parameters: ?struct {
            source_s3_directory_path: []const u8,
            transform_entry_point_script: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_s3_directory_path = "sourceS3DirectoryPath",
                    .transform_entry_point_script = "transformEntryPointScript",
                };
                return @field(mappings, field_name);
            }
        } = null,
        base_processing_instance_type: ?[]const u8 = null,
        base_processing_instance_volume_size_in_gb: ?i64 = null,
        subnets: ?[][]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        volume_encryption_kms_key: ?[]const u8 = null,
        s3_output_encryption_kms_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .data_processing_job_id = "dataProcessingJobId",
                .ml_model_training_job_id = "mlModelTrainingJobId",
                .training_job_name = "trainingJobName",
                .model_transform_output_s3_location = "modelTransformOutputS3Location",
                .sagemaker_iam_role_arn = "sagemakerIamRoleArn",
                .neptune_iam_role_arn = "neptuneIamRoleArn",
                .custom_model_transform_parameters = "customModelTransformParameters",
                .base_processing_instance_type = "baseProcessingInstanceType",
                .base_processing_instance_volume_size_in_gb = "baseProcessingInstanceVolumeSizeInGB",
                .subnets = "subnets",
                .security_group_ids = "securityGroupIds",
                .volume_encryption_kms_key = "volumeEncryptionKMSKey",
                .s3_output_encryption_kms_key = "s3OutputEncryptionKMSKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_ml_model_transform_job) } {
            return .{ .service_metadata = service_metadata, .action = start_ml_model_transform_job };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        creation_time_in_millis: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .creation_time_in_millis = "creationTimeInMillis",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ClientTimeout,
        ConstraintViolation,
        IllegalArgument,
        InvalidArgument,
        InvalidParameter,
        MissingParameter,
        MLResourceNotFound,
        PreconditionsFailed,
        TooManyRequests,
        UnsupportedOperation,
    },
} = .{};

pub const RefreshStatisticsIdMap = struct {
    statistics_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statistics_id = "statisticsId",
        };
        return @field(mappings, field_name);
    }
};

pub const GremlinQueryStatus = struct {
    query_id: ?[]const u8 = null,
    query_string: ?[]const u8 = null,
    query_eval_stats: ?QueryEvalStats = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_id = "queryId",
            .query_string = "queryString",
            .query_eval_stats = "queryEvalStats",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryEvalStats = struct {
    waited: ?i64 = null,
    elapsed: ?i64 = null,
    cancelled: ?bool = null,
    subqueries: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .waited = "waited",
            .elapsed = "elapsed",
            .cancelled = "cancelled",
            .subqueries = "subqueries",
        };
        return @field(mappings, field_name);
    }
};

pub const Statistics = struct {
    auto_compute: ?bool = null,
    active: ?bool = null,
    statistics_id: ?[]const u8 = null,
    date: ?i64 = null,
    note: ?[]const u8 = null,
    signature_info: ?StatisticsSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_compute = "autoCompute",
            .active = "active",
            .statistics_id = "statisticsId",
            .date = "date",
            .note = "note",
            .signature_info = "signatureInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const StatisticsSummary = struct {
    signature_count: ?i64 = null,
    instance_count: ?i64 = null,
    predicate_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signature_count = "signatureCount",
            .instance_count = "instanceCount",
            .predicate_count = "predicateCount",
        };
        return @field(mappings, field_name);
    }
};

pub const MlConfigDefinition = struct {
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const MlResourceDefinition = struct {
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    output_location: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    cloudwatch_log_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .arn = "arn",
            .status = "status",
            .output_location = "outputLocation",
            .failure_reason = "failureReason",
            .cloudwatch_log_url = "cloudwatchLogUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryLanguageVersion = struct {
    version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const DeleteStatisticsValueMap = struct {
    active: ?bool = null,
    statistics_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active = "active",
            .statistics_id = "statisticsId",
        };
        return @field(mappings, field_name);
    }
};
