const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-11-12";
pub const sdk_id: []const u8 = "Network Firewall";
pub const arn_namespace: ?[]const u8 = "network-firewall";
pub const endpoint_prefix: []const u8 = "network-firewall";
pub const sigv4_name: []const u8 = "network-firewall";
pub const name: []const u8 = "NetworkFirewall_20201112";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2020-11-12",
    sdk_id: []const u8 = "Network Firewall",
    arn_namespace: ?[]const u8 = "network-firewall",
    endpoint_prefix: []const u8 = "network-firewall",
    sigv4_name: []const u8 = "network-firewall",
    name: []const u8 = "NetworkFirewall_20201112",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const associate_firewall_policy: struct {
    action_name: []const u8 = "AssociateFirewallPolicy",
    Request: type = struct {
        update_token: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        firewall_policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .firewall_policy_arn = "FirewallPolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_firewall_policy) } {
            return .{ .service_metadata = service_metadata, .action = associate_firewall_policy };
        }
    },
    Response: type = struct {
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        firewall_policy_arn: ?[]const u8 = null,
        update_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .firewall_policy_arn = "FirewallPolicyArn",
                .update_token = "UpdateToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidOperation,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_subnets: struct {
    action_name: []const u8 = "AssociateSubnets",
    Request: type = struct {
        update_token: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        subnet_mappings: []SubnetMapping,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .subnet_mappings = "SubnetMappings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_subnets) } {
            return .{ .service_metadata = service_metadata, .action = associate_subnets };
        }
    },
    Response: type = struct {
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        subnet_mappings: ?[]SubnetMapping = null,
        update_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .subnet_mappings = "SubnetMappings",
                .update_token = "UpdateToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientCapacity,
        InternalServerError,
        InvalidOperation,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_firewall: struct {
    action_name: []const u8 = "CreateFirewall",
    Request: type = struct {
        firewall_name: []const u8,
        firewall_policy_arn: []const u8,
        vpc_id: []const u8,
        subnet_mappings: []SubnetMapping,
        delete_protection: ?bool = null,
        subnet_change_protection: ?bool = null,
        firewall_policy_change_protection: ?bool = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        encryption_configuration: ?EncryptionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_name = "FirewallName",
                .firewall_policy_arn = "FirewallPolicyArn",
                .vpc_id = "VpcId",
                .subnet_mappings = "SubnetMappings",
                .delete_protection = "DeleteProtection",
                .subnet_change_protection = "SubnetChangeProtection",
                .firewall_policy_change_protection = "FirewallPolicyChangeProtection",
                .description = "Description",
                .tags = "Tags",
                .encryption_configuration = "EncryptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_firewall) } {
            return .{ .service_metadata = service_metadata, .action = create_firewall };
        }
    },
    Response: type = struct {
        firewall: ?Firewall = null,
        firewall_status: ?FirewallStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall = "Firewall",
                .firewall_status = "FirewallStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientCapacity,
        InternalServerError,
        InvalidOperation,
        InvalidRequest,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const create_firewall_policy: struct {
    action_name: []const u8 = "CreateFirewallPolicy",
    Request: type = struct {
        firewall_policy_name: []const u8,
        firewall_policy: FirewallPolicy,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        dry_run: ?bool = null,
        encryption_configuration: ?EncryptionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_policy_name = "FirewallPolicyName",
                .firewall_policy = "FirewallPolicy",
                .description = "Description",
                .tags = "Tags",
                .dry_run = "DryRun",
                .encryption_configuration = "EncryptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_firewall_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_firewall_policy };
        }
    },
    Response: type = struct {
        update_token: []const u8,
        firewall_policy_response: FirewallPolicyResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_policy_response = "FirewallPolicyResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientCapacity,
        InternalServerError,
        InvalidRequest,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const create_rule_group: struct {
    action_name: []const u8 = "CreateRuleGroup",
    Request: type = struct {
        rule_group_name: []const u8,
        rule_group: ?RuleGroup = null,
        rules: ?[]const u8 = null,
        type: []const u8,
        description: ?[]const u8 = null,
        capacity: i64,
        tags: ?[]Tag = null,
        dry_run: ?bool = null,
        encryption_configuration: ?EncryptionConfiguration = null,
        source_metadata: ?SourceMetadata = null,
        analyze_rule_group: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group_name = "RuleGroupName",
                .rule_group = "RuleGroup",
                .rules = "Rules",
                .type = "Type",
                .description = "Description",
                .capacity = "Capacity",
                .tags = "Tags",
                .dry_run = "DryRun",
                .encryption_configuration = "EncryptionConfiguration",
                .source_metadata = "SourceMetadata",
                .analyze_rule_group = "AnalyzeRuleGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = create_rule_group };
        }
    },
    Response: type = struct {
        update_token: []const u8,
        rule_group_response: RuleGroupResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .rule_group_response = "RuleGroupResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientCapacity,
        InternalServerError,
        InvalidRequest,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const create_tls_inspection_configuration: struct {
    action_name: []const u8 = "CreateTLSInspectionConfiguration",
    Request: type = struct {
        tls_inspection_configuration_name: []const u8,
        tls_inspection_configuration: TLSInspectionConfiguration,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        encryption_configuration: ?EncryptionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tls_inspection_configuration_name = "TLSInspectionConfigurationName",
                .tls_inspection_configuration = "TLSInspectionConfiguration",
                .description = "Description",
                .tags = "Tags",
                .encryption_configuration = "EncryptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tls_inspection_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_tls_inspection_configuration };
        }
    },
    Response: type = struct {
        update_token: []const u8,
        tls_inspection_configuration_response: TLSInspectionConfigurationResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .tls_inspection_configuration_response = "TLSInspectionConfigurationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientCapacity,
        InternalServerError,
        InvalidRequest,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const delete_firewall: struct {
    action_name: []const u8 = "DeleteFirewall",
    Request: type = struct {
        firewall_name: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_name = "FirewallName",
                .firewall_arn = "FirewallArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_firewall) } {
            return .{ .service_metadata = service_metadata, .action = delete_firewall };
        }
    },
    Response: type = struct {
        firewall: ?Firewall = null,
        firewall_status: ?FirewallStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall = "Firewall",
                .firewall_status = "FirewallStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidOperation,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        UnsupportedOperation,
    },
} = .{};
pub const delete_firewall_policy: struct {
    action_name: []const u8 = "DeleteFirewallPolicy",
    Request: type = struct {
        firewall_policy_name: ?[]const u8 = null,
        firewall_policy_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_policy_name = "FirewallPolicyName",
                .firewall_policy_arn = "FirewallPolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_firewall_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_firewall_policy };
        }
    },
    Response: type = struct {
        firewall_policy_response: FirewallPolicyResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_policy_response = "FirewallPolicyResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidOperation,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        UnsupportedOperation,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidResourcePolicy,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_rule_group: struct {
    action_name: []const u8 = "DeleteRuleGroup",
    Request: type = struct {
        rule_group_name: ?[]const u8 = null,
        rule_group_arn: ?[]const u8 = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group_name = "RuleGroupName",
                .rule_group_arn = "RuleGroupArn",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_rule_group };
        }
    },
    Response: type = struct {
        rule_group_response: RuleGroupResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group_response = "RuleGroupResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidOperation,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
        UnsupportedOperation,
    },
} = .{};
pub const delete_tls_inspection_configuration: struct {
    action_name: []const u8 = "DeleteTLSInspectionConfiguration",
    Request: type = struct {
        tls_inspection_configuration_arn: ?[]const u8 = null,
        tls_inspection_configuration_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tls_inspection_configuration_arn = "TLSInspectionConfigurationArn",
                .tls_inspection_configuration_name = "TLSInspectionConfigurationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tls_inspection_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_tls_inspection_configuration };
        }
    },
    Response: type = struct {
        tls_inspection_configuration_response: TLSInspectionConfigurationResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tls_inspection_configuration_response = "TLSInspectionConfigurationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidOperation,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_firewall: struct {
    action_name: []const u8 = "DescribeFirewall",
    Request: type = struct {
        firewall_name: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_name = "FirewallName",
                .firewall_arn = "FirewallArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_firewall) } {
            return .{ .service_metadata = service_metadata, .action = describe_firewall };
        }
    },
    Response: type = struct {
        update_token: ?[]const u8 = null,
        firewall: ?Firewall = null,
        firewall_status: ?FirewallStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall = "Firewall",
                .firewall_status = "FirewallStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_firewall_policy: struct {
    action_name: []const u8 = "DescribeFirewallPolicy",
    Request: type = struct {
        firewall_policy_name: ?[]const u8 = null,
        firewall_policy_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_policy_name = "FirewallPolicyName",
                .firewall_policy_arn = "FirewallPolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_firewall_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_firewall_policy };
        }
    },
    Response: type = struct {
        update_token: []const u8,
        firewall_policy_response: FirewallPolicyResponse,
        firewall_policy: ?FirewallPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_policy_response = "FirewallPolicyResponse",
                .firewall_policy = "FirewallPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_logging_configuration: struct {
    action_name: []const u8 = "DescribeLoggingConfiguration",
    Request: type = struct {
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_logging_configuration };
        }
    },
    Response: type = struct {
        firewall_arn: ?[]const u8 = null,
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_arn = "FirewallArn",
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_resource_policy: struct {
    action_name: []const u8 = "DescribeResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_rule_group: struct {
    action_name: []const u8 = "DescribeRuleGroup",
    Request: type = struct {
        rule_group_name: ?[]const u8 = null,
        rule_group_arn: ?[]const u8 = null,
        type: ?[]const u8 = null,
        analyze_rule_group: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group_name = "RuleGroupName",
                .rule_group_arn = "RuleGroupArn",
                .type = "Type",
                .analyze_rule_group = "AnalyzeRuleGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_rule_group };
        }
    },
    Response: type = struct {
        update_token: []const u8,
        rule_group: ?RuleGroup = null,
        rule_group_response: RuleGroupResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .rule_group = "RuleGroup",
                .rule_group_response = "RuleGroupResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_rule_group_metadata: struct {
    action_name: []const u8 = "DescribeRuleGroupMetadata",
    Request: type = struct {
        rule_group_name: ?[]const u8 = null,
        rule_group_arn: ?[]const u8 = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group_name = "RuleGroupName",
                .rule_group_arn = "RuleGroupArn",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_rule_group_metadata) } {
            return .{ .service_metadata = service_metadata, .action = describe_rule_group_metadata };
        }
    },
    Response: type = struct {
        rule_group_arn: []const u8,
        rule_group_name: []const u8,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        capacity: ?i64 = null,
        stateful_rule_options: ?StatefulRuleOptions = null,
        last_modified_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group_arn = "RuleGroupArn",
                .rule_group_name = "RuleGroupName",
                .description = "Description",
                .type = "Type",
                .capacity = "Capacity",
                .stateful_rule_options = "StatefulRuleOptions",
                .last_modified_time = "LastModifiedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_tls_inspection_configuration: struct {
    action_name: []const u8 = "DescribeTLSInspectionConfiguration",
    Request: type = struct {
        tls_inspection_configuration_arn: ?[]const u8 = null,
        tls_inspection_configuration_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tls_inspection_configuration_arn = "TLSInspectionConfigurationArn",
                .tls_inspection_configuration_name = "TLSInspectionConfigurationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tls_inspection_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_tls_inspection_configuration };
        }
    },
    Response: type = struct {
        update_token: []const u8,
        tls_inspection_configuration: ?TLSInspectionConfiguration = null,
        tls_inspection_configuration_response: TLSInspectionConfigurationResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .tls_inspection_configuration = "TLSInspectionConfiguration",
                .tls_inspection_configuration_response = "TLSInspectionConfigurationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_subnets: struct {
    action_name: []const u8 = "DisassociateSubnets",
    Request: type = struct {
        update_token: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        subnet_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .subnet_ids = "SubnetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_subnets) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_subnets };
        }
    },
    Response: type = struct {
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        subnet_mappings: ?[]SubnetMapping = null,
        update_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .subnet_mappings = "SubnetMappings",
                .update_token = "UpdateToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidOperation,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_firewall_policies: struct {
    action_name: []const u8 = "ListFirewallPolicies",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_firewall_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_firewall_policies };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        firewall_policies: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .firewall_policies = "FirewallPolicies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_firewalls: struct {
    action_name: []const u8 = "ListFirewalls",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        vpc_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .vpc_ids = "VpcIds",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_firewalls) } {
            return .{ .service_metadata = service_metadata, .action = list_firewalls };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        firewalls: ?[]struct {
            firewall_name: ?[]const u8 = null,
            firewall_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .firewall_name = "FirewallName",
                    .firewall_arn = "FirewallArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .firewalls = "Firewalls",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_rule_groups: struct {
    action_name: []const u8 = "ListRuleGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        scope: ?[]const u8 = null,
        managed_type: ?[]const u8 = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .scope = "Scope",
                .managed_type = "ManagedType",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rule_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_rule_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        rule_groups: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .rule_groups = "RuleGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_tls_inspection_configurations: struct {
    action_name: []const u8 = "ListTLSInspectionConfigurations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tls_inspection_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_tls_inspection_configurations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        tls_inspection_configurations: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .tls_inspection_configurations = "TLSInspectionConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidResourcePolicy,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_firewall_delete_protection: struct {
    action_name: []const u8 = "UpdateFirewallDeleteProtection",
    Request: type = struct {
        update_token: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        delete_protection: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .delete_protection = "DeleteProtection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_firewall_delete_protection) } {
            return .{ .service_metadata = service_metadata, .action = update_firewall_delete_protection };
        }
    },
    Response: type = struct {
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        delete_protection: ?bool = null,
        update_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .delete_protection = "DeleteProtection",
                .update_token = "UpdateToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        ResourceOwnerCheck,
        Throttling,
    },
} = .{};
pub const update_firewall_description: struct {
    action_name: []const u8 = "UpdateFirewallDescription",
    Request: type = struct {
        update_token: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_firewall_description) } {
            return .{ .service_metadata = service_metadata, .action = update_firewall_description };
        }
    },
    Response: type = struct {
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        update_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .description = "Description",
                .update_token = "UpdateToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_firewall_encryption_configuration: struct {
    action_name: []const u8 = "UpdateFirewallEncryptionConfiguration",
    Request: type = struct {
        update_token: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        encryption_configuration: ?EncryptionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .encryption_configuration = "EncryptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_firewall_encryption_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_firewall_encryption_configuration };
        }
    },
    Response: type = struct {
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        update_token: ?[]const u8 = null,
        encryption_configuration: ?EncryptionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .update_token = "UpdateToken",
                .encryption_configuration = "EncryptionConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        ResourceOwnerCheck,
        Throttling,
    },
} = .{};
pub const update_firewall_policy: struct {
    action_name: []const u8 = "UpdateFirewallPolicy",
    Request: type = struct {
        update_token: []const u8,
        firewall_policy_arn: ?[]const u8 = null,
        firewall_policy_name: ?[]const u8 = null,
        firewall_policy: FirewallPolicy,
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        encryption_configuration: ?EncryptionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_policy_arn = "FirewallPolicyArn",
                .firewall_policy_name = "FirewallPolicyName",
                .firewall_policy = "FirewallPolicy",
                .description = "Description",
                .dry_run = "DryRun",
                .encryption_configuration = "EncryptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_firewall_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_firewall_policy };
        }
    },
    Response: type = struct {
        update_token: []const u8,
        firewall_policy_response: FirewallPolicyResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_policy_response = "FirewallPolicyResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_firewall_policy_change_protection: struct {
    action_name: []const u8 = "UpdateFirewallPolicyChangeProtection",
    Request: type = struct {
        update_token: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        firewall_policy_change_protection: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .firewall_policy_change_protection = "FirewallPolicyChangeProtection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_firewall_policy_change_protection) } {
            return .{ .service_metadata = service_metadata, .action = update_firewall_policy_change_protection };
        }
    },
    Response: type = struct {
        update_token: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        firewall_policy_change_protection: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .firewall_policy_change_protection = "FirewallPolicyChangeProtection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        ResourceOwnerCheck,
        Throttling,
    },
} = .{};
pub const update_logging_configuration: struct {
    action_name: []const u8 = "UpdateLoggingConfiguration",
    Request: type = struct {
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_logging_configuration };
        }
    },
    Response: type = struct {
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidToken,
        LogDestinationPermission,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_rule_group: struct {
    action_name: []const u8 = "UpdateRuleGroup",
    Request: type = struct {
        update_token: []const u8,
        rule_group_arn: ?[]const u8 = null,
        rule_group_name: ?[]const u8 = null,
        rule_group: ?RuleGroup = null,
        rules: ?[]const u8 = null,
        type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        dry_run: ?bool = null,
        encryption_configuration: ?EncryptionConfiguration = null,
        source_metadata: ?SourceMetadata = null,
        analyze_rule_group: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .rule_group_arn = "RuleGroupArn",
                .rule_group_name = "RuleGroupName",
                .rule_group = "RuleGroup",
                .rules = "Rules",
                .type = "Type",
                .description = "Description",
                .dry_run = "DryRun",
                .encryption_configuration = "EncryptionConfiguration",
                .source_metadata = "SourceMetadata",
                .analyze_rule_group = "AnalyzeRuleGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = update_rule_group };
        }
    },
    Response: type = struct {
        update_token: []const u8,
        rule_group_response: RuleGroupResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .rule_group_response = "RuleGroupResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_subnet_change_protection: struct {
    action_name: []const u8 = "UpdateSubnetChangeProtection",
    Request: type = struct {
        update_token: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        subnet_change_protection: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .subnet_change_protection = "SubnetChangeProtection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_subnet_change_protection) } {
            return .{ .service_metadata = service_metadata, .action = update_subnet_change_protection };
        }
    },
    Response: type = struct {
        update_token: ?[]const u8 = null,
        firewall_arn: ?[]const u8 = null,
        firewall_name: ?[]const u8 = null,
        subnet_change_protection: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .firewall_arn = "FirewallArn",
                .firewall_name = "FirewallName",
                .subnet_change_protection = "SubnetChangeProtection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        ResourceOwnerCheck,
        Throttling,
    },
} = .{};
pub const update_tls_inspection_configuration: struct {
    action_name: []const u8 = "UpdateTLSInspectionConfiguration",
    Request: type = struct {
        tls_inspection_configuration_arn: ?[]const u8 = null,
        tls_inspection_configuration_name: ?[]const u8 = null,
        tls_inspection_configuration: TLSInspectionConfiguration,
        description: ?[]const u8 = null,
        encryption_configuration: ?EncryptionConfiguration = null,
        update_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tls_inspection_configuration_arn = "TLSInspectionConfigurationArn",
                .tls_inspection_configuration_name = "TLSInspectionConfigurationName",
                .tls_inspection_configuration = "TLSInspectionConfiguration",
                .description = "Description",
                .encryption_configuration = "EncryptionConfiguration",
                .update_token = "UpdateToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_tls_inspection_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_tls_inspection_configuration };
        }
    },
    Response: type = struct {
        update_token: []const u8,
        tls_inspection_configuration_response: TLSInspectionConfigurationResponse,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_token = "UpdateToken",
                .tls_inspection_configuration_response = "TLSInspectionConfigurationResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        InvalidToken,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const TLSInspectionConfigurationResponse = struct {
    tls_inspection_configuration_arn: []const u8,
    tls_inspection_configuration_name: []const u8,
    tls_inspection_configuration_id: []const u8,
    tls_inspection_configuration_status: ?[]const u8 = null,
    description: ?[]const u8 = null,
    tags: ?[]Tag = null,
    last_modified_time: ?i64 = null,
    number_of_associations: ?i64 = null,
    encryption_configuration: ?EncryptionConfiguration = null,
    certificates: ?[]TlsCertificateData = null,
    certificate_authority: ?TlsCertificateData = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tls_inspection_configuration_arn = "TLSInspectionConfigurationArn",
            .tls_inspection_configuration_name = "TLSInspectionConfigurationName",
            .tls_inspection_configuration_id = "TLSInspectionConfigurationId",
            .tls_inspection_configuration_status = "TLSInspectionConfigurationStatus",
            .description = "Description",
            .tags = "Tags",
            .last_modified_time = "LastModifiedTime",
            .number_of_associations = "NumberOfAssociations",
            .encryption_configuration = "EncryptionConfiguration",
            .certificates = "Certificates",
            .certificate_authority = "CertificateAuthority",
        };
        return @field(mappings, field_name);
    }
};

pub const TlsCertificateData = struct {
    certificate_arn: ?[]const u8 = null,
    certificate_serial: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "CertificateArn",
            .certificate_serial = "CertificateSerial",
            .status = "Status",
            .status_message = "StatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfiguration = struct {
    key_id: ?[]const u8 = null,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_id = "KeyId",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TLSInspectionConfiguration = struct {
    server_certificate_configurations: ?[]ServerCertificateConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_certificate_configurations = "ServerCertificateConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerCertificateConfiguration = struct {
    server_certificates: ?[]ServerCertificate = null,
    scopes: ?[]ServerCertificateScope = null,
    certificate_authority_arn: ?[]const u8 = null,
    check_certificate_revocation_status: ?CheckCertificateRevocationStatusActions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_certificates = "ServerCertificates",
            .scopes = "Scopes",
            .certificate_authority_arn = "CertificateAuthorityArn",
            .check_certificate_revocation_status = "CheckCertificateRevocationStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const CheckCertificateRevocationStatusActions = struct {
    revoked_status_action: ?[]const u8 = null,
    unknown_status_action: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .revoked_status_action = "RevokedStatusAction",
            .unknown_status_action = "UnknownStatusAction",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerCertificateScope = struct {
    sources: ?[]Address = null,
    destinations: ?[]Address = null,
    source_ports: ?[]PortRange = null,
    destination_ports: ?[]PortRange = null,
    protocols: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sources = "Sources",
            .destinations = "Destinations",
            .source_ports = "SourcePorts",
            .destination_ports = "DestinationPorts",
            .protocols = "Protocols",
        };
        return @field(mappings, field_name);
    }
};

pub const PortRange = struct {
    from_port: i64,
    to_port: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_port = "FromPort",
            .to_port = "ToPort",
        };
        return @field(mappings, field_name);
    }
};

pub const Address = struct {
    address_definition: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address_definition = "AddressDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerCertificate = struct {
    resource_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupResponse = struct {
    rule_group_arn: []const u8,
    rule_group_name: []const u8,
    rule_group_id: []const u8,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    capacity: ?i64 = null,
    rule_group_status: ?[]const u8 = null,
    tags: ?[]Tag = null,
    consumed_capacity: ?i64 = null,
    number_of_associations: ?i64 = null,
    encryption_configuration: ?EncryptionConfiguration = null,
    source_metadata: ?SourceMetadata = null,
    sns_topic: ?[]const u8 = null,
    last_modified_time: ?i64 = null,
    analysis_results: ?[]AnalysisResult = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_group_arn = "RuleGroupArn",
            .rule_group_name = "RuleGroupName",
            .rule_group_id = "RuleGroupId",
            .description = "Description",
            .type = "Type",
            .capacity = "Capacity",
            .rule_group_status = "RuleGroupStatus",
            .tags = "Tags",
            .consumed_capacity = "ConsumedCapacity",
            .number_of_associations = "NumberOfAssociations",
            .encryption_configuration = "EncryptionConfiguration",
            .source_metadata = "SourceMetadata",
            .sns_topic = "SnsTopic",
            .last_modified_time = "LastModifiedTime",
            .analysis_results = "AnalysisResults",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisResult = struct {
    identified_rule_ids: ?[][]const u8 = null,
    identified_type: ?[]const u8 = null,
    analysis_detail: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identified_rule_ids = "IdentifiedRuleIds",
            .identified_type = "IdentifiedType",
            .analysis_detail = "AnalysisDetail",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceMetadata = struct {
    source_arn: ?[]const u8 = null,
    source_update_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_arn = "SourceArn",
            .source_update_token = "SourceUpdateToken",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroup = struct {
    rule_variables: ?RuleVariables = null,
    reference_sets: ?ReferenceSets = null,
    rules_source: RulesSource,
    stateful_rule_options: ?StatefulRuleOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_variables = "RuleVariables",
            .reference_sets = "ReferenceSets",
            .rules_source = "RulesSource",
            .stateful_rule_options = "StatefulRuleOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const StatefulRuleOptions = struct {
    rule_order: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_order = "RuleOrder",
        };
        return @field(mappings, field_name);
    }
};

pub const RulesSource = struct {
    rules_string: ?[]const u8 = null,
    rules_source_list: ?RulesSourceList = null,
    stateful_rules: ?[]StatefulRule = null,
    stateless_rules_and_custom_actions: ?StatelessRulesAndCustomActions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules_string = "RulesString",
            .rules_source_list = "RulesSourceList",
            .stateful_rules = "StatefulRules",
            .stateless_rules_and_custom_actions = "StatelessRulesAndCustomActions",
        };
        return @field(mappings, field_name);
    }
};

pub const StatelessRulesAndCustomActions = struct {
    stateless_rules: []StatelessRule,
    custom_actions: ?[]CustomAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stateless_rules = "StatelessRules",
            .custom_actions = "CustomActions",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomAction = struct {
    action_name: []const u8,
    action_definition: ActionDefinition,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_name = "ActionName",
            .action_definition = "ActionDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionDefinition = struct {
    publish_metric_action: ?PublishMetricAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .publish_metric_action = "PublishMetricAction",
        };
        return @field(mappings, field_name);
    }
};

pub const PublishMetricAction = struct {
    dimensions: []Dimension,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimensions = "Dimensions",
        };
        return @field(mappings, field_name);
    }
};

pub const Dimension = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const StatelessRule = struct {
    rule_definition: RuleDefinition,
    priority: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_definition = "RuleDefinition",
            .priority = "Priority",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleDefinition = struct {
    match_attributes: MatchAttributes,
    actions: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_attributes = "MatchAttributes",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchAttributes = struct {
    sources: ?[]Address = null,
    destinations: ?[]Address = null,
    source_ports: ?[]PortRange = null,
    destination_ports: ?[]PortRange = null,
    protocols: ?[]i64 = null,
    tcp_flags: ?[]TCPFlagField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sources = "Sources",
            .destinations = "Destinations",
            .source_ports = "SourcePorts",
            .destination_ports = "DestinationPorts",
            .protocols = "Protocols",
            .tcp_flags = "TCPFlags",
        };
        return @field(mappings, field_name);
    }
};

pub const TCPFlagField = struct {
    flags: [][]const u8,
    masks: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .flags = "Flags",
            .masks = "Masks",
        };
        return @field(mappings, field_name);
    }
};

pub const StatefulRule = struct {
    action: []const u8,
    header: Header,
    rule_options: []RuleOption,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .header = "Header",
            .rule_options = "RuleOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleOption = struct {
    keyword: []const u8,
    settings: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .keyword = "Keyword",
            .settings = "Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const Header = struct {
    protocol: []const u8,
    source: []const u8,
    source_port: []const u8,
    direction: []const u8,
    destination: []const u8,
    destination_port: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .protocol = "Protocol",
            .source = "Source",
            .source_port = "SourcePort",
            .direction = "Direction",
            .destination = "Destination",
            .destination_port = "DestinationPort",
        };
        return @field(mappings, field_name);
    }
};

pub const RulesSourceList = struct {
    targets: [][]const u8,
    target_types: [][]const u8,
    generated_rules_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .targets = "Targets",
            .target_types = "TargetTypes",
            .generated_rules_type = "GeneratedRulesType",
        };
        return @field(mappings, field_name);
    }
};

pub const ReferenceSets = struct {
    ip_set_references: ?[]struct {
        key: ?[]const u8 = null,
        value: ?IPSetReference = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_set_references = "IPSetReferences",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "ip_set_references", field_name))
            return try serializeMap(self.ip_set_references, self.fieldNameFor("ip_set_references"), options, out_stream);
        return false;
    }
};

pub const IPSetReference = struct {
    reference_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reference_arn = "ReferenceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleVariables = struct {
    ip_sets: ?[]struct {
        key: ?[]const u8 = null,
        value: ?IPSet = null,
    } = null,
    port_sets: ?[]struct {
        key: ?[]const u8 = null,
        value: ?PortSet = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_sets = "IPSets",
            .port_sets = "PortSets",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "ip_sets", field_name))
            return try serializeMap(self.ip_sets, self.fieldNameFor("ip_sets"), options, out_stream);
        if (std.mem.eql(u8, "port_sets", field_name))
            return try serializeMap(self.port_sets, self.fieldNameFor("port_sets"), options, out_stream);
        return false;
    }
};

pub const PortSet = struct {
    definition: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .definition = "Definition",
        };
        return @field(mappings, field_name);
    }
};

pub const IPSet = struct {
    definition: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .definition = "Definition",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingConfiguration = struct {
    log_destination_configs: []LogDestinationConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_destination_configs = "LogDestinationConfigs",
        };
        return @field(mappings, field_name);
    }
};

pub const LogDestinationConfig = struct {
    log_type: []const u8,
    log_destination_type: []const u8,
    log_destination: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_type = "LogType",
            .log_destination_type = "LogDestinationType",
            .log_destination = "LogDestination",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "log_destination", field_name))
            return try serializeMap(self.log_destination, self.fieldNameFor("log_destination"), options, out_stream);
        return false;
    }
};

pub const FirewallPolicyResponse = struct {
    firewall_policy_name: []const u8,
    firewall_policy_arn: []const u8,
    firewall_policy_id: []const u8,
    description: ?[]const u8 = null,
    firewall_policy_status: ?[]const u8 = null,
    tags: ?[]Tag = null,
    consumed_stateless_rule_capacity: ?i64 = null,
    consumed_stateful_rule_capacity: ?i64 = null,
    number_of_associations: ?i64 = null,
    encryption_configuration: ?EncryptionConfiguration = null,
    last_modified_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .firewall_policy_name = "FirewallPolicyName",
            .firewall_policy_arn = "FirewallPolicyArn",
            .firewall_policy_id = "FirewallPolicyId",
            .description = "Description",
            .firewall_policy_status = "FirewallPolicyStatus",
            .tags = "Tags",
            .consumed_stateless_rule_capacity = "ConsumedStatelessRuleCapacity",
            .consumed_stateful_rule_capacity = "ConsumedStatefulRuleCapacity",
            .number_of_associations = "NumberOfAssociations",
            .encryption_configuration = "EncryptionConfiguration",
            .last_modified_time = "LastModifiedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const FirewallPolicy = struct {
    stateless_rule_group_references: ?[]StatelessRuleGroupReference = null,
    stateless_default_actions: [][]const u8,
    stateless_fragment_default_actions: [][]const u8,
    stateless_custom_actions: ?[]CustomAction = null,
    stateful_rule_group_references: ?[]StatefulRuleGroupReference = null,
    stateful_default_actions: ?[][]const u8 = null,
    stateful_engine_options: ?StatefulEngineOptions = null,
    tls_inspection_configuration_arn: ?[]const u8 = null,
    policy_variables: ?PolicyVariables = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stateless_rule_group_references = "StatelessRuleGroupReferences",
            .stateless_default_actions = "StatelessDefaultActions",
            .stateless_fragment_default_actions = "StatelessFragmentDefaultActions",
            .stateless_custom_actions = "StatelessCustomActions",
            .stateful_rule_group_references = "StatefulRuleGroupReferences",
            .stateful_default_actions = "StatefulDefaultActions",
            .stateful_engine_options = "StatefulEngineOptions",
            .tls_inspection_configuration_arn = "TLSInspectionConfigurationArn",
            .policy_variables = "PolicyVariables",
        };
        return @field(mappings, field_name);
    }
};

pub const PolicyVariables = struct {
    rule_variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?IPSet = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_variables = "RuleVariables",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "rule_variables", field_name))
            return try serializeMap(self.rule_variables, self.fieldNameFor("rule_variables"), options, out_stream);
        return false;
    }
};

pub const StatefulEngineOptions = struct {
    rule_order: ?[]const u8 = null,
    stream_exception_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_order = "RuleOrder",
            .stream_exception_policy = "StreamExceptionPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const StatefulRuleGroupReference = struct {
    resource_arn: []const u8,
    priority: ?i64 = null,
    override: ?StatefulRuleGroupOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .priority = "Priority",
            .override = "Override",
        };
        return @field(mappings, field_name);
    }
};

pub const StatefulRuleGroupOverride = struct {
    action: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
        };
        return @field(mappings, field_name);
    }
};

pub const StatelessRuleGroupReference = struct {
    resource_arn: []const u8,
    priority: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .priority = "Priority",
        };
        return @field(mappings, field_name);
    }
};

pub const SubnetMapping = struct {
    subnet_id: []const u8,
    ip_address_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_id = "SubnetId",
            .ip_address_type = "IPAddressType",
        };
        return @field(mappings, field_name);
    }
};

pub const FirewallStatus = struct {
    status: []const u8,
    configuration_sync_state_summary: []const u8,
    sync_states: ?[]struct {
        key: ?[]const u8 = null,
        value: ?SyncState = null,
    } = null,
    capacity_usage_summary: ?CapacityUsageSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .configuration_sync_state_summary = "ConfigurationSyncStateSummary",
            .sync_states = "SyncStates",
            .capacity_usage_summary = "CapacityUsageSummary",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "sync_states", field_name))
            return try serializeMap(self.sync_states, self.fieldNameFor("sync_states"), options, out_stream);
        return false;
    }
};

pub const CapacityUsageSummary = struct {
    cid_rs: ?CIDRSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cid_rs = "CIDRs",
        };
        return @field(mappings, field_name);
    }
};

pub const CIDRSummary = struct {
    available_cidr_count: ?i64 = null,
    utilized_cidr_count: ?i64 = null,
    ip_set_references: ?[]struct {
        key: ?[]const u8 = null,
        value: ?IPSetMetadata = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .available_cidr_count = "AvailableCIDRCount",
            .utilized_cidr_count = "UtilizedCIDRCount",
            .ip_set_references = "IPSetReferences",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "ip_set_references", field_name))
            return try serializeMap(self.ip_set_references, self.fieldNameFor("ip_set_references"), options, out_stream);
        return false;
    }
};

pub const IPSetMetadata = struct {
    resolved_cidr_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resolved_cidr_count = "ResolvedCIDRCount",
        };
        return @field(mappings, field_name);
    }
};

pub const SyncState = struct {
    attachment: ?Attachment = null,
    config: ?[]struct {
        key: ?[]const u8 = null,
        value: ?PerObjectStatus = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment = "Attachment",
            .config = "Config",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "config", field_name))
            return try serializeMap(self.config, self.fieldNameFor("config"), options, out_stream);
        return false;
    }
};

pub const PerObjectStatus = struct {
    sync_status: ?[]const u8 = null,
    update_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sync_status = "SyncStatus",
            .update_token = "UpdateToken",
        };
        return @field(mappings, field_name);
    }
};

pub const Attachment = struct {
    subnet_id: ?[]const u8 = null,
    endpoint_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_id = "SubnetId",
            .endpoint_id = "EndpointId",
            .status = "Status",
            .status_message = "StatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const Firewall = struct {
    firewall_name: ?[]const u8 = null,
    firewall_arn: ?[]const u8 = null,
    firewall_policy_arn: []const u8,
    vpc_id: []const u8,
    subnet_mappings: []SubnetMapping,
    delete_protection: ?bool = null,
    subnet_change_protection: ?bool = null,
    firewall_policy_change_protection: ?bool = null,
    description: ?[]const u8 = null,
    firewall_id: []const u8,
    tags: ?[]Tag = null,
    encryption_configuration: ?EncryptionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .firewall_name = "FirewallName",
            .firewall_arn = "FirewallArn",
            .firewall_policy_arn = "FirewallPolicyArn",
            .vpc_id = "VpcId",
            .subnet_mappings = "SubnetMappings",
            .delete_protection = "DeleteProtection",
            .subnet_change_protection = "SubnetChangeProtection",
            .firewall_policy_change_protection = "FirewallPolicyChangeProtection",
            .description = "Description",
            .firewall_id = "FirewallId",
            .tags = "Tags",
            .encryption_configuration = "EncryptionConfiguration",
        };
        return @field(mappings, field_name);
    }
};
