const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-07-05";
pub const sdk_id: []const u8 = "NetworkManager";
pub const arn_namespace: ?[]const u8 = "networkmanager";
pub const endpoint_prefix: []const u8 = "networkmanager";
pub const sigv4_name: []const u8 = "networkmanager";
pub const name: []const u8 = "NetworkManager";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-07-05",
    sdk_id: []const u8 = "NetworkManager",
    arn_namespace: ?[]const u8 = "networkmanager",
    endpoint_prefix: []const u8 = "networkmanager",
    sigv4_name: []const u8 = "networkmanager",
    name: []const u8 = "NetworkManager",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_attachment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/attachments/{AttachmentId}/accept",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptAttachment",
    Request: type = struct {
        attachment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "AttachmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_attachment) } {
            return .{ .service_metadata = service_metadata, .action = accept_attachment };
        }
    },
    Response: type = struct {
        attachment: ?Attachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment = "Attachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_connect_peer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/connect-peer-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateConnectPeer",
    Request: type = struct {
        global_network_id: []const u8,
        connect_peer_id: []const u8,
        device_id: []const u8,
        link_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .connect_peer_id = "ConnectPeerId",
                .device_id = "DeviceId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = associate_connect_peer };
        }
    },
    Response: type = struct {
        connect_peer_association: ?ConnectPeerAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_peer_association = "ConnectPeerAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_customer_gateway: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/customer-gateway-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateCustomerGateway",
    Request: type = struct {
        customer_gateway_arn: []const u8,
        global_network_id: []const u8,
        device_id: []const u8,
        link_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_arn = "CustomerGatewayArn",
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_customer_gateway) } {
            return .{ .service_metadata = service_metadata, .action = associate_customer_gateway };
        }
    },
    Response: type = struct {
        customer_gateway_association: ?CustomerGatewayAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_association = "CustomerGatewayAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_link: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/link-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateLink",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: []const u8,
        link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_link) } {
            return .{ .service_metadata = service_metadata, .action = associate_link };
        }
    },
    Response: type = struct {
        link_association: ?LinkAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link_association = "LinkAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_transit_gateway_connect_peer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-connect-peer-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateTransitGatewayConnectPeer",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_connect_peer_arn: []const u8,
        device_id: []const u8,
        link_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_connect_peer_arn = "TransitGatewayConnectPeerArn",
                .device_id = "DeviceId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_transit_gateway_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = associate_transit_gateway_connect_peer };
        }
    },
    Response: type = struct {
        transit_gateway_connect_peer_association: ?TransitGatewayConnectPeerAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peer_association = "TransitGatewayConnectPeerAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_connect_attachment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/connect-attachments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConnectAttachment",
    Request: type = struct {
        core_network_id: []const u8,
        edge_location: []const u8,
        transport_attachment_id: []const u8,
        options: ConnectAttachmentOptions,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .edge_location = "EdgeLocation",
                .transport_attachment_id = "TransportAttachmentId",
                .options = "Options",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connect_attachment) } {
            return .{ .service_metadata = service_metadata, .action = create_connect_attachment };
        }
    },
    Response: type = struct {
        connect_attachment: ?ConnectAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_attachment = "ConnectAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_connection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/connections",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConnection",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: []const u8,
        connected_device_id: []const u8,
        link_id: ?[]const u8 = null,
        connected_link_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .connected_device_id = "ConnectedDeviceId",
                .link_id = "LinkId",
                .connected_link_id = "ConnectedLinkId",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_connect_peer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/connect-peers",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConnectPeer",
    Request: type = struct {
        connect_attachment_id: []const u8,
        core_network_address: ?[]const u8 = null,
        peer_address: []const u8,
        bgp_options: ?struct {
            peer_asn: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .peer_asn = "PeerAsn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        inside_cidr_blocks: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,
        subnet_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_attachment_id = "ConnectAttachmentId",
                .core_network_address = "CoreNetworkAddress",
                .peer_address = "PeerAddress",
                .bgp_options = "BgpOptions",
                .inside_cidr_blocks = "InsideCidrBlocks",
                .tags = "Tags",
                .client_token = "ClientToken",
                .subnet_arn = "SubnetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = create_connect_peer };
        }
    },
    Response: type = struct {
        connect_peer: ?ConnectPeer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_peer = "ConnectPeer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_core_network: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/core-networks",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCoreNetwork",
    Request: type = struct {
        global_network_id: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        policy_document: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .description = "Description",
                .tags = "Tags",
                .policy_document = "PolicyDocument",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_core_network) } {
            return .{ .service_metadata = service_metadata, .action = create_core_network };
        }
    },
    Response: type = struct {
        core_network: ?CoreNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network = "CoreNetwork",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        CoreNetworkPolicy,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDevice",
    Request: type = struct {
        global_network_id: []const u8,
        aws_location: ?AWSLocation = null,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        vendor: ?[]const u8 = null,
        model: ?[]const u8 = null,
        serial_number: ?[]const u8 = null,
        location: ?Location = null,
        site_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .aws_location = "AWSLocation",
                .description = "Description",
                .type = "Type",
                .vendor = "Vendor",
                .model = "Model",
                .serial_number = "SerialNumber",
                .location = "Location",
                .site_id = "SiteId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_device) } {
            return .{ .service_metadata = service_metadata, .action = create_device };
        }
    },
    Response: type = struct {
        device: ?Device = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "Device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_global_network: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGlobalNetwork",
    Request: type = struct {
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_global_network) } {
            return .{ .service_metadata = service_metadata, .action = create_global_network };
        }
    },
    Response: type = struct {
        global_network: ?GlobalNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network = "GlobalNetwork",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_link: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/links",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLink",
    Request: type = struct {
        global_network_id: []const u8,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        bandwidth: Bandwidth,
        provider: ?[]const u8 = null,
        site_id: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .description = "Description",
                .type = "Type",
                .bandwidth = "Bandwidth",
                .provider = "Provider",
                .site_id = "SiteId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_link) } {
            return .{ .service_metadata = service_metadata, .action = create_link };
        }
    },
    Response: type = struct {
        link: ?Link = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link = "Link",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_site: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/sites",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSite",
    Request: type = struct {
        global_network_id: []const u8,
        description: ?[]const u8 = null,
        location: ?Location = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .description = "Description",
                .location = "Location",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_site) } {
            return .{ .service_metadata = service_metadata, .action = create_site };
        }
    },
    Response: type = struct {
        site: ?Site = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "Site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_site_to_site_vpn_attachment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/site-to-site-vpn-attachments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSiteToSiteVpnAttachment",
    Request: type = struct {
        core_network_id: []const u8,
        vpn_connection_arn: []const u8,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .vpn_connection_arn = "VpnConnectionArn",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_site_to_site_vpn_attachment) } {
            return .{ .service_metadata = service_metadata, .action = create_site_to_site_vpn_attachment };
        }
    },
    Response: type = struct {
        site_to_site_vpn_attachment: ?SiteToSiteVpnAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site_to_site_vpn_attachment = "SiteToSiteVpnAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_transit_gateway_peering: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/transit-gateway-peerings",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTransitGatewayPeering",
    Request: type = struct {
        core_network_id: []const u8,
        transit_gateway_arn: []const u8,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .transit_gateway_arn = "TransitGatewayArn",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_peering) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_peering };
        }
    },
    Response: type = struct {
        transit_gateway_peering: ?TransitGatewayPeering = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_peering = "TransitGatewayPeering",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_transit_gateway_route_table_attachment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/transit-gateway-route-table-attachments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTransitGatewayRouteTableAttachment",
    Request: type = struct {
        peering_id: []const u8,
        transit_gateway_route_table_arn: []const u8,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .peering_id = "PeeringId",
                .transit_gateway_route_table_arn = "TransitGatewayRouteTableArn",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transit_gateway_route_table_attachment) } {
            return .{ .service_metadata = service_metadata, .action = create_transit_gateway_route_table_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_route_table_attachment: ?TransitGatewayRouteTableAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_attachment = "TransitGatewayRouteTableAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_vpc_attachment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/vpc-attachments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateVpcAttachment",
    Request: type = struct {
        core_network_id: []const u8,
        vpc_arn: []const u8,
        subnet_arns: [][]const u8,
        options: ?VpcOptions = null,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .vpc_arn = "VpcArn",
                .subnet_arns = "SubnetArns",
                .options = "Options",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_attachment) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_attachment };
        }
    },
    Response: type = struct {
        vpc_attachment: ?VpcAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_attachment = "VpcAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_attachment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/attachments/{AttachmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAttachment",
    Request: type = struct {
        attachment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "AttachmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_attachment) } {
            return .{ .service_metadata = service_metadata, .action = delete_attachment };
        }
    },
    Response: type = struct {
        attachment: ?Attachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment = "Attachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_connection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/connections/{ConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        global_network_id: []const u8,
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .connection_id = "ConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_connect_peer: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/connect-peers/{ConnectPeerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConnectPeer",
    Request: type = struct {
        connect_peer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_peer_id = "ConnectPeerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = delete_connect_peer };
        }
    },
    Response: type = struct {
        connect_peer: ?ConnectPeer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_peer = "ConnectPeer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_core_network: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/core-networks/{CoreNetworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCoreNetwork",
    Request: type = struct {
        core_network_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_core_network) } {
            return .{ .service_metadata = service_metadata, .action = delete_core_network };
        }
    },
    Response: type = struct {
        core_network: ?CoreNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network = "CoreNetwork",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_core_network_policy_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/core-networks/{CoreNetworkId}/core-network-policy-versions/{PolicyVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCoreNetworkPolicyVersion",
    Request: type = struct {
        core_network_id: []const u8,
        policy_version_id: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .policy_version_id = "PolicyVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_core_network_policy_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_core_network_policy_version };
        }
    },
    Response: type = struct {
        core_network_policy: ?CoreNetworkPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_policy = "CoreNetworkPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_device: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/devices/{DeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDevice",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_device) } {
            return .{ .service_metadata = service_metadata, .action = delete_device };
        }
    },
    Response: type = struct {
        device: ?Device = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "Device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_global_network: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGlobalNetwork",
    Request: type = struct {
        global_network_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_global_network) } {
            return .{ .service_metadata = service_metadata, .action = delete_global_network };
        }
    },
    Response: type = struct {
        global_network: ?GlobalNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network = "GlobalNetwork",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_link: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/links/{LinkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLink",
    Request: type = struct {
        global_network_id: []const u8,
        link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_link) } {
            return .{ .service_metadata = service_metadata, .action = delete_link };
        }
    },
    Response: type = struct {
        link: ?Link = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link = "Link",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_peering: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/peerings/{PeeringId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePeering",
    Request: type = struct {
        peering_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .peering_id = "PeeringId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_peering) } {
            return .{ .service_metadata = service_metadata, .action = delete_peering };
        }
    },
    Response: type = struct {
        peering: ?Peering = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .peering = "Peering",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resource_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/resource-policy/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_site: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/sites/{SiteId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSite",
    Request: type = struct {
        global_network_id: []const u8,
        site_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .site_id = "SiteId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_site) } {
            return .{ .service_metadata = service_metadata, .action = delete_site };
        }
    },
    Response: type = struct {
        site: ?Site = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "Site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const deregister_transit_gateway: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-registrations/{TransitGatewayArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterTransitGateway",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_arn = "TransitGatewayArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_transit_gateway) } {
            return .{ .service_metadata = service_metadata, .action = deregister_transit_gateway };
        }
    },
    Response: type = struct {
        transit_gateway_registration: ?TransitGatewayRegistration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_registration = "TransitGatewayRegistration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_global_networks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGlobalNetworks",
    Request: type = struct {
        global_network_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .global_network_ids = "globalNetworkIds",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_ids = "GlobalNetworkIds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_global_networks) } {
            return .{ .service_metadata = service_metadata, .action = describe_global_networks };
        }
    },
    Response: type = struct {
        global_networks: ?[]GlobalNetwork = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_networks = "GlobalNetworks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_connect_peer: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/connect-peer-associations/{ConnectPeerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateConnectPeer",
    Request: type = struct {
        global_network_id: []const u8,
        connect_peer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .connect_peer_id = "ConnectPeerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_connect_peer };
        }
    },
    Response: type = struct {
        connect_peer_association: ?ConnectPeerAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_peer_association = "ConnectPeerAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_customer_gateway: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/customer-gateway-associations/{CustomerGatewayArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateCustomerGateway",
    Request: type = struct {
        global_network_id: []const u8,
        customer_gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .customer_gateway_arn = "CustomerGatewayArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_customer_gateway) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_customer_gateway };
        }
    },
    Response: type = struct {
        customer_gateway_association: ?CustomerGatewayAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_association = "CustomerGatewayAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_link: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/link-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateLink",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: []const u8,
        link_id: []const u8,

        pub const http_query = .{
            .device_id = "deviceId",
            .link_id = "linkId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .link_id = "LinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_link) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_link };
        }
    },
    Response: type = struct {
        link_association: ?LinkAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link_association = "LinkAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_transit_gateway_connect_peer: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-connect-peer-associations/{TransitGatewayConnectPeerArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateTransitGatewayConnectPeer",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_connect_peer_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_connect_peer_arn = "TransitGatewayConnectPeerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_transit_gateway_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_transit_gateway_connect_peer };
        }
    },
    Response: type = struct {
        transit_gateway_connect_peer_association: ?TransitGatewayConnectPeerAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peer_association = "TransitGatewayConnectPeerAssociation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const execute_core_network_change_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/core-networks/{CoreNetworkId}/core-network-change-sets/{PolicyVersionId}/execute",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteCoreNetworkChangeSet",
    Request: type = struct {
        core_network_id: []const u8,
        policy_version_id: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .policy_version_id = "PolicyVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_core_network_change_set) } {
            return .{ .service_metadata = service_metadata, .action = execute_core_network_change_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_connect_attachment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/connect-attachments/{AttachmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnectAttachment",
    Request: type = struct {
        attachment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "AttachmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connect_attachment) } {
            return .{ .service_metadata = service_metadata, .action = get_connect_attachment };
        }
    },
    Response: type = struct {
        connect_attachment: ?ConnectAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_attachment = "ConnectAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_connections: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/connections",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnections",
    Request: type = struct {
        global_network_id: []const u8,
        connection_ids: ?[][]const u8 = null,
        device_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .connection_ids = "connectionIds",
            .device_id = "deviceId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .connection_ids = "ConnectionIds",
                .device_id = "DeviceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connections) } {
            return .{ .service_metadata = service_metadata, .action = get_connections };
        }
    },
    Response: type = struct {
        connections: ?[]Connection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "Connections",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_connect_peer: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/connect-peers/{ConnectPeerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnectPeer",
    Request: type = struct {
        connect_peer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_peer_id = "ConnectPeerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connect_peer) } {
            return .{ .service_metadata = service_metadata, .action = get_connect_peer };
        }
    },
    Response: type = struct {
        connect_peer: ?ConnectPeer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_peer = "ConnectPeer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_connect_peer_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/connect-peer-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnectPeerAssociations",
    Request: type = struct {
        global_network_id: []const u8,
        connect_peer_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .connect_peer_ids = "connectPeerIds",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .connect_peer_ids = "ConnectPeerIds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connect_peer_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_connect_peer_associations };
        }
    },
    Response: type = struct {
        connect_peer_associations: ?[]ConnectPeerAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_peer_associations = "ConnectPeerAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_core_network: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/core-networks/{CoreNetworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCoreNetwork",
    Request: type = struct {
        core_network_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_core_network) } {
            return .{ .service_metadata = service_metadata, .action = get_core_network };
        }
    },
    Response: type = struct {
        core_network: ?CoreNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network = "CoreNetwork",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_core_network_change_events: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/core-networks/{CoreNetworkId}/core-network-change-events/{PolicyVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCoreNetworkChangeEvents",
    Request: type = struct {
        core_network_id: []const u8,
        policy_version_id: i64,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .policy_version_id = "PolicyVersionId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_core_network_change_events) } {
            return .{ .service_metadata = service_metadata, .action = get_core_network_change_events };
        }
    },
    Response: type = struct {
        core_network_change_events: ?[]struct {
            type: ?[]const u8 = null,
            action: ?[]const u8 = null,
            identifier_path: ?[]const u8 = null,
            event_time: ?i64 = null,
            status: ?[]const u8 = null,
            values: ?struct {
                edge_location: ?[]const u8 = null,
                segment_name: ?[]const u8 = null,
                attachment_id: ?[]const u8 = null,
                cidr: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .edge_location = "EdgeLocation",
                        .segment_name = "SegmentName",
                        .attachment_id = "AttachmentId",
                        .cidr = "Cidr",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .action = "Action",
                    .identifier_path = "IdentifierPath",
                    .event_time = "EventTime",
                    .status = "Status",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_change_events = "CoreNetworkChangeEvents",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_core_network_change_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/core-networks/{CoreNetworkId}/core-network-change-sets/{PolicyVersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCoreNetworkChangeSet",
    Request: type = struct {
        core_network_id: []const u8,
        policy_version_id: i64,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .policy_version_id = "PolicyVersionId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_core_network_change_set) } {
            return .{ .service_metadata = service_metadata, .action = get_core_network_change_set };
        }
    },
    Response: type = struct {
        core_network_changes: ?[]struct {
            type: ?[]const u8 = null,
            action: ?[]const u8 = null,
            identifier: ?[]const u8 = null,
            previous_values: ?CoreNetworkChangeValues = null,
            new_values: ?CoreNetworkChangeValues = null,
            identifier_path: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .action = "Action",
                    .identifier = "Identifier",
                    .previous_values = "PreviousValues",
                    .new_values = "NewValues",
                    .identifier_path = "IdentifierPath",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_changes = "CoreNetworkChanges",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_core_network_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/core-networks/{CoreNetworkId}/core-network-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCoreNetworkPolicy",
    Request: type = struct {
        core_network_id: []const u8,
        policy_version_id: ?i64 = null,
        alias: ?[]const u8 = null,

        pub const http_query = .{
            .policy_version_id = "policyVersionId",
            .alias = "alias",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .policy_version_id = "PolicyVersionId",
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_core_network_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_core_network_policy };
        }
    },
    Response: type = struct {
        core_network_policy: ?CoreNetworkPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_policy = "CoreNetworkPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_customer_gateway_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/customer-gateway-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCustomerGatewayAssociations",
    Request: type = struct {
        global_network_id: []const u8,
        customer_gateway_arns: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .customer_gateway_arns = "customerGatewayArns",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .customer_gateway_arns = "CustomerGatewayArns",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_customer_gateway_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_customer_gateway_associations };
        }
    },
    Response: type = struct {
        customer_gateway_associations: ?[]CustomerGatewayAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_gateway_associations = "CustomerGatewayAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_devices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDevices",
    Request: type = struct {
        global_network_id: []const u8,
        device_ids: ?[][]const u8 = null,
        site_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .device_ids = "deviceIds",
            .site_id = "siteId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_ids = "DeviceIds",
                .site_id = "SiteId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_devices) } {
            return .{ .service_metadata = service_metadata, .action = get_devices };
        }
    },
    Response: type = struct {
        devices: ?[]Device = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .devices = "Devices",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_link_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/link-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLinkAssociations",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: ?[]const u8 = null,
        link_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .device_id = "deviceId",
            .link_id = "linkId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .link_id = "LinkId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_link_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_link_associations };
        }
    },
    Response: type = struct {
        link_associations: ?[]LinkAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link_associations = "LinkAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_links: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/links",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLinks",
    Request: type = struct {
        global_network_id: []const u8,
        link_ids: ?[][]const u8 = null,
        site_id: ?[]const u8 = null,
        type: ?[]const u8 = null,
        provider: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .link_ids = "linkIds",
            .site_id = "siteId",
            .type = "type",
            .provider = "provider",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .link_ids = "LinkIds",
                .site_id = "SiteId",
                .type = "Type",
                .provider = "Provider",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_links) } {
            return .{ .service_metadata = service_metadata, .action = get_links };
        }
    },
    Response: type = struct {
        links: ?[]Link = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .links = "Links",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_network_resource_counts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/network-resource-count",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNetworkResourceCounts",
    Request: type = struct {
        global_network_id: []const u8,
        resource_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .resource_type = "resourceType",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .resource_type = "ResourceType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_resource_counts) } {
            return .{ .service_metadata = service_metadata, .action = get_network_resource_counts };
        }
    },
    Response: type = struct {
        network_resource_counts: ?[]struct {
            resource_type: ?[]const u8 = null,
            count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "ResourceType",
                    .count = "Count",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_resource_counts = "NetworkResourceCounts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_network_resource_relationships: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/network-resource-relationships",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNetworkResourceRelationships",
    Request: type = struct {
        global_network_id: []const u8,
        core_network_id: ?[]const u8 = null,
        registered_gateway_arn: ?[]const u8 = null,
        aws_region: ?[]const u8 = null,
        account_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .core_network_id = "coreNetworkId",
            .registered_gateway_arn = "registeredGatewayArn",
            .aws_region = "awsRegion",
            .account_id = "accountId",
            .resource_type = "resourceType",
            .resource_arn = "resourceArn",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .core_network_id = "CoreNetworkId",
                .registered_gateway_arn = "RegisteredGatewayArn",
                .aws_region = "AwsRegion",
                .account_id = "AccountId",
                .resource_type = "ResourceType",
                .resource_arn = "ResourceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_resource_relationships) } {
            return .{ .service_metadata = service_metadata, .action = get_network_resource_relationships };
        }
    },
    Response: type = struct {
        relationships: ?[]struct {
            from: ?[]const u8 = null,
            to: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .from = "From",
                    .to = "To",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .relationships = "Relationships",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_network_resources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/network-resources",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNetworkResources",
    Request: type = struct {
        global_network_id: []const u8,
        core_network_id: ?[]const u8 = null,
        registered_gateway_arn: ?[]const u8 = null,
        aws_region: ?[]const u8 = null,
        account_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .core_network_id = "coreNetworkId",
            .registered_gateway_arn = "registeredGatewayArn",
            .aws_region = "awsRegion",
            .account_id = "accountId",
            .resource_type = "resourceType",
            .resource_arn = "resourceArn",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .core_network_id = "CoreNetworkId",
                .registered_gateway_arn = "RegisteredGatewayArn",
                .aws_region = "AwsRegion",
                .account_id = "AccountId",
                .resource_type = "ResourceType",
                .resource_arn = "ResourceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_resources) } {
            return .{ .service_metadata = service_metadata, .action = get_network_resources };
        }
    },
    Response: type = struct {
        network_resources: ?[]struct {
            registered_gateway_arn: ?[]const u8 = null,
            core_network_id: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            definition: ?[]const u8 = null,
            definition_timestamp: ?i64 = null,
            tags: ?[]Tag = null,
            metadata: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registered_gateway_arn = "RegisteredGatewayArn",
                    .core_network_id = "CoreNetworkId",
                    .aws_region = "AwsRegion",
                    .account_id = "AccountId",
                    .resource_type = "ResourceType",
                    .resource_id = "ResourceId",
                    .resource_arn = "ResourceArn",
                    .definition = "Definition",
                    .definition_timestamp = "DefinitionTimestamp",
                    .tags = "Tags",
                    .metadata = "Metadata",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "metadata", field_name))
                    return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_resources = "NetworkResources",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_network_routes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/network-routes",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNetworkRoutes",
    Request: type = struct {
        global_network_id: []const u8,
        route_table_identifier: struct {
            transit_gateway_route_table_arn: ?[]const u8 = null,
            core_network_segment_edge: ?CoreNetworkSegmentEdgeIdentifier = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transit_gateway_route_table_arn = "TransitGatewayRouteTableArn",
                    .core_network_segment_edge = "CoreNetworkSegmentEdge",
                };
                return @field(mappings, field_name);
            }
        },
        exact_cidr_matches: ?[][]const u8 = null,
        longest_prefix_matches: ?[][]const u8 = null,
        subnet_of_matches: ?[][]const u8 = null,
        supernet_of_matches: ?[][]const u8 = null,
        prefix_list_ids: ?[][]const u8 = null,
        states: ?[][]const u8 = null,
        types: ?[][]const u8 = null,
        destination_filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .route_table_identifier = "RouteTableIdentifier",
                .exact_cidr_matches = "ExactCidrMatches",
                .longest_prefix_matches = "LongestPrefixMatches",
                .subnet_of_matches = "SubnetOfMatches",
                .supernet_of_matches = "SupernetOfMatches",
                .prefix_list_ids = "PrefixListIds",
                .states = "States",
                .types = "Types",
                .destination_filters = "DestinationFilters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "destination_filters", field_name))
                return try serializeMap(self.destination_filters, self.fieldNameFor("destination_filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_routes) } {
            return .{ .service_metadata = service_metadata, .action = get_network_routes };
        }
    },
    Response: type = struct {
        route_table_arn: ?[]const u8 = null,
        core_network_segment_edge: ?CoreNetworkSegmentEdgeIdentifier = null,
        route_table_type: ?[]const u8 = null,
        route_table_timestamp: ?i64 = null,
        network_routes: ?[]struct {
            destination_cidr_block: ?[]const u8 = null,
            destinations: ?[]struct {
                core_network_attachment_id: ?[]const u8 = null,
                transit_gateway_attachment_id: ?[]const u8 = null,
                segment_name: ?[]const u8 = null,
                edge_location: ?[]const u8 = null,
                resource_type: ?[]const u8 = null,
                resource_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .core_network_attachment_id = "CoreNetworkAttachmentId",
                        .transit_gateway_attachment_id = "TransitGatewayAttachmentId",
                        .segment_name = "SegmentName",
                        .edge_location = "EdgeLocation",
                        .resource_type = "ResourceType",
                        .resource_id = "ResourceId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            prefix_list_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .destination_cidr_block = "DestinationCidrBlock",
                    .destinations = "Destinations",
                    .prefix_list_id = "PrefixListId",
                    .state = "State",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route_table_arn = "RouteTableArn",
                .core_network_segment_edge = "CoreNetworkSegmentEdge",
                .route_table_type = "RouteTableType",
                .route_table_timestamp = "RouteTableTimestamp",
                .network_routes = "NetworkRoutes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_network_telemetry: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/network-telemetry",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNetworkTelemetry",
    Request: type = struct {
        global_network_id: []const u8,
        core_network_id: ?[]const u8 = null,
        registered_gateway_arn: ?[]const u8 = null,
        aws_region: ?[]const u8 = null,
        account_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .core_network_id = "coreNetworkId",
            .registered_gateway_arn = "registeredGatewayArn",
            .aws_region = "awsRegion",
            .account_id = "accountId",
            .resource_type = "resourceType",
            .resource_arn = "resourceArn",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .core_network_id = "CoreNetworkId",
                .registered_gateway_arn = "RegisteredGatewayArn",
                .aws_region = "AwsRegion",
                .account_id = "AccountId",
                .resource_type = "ResourceType",
                .resource_arn = "ResourceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_telemetry) } {
            return .{ .service_metadata = service_metadata, .action = get_network_telemetry };
        }
    },
    Response: type = struct {
        network_telemetry: ?[]struct {
            registered_gateway_arn: ?[]const u8 = null,
            core_network_id: ?[]const u8 = null,
            aws_region: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            address: ?[]const u8 = null,
            health: ?struct {
                type: ?[]const u8 = null,
                status: ?[]const u8 = null,
                timestamp: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .status = "Status",
                        .timestamp = "Timestamp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registered_gateway_arn = "RegisteredGatewayArn",
                    .core_network_id = "CoreNetworkId",
                    .aws_region = "AwsRegion",
                    .account_id = "AccountId",
                    .resource_type = "ResourceType",
                    .resource_id = "ResourceId",
                    .resource_arn = "ResourceArn",
                    .address = "Address",
                    .health = "Health",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_telemetry = "NetworkTelemetry",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resource-policy/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        policy_document: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_document = "PolicyDocument",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_route_analysis: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/route-analyses/{RouteAnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRouteAnalysis",
    Request: type = struct {
        global_network_id: []const u8,
        route_analysis_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .route_analysis_id = "RouteAnalysisId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_route_analysis) } {
            return .{ .service_metadata = service_metadata, .action = get_route_analysis };
        }
    },
    Response: type = struct {
        route_analysis: ?RouteAnalysis = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route_analysis = "RouteAnalysis",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sites: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/sites",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSites",
    Request: type = struct {
        global_network_id: []const u8,
        site_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .site_ids = "siteIds",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .site_ids = "SiteIds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sites) } {
            return .{ .service_metadata = service_metadata, .action = get_sites };
        }
    },
    Response: type = struct {
        sites: ?[]Site = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sites = "Sites",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_site_to_site_vpn_attachment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/site-to-site-vpn-attachments/{AttachmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSiteToSiteVpnAttachment",
    Request: type = struct {
        attachment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "AttachmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_site_to_site_vpn_attachment) } {
            return .{ .service_metadata = service_metadata, .action = get_site_to_site_vpn_attachment };
        }
    },
    Response: type = struct {
        site_to_site_vpn_attachment: ?SiteToSiteVpnAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site_to_site_vpn_attachment = "SiteToSiteVpnAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_transit_gateway_connect_peer_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-connect-peer-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTransitGatewayConnectPeerAssociations",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_connect_peer_arns: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .transit_gateway_connect_peer_arns = "transitGatewayConnectPeerArns",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_connect_peer_arns = "TransitGatewayConnectPeerArns",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_connect_peer_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_connect_peer_associations };
        }
    },
    Response: type = struct {
        transit_gateway_connect_peer_associations: ?[]TransitGatewayConnectPeerAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_connect_peer_associations = "TransitGatewayConnectPeerAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_transit_gateway_peering: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/transit-gateway-peerings/{PeeringId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTransitGatewayPeering",
    Request: type = struct {
        peering_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .peering_id = "PeeringId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_peering) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_peering };
        }
    },
    Response: type = struct {
        transit_gateway_peering: ?TransitGatewayPeering = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_peering = "TransitGatewayPeering",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_transit_gateway_registrations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-registrations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTransitGatewayRegistrations",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_arns: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .transit_gateway_arns = "transitGatewayArns",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_arns = "TransitGatewayArns",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_registrations) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_registrations };
        }
    },
    Response: type = struct {
        transit_gateway_registrations: ?[]TransitGatewayRegistration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_registrations = "TransitGatewayRegistrations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_transit_gateway_route_table_attachment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/transit-gateway-route-table-attachments/{AttachmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTransitGatewayRouteTableAttachment",
    Request: type = struct {
        attachment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "AttachmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transit_gateway_route_table_attachment) } {
            return .{ .service_metadata = service_metadata, .action = get_transit_gateway_route_table_attachment };
        }
    },
    Response: type = struct {
        transit_gateway_route_table_attachment: ?TransitGatewayRouteTableAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_route_table_attachment = "TransitGatewayRouteTableAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_vpc_attachment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/vpc-attachments/{AttachmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVpcAttachment",
    Request: type = struct {
        attachment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "AttachmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vpc_attachment) } {
            return .{ .service_metadata = service_metadata, .action = get_vpc_attachment };
        }
    },
    Response: type = struct {
        vpc_attachment: ?VpcAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_attachment = "VpcAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_attachments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/attachments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAttachments",
    Request: type = struct {
        core_network_id: ?[]const u8 = null,
        attachment_type: ?[]const u8 = null,
        edge_location: ?[]const u8 = null,
        state: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .core_network_id = "coreNetworkId",
            .attachment_type = "attachmentType",
            .edge_location = "edgeLocation",
            .state = "state",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .attachment_type = "AttachmentType",
                .edge_location = "EdgeLocation",
                .state = "State",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_attachments) } {
            return .{ .service_metadata = service_metadata, .action = list_attachments };
        }
    },
    Response: type = struct {
        attachments: ?[]Attachment = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachments = "Attachments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_connect_peers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/connect-peers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConnectPeers",
    Request: type = struct {
        core_network_id: ?[]const u8 = null,
        connect_attachment_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .core_network_id = "coreNetworkId",
            .connect_attachment_id = "connectAttachmentId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .connect_attachment_id = "ConnectAttachmentId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connect_peers) } {
            return .{ .service_metadata = service_metadata, .action = list_connect_peers };
        }
    },
    Response: type = struct {
        connect_peers: ?[]struct {
            core_network_id: ?[]const u8 = null,
            connect_attachment_id: ?[]const u8 = null,
            connect_peer_id: ?[]const u8 = null,
            edge_location: ?[]const u8 = null,
            connect_peer_state: ?[]const u8 = null,
            created_at: ?i64 = null,
            tags: ?[]Tag = null,
            subnet_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .core_network_id = "CoreNetworkId",
                    .connect_attachment_id = "ConnectAttachmentId",
                    .connect_peer_id = "ConnectPeerId",
                    .edge_location = "EdgeLocation",
                    .connect_peer_state = "ConnectPeerState",
                    .created_at = "CreatedAt",
                    .tags = "Tags",
                    .subnet_arn = "SubnetArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connect_peers = "ConnectPeers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_core_network_policy_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/core-networks/{CoreNetworkId}/core-network-policy-versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCoreNetworkPolicyVersions",
    Request: type = struct {
        core_network_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_core_network_policy_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_core_network_policy_versions };
        }
    },
    Response: type = struct {
        core_network_policy_versions: ?[]struct {
            core_network_id: ?[]const u8 = null,
            policy_version_id: ?i64 = null,
            alias: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_at: ?i64 = null,
            change_set_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .core_network_id = "CoreNetworkId",
                    .policy_version_id = "PolicyVersionId",
                    .alias = "Alias",
                    .description = "Description",
                    .created_at = "CreatedAt",
                    .change_set_state = "ChangeSetState",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_policy_versions = "CoreNetworkPolicyVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_core_networks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/core-networks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCoreNetworks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_core_networks) } {
            return .{ .service_metadata = service_metadata, .action = list_core_networks };
        }
    },
    Response: type = struct {
        core_networks: ?[]struct {
            core_network_id: ?[]const u8 = null,
            core_network_arn: ?[]const u8 = null,
            global_network_id: ?[]const u8 = null,
            owner_account_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            description: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .core_network_id = "CoreNetworkId",
                    .core_network_arn = "CoreNetworkArn",
                    .global_network_id = "GlobalNetworkId",
                    .owner_account_id = "OwnerAccountId",
                    .state = "State",
                    .description = "Description",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_networks = "CoreNetworks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_organization_service_access_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/organizations/service-access",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrganizationServiceAccessStatus",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_service_access_status) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_service_access_status };
        }
    },
    Response: type = struct {
        organization_status: ?OrganizationStatus = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_status = "OrganizationStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_peerings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/peerings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPeerings",
    Request: type = struct {
        core_network_id: ?[]const u8 = null,
        peering_type: ?[]const u8 = null,
        edge_location: ?[]const u8 = null,
        state: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .core_network_id = "coreNetworkId",
            .peering_type = "peeringType",
            .edge_location = "edgeLocation",
            .state = "state",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .peering_type = "PeeringType",
                .edge_location = "EdgeLocation",
                .state = "State",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_peerings) } {
            return .{ .service_metadata = service_metadata, .action = list_peerings };
        }
    },
    Response: type = struct {
        peerings: ?[]Peering = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .peerings = "Peerings",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_core_network_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/core-networks/{CoreNetworkId}/core-network-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutCoreNetworkPolicy",
    Request: type = struct {
        core_network_id: []const u8,
        policy_document: []const u8,
        description: ?[]const u8 = null,
        latest_version_id: ?i64 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .policy_document = "PolicyDocument",
                .description = "Description",
                .latest_version_id = "LatestVersionId",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_core_network_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_core_network_policy };
        }
    },
    Response: type = struct {
        core_network_policy: ?CoreNetworkPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_policy = "CoreNetworkPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        CoreNetworkPolicy,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_resource_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/resource-policy/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        policy_document: []const u8,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_document = "PolicyDocument",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const register_transit_gateway: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/transit-gateway-registrations",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterTransitGateway",
    Request: type = struct {
        global_network_id: []const u8,
        transit_gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .transit_gateway_arn = "TransitGatewayArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_transit_gateway) } {
            return .{ .service_metadata = service_metadata, .action = register_transit_gateway };
        }
    },
    Response: type = struct {
        transit_gateway_registration: ?TransitGatewayRegistration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transit_gateway_registration = "TransitGatewayRegistration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const reject_attachment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/attachments/{AttachmentId}/reject",
        .success_code = 200,
    };

    action_name: []const u8 = "RejectAttachment",
    Request: type = struct {
        attachment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "AttachmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_attachment) } {
            return .{ .service_metadata = service_metadata, .action = reject_attachment };
        }
    },
    Response: type = struct {
        attachment: ?Attachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment = "Attachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const restore_core_network_policy_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/core-networks/{CoreNetworkId}/core-network-policy-versions/{PolicyVersionId}/restore",
        .success_code = 200,
    };

    action_name: []const u8 = "RestoreCoreNetworkPolicyVersion",
    Request: type = struct {
        core_network_id: []const u8,
        policy_version_id: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .policy_version_id = "PolicyVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_core_network_policy_version) } {
            return .{ .service_metadata = service_metadata, .action = restore_core_network_policy_version };
        }
    },
    Response: type = struct {
        core_network_policy: ?CoreNetworkPolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_policy = "CoreNetworkPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_organization_service_access_update: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/organizations/service-access",
        .success_code = 200,
    };

    action_name: []const u8 = "StartOrganizationServiceAccessUpdate",
    Request: type = struct {
        action: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "Action",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_organization_service_access_update) } {
            return .{ .service_metadata = service_metadata, .action = start_organization_service_access_update };
        }
    },
    Response: type = struct {
        organization_status: ?OrganizationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_status = "OrganizationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_route_analysis: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/global-networks/{GlobalNetworkId}/route-analyses",
        .success_code = 200,
    };

    action_name: []const u8 = "StartRouteAnalysis",
    Request: type = struct {
        global_network_id: []const u8,
        source: RouteAnalysisEndpointOptionsSpecification,
        destination: RouteAnalysisEndpointOptionsSpecification,
        include_return_path: ?bool = null,
        use_middleboxes: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .source = "Source",
                .destination = "Destination",
                .include_return_path = "IncludeReturnPath",
                .use_middleboxes = "UseMiddleboxes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_route_analysis) } {
            return .{ .service_metadata = service_metadata, .action = start_route_analysis };
        }
    },
    Response: type = struct {
        route_analysis: ?RouteAnalysis = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .route_analysis = "RouteAnalysis",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_connection: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}/connections/{ConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConnection",
    Request: type = struct {
        global_network_id: []const u8,
        connection_id: []const u8,
        link_id: ?[]const u8 = null,
        connected_link_id: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .connection_id = "ConnectionId",
                .link_id = "LinkId",
                .connected_link_id = "ConnectedLinkId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connection) } {
            return .{ .service_metadata = service_metadata, .action = update_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_core_network: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/core-networks/{CoreNetworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCoreNetwork",
    Request: type = struct {
        core_network_id: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network_id = "CoreNetworkId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_core_network) } {
            return .{ .service_metadata = service_metadata, .action = update_core_network };
        }
    },
    Response: type = struct {
        core_network: ?CoreNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .core_network = "CoreNetwork",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_device: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}/devices/{DeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDevice",
    Request: type = struct {
        global_network_id: []const u8,
        device_id: []const u8,
        aws_location: ?AWSLocation = null,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        vendor: ?[]const u8 = null,
        model: ?[]const u8 = null,
        serial_number: ?[]const u8 = null,
        location: ?Location = null,
        site_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .device_id = "DeviceId",
                .aws_location = "AWSLocation",
                .description = "Description",
                .type = "Type",
                .vendor = "Vendor",
                .model = "Model",
                .serial_number = "SerialNumber",
                .location = "Location",
                .site_id = "SiteId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device) } {
            return .{ .service_metadata = service_metadata, .action = update_device };
        }
    },
    Response: type = struct {
        device: ?Device = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "Device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_global_network: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGlobalNetwork",
    Request: type = struct {
        global_network_id: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_global_network) } {
            return .{ .service_metadata = service_metadata, .action = update_global_network };
        }
    },
    Response: type = struct {
        global_network: ?GlobalNetwork = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network = "GlobalNetwork",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_link: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}/links/{LinkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLink",
    Request: type = struct {
        global_network_id: []const u8,
        link_id: []const u8,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        bandwidth: ?Bandwidth = null,
        provider: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .link_id = "LinkId",
                .description = "Description",
                .type = "Type",
                .bandwidth = "Bandwidth",
                .provider = "Provider",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_link) } {
            return .{ .service_metadata = service_metadata, .action = update_link };
        }
    },
    Response: type = struct {
        link: ?Link = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .link = "Link",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_network_resource_metadata: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}/network-resources/{ResourceArn}/metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateNetworkResourceMetadata",
    Request: type = struct {
        global_network_id: []const u8,
        resource_arn: []const u8,
        metadata: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .resource_arn = "ResourceArn",
                .metadata = "Metadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_network_resource_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_network_resource_metadata };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .metadata = "Metadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_site: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-networks/{GlobalNetworkId}/sites/{SiteId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSite",
    Request: type = struct {
        global_network_id: []const u8,
        site_id: []const u8,
        description: ?[]const u8 = null,
        location: ?Location = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_network_id = "GlobalNetworkId",
                .site_id = "SiteId",
                .description = "Description",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_site) } {
            return .{ .service_metadata = service_metadata, .action = update_site };
        }
    },
    Response: type = struct {
        site: ?Site = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "Site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_vpc_attachment: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/vpc-attachments/{AttachmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVpcAttachment",
    Request: type = struct {
        attachment_id: []const u8,
        add_subnet_arns: ?[][]const u8 = null,
        remove_subnet_arns: ?[][]const u8 = null,
        options: ?VpcOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "AttachmentId",
                .add_subnet_arns = "AddSubnetArns",
                .remove_subnet_arns = "RemoveSubnetArns",
                .options = "Options",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vpc_attachment) } {
            return .{ .service_metadata = service_metadata, .action = update_vpc_attachment };
        }
    },
    Response: type = struct {
        vpc_attachment: ?VpcAttachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_attachment = "VpcAttachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const VpcAttachment = struct {
    attachment: ?Attachment = null,
    subnet_arns: ?[][]const u8 = null,
    options: ?VpcOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment = "Attachment",
            .subnet_arns = "SubnetArns",
            .options = "Options",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcOptions = struct {
    ipv6_support: ?bool = null,
    appliance_mode_support: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ipv6_support = "Ipv6Support",
            .appliance_mode_support = "ApplianceModeSupport",
        };
        return @field(mappings, field_name);
    }
};

pub const Attachment = struct {
    core_network_id: ?[]const u8 = null,
    core_network_arn: ?[]const u8 = null,
    attachment_id: ?[]const u8 = null,
    owner_account_id: ?[]const u8 = null,
    attachment_type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    edge_location: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    attachment_policy_rule_number: ?i64 = null,
    segment_name: ?[]const u8 = null,
    tags: ?[]Tag = null,
    proposed_segment_change: ?ProposedSegmentChange = null,
    created_at: ?i64 = null,
    updated_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_network_id = "CoreNetworkId",
            .core_network_arn = "CoreNetworkArn",
            .attachment_id = "AttachmentId",
            .owner_account_id = "OwnerAccountId",
            .attachment_type = "AttachmentType",
            .state = "State",
            .edge_location = "EdgeLocation",
            .resource_arn = "ResourceArn",
            .attachment_policy_rule_number = "AttachmentPolicyRuleNumber",
            .segment_name = "SegmentName",
            .tags = "Tags",
            .proposed_segment_change = "ProposedSegmentChange",
            .created_at = "CreatedAt",
            .updated_at = "UpdatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const ProposedSegmentChange = struct {
    tags: ?[]Tag = null,
    attachment_policy_rule_number: ?i64 = null,
    segment_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tags = "Tags",
            .attachment_policy_rule_number = "AttachmentPolicyRuleNumber",
            .segment_name = "SegmentName",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Site = struct {
    site_id: ?[]const u8 = null,
    site_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    location: ?Location = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .site_id = "SiteId",
            .site_arn = "SiteArn",
            .global_network_id = "GlobalNetworkId",
            .description = "Description",
            .location = "Location",
            .created_at = "CreatedAt",
            .state = "State",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Location = struct {
    address: ?[]const u8 = null,
    latitude: ?[]const u8 = null,
    longitude: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address = "Address",
            .latitude = "Latitude",
            .longitude = "Longitude",
        };
        return @field(mappings, field_name);
    }
};

pub const Link = struct {
    link_id: ?[]const u8 = null,
    link_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    site_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    bandwidth: ?Bandwidth = null,
    provider: ?[]const u8 = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .link_id = "LinkId",
            .link_arn = "LinkArn",
            .global_network_id = "GlobalNetworkId",
            .site_id = "SiteId",
            .description = "Description",
            .type = "Type",
            .bandwidth = "Bandwidth",
            .provider = "Provider",
            .created_at = "CreatedAt",
            .state = "State",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Bandwidth = struct {
    upload_speed: ?i64 = null,
    download_speed: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .upload_speed = "UploadSpeed",
            .download_speed = "DownloadSpeed",
        };
        return @field(mappings, field_name);
    }
};

pub const GlobalNetwork = struct {
    global_network_id: ?[]const u8 = null,
    global_network_arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_network_id = "GlobalNetworkId",
            .global_network_arn = "GlobalNetworkArn",
            .description = "Description",
            .created_at = "CreatedAt",
            .state = "State",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Device = struct {
    device_id: ?[]const u8 = null,
    device_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    aws_location: ?AWSLocation = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    vendor: ?[]const u8 = null,
    model: ?[]const u8 = null,
    serial_number: ?[]const u8 = null,
    location: ?Location = null,
    site_id: ?[]const u8 = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_id = "DeviceId",
            .device_arn = "DeviceArn",
            .global_network_id = "GlobalNetworkId",
            .aws_location = "AWSLocation",
            .description = "Description",
            .type = "Type",
            .vendor = "Vendor",
            .model = "Model",
            .serial_number = "SerialNumber",
            .location = "Location",
            .site_id = "SiteId",
            .created_at = "CreatedAt",
            .state = "State",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const AWSLocation = struct {
    zone: ?[]const u8 = null,
    subnet_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .zone = "Zone",
            .subnet_arn = "SubnetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CoreNetwork = struct {
    global_network_id: ?[]const u8 = null,
    core_network_id: ?[]const u8 = null,
    core_network_arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    segments: ?[]CoreNetworkSegment = null,
    edges: ?[]CoreNetworkEdge = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_network_id = "GlobalNetworkId",
            .core_network_id = "CoreNetworkId",
            .core_network_arn = "CoreNetworkArn",
            .description = "Description",
            .created_at = "CreatedAt",
            .state = "State",
            .segments = "Segments",
            .edges = "Edges",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const CoreNetworkEdge = struct {
    edge_location: ?[]const u8 = null,
    asn: ?i64 = null,
    inside_cidr_blocks: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .edge_location = "EdgeLocation",
            .asn = "Asn",
            .inside_cidr_blocks = "InsideCidrBlocks",
        };
        return @field(mappings, field_name);
    }
};

pub const CoreNetworkSegment = struct {
    name: ?[]const u8 = null,
    edge_locations: ?[][]const u8 = null,
    shared_segments: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .edge_locations = "EdgeLocations",
            .shared_segments = "SharedSegments",
        };
        return @field(mappings, field_name);
    }
};

pub const Connection = struct {
    connection_id: ?[]const u8 = null,
    connection_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    connected_device_id: ?[]const u8 = null,
    link_id: ?[]const u8 = null,
    connected_link_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_at: ?i64 = null,
    state: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_id = "ConnectionId",
            .connection_arn = "ConnectionArn",
            .global_network_id = "GlobalNetworkId",
            .device_id = "DeviceId",
            .connected_device_id = "ConnectedDeviceId",
            .link_id = "LinkId",
            .connected_link_id = "ConnectedLinkId",
            .description = "Description",
            .created_at = "CreatedAt",
            .state = "State",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const RouteAnalysis = struct {
    global_network_id: ?[]const u8 = null,
    owner_account_id: ?[]const u8 = null,
    route_analysis_id: ?[]const u8 = null,
    start_timestamp: ?i64 = null,
    status: ?[]const u8 = null,
    source: ?RouteAnalysisEndpointOptions = null,
    destination: ?RouteAnalysisEndpointOptions = null,
    include_return_path: ?bool = null,
    use_middleboxes: ?bool = null,
    forward_path: ?RouteAnalysisPath = null,
    return_path: ?RouteAnalysisPath = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_network_id = "GlobalNetworkId",
            .owner_account_id = "OwnerAccountId",
            .route_analysis_id = "RouteAnalysisId",
            .start_timestamp = "StartTimestamp",
            .status = "Status",
            .source = "Source",
            .destination = "Destination",
            .include_return_path = "IncludeReturnPath",
            .use_middleboxes = "UseMiddleboxes",
            .forward_path = "ForwardPath",
            .return_path = "ReturnPath",
        };
        return @field(mappings, field_name);
    }
};

pub const RouteAnalysisPath = struct {
    completion_status: ?RouteAnalysisCompletion = null,
    path: ?[]PathComponent = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .completion_status = "CompletionStatus",
            .path = "Path",
        };
        return @field(mappings, field_name);
    }
};

pub const PathComponent = struct {
    sequence: ?i64 = null,
    resource: ?NetworkResourceSummary = null,
    destination_cidr_block: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sequence = "Sequence",
            .resource = "Resource",
            .destination_cidr_block = "DestinationCidrBlock",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkResourceSummary = struct {
    registered_gateway_arn: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    definition: ?[]const u8 = null,
    name_tag: ?[]const u8 = null,
    is_middlebox: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .registered_gateway_arn = "RegisteredGatewayArn",
            .resource_arn = "ResourceArn",
            .resource_type = "ResourceType",
            .definition = "Definition",
            .name_tag = "NameTag",
            .is_middlebox = "IsMiddlebox",
        };
        return @field(mappings, field_name);
    }
};

pub const RouteAnalysisCompletion = struct {
    result_code: ?[]const u8 = null,
    reason_code: ?[]const u8 = null,
    reason_context: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .result_code = "ResultCode",
            .reason_code = "ReasonCode",
            .reason_context = "ReasonContext",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "reason_context", field_name))
            return try serializeMap(self.reason_context, self.fieldNameFor("reason_context"), options, out_stream);
        return false;
    }
};

pub const RouteAnalysisEndpointOptions = struct {
    transit_gateway_attachment_arn: ?[]const u8 = null,
    transit_gateway_arn: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_attachment_arn = "TransitGatewayAttachmentArn",
            .transit_gateway_arn = "TransitGatewayArn",
            .ip_address = "IpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const RouteAnalysisEndpointOptionsSpecification = struct {
    transit_gateway_attachment_arn: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_attachment_arn = "TransitGatewayAttachmentArn",
            .ip_address = "IpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const OrganizationStatus = struct {
    organization_id: ?[]const u8 = null,
    organization_aws_service_access_status: ?[]const u8 = null,
    slr_deployment_status: ?[]const u8 = null,
    account_status_list: ?[]AccountStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .organization_id = "OrganizationId",
            .organization_aws_service_access_status = "OrganizationAwsServiceAccessStatus",
            .slr_deployment_status = "SLRDeploymentStatus",
            .account_status_list = "OrganizationStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountStatus = struct {
    account_id: ?[]const u8 = null,
    slr_deployment_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .slr_deployment_status = "SLRDeploymentStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const CoreNetworkPolicy = struct {
    core_network_id: ?[]const u8 = null,
    policy_version_id: ?i64 = null,
    alias: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_at: ?i64 = null,
    change_set_state: ?[]const u8 = null,
    policy_errors: ?[]CoreNetworkPolicyError = null,
    policy_document: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_network_id = "CoreNetworkId",
            .policy_version_id = "PolicyVersionId",
            .alias = "Alias",
            .description = "Description",
            .created_at = "CreatedAt",
            .change_set_state = "ChangeSetState",
            .policy_errors = "PolicyErrors",
            .policy_document = "PolicyDocument",
        };
        return @field(mappings, field_name);
    }
};

pub const CoreNetworkPolicyError = struct {
    error_code: []const u8,
    message: []const u8,
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .message = "Message",
            .path = "Path",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayRegistration = struct {
    global_network_id: ?[]const u8 = null,
    transit_gateway_arn: ?[]const u8 = null,
    state: ?TransitGatewayRegistrationStateReason = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_network_id = "GlobalNetworkId",
            .transit_gateway_arn = "TransitGatewayArn",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayRegistrationStateReason = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const Peering = struct {
    core_network_id: ?[]const u8 = null,
    core_network_arn: ?[]const u8 = null,
    peering_id: ?[]const u8 = null,
    owner_account_id: ?[]const u8 = null,
    peering_type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    edge_location: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    tags: ?[]Tag = null,
    created_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_network_id = "CoreNetworkId",
            .core_network_arn = "CoreNetworkArn",
            .peering_id = "PeeringId",
            .owner_account_id = "OwnerAccountId",
            .peering_type = "PeeringType",
            .state = "State",
            .edge_location = "EdgeLocation",
            .resource_arn = "ResourceArn",
            .tags = "Tags",
            .created_at = "CreatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayRouteTableAttachment = struct {
    attachment: ?Attachment = null,
    peering_id: ?[]const u8 = null,
    transit_gateway_route_table_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment = "Attachment",
            .peering_id = "PeeringId",
            .transit_gateway_route_table_arn = "TransitGatewayRouteTableArn",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayPeering = struct {
    peering: ?Peering = null,
    transit_gateway_arn: ?[]const u8 = null,
    transit_gateway_peering_attachment_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .peering = "Peering",
            .transit_gateway_arn = "TransitGatewayArn",
            .transit_gateway_peering_attachment_id = "TransitGatewayPeeringAttachmentId",
        };
        return @field(mappings, field_name);
    }
};

pub const TransitGatewayConnectPeerAssociation = struct {
    transit_gateway_connect_peer_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    link_id: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transit_gateway_connect_peer_arn = "TransitGatewayConnectPeerArn",
            .global_network_id = "GlobalNetworkId",
            .device_id = "DeviceId",
            .link_id = "LinkId",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const SiteToSiteVpnAttachment = struct {
    attachment: ?Attachment = null,
    vpn_connection_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment = "Attachment",
            .vpn_connection_arn = "VpnConnectionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CoreNetworkSegmentEdgeIdentifier = struct {
    core_network_id: ?[]const u8 = null,
    segment_name: ?[]const u8 = null,
    edge_location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_network_id = "CoreNetworkId",
            .segment_name = "SegmentName",
            .edge_location = "EdgeLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const LinkAssociation = struct {
    global_network_id: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    link_id: ?[]const u8 = null,
    link_association_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global_network_id = "GlobalNetworkId",
            .device_id = "DeviceId",
            .link_id = "LinkId",
            .link_association_state = "LinkAssociationState",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerGatewayAssociation = struct {
    customer_gateway_arn: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    link_id: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_gateway_arn = "CustomerGatewayArn",
            .global_network_id = "GlobalNetworkId",
            .device_id = "DeviceId",
            .link_id = "LinkId",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const CoreNetworkChangeValues = struct {
    segment_name: ?[]const u8 = null,
    edge_locations: ?[][]const u8 = null,
    asn: ?i64 = null,
    cidr: ?[]const u8 = null,
    destination_identifier: ?[]const u8 = null,
    inside_cidr_blocks: ?[][]const u8 = null,
    shared_segments: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .segment_name = "SegmentName",
            .edge_locations = "EdgeLocations",
            .asn = "Asn",
            .cidr = "Cidr",
            .destination_identifier = "DestinationIdentifier",
            .inside_cidr_blocks = "InsideCidrBlocks",
            .shared_segments = "SharedSegments",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectPeerAssociation = struct {
    connect_peer_id: ?[]const u8 = null,
    global_network_id: ?[]const u8 = null,
    device_id: ?[]const u8 = null,
    link_id: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connect_peer_id = "ConnectPeerId",
            .global_network_id = "GlobalNetworkId",
            .device_id = "DeviceId",
            .link_id = "LinkId",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectPeer = struct {
    core_network_id: ?[]const u8 = null,
    connect_attachment_id: ?[]const u8 = null,
    connect_peer_id: ?[]const u8 = null,
    edge_location: ?[]const u8 = null,
    state: ?[]const u8 = null,
    created_at: ?i64 = null,
    configuration: ?ConnectPeerConfiguration = null,
    tags: ?[]Tag = null,
    subnet_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_network_id = "CoreNetworkId",
            .connect_attachment_id = "ConnectAttachmentId",
            .connect_peer_id = "ConnectPeerId",
            .edge_location = "EdgeLocation",
            .state = "State",
            .created_at = "CreatedAt",
            .configuration = "Configuration",
            .tags = "Tags",
            .subnet_arn = "SubnetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectPeerConfiguration = struct {
    core_network_address: ?[]const u8 = null,
    peer_address: ?[]const u8 = null,
    inside_cidr_blocks: ?[][]const u8 = null,
    protocol: ?[]const u8 = null,
    bgp_configurations: ?[]ConnectPeerBgpConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_network_address = "CoreNetworkAddress",
            .peer_address = "PeerAddress",
            .inside_cidr_blocks = "InsideCidrBlocks",
            .protocol = "Protocol",
            .bgp_configurations = "BgpConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectPeerBgpConfiguration = struct {
    core_network_asn: ?i64 = null,
    peer_asn: ?i64 = null,
    core_network_address: ?[]const u8 = null,
    peer_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .core_network_asn = "CoreNetworkAsn",
            .peer_asn = "PeerAsn",
            .core_network_address = "CoreNetworkAddress",
            .peer_address = "PeerAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectAttachment = struct {
    attachment: ?Attachment = null,
    transport_attachment_id: ?[]const u8 = null,
    options: ?ConnectAttachmentOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment = "Attachment",
            .transport_attachment_id = "TransportAttachmentId",
            .options = "Options",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectAttachmentOptions = struct {
    protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .protocol = "Protocol",
        };
        return @field(mappings, field_name);
    }
};
