const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-06-10";
pub const sdk_id: []const u8 = "OAM";
pub const arn_namespace: ?[]const u8 = "oam";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "oam";
pub const name: []const u8 = "oamservice";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2022-06-10",
    sdk_id: []const u8 = "OAM",
    arn_namespace: ?[]const u8 = "oam",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "oam",
    name: []const u8 = "oamservice",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_link: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateLink",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLink",
    Request: type = struct {
        label_template: []const u8,
        resource_types: [][]const u8,
        sink_identifier: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .label_template = "LabelTemplate",
                .resource_types = "ResourceTypes",
                .sink_identifier = "SinkIdentifier",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_link) } {
            return .{ .service_metadata = service_metadata, .action = create_link };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        label: ?[]const u8 = null,
        label_template: ?[]const u8 = null,
        resource_types: ?[][]const u8 = null,
        sink_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .label = "Label",
                .label_template = "LabelTemplate",
                .resource_types = "ResourceTypes",
                .sink_arn = "SinkArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidParameter,
        MissingRequiredParameter,
        ServiceQuotaExceeded,
    },
} = .{};
pub const create_sink: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateSink",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSink",
    Request: type = struct {
        name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sink) } {
            return .{ .service_metadata = service_metadata, .action = create_sink };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .name = "Name",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidParameter,
        MissingRequiredParameter,
        ServiceQuotaExceeded,
    },
} = .{};
pub const delete_link: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteLink",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLink",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_link) } {
            return .{ .service_metadata = service_metadata, .action = delete_link };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        MissingRequiredParameter,
        ResourceNotFound,
    },
} = .{};
pub const delete_sink: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteSink",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSink",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sink) } {
            return .{ .service_metadata = service_metadata, .action = delete_sink };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalService,
        InvalidParameter,
        MissingRequiredParameter,
        ResourceNotFound,
    },
} = .{};
pub const get_link: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetLink",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLink",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_link) } {
            return .{ .service_metadata = service_metadata, .action = get_link };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        label: ?[]const u8 = null,
        label_template: ?[]const u8 = null,
        resource_types: ?[][]const u8 = null,
        sink_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .label = "Label",
                .label_template = "LabelTemplate",
                .resource_types = "ResourceTypes",
                .sink_arn = "SinkArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        MissingRequiredParameter,
        ResourceNotFound,
    },
} = .{};
pub const get_sink: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetSink",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSink",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sink) } {
            return .{ .service_metadata = service_metadata, .action = get_sink };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .name = "Name",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        MissingRequiredParameter,
        ResourceNotFound,
    },
} = .{};
pub const get_sink_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetSinkPolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSinkPolicy",
    Request: type = struct {
        sink_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sink_identifier = "SinkIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sink_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_sink_policy };
        }
    },
    Response: type = struct {
        sink_arn: ?[]const u8 = null,
        sink_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sink_arn = "SinkArn",
                .sink_id = "SinkId",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        MissingRequiredParameter,
        ResourceNotFound,
    },
} = .{};
pub const list_attached_links: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListAttachedLinks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAttachedLinks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sink_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sink_identifier = "SinkIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_attached_links) } {
            return .{ .service_metadata = service_metadata, .action = list_attached_links };
        }
    },
    Response: type = struct {
        items: []struct {
            label: ?[]const u8 = null,
            link_arn: ?[]const u8 = null,
            resource_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .label = "Label",
                    .link_arn = "LinkArn",
                    .resource_types = "ResourceTypes",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        MissingRequiredParameter,
        ResourceNotFound,
    },
} = .{};
pub const list_links: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListLinks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLinks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_links) } {
            return .{ .service_metadata = service_metadata, .action = list_links };
        }
    },
    Response: type = struct {
        items: []struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            label: ?[]const u8 = null,
            resource_types: ?[][]const u8 = null,
            sink_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .label = "Label",
                    .resource_types = "ResourceTypes",
                    .sink_arn = "SinkArn",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const list_sinks: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListSinks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSinks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sinks) } {
            return .{ .service_metadata = service_metadata, .action = list_sinks };
        }
    },
    Response: type = struct {
        items: []struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_sink_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/PutSinkPolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSinkPolicy",
    Request: type = struct {
        sink_identifier: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sink_identifier = "SinkIdentifier",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_sink_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_sink_policy };
        }
    },
    Response: type = struct {
        sink_arn: ?[]const u8 = null,
        sink_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sink_arn = "SinkArn",
                .sink_id = "SinkId",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        MissingRequiredParameter,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        TooManyTags,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_link: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateLink",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLink",
    Request: type = struct {
        identifier: []const u8,
        resource_types: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .resource_types = "ResourceTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_link) } {
            return .{ .service_metadata = service_metadata, .action = update_link };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,
        label: ?[]const u8 = null,
        label_template: ?[]const u8 = null,
        resource_types: ?[][]const u8 = null,
        sink_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
                .label = "Label",
                .label_template = "LabelTemplate",
                .resource_types = "ResourceTypes",
                .sink_arn = "SinkArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        MissingRequiredParameter,
        ResourceNotFound,
    },
} = .{};
