const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-01-01";
pub const sdk_id: []const u8 = "OpenSearch";
pub const arn_namespace: ?[]const u8 = "es";
pub const endpoint_prefix: []const u8 = "es";
pub const sigv4_name: []const u8 = "es";
pub const name: []const u8 = "AmazonOpenSearchService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-01-01",
    sdk_id: []const u8 = "OpenSearch",
    arn_namespace: ?[]const u8 = "es",
    endpoint_prefix: []const u8 = "es",
    sigv4_name: []const u8 = "es",
    name: []const u8 = "AmazonOpenSearchService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_inbound_connection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2021-01-01/opensearch/cc/inboundConnection/{ConnectionId}/accept",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptInboundConnection",
    Request: type = struct {
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "ConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_inbound_connection) } {
            return .{ .service_metadata = service_metadata, .action = accept_inbound_connection };
        }
    },
    Response: type = struct {
        connection: ?InboundConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const add_data_source: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/dataSource",
        .success_code = 200,
    };

    action_name: []const u8 = "AddDataSource",
    Request: type = struct {
        domain_name: []const u8,
        name: []const u8,
        data_source_type: DataSourceType,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .name = "Name",
                .data_source_type = "DataSourceType",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_data_source) } {
            return .{ .service_metadata = service_metadata, .action = add_data_source };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DependencyFailure,
        DisabledOperation,
        Internal,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const add_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "AddTags",
    Request: type = struct {
        arn: []const u8,
        tag_list: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags) } {
            return .{ .service_metadata = service_metadata, .action = add_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Base,
        Internal,
        LimitExceeded,
        Validation,
    },
} = .{};
pub const associate_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/packages/associate/{PackageID}/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociatePackage",
    Request: type = struct {
        package_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_package) } {
            return .{ .service_metadata = service_metadata, .action = associate_package };
        }
    },
    Response: type = struct {
        domain_package_details: ?DomainPackageDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_package_details = "DomainPackageDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Conflict,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const authorize_vpc_endpoint_access: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/authorizeVpcEndpointAccess",
        .success_code = 200,
    };

    action_name: []const u8 = "AuthorizeVpcEndpointAccess",
    Request: type = struct {
        domain_name: []const u8,
        account: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .account = "Account",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_vpc_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = authorize_vpc_endpoint_access };
        }
    },
    Response: type = struct {
        authorized_principal: AuthorizedPrincipal,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorized_principal = "AuthorizedPrincipal",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const cancel_domain_config_change: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/config/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelDomainConfigChange",
    Request: type = struct {
        domain_name: []const u8,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_domain_config_change) } {
            return .{ .service_metadata = service_metadata, .action = cancel_domain_config_change };
        }
    },
    Response: type = struct {
        cancelled_change_ids: ?[][]const u8 = null,
        cancelled_change_properties: ?[]struct {
            property_name: ?[]const u8 = null,
            cancelled_value: ?[]const u8 = null,
            active_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .property_name = "PropertyName",
                    .cancelled_value = "CancelledValue",
                    .active_value = "ActiveValue",
                };
                return @field(mappings, field_name);
            }
        } = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cancelled_change_ids = "CancelledChangeIds",
                .cancelled_change_properties = "CancelledChangeProperties",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const cancel_service_software_update: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/serviceSoftwareUpdate/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelServiceSoftwareUpdate",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_service_software_update) } {
            return .{ .service_metadata = service_metadata, .action = cancel_service_software_update };
        }
    },
    Response: type = struct {
        service_software_options: ?ServiceSoftwareOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_software_options = "ServiceSoftwareOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/domain",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDomain",
    Request: type = struct {
        domain_name: []const u8,
        engine_version: ?[]const u8 = null,
        cluster_config: ?ClusterConfig = null,
        ebs_options: ?EBSOptions = null,
        access_policies: ?[]const u8 = null,
        ip_address_type: ?[]const u8 = null,
        snapshot_options: ?SnapshotOptions = null,
        vpc_options: ?VPCOptions = null,
        cognito_options: ?CognitoOptions = null,
        encryption_at_rest_options: ?EncryptionAtRestOptions = null,
        node_to_node_encryption_options: ?NodeToNodeEncryptionOptions = null,
        advanced_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        log_publishing_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LogPublishingOption = null,
        } = null,
        domain_endpoint_options: ?DomainEndpointOptions = null,
        advanced_security_options: ?AdvancedSecurityOptionsInput = null,
        tag_list: ?[]Tag = null,
        auto_tune_options: ?struct {
            desired_state: ?[]const u8 = null,
            maintenance_schedules: ?[]AutoTuneMaintenanceSchedule = null,
            use_off_peak_window: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .desired_state = "DesiredState",
                    .maintenance_schedules = "MaintenanceSchedules",
                    .use_off_peak_window = "UseOffPeakWindow",
                };
                return @field(mappings, field_name);
            }
        } = null,
        off_peak_window_options: ?OffPeakWindowOptions = null,
        software_update_options: ?SoftwareUpdateOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .engine_version = "EngineVersion",
                .cluster_config = "ClusterConfig",
                .ebs_options = "EBSOptions",
                .access_policies = "AccessPolicies",
                .ip_address_type = "IPAddressType",
                .snapshot_options = "SnapshotOptions",
                .vpc_options = "VPCOptions",
                .cognito_options = "CognitoOptions",
                .encryption_at_rest_options = "EncryptionAtRestOptions",
                .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
                .advanced_options = "AdvancedOptions",
                .log_publishing_options = "LogPublishingOptions",
                .domain_endpoint_options = "DomainEndpointOptions",
                .advanced_security_options = "AdvancedSecurityOptions",
                .tag_list = "TagList",
                .auto_tune_options = "AutoTuneOptions",
                .off_peak_window_options = "OffPeakWindowOptions",
                .software_update_options = "SoftwareUpdateOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "advanced_options", field_name))
                return try serializeMap(self.advanced_options, self.fieldNameFor("advanced_options"), options, out_stream);
            if (std.mem.eql(u8, "log_publishing_options", field_name))
                return try serializeMap(self.log_publishing_options, self.fieldNameFor("log_publishing_options"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_domain) } {
            return .{ .service_metadata = service_metadata, .action = create_domain };
        }
    },
    Response: type = struct {
        domain_status: ?DomainStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_status = "DomainStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        InvalidType,
        LimitExceeded,
        ResourceAlreadyExists,
        Validation,
    },
} = .{};
pub const create_outbound_connection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/cc/outboundConnection",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateOutboundConnection",
    Request: type = struct {
        local_domain_info: DomainInformationContainer,
        remote_domain_info: DomainInformationContainer,
        connection_alias: []const u8,
        connection_mode: ?[]const u8 = null,
        connection_properties: ?ConnectionProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_domain_info = "LocalDomainInfo",
                .remote_domain_info = "RemoteDomainInfo",
                .connection_alias = "ConnectionAlias",
                .connection_mode = "ConnectionMode",
                .connection_properties = "ConnectionProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_outbound_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_outbound_connection };
        }
    },
    Response: type = struct {
        local_domain_info: ?DomainInformationContainer = null,
        remote_domain_info: ?DomainInformationContainer = null,
        connection_alias: ?[]const u8 = null,
        connection_status: ?OutboundConnectionStatus = null,
        connection_id: ?[]const u8 = null,
        connection_mode: ?[]const u8 = null,
        connection_properties: ?ConnectionProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .local_domain_info = "LocalDomainInfo",
                .remote_domain_info = "RemoteDomainInfo",
                .connection_alias = "ConnectionAlias",
                .connection_status = "ConnectionStatus",
                .connection_id = "ConnectionId",
                .connection_mode = "ConnectionMode",
                .connection_properties = "ConnectionProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        Internal,
        LimitExceeded,
        ResourceAlreadyExists,
    },
} = .{};
pub const create_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/packages",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePackage",
    Request: type = struct {
        package_name: []const u8,
        package_type: []const u8,
        package_description: ?[]const u8 = null,
        package_source: PackageSource,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "PackageName",
                .package_type = "PackageType",
                .package_description = "PackageDescription",
                .package_source = "PackageSource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_package) } {
            return .{ .service_metadata = service_metadata, .action = create_package };
        }
    },
    Response: type = struct {
        package_details: ?PackageDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_details = "PackageDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        InvalidType,
        LimitExceeded,
        ResourceAlreadyExists,
        Validation,
    },
} = .{};
pub const create_vpc_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/vpcEndpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateVpcEndpoint",
    Request: type = struct {
        domain_arn: []const u8,
        vpc_options: VPCOptions,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_arn = "DomainArn",
                .vpc_options = "VpcOptions",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_endpoint };
        }
    },
    Response: type = struct {
        vpc_endpoint: VpcEndpoint,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint = "VpcEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Conflict,
        DisabledOperation,
        Internal,
        LimitExceeded,
        Validation,
    },
} = .{};
pub const delete_data_source: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/dataSource/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataSource",
    Request: type = struct {
        domain_name: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_source) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_source };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DependencyFailure,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_domain: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDomain",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_domain) } {
            return .{ .service_metadata = service_metadata, .action = delete_domain };
        }
    },
    Response: type = struct {
        domain_status: ?DomainStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_status = "DomainStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_inbound_connection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2021-01-01/opensearch/cc/inboundConnection/{ConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInboundConnection",
    Request: type = struct {
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "ConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_inbound_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_inbound_connection };
        }
    },
    Response: type = struct {
        connection: ?InboundConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        ResourceNotFound,
    },
} = .{};
pub const delete_outbound_connection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2021-01-01/opensearch/cc/outboundConnection/{ConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteOutboundConnection",
    Request: type = struct {
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "ConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_outbound_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_outbound_connection };
        }
    },
    Response: type = struct {
        connection: ?OutboundConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        ResourceNotFound,
    },
} = .{};
pub const delete_package: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2021-01-01/packages/{PackageID}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePackage",
    Request: type = struct {
        package_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_package) } {
            return .{ .service_metadata = service_metadata, .action = delete_package };
        }
    },
    Response: type = struct {
        package_details: ?PackageDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_details = "PackageDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Conflict,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_vpc_endpoint: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2021-01-01/opensearch/vpcEndpoints/{VpcEndpointId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteVpcEndpoint",
    Request: type = struct {
        vpc_endpoint_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_id = "VpcEndpointId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_endpoint };
        }
    },
    Response: type = struct {
        vpc_endpoint_summary: VpcEndpointSummary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_summary = "VpcEndpointSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const describe_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomain",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain };
        }
    },
    Response: type = struct {
        domain_status: DomainStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_status = "DomainStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_domain_auto_tunes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/autoTunes",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomainAutoTunes",
    Request: type = struct {
        domain_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain_auto_tunes) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain_auto_tunes };
        }
    },
    Response: type = struct {
        auto_tunes: ?[]struct {
            auto_tune_type: ?[]const u8 = null,
            auto_tune_details: ?struct {
                scheduled_auto_tune_details: ?struct {
                    date: ?i64 = null,
                    action_type: ?[]const u8 = null,
                    action: ?[]const u8 = null,
                    severity: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .date = "Date",
                            .action_type = "ActionType",
                            .action = "Action",
                            .severity = "Severity",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .scheduled_auto_tune_details = "ScheduledAutoTuneDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auto_tune_type = "AutoTuneType",
                    .auto_tune_details = "AutoTuneDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_tunes = "AutoTunes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_domain_change_progress: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/progress",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomainChangeProgress",
    Request: type = struct {
        domain_name: []const u8,
        change_id: ?[]const u8 = null,

        pub const http_query = .{
            .change_id = "changeid",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .change_id = "ChangeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain_change_progress) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain_change_progress };
        }
    },
    Response: type = struct {
        change_progress_status: ?struct {
            change_id: ?[]const u8 = null,
            start_time: ?i64 = null,
            status: ?[]const u8 = null,
            pending_properties: ?[][]const u8 = null,
            completed_properties: ?[][]const u8 = null,
            total_number_of_stages: ?i64 = null,
            change_progress_stages: ?[]struct {
                name: ?[]const u8 = null,
                status: ?[]const u8 = null,
                description: ?[]const u8 = null,
                last_updated: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .status = "Status",
                        .description = "Description",
                        .last_updated = "LastUpdated",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_updated_time: ?i64 = null,
            config_change_status: ?[]const u8 = null,
            initiated_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .change_id = "ChangeId",
                    .start_time = "StartTime",
                    .status = "Status",
                    .pending_properties = "PendingProperties",
                    .completed_properties = "CompletedProperties",
                    .total_number_of_stages = "TotalNumberOfStages",
                    .change_progress_stages = "ChangeProgressStages",
                    .last_updated_time = "LastUpdatedTime",
                    .config_change_status = "ConfigChangeStatus",
                    .initiated_by = "InitiatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_progress_status = "ChangeProgressStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_domain_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomainConfig",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain_config) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain_config };
        }
    },
    Response: type = struct {
        domain_config: DomainConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_config = "DomainConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_domain_health: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/health",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomainHealth",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain_health };
        }
    },
    Response: type = struct {
        domain_state: ?[]const u8 = null,
        availability_zone_count: ?[]const u8 = null,
        active_availability_zone_count: ?[]const u8 = null,
        stand_by_availability_zone_count: ?[]const u8 = null,
        data_node_count: ?[]const u8 = null,
        dedicated_master: ?bool = null,
        master_eligible_node_count: ?[]const u8 = null,
        warm_node_count: ?[]const u8 = null,
        master_node: ?[]const u8 = null,
        cluster_health: ?[]const u8 = null,
        total_shards: ?[]const u8 = null,
        total_un_assigned_shards: ?[]const u8 = null,
        environment_information: ?[]struct {
            availability_zone_information: ?[]struct {
                availability_zone_name: ?[]const u8 = null,
                zone_status: ?[]const u8 = null,
                configured_data_node_count: ?[]const u8 = null,
                available_data_node_count: ?[]const u8 = null,
                total_shards: ?[]const u8 = null,
                total_un_assigned_shards: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .availability_zone_name = "AvailabilityZoneName",
                        .zone_status = "ZoneStatus",
                        .configured_data_node_count = "ConfiguredDataNodeCount",
                        .available_data_node_count = "AvailableDataNodeCount",
                        .total_shards = "TotalShards",
                        .total_un_assigned_shards = "TotalUnAssignedShards",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .availability_zone_information = "AvailabilityZoneInformation",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_state = "DomainState",
                .availability_zone_count = "AvailabilityZoneCount",
                .active_availability_zone_count = "ActiveAvailabilityZoneCount",
                .stand_by_availability_zone_count = "StandByAvailabilityZoneCount",
                .data_node_count = "DataNodeCount",
                .dedicated_master = "DedicatedMaster",
                .master_eligible_node_count = "MasterEligibleNodeCount",
                .warm_node_count = "WarmNodeCount",
                .master_node = "MasterNode",
                .cluster_health = "ClusterHealth",
                .total_shards = "TotalShards",
                .total_un_assigned_shards = "TotalUnAssignedShards",
                .environment_information = "EnvironmentInformation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_domain_nodes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/nodes",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomainNodes",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain_nodes) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain_nodes };
        }
    },
    Response: type = struct {
        domain_nodes_status_list: ?[]struct {
            node_id: ?[]const u8 = null,
            node_type: ?[]const u8 = null,
            availability_zone: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            node_status: ?[]const u8 = null,
            storage_type: ?[]const u8 = null,
            storage_volume_type: ?[]const u8 = null,
            storage_size: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .node_id = "NodeId",
                    .node_type = "NodeType",
                    .availability_zone = "AvailabilityZone",
                    .instance_type = "InstanceType",
                    .node_status = "NodeStatus",
                    .storage_type = "StorageType",
                    .storage_volume_type = "StorageVolumeType",
                    .storage_size = "StorageSize",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_nodes_status_list = "DomainNodesStatusList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DependencyFailure,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_domains: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/domain-info",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomains",
    Request: type = struct {
        domain_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_names = "DomainNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domains) } {
            return .{ .service_metadata = service_metadata, .action = describe_domains };
        }
    },
    Response: type = struct {
        domain_status_list: []DomainStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_status_list = "DomainStatusList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        Validation,
    },
} = .{};
pub const describe_dry_run_progress: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/dryRun",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDryRunProgress",
    Request: type = struct {
        domain_name: []const u8,
        dry_run_id: ?[]const u8 = null,
        load_dry_run_config: ?bool = null,

        pub const http_query = .{
            .dry_run_id = "dryRunId",
            .load_dry_run_config = "loadDryRunConfig",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .dry_run_id = "DryRunId",
                .load_dry_run_config = "LoadDryRunConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dry_run_progress) } {
            return .{ .service_metadata = service_metadata, .action = describe_dry_run_progress };
        }
    },
    Response: type = struct {
        dry_run_progress_status: ?DryRunProgressStatus = null,
        dry_run_config: ?DomainStatus = null,
        dry_run_results: ?DryRunResults = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dry_run_progress_status = "DryRunProgressStatus",
                .dry_run_config = "DryRunConfig",
                .dry_run_results = "DryRunResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_inbound_connections: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/cc/inboundConnection/search",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInboundConnections",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_inbound_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_inbound_connections };
        }
    },
    Response: type = struct {
        connections: ?[]InboundConnection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "Connections",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        InvalidPaginationToken,
    },
} = .{};
pub const describe_instance_type_limits: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/instanceTypeLimits/{EngineVersion}/{InstanceType}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInstanceTypeLimits",
    Request: type = struct {
        domain_name: ?[]const u8 = null,
        instance_type: []const u8,
        engine_version: []const u8,

        pub const http_query = .{
            .domain_name = "domainName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .instance_type = "InstanceType",
                .engine_version = "EngineVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_type_limits) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_type_limits };
        }
    },
    Response: type = struct {
        limits_by_role: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                storage_types: ?[]struct {
                    storage_type_name: ?[]const u8 = null,
                    storage_sub_type_name: ?[]const u8 = null,
                    storage_type_limits: ?[]struct {
                        limit_name: ?[]const u8 = null,
                        limit_values: ?[][]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .limit_name = "LimitName",
                                .limit_values = "LimitValues",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .storage_type_name = "StorageTypeName",
                            .storage_sub_type_name = "StorageSubTypeName",
                            .storage_type_limits = "StorageTypeLimits",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                instance_limits: ?struct {
                    instance_count_limits: ?struct {
                        minimum_instance_count: ?i64 = null,
                        maximum_instance_count: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .minimum_instance_count = "MinimumInstanceCount",
                                .maximum_instance_count = "MaximumInstanceCount",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .instance_count_limits = "InstanceCountLimits",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                additional_limits: ?[]struct {
                    limit_name: ?[]const u8 = null,
                    limit_values: ?[][]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .limit_name = "LimitName",
                            .limit_values = "LimitValues",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .storage_types = "StorageTypes",
                        .instance_limits = "InstanceLimits",
                        .additional_limits = "AdditionalLimits",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limits_by_role = "LimitsByRole",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "limits_by_role", field_name))
                return try serializeMap(self.limits_by_role, self.fieldNameFor("limits_by_role"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        InvalidType,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_outbound_connections: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/cc/outboundConnection/search",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeOutboundConnections",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_outbound_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_outbound_connections };
        }
    },
    Response: type = struct {
        connections: ?[]OutboundConnection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "Connections",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        InvalidPaginationToken,
    },
} = .{};
pub const describe_packages: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/packages/describe",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePackages",
    Request: type = struct {
        filters: ?[]struct {
            name: ?[]const u8 = null,
            value: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_packages) } {
            return .{ .service_metadata = service_metadata, .action = describe_packages };
        }
    },
    Response: type = struct {
        package_details_list: ?[]PackageDetails = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_details_list = "PackageDetailsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_reserved_instance_offerings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/reservedInstanceOfferings",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeReservedInstanceOfferings",
    Request: type = struct {
        reserved_instance_offering_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .reserved_instance_offering_id = "offeringId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instance_offering_id = "ReservedInstanceOfferingId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_instance_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_instance_offerings };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        reserved_instance_offerings: ?[]struct {
            reserved_instance_offering_id: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            duration: ?i64 = null,
            fixed_price: ?f64 = null,
            usage_price: ?f64 = null,
            currency_code: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            recurring_charges: ?[]RecurringCharge = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reserved_instance_offering_id = "ReservedInstanceOfferingId",
                    .instance_type = "InstanceType",
                    .duration = "Duration",
                    .fixed_price = "FixedPrice",
                    .usage_price = "UsagePrice",
                    .currency_code = "CurrencyCode",
                    .payment_option = "PaymentOption",
                    .recurring_charges = "RecurringCharges",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .reserved_instance_offerings = "ReservedInstanceOfferings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_reserved_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/reservedInstances",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeReservedInstances",
    Request: type = struct {
        reserved_instance_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .reserved_instance_id = "reservationId",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instance_id = "ReservedInstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_reserved_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_reserved_instances };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        reserved_instances: ?[]struct {
            reservation_name: ?[]const u8 = null,
            reserved_instance_id: ?[]const u8 = null,
            billing_subscription_id: ?i64 = null,
            reserved_instance_offering_id: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            start_time: ?i64 = null,
            duration: ?i64 = null,
            fixed_price: ?f64 = null,
            usage_price: ?f64 = null,
            currency_code: ?[]const u8 = null,
            instance_count: ?i64 = null,
            state: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            recurring_charges: ?[]RecurringCharge = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reservation_name = "ReservationName",
                    .reserved_instance_id = "ReservedInstanceId",
                    .billing_subscription_id = "BillingSubscriptionId",
                    .reserved_instance_offering_id = "ReservedInstanceOfferingId",
                    .instance_type = "InstanceType",
                    .start_time = "StartTime",
                    .duration = "Duration",
                    .fixed_price = "FixedPrice",
                    .usage_price = "UsagePrice",
                    .currency_code = "CurrencyCode",
                    .instance_count = "InstanceCount",
                    .state = "State",
                    .payment_option = "PaymentOption",
                    .recurring_charges = "RecurringCharges",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .reserved_instances = "ReservedInstances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_vpc_endpoints: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/vpcEndpoints/describe",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeVpcEndpoints",
    Request: type = struct {
        vpc_endpoint_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_ids = "VpcEndpointIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vpc_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_vpc_endpoints };
        }
    },
    Response: type = struct {
        vpc_endpoints: []VpcEndpoint,
        vpc_endpoint_errors: []struct {
            vpc_endpoint_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vpc_endpoint_id = "VpcEndpointId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoints = "VpcEndpoints",
                .vpc_endpoint_errors = "VpcEndpointErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        Validation,
    },
} = .{};
pub const dissociate_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/packages/dissociate/{PackageID}/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DissociatePackage",
    Request: type = struct {
        package_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(dissociate_package) } {
            return .{ .service_metadata = service_metadata, .action = dissociate_package };
        }
    },
    Response: type = struct {
        domain_package_details: ?DomainPackageDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_package_details = "DomainPackageDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Conflict,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_compatible_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/compatibleVersions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCompatibleVersions",
    Request: type = struct {
        domain_name: ?[]const u8 = null,

        pub const http_query = .{
            .domain_name = "domainName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_compatible_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_compatible_versions };
        }
    },
    Response: type = struct {
        compatible_versions: ?[]struct {
            source_version: ?[]const u8 = null,
            target_versions: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_version = "SourceVersion",
                    .target_versions = "TargetVersions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compatible_versions = "CompatibleVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_data_source: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/dataSource/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataSource",
    Request: type = struct {
        domain_name: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_source) } {
            return .{ .service_metadata = service_metadata, .action = get_data_source };
        }
    },
    Response: type = struct {
        data_source_type: ?DataSourceType = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_type = "DataSourceType",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DependencyFailure,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_domain_maintenance_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/domainMaintenance",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainMaintenanceStatus",
    Request: type = struct {
        domain_name: []const u8,
        maintenance_id: []const u8,

        pub const http_query = .{
            .maintenance_id = "maintenanceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .maintenance_id = "MaintenanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_maintenance_status) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_maintenance_status };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        node_id: ?[]const u8 = null,
        action: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .status_message = "StatusMessage",
                .node_id = "NodeId",
                .action = "Action",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_package_version_history: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/packages/{PackageID}/history",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPackageVersionHistory",
    Request: type = struct {
        package_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_package_version_history) } {
            return .{ .service_metadata = service_metadata, .action = get_package_version_history };
        }
    },
    Response: type = struct {
        package_id: ?[]const u8 = null,
        package_version_history_list: ?[]struct {
            package_version: ?[]const u8 = null,
            commit_message: ?[]const u8 = null,
            created_at: ?i64 = null,
            plugin_properties: ?PluginProperties = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .package_version = "PackageVersion",
                    .commit_message = "CommitMessage",
                    .created_at = "CreatedAt",
                    .plugin_properties = "PluginProperties",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .package_version_history_list = "PackageVersionHistoryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_upgrade_history: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/upgradeDomain/{DomainName}/history",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUpgradeHistory",
    Request: type = struct {
        domain_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_upgrade_history) } {
            return .{ .service_metadata = service_metadata, .action = get_upgrade_history };
        }
    },
    Response: type = struct {
        upgrade_histories: ?[]struct {
            upgrade_name: ?[]const u8 = null,
            start_timestamp: ?i64 = null,
            upgrade_status: ?[]const u8 = null,
            steps_list: ?[]struct {
                upgrade_step: ?[]const u8 = null,
                upgrade_step_status: ?[]const u8 = null,
                issues: ?[][]const u8 = null,
                progress_percent: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .upgrade_step = "UpgradeStep",
                        .upgrade_step_status = "UpgradeStepStatus",
                        .issues = "Issues",
                        .progress_percent = "ProgressPercent",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .upgrade_name = "UpgradeName",
                    .start_timestamp = "StartTimestamp",
                    .upgrade_status = "UpgradeStatus",
                    .steps_list = "StepsList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upgrade_histories = "UpgradeHistories",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_upgrade_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/upgradeDomain/{DomainName}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUpgradeStatus",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_upgrade_status) } {
            return .{ .service_metadata = service_metadata, .action = get_upgrade_status };
        }
    },
    Response: type = struct {
        upgrade_step: ?[]const u8 = null,
        step_status: ?[]const u8 = null,
        upgrade_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upgrade_step = "UpgradeStep",
                .step_status = "StepStatus",
                .upgrade_name = "UpgradeName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_data_sources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/dataSource",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataSources",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_sources) } {
            return .{ .service_metadata = service_metadata, .action = list_data_sources };
        }
    },
    Response: type = struct {
        data_sources: ?[]struct {
            data_source_type: ?DataSourceType = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_source_type = "DataSourceType",
                    .name = "Name",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_sources = "DataSources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DependencyFailure,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_domain_maintenances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/domainMaintenances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomainMaintenances",
    Request: type = struct {
        domain_name: []const u8,
        action: ?[]const u8 = null,
        status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .action = "action",
            .status = "status",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .action = "Action",
                .status = "Status",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domain_maintenances) } {
            return .{ .service_metadata = service_metadata, .action = list_domain_maintenances };
        }
    },
    Response: type = struct {
        domain_maintenances: ?[]struct {
            maintenance_id: ?[]const u8 = null,
            domain_name: ?[]const u8 = null,
            action: ?[]const u8 = null,
            node_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .maintenance_id = "MaintenanceId",
                    .domain_name = "DomainName",
                    .action = "Action",
                    .node_id = "NodeId",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_maintenances = "DomainMaintenances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_domain_names: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/domain",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomainNames",
    Request: type = struct {
        engine_type: ?[]const u8 = null,

        pub const http_query = .{
            .engine_type = "engineType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_type = "EngineType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domain_names) } {
            return .{ .service_metadata = service_metadata, .action = list_domain_names };
        }
    },
    Response: type = struct {
        domain_names: ?[]struct {
            domain_name: ?[]const u8 = null,
            engine_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .engine_type = "EngineType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_names = "DomainNames",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Validation,
    },
} = .{};
pub const list_domains_for_package: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/packages/{PackageID}/domains",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomainsForPackage",
    Request: type = struct {
        package_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domains_for_package) } {
            return .{ .service_metadata = service_metadata, .action = list_domains_for_package };
        }
    },
    Response: type = struct {
        domain_package_details_list: ?[]DomainPackageDetails = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_package_details_list = "DomainPackageDetailsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_instance_type_details: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/instanceTypeDetails/{EngineVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInstanceTypeDetails",
    Request: type = struct {
        engine_version: []const u8,
        domain_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        retrieve_a_zs: ?bool = null,
        instance_type: ?[]const u8 = null,

        pub const http_query = .{
            .domain_name = "domainName",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .retrieve_a_zs = "retrieveAZs",
            .instance_type = "instanceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_version = "EngineVersion",
                .domain_name = "DomainName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .retrieve_a_zs = "RetrieveAZs",
                .instance_type = "InstanceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instance_type_details) } {
            return .{ .service_metadata = service_metadata, .action = list_instance_type_details };
        }
    },
    Response: type = struct {
        instance_type_details: ?[]struct {
            instance_type: ?[]const u8 = null,
            encryption_enabled: ?bool = null,
            cognito_enabled: ?bool = null,
            app_logs_enabled: ?bool = null,
            advanced_security_enabled: ?bool = null,
            warm_enabled: ?bool = null,
            instance_role: ?[][]const u8 = null,
            availability_zones: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_type = "InstanceType",
                    .encryption_enabled = "EncryptionEnabled",
                    .cognito_enabled = "CognitoEnabled",
                    .app_logs_enabled = "AppLogsEnabled",
                    .advanced_security_enabled = "AdvancedSecurityEnabled",
                    .warm_enabled = "WarmEnabled",
                    .instance_role = "InstanceRole",
                    .availability_zones = "AvailabilityZones",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_type_details = "InstanceTypeDetails",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_packages_for_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/domain/{DomainName}/packages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackagesForDomain",
    Request: type = struct {
        domain_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_packages_for_domain) } {
            return .{ .service_metadata = service_metadata, .action = list_packages_for_domain };
        }
    },
    Response: type = struct {
        domain_package_details_list: ?[]DomainPackageDetails = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_package_details_list = "DomainPackageDetailsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_scheduled_actions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/scheduledActions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListScheduledActions",
    Request: type = struct {
        domain_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_scheduled_actions) } {
            return .{ .service_metadata = service_metadata, .action = list_scheduled_actions };
        }
    },
    Response: type = struct {
        scheduled_actions: ?[]ScheduledAction = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_actions = "ScheduledActions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        InvalidPaginationToken,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTags",
    Request: type = struct {
        arn: []const u8,

        pub const http_query = .{
            .arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVersions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_versions };
        }
    },
    Response: type = struct {
        versions: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .versions = "Versions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_vpc_endpoint_access: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/listVpcEndpointAccess",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVpcEndpointAccess",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpc_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = list_vpc_endpoint_access };
        }
    },
    Response: type = struct {
        authorized_principal_list: []AuthorizedPrincipal,
        next_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorized_principal_list = "AuthorizedPrincipalList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const list_vpc_endpoints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/vpcEndpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVpcEndpoints",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpc_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_vpc_endpoints };
        }
    },
    Response: type = struct {
        vpc_endpoint_summary_list: []VpcEndpointSummary,
        next_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_summary_list = "VpcEndpointSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
    },
} = .{};
pub const list_vpc_endpoints_for_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/vpcEndpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVpcEndpointsForDomain",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpc_endpoints_for_domain) } {
            return .{ .service_metadata = service_metadata, .action = list_vpc_endpoints_for_domain };
        }
    },
    Response: type = struct {
        vpc_endpoint_summary_list: []VpcEndpointSummary,
        next_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_summary_list = "VpcEndpointSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
    },
} = .{};
pub const purchase_reserved_instance_offering: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/purchaseReservedInstanceOffering",
        .success_code = 200,
    };

    action_name: []const u8 = "PurchaseReservedInstanceOffering",
    Request: type = struct {
        reserved_instance_offering_id: []const u8,
        reservation_name: []const u8,
        instance_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instance_offering_id = "ReservedInstanceOfferingId",
                .reservation_name = "ReservationName",
                .instance_count = "InstanceCount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purchase_reserved_instance_offering) } {
            return .{ .service_metadata = service_metadata, .action = purchase_reserved_instance_offering };
        }
    },
    Response: type = struct {
        reserved_instance_id: ?[]const u8 = null,
        reservation_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reserved_instance_id = "ReservedInstanceId",
                .reservation_name = "ReservationName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        Internal,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const reject_inbound_connection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2021-01-01/opensearch/cc/inboundConnection/{ConnectionId}/reject",
        .success_code = 200,
    };

    action_name: []const u8 = "RejectInboundConnection",
    Request: type = struct {
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "ConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_inbound_connection) } {
            return .{ .service_metadata = service_metadata, .action = reject_inbound_connection };
        }
    },
    Response: type = struct {
        connection: ?InboundConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DisabledOperation,
        ResourceNotFound,
    },
} = .{};
pub const remove_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/tags-removal",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveTags",
    Request: type = struct {
        arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Base,
        Internal,
        Validation,
    },
} = .{};
pub const revoke_vpc_endpoint_access: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/revokeVpcEndpointAccess",
        .success_code = 200,
    };

    action_name: []const u8 = "RevokeVpcEndpointAccess",
    Request: type = struct {
        domain_name: []const u8,
        account: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .account = "Account",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_vpc_endpoint_access) } {
            return .{ .service_metadata = service_metadata, .action = revoke_vpc_endpoint_access };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_domain_maintenance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/domainMaintenance",
        .success_code = 200,
    };

    action_name: []const u8 = "StartDomainMaintenance",
    Request: type = struct {
        domain_name: []const u8,
        action: []const u8,
        node_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .action = "Action",
                .node_id = "NodeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_domain_maintenance) } {
            return .{ .service_metadata = service_metadata, .action = start_domain_maintenance };
        }
    },
    Response: type = struct {
        maintenance_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .maintenance_id = "MaintenanceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_service_software_update: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/serviceSoftwareUpdate/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartServiceSoftwareUpdate",
    Request: type = struct {
        domain_name: []const u8,
        schedule_at: ?[]const u8 = null,
        desired_start_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .schedule_at = "ScheduleAt",
                .desired_start_time = "DesiredStartTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_service_software_update) } {
            return .{ .service_metadata = service_metadata, .action = start_service_software_update };
        }
    },
    Response: type = struct {
        service_software_options: ?ServiceSoftwareOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_software_options = "ServiceSoftwareOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_data_source: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/dataSource/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSource",
    Request: type = struct {
        domain_name: []const u8,
        name: []const u8,
        data_source_type: DataSourceType,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .name = "Name",
                .data_source_type = "DataSourceType",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_source) } {
            return .{ .service_metadata = service_metadata, .action = update_data_source };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        DependencyFailure,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_domain_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDomainConfig",
    Request: type = struct {
        domain_name: []const u8,
        cluster_config: ?ClusterConfig = null,
        ebs_options: ?EBSOptions = null,
        snapshot_options: ?SnapshotOptions = null,
        vpc_options: ?VPCOptions = null,
        cognito_options: ?CognitoOptions = null,
        advanced_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        access_policies: ?[]const u8 = null,
        ip_address_type: ?[]const u8 = null,
        log_publishing_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LogPublishingOption = null,
        } = null,
        encryption_at_rest_options: ?EncryptionAtRestOptions = null,
        domain_endpoint_options: ?DomainEndpointOptions = null,
        node_to_node_encryption_options: ?NodeToNodeEncryptionOptions = null,
        advanced_security_options: ?AdvancedSecurityOptionsInput = null,
        auto_tune_options: ?AutoTuneOptions = null,
        dry_run: ?bool = null,
        dry_run_mode: ?[]const u8 = null,
        off_peak_window_options: ?OffPeakWindowOptions = null,
        software_update_options: ?SoftwareUpdateOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .cluster_config = "ClusterConfig",
                .ebs_options = "EBSOptions",
                .snapshot_options = "SnapshotOptions",
                .vpc_options = "VPCOptions",
                .cognito_options = "CognitoOptions",
                .advanced_options = "AdvancedOptions",
                .access_policies = "AccessPolicies",
                .ip_address_type = "IPAddressType",
                .log_publishing_options = "LogPublishingOptions",
                .encryption_at_rest_options = "EncryptionAtRestOptions",
                .domain_endpoint_options = "DomainEndpointOptions",
                .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
                .advanced_security_options = "AdvancedSecurityOptions",
                .auto_tune_options = "AutoTuneOptions",
                .dry_run = "DryRun",
                .dry_run_mode = "DryRunMode",
                .off_peak_window_options = "OffPeakWindowOptions",
                .software_update_options = "SoftwareUpdateOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "advanced_options", field_name))
                return try serializeMap(self.advanced_options, self.fieldNameFor("advanced_options"), options, out_stream);
            if (std.mem.eql(u8, "log_publishing_options", field_name))
                return try serializeMap(self.log_publishing_options, self.fieldNameFor("log_publishing_options"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_domain_config) } {
            return .{ .service_metadata = service_metadata, .action = update_domain_config };
        }
    },
    Response: type = struct {
        domain_config: DomainConfig,
        dry_run_results: ?DryRunResults = null,
        dry_run_progress_status: ?DryRunProgressStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_config = "DomainConfig",
                .dry_run_results = "DryRunResults",
                .dry_run_progress_status = "DryRunProgressStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Internal,
        InvalidType,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/packages/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePackage",
    Request: type = struct {
        package_id: []const u8,
        package_source: PackageSource,
        package_description: ?[]const u8 = null,
        commit_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageID",
                .package_source = "PackageSource",
                .package_description = "PackageDescription",
                .commit_message = "CommitMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_package) } {
            return .{ .service_metadata = service_metadata, .action = update_package };
        }
    },
    Response: type = struct {
        package_details: ?PackageDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_details = "PackageDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Base,
        Internal,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_scheduled_action: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2021-01-01/opensearch/domain/{DomainName}/scheduledAction/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateScheduledAction",
    Request: type = struct {
        domain_name: []const u8,
        action_id: []const u8,
        action_type: []const u8,
        schedule_at: []const u8,
        desired_start_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .action_id = "ActionID",
                .action_type = "ActionType",
                .schedule_at = "ScheduleAt",
                .desired_start_time = "DesiredStartTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_scheduled_action) } {
            return .{ .service_metadata = service_metadata, .action = update_scheduled_action };
        }
    },
    Response: type = struct {
        scheduled_action: ?ScheduledAction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_action = "ScheduledAction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Conflict,
        Internal,
        LimitExceeded,
        ResourceNotFound,
        SlotNotAvailable,
        Validation,
    },
} = .{};
pub const update_vpc_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/vpcEndpoints/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVpcEndpoint",
    Request: type = struct {
        vpc_endpoint_id: []const u8,
        vpc_options: VPCOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_id = "VpcEndpointId",
                .vpc_options = "VpcOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vpc_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = update_vpc_endpoint };
        }
    },
    Response: type = struct {
        vpc_endpoint: VpcEndpoint,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint = "VpcEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Base,
        Conflict,
        DisabledOperation,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const upgrade_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2021-01-01/opensearch/upgradeDomain",
        .success_code = 200,
    };

    action_name: []const u8 = "UpgradeDomain",
    Request: type = struct {
        domain_name: []const u8,
        target_version: []const u8,
        perform_check_only: ?bool = null,
        advanced_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .target_version = "TargetVersion",
                .perform_check_only = "PerformCheckOnly",
                .advanced_options = "AdvancedOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "advanced_options", field_name))
                return try serializeMap(self.advanced_options, self.fieldNameFor("advanced_options"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upgrade_domain) } {
            return .{ .service_metadata = service_metadata, .action = upgrade_domain };
        }
    },
    Response: type = struct {
        upgrade_id: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        target_version: ?[]const u8 = null,
        perform_check_only: ?bool = null,
        advanced_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        change_progress_details: ?ChangeProgressDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upgrade_id = "UpgradeId",
                .domain_name = "DomainName",
                .target_version = "TargetVersion",
                .perform_check_only = "PerformCheckOnly",
                .advanced_options = "AdvancedOptions",
                .change_progress_details = "ChangeProgressDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "advanced_options", field_name))
                return try serializeMap(self.advanced_options, self.fieldNameFor("advanced_options"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Base,
        DisabledOperation,
        Internal,
        ResourceAlreadyExists,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const ChangeProgressDetails = struct {
    change_id: ?[]const u8 = null,
    message: ?[]const u8 = null,
    config_change_status: ?[]const u8 = null,
    initiated_by: ?[]const u8 = null,
    start_time: ?i64 = null,
    last_updated_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .change_id = "ChangeId",
            .message = "Message",
            .config_change_status = "ConfigChangeStatus",
            .initiated_by = "InitiatedBy",
            .start_time = "StartTime",
            .last_updated_time = "LastUpdatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcEndpoint = struct {
    vpc_endpoint_id: ?[]const u8 = null,
    vpc_endpoint_owner: ?[]const u8 = null,
    domain_arn: ?[]const u8 = null,
    vpc_options: ?VPCDerivedInfo = null,
    status: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_endpoint_id = "VpcEndpointId",
            .vpc_endpoint_owner = "VpcEndpointOwner",
            .domain_arn = "DomainArn",
            .vpc_options = "VpcOptions",
            .status = "Status",
            .endpoint = "Endpoint",
        };
        return @field(mappings, field_name);
    }
};

pub const VPCDerivedInfo = struct {
    vpc_id: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    availability_zones: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VPCId",
            .subnet_ids = "SubnetIds",
            .availability_zones = "AvailabilityZones",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const VPCOptions = struct {
    subnet_ids: ?[][]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduledAction = struct {
    id: []const u8,
    type: []const u8,
    severity: []const u8,
    scheduled_time: i64,
    description: ?[]const u8 = null,
    scheduled_by: ?[]const u8 = null,
    status: ?[]const u8 = null,
    mandatory: ?bool = null,
    cancellable: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .type = "Type",
            .severity = "Severity",
            .scheduled_time = "ScheduledTime",
            .description = "Description",
            .scheduled_by = "ScheduledBy",
            .status = "Status",
            .mandatory = "Mandatory",
            .cancellable = "Cancellable",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageDetails = struct {
    package_id: ?[]const u8 = null,
    package_name: ?[]const u8 = null,
    package_type: ?[]const u8 = null,
    package_description: ?[]const u8 = null,
    package_status: ?[]const u8 = null,
    created_at: ?i64 = null,
    last_updated_at: ?i64 = null,
    available_package_version: ?[]const u8 = null,
    error_details: ?ErrorDetails = null,
    engine_version: ?[]const u8 = null,
    available_plugin_properties: ?PluginProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_id = "PackageID",
            .package_name = "PackageName",
            .package_type = "PackageType",
            .package_description = "PackageDescription",
            .package_status = "PackageStatus",
            .created_at = "CreatedAt",
            .last_updated_at = "LastUpdatedAt",
            .available_package_version = "AvailablePackageVersion",
            .error_details = "ErrorDetails",
            .engine_version = "EngineVersion",
            .available_plugin_properties = "AvailablePluginProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const PluginProperties = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    version: ?[]const u8 = null,
    class_name: ?[]const u8 = null,
    uncompressed_size_in_bytes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .version = "Version",
            .class_name = "ClassName",
            .uncompressed_size_in_bytes = "UncompressedSizeInBytes",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetails = struct {
    error_type: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_type = "ErrorType",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageSource = struct {
    s3_bucket_name: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "S3BucketName",
            .s3_key = "S3Key",
        };
        return @field(mappings, field_name);
    }
};

pub const DryRunProgressStatus = struct {
    dry_run_id: []const u8,
    dry_run_status: []const u8,
    creation_date: []const u8,
    update_date: []const u8,
    validation_failures: ?[]ValidationFailure = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dry_run_id = "DryRunId",
            .dry_run_status = "DryRunStatus",
            .creation_date = "CreationDate",
            .update_date = "UpdateDate",
            .validation_failures = "ValidationFailures",
        };
        return @field(mappings, field_name);
    }
};

pub const ValidationFailure = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const DryRunResults = struct {
    deployment_type: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .deployment_type = "DeploymentType",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainConfig = struct {
    engine_version: ?VersionStatus = null,
    cluster_config: ?ClusterConfigStatus = null,
    ebs_options: ?EBSOptionsStatus = null,
    access_policies: ?AccessPoliciesStatus = null,
    ip_address_type: ?IPAddressTypeStatus = null,
    snapshot_options: ?SnapshotOptionsStatus = null,
    vpc_options: ?VPCDerivedInfoStatus = null,
    cognito_options: ?CognitoOptionsStatus = null,
    encryption_at_rest_options: ?EncryptionAtRestOptionsStatus = null,
    node_to_node_encryption_options: ?NodeToNodeEncryptionOptionsStatus = null,
    advanced_options: ?AdvancedOptionsStatus = null,
    log_publishing_options: ?LogPublishingOptionsStatus = null,
    domain_endpoint_options: ?DomainEndpointOptionsStatus = null,
    advanced_security_options: ?AdvancedSecurityOptionsStatus = null,
    auto_tune_options: ?AutoTuneOptionsStatus = null,
    change_progress_details: ?ChangeProgressDetails = null,
    off_peak_window_options: ?OffPeakWindowOptionsStatus = null,
    software_update_options: ?SoftwareUpdateOptionsStatus = null,
    modifying_properties: ?[]ModifyingProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .engine_version = "EngineVersion",
            .cluster_config = "ClusterConfig",
            .ebs_options = "EBSOptions",
            .access_policies = "AccessPolicies",
            .ip_address_type = "IPAddressType",
            .snapshot_options = "SnapshotOptions",
            .vpc_options = "VPCOptions",
            .cognito_options = "CognitoOptions",
            .encryption_at_rest_options = "EncryptionAtRestOptions",
            .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
            .advanced_options = "AdvancedOptions",
            .log_publishing_options = "LogPublishingOptions",
            .domain_endpoint_options = "DomainEndpointOptions",
            .advanced_security_options = "AdvancedSecurityOptions",
            .auto_tune_options = "AutoTuneOptions",
            .change_progress_details = "ChangeProgressDetails",
            .off_peak_window_options = "OffPeakWindowOptions",
            .software_update_options = "SoftwareUpdateOptions",
            .modifying_properties = "ModifyingProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const ModifyingProperties = struct {
    name: ?[]const u8 = null,
    active_value: ?[]const u8 = null,
    pending_value: ?[]const u8 = null,
    value_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .active_value = "ActiveValue",
            .pending_value = "PendingValue",
            .value_type = "ValueType",
        };
        return @field(mappings, field_name);
    }
};

pub const SoftwareUpdateOptionsStatus = struct {
    options: ?SoftwareUpdateOptions = null,
    status: ?OptionStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const OptionStatus = struct {
    creation_date: i64,
    update_date: i64,
    update_version: ?i64 = null,
    state: []const u8,
    pending_deletion: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_date = "CreationDate",
            .update_date = "UpdateDate",
            .update_version = "UpdateVersion",
            .state = "State",
            .pending_deletion = "PendingDeletion",
        };
        return @field(mappings, field_name);
    }
};

pub const SoftwareUpdateOptions = struct {
    auto_software_update_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_software_update_enabled = "AutoSoftwareUpdateEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const OffPeakWindowOptionsStatus = struct {
    options: ?OffPeakWindowOptions = null,
    status: ?OptionStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const OffPeakWindowOptions = struct {
    enabled: ?bool = null,
    off_peak_window: ?OffPeakWindow = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .off_peak_window = "OffPeakWindow",
        };
        return @field(mappings, field_name);
    }
};

pub const OffPeakWindow = struct {
    window_start_time: ?WindowStartTime = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .window_start_time = "WindowStartTime",
        };
        return @field(mappings, field_name);
    }
};

pub const WindowStartTime = struct {
    hours: i64,
    minutes: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hours = "Hours",
            .minutes = "Minutes",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoTuneOptionsStatus = struct {
    options: ?AutoTuneOptions = null,
    status: ?AutoTuneStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoTuneStatus = struct {
    creation_date: i64,
    update_date: i64,
    update_version: ?i64 = null,
    state: []const u8,
    error_message: ?[]const u8 = null,
    pending_deletion: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_date = "CreationDate",
            .update_date = "UpdateDate",
            .update_version = "UpdateVersion",
            .state = "State",
            .error_message = "ErrorMessage",
            .pending_deletion = "PendingDeletion",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoTuneOptions = struct {
    desired_state: ?[]const u8 = null,
    rollback_on_disable: ?[]const u8 = null,
    maintenance_schedules: ?[]AutoTuneMaintenanceSchedule = null,
    use_off_peak_window: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .desired_state = "DesiredState",
            .rollback_on_disable = "RollbackOnDisable",
            .maintenance_schedules = "MaintenanceSchedules",
            .use_off_peak_window = "UseOffPeakWindow",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoTuneMaintenanceSchedule = struct {
    start_at: ?i64 = null,
    duration: ?Duration = null,
    cron_expression_for_recurrence: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_at = "StartAt",
            .duration = "Duration",
            .cron_expression_for_recurrence = "CronExpressionForRecurrence",
        };
        return @field(mappings, field_name);
    }
};

pub const Duration = struct {
    value: ?i64 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedSecurityOptionsStatus = struct {
    options: AdvancedSecurityOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedSecurityOptions = struct {
    enabled: ?bool = null,
    internal_user_database_enabled: ?bool = null,
    saml_options: ?SAMLOptionsOutput = null,
    anonymous_auth_disable_date: ?i64 = null,
    anonymous_auth_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .internal_user_database_enabled = "InternalUserDatabaseEnabled",
            .saml_options = "SAMLOptions",
            .anonymous_auth_disable_date = "AnonymousAuthDisableDate",
            .anonymous_auth_enabled = "AnonymousAuthEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const SAMLOptionsOutput = struct {
    enabled: ?bool = null,
    idp: ?SAMLIdp = null,
    subject_key: ?[]const u8 = null,
    roles_key: ?[]const u8 = null,
    session_timeout_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .idp = "Idp",
            .subject_key = "SubjectKey",
            .roles_key = "RolesKey",
            .session_timeout_minutes = "SessionTimeoutMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const SAMLIdp = struct {
    metadata_content: []const u8,
    entity_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metadata_content = "MetadataContent",
            .entity_id = "EntityId",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainEndpointOptionsStatus = struct {
    options: DomainEndpointOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainEndpointOptions = struct {
    enforce_https: ?bool = null,
    tls_security_policy: ?[]const u8 = null,
    custom_endpoint_enabled: ?bool = null,
    custom_endpoint: ?[]const u8 = null,
    custom_endpoint_certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enforce_https = "EnforceHTTPS",
            .tls_security_policy = "TLSSecurityPolicy",
            .custom_endpoint_enabled = "CustomEndpointEnabled",
            .custom_endpoint = "CustomEndpoint",
            .custom_endpoint_certificate_arn = "CustomEndpointCertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LogPublishingOptionsStatus = struct {
    options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?LogPublishingOption = null,
    } = null,
    status: ?OptionStatus = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "options", field_name))
            return try serializeMap(self.options, self.fieldNameFor("options"), options, out_stream);
        return false;
    }
};

pub const LogPublishingOption = struct {
    cloud_watch_logs_log_group_arn: ?[]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedOptionsStatus = struct {
    options: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "options", field_name))
            return try serializeMap(self.options, self.fieldNameFor("options"), options, out_stream);
        return false;
    }
};

pub const NodeToNodeEncryptionOptionsStatus = struct {
    options: NodeToNodeEncryptionOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeToNodeEncryptionOptions = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionAtRestOptionsStatus = struct {
    options: EncryptionAtRestOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionAtRestOptions = struct {
    enabled: ?bool = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const CognitoOptionsStatus = struct {
    options: CognitoOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const CognitoOptions = struct {
    enabled: ?bool = null,
    user_pool_id: ?[]const u8 = null,
    identity_pool_id: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .user_pool_id = "UserPoolId",
            .identity_pool_id = "IdentityPoolId",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const VPCDerivedInfoStatus = struct {
    options: VPCDerivedInfo,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotOptionsStatus = struct {
    options: SnapshotOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const SnapshotOptions = struct {
    automated_snapshot_start_hour: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automated_snapshot_start_hour = "AutomatedSnapshotStartHour",
        };
        return @field(mappings, field_name);
    }
};

pub const IPAddressTypeStatus = struct {
    options: []const u8,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessPoliciesStatus = struct {
    options: []const u8,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const EBSOptionsStatus = struct {
    options: EBSOptions,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const EBSOptions = struct {
    ebs_enabled: ?bool = null,
    volume_type: ?[]const u8 = null,
    volume_size: ?i64 = null,
    iops: ?i64 = null,
    throughput: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ebs_enabled = "EBSEnabled",
            .volume_type = "VolumeType",
            .volume_size = "VolumeSize",
            .iops = "Iops",
            .throughput = "Throughput",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterConfigStatus = struct {
    options: ClusterConfig,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterConfig = struct {
    instance_type: ?[]const u8 = null,
    instance_count: ?i64 = null,
    dedicated_master_enabled: ?bool = null,
    zone_awareness_enabled: ?bool = null,
    zone_awareness_config: ?ZoneAwarenessConfig = null,
    dedicated_master_type: ?[]const u8 = null,
    dedicated_master_count: ?i64 = null,
    warm_enabled: ?bool = null,
    warm_type: ?[]const u8 = null,
    warm_count: ?i64 = null,
    cold_storage_options: ?ColdStorageOptions = null,
    multi_az_with_standby_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_type = "InstanceType",
            .instance_count = "InstanceCount",
            .dedicated_master_enabled = "DedicatedMasterEnabled",
            .zone_awareness_enabled = "ZoneAwarenessEnabled",
            .zone_awareness_config = "ZoneAwarenessConfig",
            .dedicated_master_type = "DedicatedMasterType",
            .dedicated_master_count = "DedicatedMasterCount",
            .warm_enabled = "WarmEnabled",
            .warm_type = "WarmType",
            .warm_count = "WarmCount",
            .cold_storage_options = "ColdStorageOptions",
            .multi_az_with_standby_enabled = "MultiAZWithStandbyEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ColdStorageOptions = struct {
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ZoneAwarenessConfig = struct {
    availability_zone_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone_count = "AvailabilityZoneCount",
        };
        return @field(mappings, field_name);
    }
};

pub const VersionStatus = struct {
    options: []const u8,
    status: OptionStatus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedSecurityOptionsInput = struct {
    enabled: ?bool = null,
    internal_user_database_enabled: ?bool = null,
    master_user_options: ?MasterUserOptions = null,
    saml_options: ?SAMLOptionsInput = null,
    anonymous_auth_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .internal_user_database_enabled = "InternalUserDatabaseEnabled",
            .master_user_options = "MasterUserOptions",
            .saml_options = "SAMLOptions",
            .anonymous_auth_enabled = "AnonymousAuthEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const SAMLOptionsInput = struct {
    enabled: ?bool = null,
    idp: ?SAMLIdp = null,
    master_user_name: ?[]const u8 = null,
    master_backend_role: ?[]const u8 = null,
    subject_key: ?[]const u8 = null,
    roles_key: ?[]const u8 = null,
    session_timeout_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .idp = "Idp",
            .master_user_name = "MasterUserName",
            .master_backend_role = "MasterBackendRole",
            .subject_key = "SubjectKey",
            .roles_key = "RolesKey",
            .session_timeout_minutes = "SessionTimeoutMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const MasterUserOptions = struct {
    master_user_arn: ?[]const u8 = null,
    master_user_name: ?[]const u8 = null,
    master_user_password: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .master_user_arn = "MasterUserARN",
            .master_user_name = "MasterUserName",
            .master_user_password = "MasterUserPassword",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceType = union {
    s3_glue_data_catalog: ?S3GlueDataCatalog,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_glue_data_catalog = "S3GlueDataCatalog",
        };
        return @field(mappings, field_name);
    }
};

pub const S3GlueDataCatalog = struct {
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceSoftwareOptions = struct {
    current_version: ?[]const u8 = null,
    new_version: ?[]const u8 = null,
    update_available: ?bool = null,
    cancellable: ?bool = null,
    update_status: ?[]const u8 = null,
    description: ?[]const u8 = null,
    automated_update_date: ?i64 = null,
    optional_deployment: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .current_version = "CurrentVersion",
            .new_version = "NewVersion",
            .update_available = "UpdateAvailable",
            .cancellable = "Cancellable",
            .update_status = "UpdateStatus",
            .description = "Description",
            .automated_update_date = "AutomatedUpdateDate",
            .optional_deployment = "OptionalDeployment",
        };
        return @field(mappings, field_name);
    }
};

pub const InboundConnection = struct {
    local_domain_info: ?DomainInformationContainer = null,
    remote_domain_info: ?DomainInformationContainer = null,
    connection_id: ?[]const u8 = null,
    connection_status: ?InboundConnectionStatus = null,
    connection_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_domain_info = "LocalDomainInfo",
            .remote_domain_info = "RemoteDomainInfo",
            .connection_id = "ConnectionId",
            .connection_status = "ConnectionStatus",
            .connection_mode = "ConnectionMode",
        };
        return @field(mappings, field_name);
    }
};

pub const InboundConnectionStatus = struct {
    status_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "StatusCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainInformationContainer = struct {
    aws_domain_information: ?AWSDomainInformation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_domain_information = "AWSDomainInformation",
        };
        return @field(mappings, field_name);
    }
};

pub const AWSDomainInformation = struct {
    owner_id: ?[]const u8 = null,
    domain_name: []const u8,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .domain_name = "DomainName",
            .region = "Region",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcEndpointSummary = struct {
    vpc_endpoint_id: ?[]const u8 = null,
    vpc_endpoint_owner: ?[]const u8 = null,
    domain_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_endpoint_id = "VpcEndpointId",
            .vpc_endpoint_owner = "VpcEndpointOwner",
            .domain_arn = "DomainArn",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthorizedPrincipal = struct {
    principal_type: ?[]const u8 = null,
    principal: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal_type = "PrincipalType",
            .principal = "Principal",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainPackageDetails = struct {
    package_id: ?[]const u8 = null,
    package_name: ?[]const u8 = null,
    package_type: ?[]const u8 = null,
    last_updated: ?i64 = null,
    domain_name: ?[]const u8 = null,
    domain_package_status: ?[]const u8 = null,
    package_version: ?[]const u8 = null,
    reference_path: ?[]const u8 = null,
    error_details: ?ErrorDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_id = "PackageID",
            .package_name = "PackageName",
            .package_type = "PackageType",
            .last_updated = "LastUpdated",
            .domain_name = "DomainName",
            .domain_package_status = "DomainPackageStatus",
            .package_version = "PackageVersion",
            .reference_path = "ReferencePath",
            .error_details = "ErrorDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const RecurringCharge = struct {
    recurring_charge_amount: ?f64 = null,
    recurring_charge_frequency: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recurring_charge_amount = "RecurringChargeAmount",
            .recurring_charge_frequency = "RecurringChargeFrequency",
        };
        return @field(mappings, field_name);
    }
};

pub const OutboundConnection = struct {
    local_domain_info: ?DomainInformationContainer = null,
    remote_domain_info: ?DomainInformationContainer = null,
    connection_id: ?[]const u8 = null,
    connection_alias: ?[]const u8 = null,
    connection_status: ?OutboundConnectionStatus = null,
    connection_mode: ?[]const u8 = null,
    connection_properties: ?ConnectionProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_domain_info = "LocalDomainInfo",
            .remote_domain_info = "RemoteDomainInfo",
            .connection_id = "ConnectionId",
            .connection_alias = "ConnectionAlias",
            .connection_status = "ConnectionStatus",
            .connection_mode = "ConnectionMode",
            .connection_properties = "ConnectionProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionProperties = struct {
    endpoint: ?[]const u8 = null,
    cross_cluster_search: ?CrossClusterSearchConnectionProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint = "Endpoint",
            .cross_cluster_search = "CrossClusterSearch",
        };
        return @field(mappings, field_name);
    }
};

pub const CrossClusterSearchConnectionProperties = struct {
    skip_unavailable: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .skip_unavailable = "SkipUnavailable",
        };
        return @field(mappings, field_name);
    }
};

pub const OutboundConnectionStatus = struct {
    status_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "StatusCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainStatus = struct {
    domain_id: []const u8,
    domain_name: []const u8,
    arn: []const u8,
    created: ?bool = null,
    deleted: ?bool = null,
    endpoint: ?[]const u8 = null,
    endpoint_v2: ?[]const u8 = null,
    endpoints: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    processing: ?bool = null,
    upgrade_processing: ?bool = null,
    engine_version: ?[]const u8 = null,
    cluster_config: ClusterConfig,
    ebs_options: ?EBSOptions = null,
    access_policies: ?[]const u8 = null,
    ip_address_type: ?[]const u8 = null,
    snapshot_options: ?SnapshotOptions = null,
    vpc_options: ?VPCDerivedInfo = null,
    cognito_options: ?CognitoOptions = null,
    encryption_at_rest_options: ?EncryptionAtRestOptions = null,
    node_to_node_encryption_options: ?NodeToNodeEncryptionOptions = null,
    advanced_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    log_publishing_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?LogPublishingOption = null,
    } = null,
    service_software_options: ?ServiceSoftwareOptions = null,
    domain_endpoint_options: ?DomainEndpointOptions = null,
    advanced_security_options: ?AdvancedSecurityOptions = null,
    auto_tune_options: ?AutoTuneOptionsOutput = null,
    change_progress_details: ?ChangeProgressDetails = null,
    off_peak_window_options: ?OffPeakWindowOptions = null,
    software_update_options: ?SoftwareUpdateOptions = null,
    domain_processing_status: ?[]const u8 = null,
    modifying_properties: ?[]ModifyingProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_id = "DomainId",
            .domain_name = "DomainName",
            .arn = "ARN",
            .created = "Created",
            .deleted = "Deleted",
            .endpoint = "Endpoint",
            .endpoint_v2 = "EndpointV2",
            .endpoints = "Endpoints",
            .processing = "Processing",
            .upgrade_processing = "UpgradeProcessing",
            .engine_version = "EngineVersion",
            .cluster_config = "ClusterConfig",
            .ebs_options = "EBSOptions",
            .access_policies = "AccessPolicies",
            .ip_address_type = "IPAddressType",
            .snapshot_options = "SnapshotOptions",
            .vpc_options = "VPCOptions",
            .cognito_options = "CognitoOptions",
            .encryption_at_rest_options = "EncryptionAtRestOptions",
            .node_to_node_encryption_options = "NodeToNodeEncryptionOptions",
            .advanced_options = "AdvancedOptions",
            .log_publishing_options = "LogPublishingOptions",
            .service_software_options = "ServiceSoftwareOptions",
            .domain_endpoint_options = "DomainEndpointOptions",
            .advanced_security_options = "AdvancedSecurityOptions",
            .auto_tune_options = "AutoTuneOptions",
            .change_progress_details = "ChangeProgressDetails",
            .off_peak_window_options = "OffPeakWindowOptions",
            .software_update_options = "SoftwareUpdateOptions",
            .domain_processing_status = "DomainProcessingStatus",
            .modifying_properties = "ModifyingProperties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "endpoints", field_name))
            return try serializeMap(self.endpoints, self.fieldNameFor("endpoints"), options, out_stream);
        if (std.mem.eql(u8, "advanced_options", field_name))
            return try serializeMap(self.advanced_options, self.fieldNameFor("advanced_options"), options, out_stream);
        if (std.mem.eql(u8, "log_publishing_options", field_name))
            return try serializeMap(self.log_publishing_options, self.fieldNameFor("log_publishing_options"), options, out_stream);
        return false;
    }
};

pub const AutoTuneOptionsOutput = struct {
    state: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    use_off_peak_window: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .error_message = "ErrorMessage",
            .use_off_peak_window = "UseOffPeakWindow",
        };
        return @field(mappings, field_name);
    }
};
