const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-11-01";
pub const sdk_id: []const u8 = "OpenSearchServerless";
pub const arn_namespace: ?[]const u8 = "aoss";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "aoss";
pub const name: []const u8 = "OpenSearchServerless";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2021-11-01",
    sdk_id: []const u8 = "OpenSearchServerless",
    arn_namespace: ?[]const u8 = "aoss",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "aoss",
    name: []const u8 = "OpenSearchServerless",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const batch_get_collection: struct {
    action_name: []const u8 = "BatchGetCollection",
    Request: type = struct {
        ids: ?[][]const u8 = null,
        names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
                .names = "names",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_collection) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_collection };
        }
    },
    Response: type = struct {
        collection_details: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            kms_key_arn: ?[]const u8 = null,
            standby_replicas: ?[]const u8 = null,
            created_date: ?i64 = null,
            last_modified_date: ?i64 = null,
            collection_endpoint: ?[]const u8 = null,
            dashboard_endpoint: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .status = "status",
                    .type = "type",
                    .description = "description",
                    .arn = "arn",
                    .kms_key_arn = "kmsKeyArn",
                    .standby_replicas = "standbyReplicas",
                    .created_date = "createdDate",
                    .last_modified_date = "lastModifiedDate",
                    .collection_endpoint = "collectionEndpoint",
                    .dashboard_endpoint = "dashboardEndpoint",
                };
                return @field(mappings, field_name);
            }
        } = null,
        collection_error_details: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            error_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .error_message = "errorMessage",
                    .error_code = "errorCode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_details = "collectionDetails",
                .collection_error_details = "collectionErrorDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const batch_get_effective_lifecycle_policy: struct {
    action_name: []const u8 = "BatchGetEffectiveLifecyclePolicy",
    Request: type = struct {
        resource_identifiers: []struct {
            type: []const u8,
            resource: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "type",
                    .resource = "resource",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifiers = "resourceIdentifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_effective_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_effective_lifecycle_policy };
        }
    },
    Response: type = struct {
        effective_lifecycle_policy_details: ?[]struct {
            type: ?[]const u8 = null,
            resource: ?[]const u8 = null,
            policy_name: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            retention_period: ?[]const u8 = null,
            no_min_retention_period: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "type",
                    .resource = "resource",
                    .policy_name = "policyName",
                    .resource_type = "resourceType",
                    .retention_period = "retentionPeriod",
                    .no_min_retention_period = "noMinRetentionPeriod",
                };
                return @field(mappings, field_name);
            }
        } = null,
        effective_lifecycle_policy_error_details: ?[]struct {
            type: ?[]const u8 = null,
            resource: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            error_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "type",
                    .resource = "resource",
                    .error_message = "errorMessage",
                    .error_code = "errorCode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .effective_lifecycle_policy_details = "effectiveLifecyclePolicyDetails",
                .effective_lifecycle_policy_error_details = "effectiveLifecyclePolicyErrorDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const batch_get_lifecycle_policy: struct {
    action_name: []const u8 = "BatchGetLifecyclePolicy",
    Request: type = struct {
        identifiers: []struct {
            type: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "type",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifiers = "identifiers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_lifecycle_policy };
        }
    },
    Response: type = struct {
        lifecycle_policy_details: ?[]LifecyclePolicyDetail = null,
        lifecycle_policy_error_details: ?[]struct {
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            error_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "type",
                    .name = "name",
                    .error_message = "errorMessage",
                    .error_code = "errorCode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policy_details = "lifecyclePolicyDetails",
                .lifecycle_policy_error_details = "lifecyclePolicyErrorDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const batch_get_vpc_endpoint: struct {
    action_name: []const u8 = "BatchGetVpcEndpoint",
    Request: type = struct {
        ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_vpc_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_vpc_endpoint };
        }
    },
    Response: type = struct {
        vpc_endpoint_details: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            vpc_id: ?[]const u8 = null,
            subnet_ids: ?[][]const u8 = null,
            security_group_ids: ?[][]const u8 = null,
            status: ?[]const u8 = null,
            created_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .vpc_id = "vpcId",
                    .subnet_ids = "subnetIds",
                    .security_group_ids = "securityGroupIds",
                    .status = "status",
                    .created_date = "createdDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        vpc_endpoint_error_details: ?[]struct {
            id: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            error_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .error_message = "errorMessage",
                    .error_code = "errorCode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_endpoint_details = "vpcEndpointDetails",
                .vpc_endpoint_error_details = "vpcEndpointErrorDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const create_lifecycle_policy: struct {
    action_name: []const u8 = "CreateLifecyclePolicy",
    Request: type = struct {
        type: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        policy: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "type",
                .name = "name",
                .description = "description",
                .policy = "policy",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_lifecycle_policy };
        }
    },
    Response: type = struct {
        lifecycle_policy_detail: ?LifecyclePolicyDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_policy_detail = "lifecyclePolicyDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_security_policy: struct {
    action_name: []const u8 = "CreateSecurityPolicy",
    Request: type = struct {
        type: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        policy: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "type",
                .name = "name",
                .description = "description",
                .policy = "policy",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_security_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_security_policy };
        }
    },
    Response: type = struct {
        security_policy_detail: ?struct {
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            policy_version: ?[]const u8 = null,
            description: ?[]const u8 = null,
            policy: ?[]const u8 = null,
            created_date: ?i64 = null,
            last_modified_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "type",
                    .name = "name",
                    .policy_version = "policyVersion",
                    .description = "description",
                    .policy = "policy",
                    .created_date = "createdDate",
                    .last_modified_date = "lastModifiedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_policy_detail = "securityPolicyDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const get_account_settings: struct {
    action_name: []const u8 = "GetAccountSettings",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_account_settings };
        }
    },
    Response: type = struct {
        account_settings_detail: ?AccountSettingsDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_settings_detail = "accountSettingsDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const get_policies_stats: struct {
    action_name: []const u8 = "GetPoliciesStats",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_policies_stats) } {
            return .{ .service_metadata = service_metadata, .action = get_policies_stats };
        }
    },
    Response: type = struct {
        access_policy_stats: ?struct {
            data_policy_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data_policy_count = "DataPolicyCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        security_policy_stats: ?struct {
            encryption_policy_count: ?i64 = null,
            network_policy_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .encryption_policy_count = "EncryptionPolicyCount",
                    .network_policy_count = "NetworkPolicyCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        security_config_stats: ?struct {
            saml_config_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .saml_config_count = "SamlConfigCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lifecycle_policy_stats: ?struct {
            retention_policy_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .retention_policy_count = "RetentionPolicyCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        total_policy_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_policy_stats = "AccessPolicyStats",
                .security_policy_stats = "SecurityPolicyStats",
                .security_config_stats = "SecurityConfigStats",
                .lifecycle_policy_stats = "LifecyclePolicyStats",
                .total_policy_count = "TotalPolicyCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_account_settings: struct {
    action_name: []const u8 = "UpdateAccountSettings",
    Request: type = struct {
        capacity_limits: ?CapacityLimits = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity_limits = "capacityLimits",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_account_settings };
        }
    },
    Response: type = struct {
        account_settings_detail: ?AccountSettingsDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_settings_detail = "accountSettingsDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const update_vpc_endpoint: struct {
    action_name: []const u8 = "UpdateVpcEndpoint",
    Request: type = struct {
        id: []const u8,
        add_subnet_ids: ?[][]const u8 = null,
        remove_subnet_ids: ?[][]const u8 = null,
        add_security_group_ids: ?[][]const u8 = null,
        remove_security_group_ids: ?[][]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .add_subnet_ids = "addSubnetIds",
                .remove_subnet_ids = "removeSubnetIds",
                .add_security_group_ids = "addSecurityGroupIds",
                .remove_security_group_ids = "removeSecurityGroupIds",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vpc_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = update_vpc_endpoint };
        }
    },
    Response: type = struct {
        update_vpc_endpoint_detail: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            subnet_ids: ?[][]const u8 = null,
            security_group_ids: ?[][]const u8 = null,
            last_modified_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .status = "status",
                    .subnet_ids = "subnetIds",
                    .security_group_ids = "securityGroupIds",
                    .last_modified_date = "lastModifiedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_vpc_endpoint_detail = "UpdateVpcEndpointDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};

pub const AccountSettingsDetail = struct {
    capacity_limits: ?CapacityLimits = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity_limits = "capacityLimits",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacityLimits = struct {
    max_indexing_capacity_in_ocu: ?i64 = null,
    max_search_capacity_in_ocu: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_indexing_capacity_in_ocu = "maxIndexingCapacityInOCU",
            .max_search_capacity_in_ocu = "maxSearchCapacityInOCU",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecyclePolicyDetail = struct {
    type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    policy_version: ?[]const u8 = null,
    description: ?[]const u8 = null,
    policy: ?[]const u8 = null,
    created_date: ?i64 = null,
    last_modified_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .name = "name",
            .policy_version = "policyVersion",
            .description = "description",
            .policy = "policy",
            .created_date = "createdDate",
            .last_modified_date = "lastModifiedDate",
        };
        return @field(mappings, field_name);
    }
};
