const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-11-01";
pub const sdk_id: []const u8 = "OpsWorksCM";
pub const arn_namespace: ?[]const u8 = "opsworks-cm";
pub const endpoint_prefix: []const u8 = "opsworks-cm";
pub const sigv4_name: []const u8 = "opsworks-cm";
pub const name: []const u8 = "OpsWorksCM_V2016_11_01";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-11-01",
    sdk_id: []const u8 = "OpsWorksCM",
    arn_namespace: ?[]const u8 = "opsworks-cm",
    endpoint_prefix: []const u8 = "opsworks-cm",
    sigv4_name: []const u8 = "opsworks-cm",
    name: []const u8 = "OpsWorksCM_V2016_11_01",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_node: struct {
    action_name: []const u8 = "AssociateNode",
    Request: type = struct {
        server_name: []const u8,
        node_name: []const u8,
        engine_attributes: []EngineAttribute,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_name = "ServerName",
                .node_name = "NodeName",
                .engine_attributes = "EngineAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_node) } {
            return .{ .service_metadata = service_metadata, .action = associate_node };
        }
    },
    Response: type = struct {
        node_association_status_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_association_status_token = "NodeAssociationStatusToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_backup: struct {
    action_name: []const u8 = "CreateBackup",
    Request: type = struct {
        server_name: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_name = "ServerName",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backup) } {
            return .{ .service_metadata = service_metadata, .action = create_backup };
        }
    },
    Response: type = struct {
        backup: ?Backup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup = "Backup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_server: struct {
    action_name: []const u8 = "CreateServer",
    Request: type = struct {
        associate_public_ip_address: ?bool = null,
        custom_domain: ?[]const u8 = null,
        custom_certificate: ?[]const u8 = null,
        custom_private_key: ?[]const u8 = null,
        disable_automated_backup: ?bool = null,
        engine: []const u8,
        engine_model: ?[]const u8 = null,
        engine_version: ?[]const u8 = null,
        engine_attributes: ?[]EngineAttribute = null,
        backup_retention_count: ?i64 = null,
        server_name: []const u8,
        instance_profile_arn: []const u8,
        instance_type: []const u8,
        key_pair: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        preferred_backup_window: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        service_role_arn: []const u8,
        subnet_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        backup_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associate_public_ip_address = "AssociatePublicIpAddress",
                .custom_domain = "CustomDomain",
                .custom_certificate = "CustomCertificate",
                .custom_private_key = "CustomPrivateKey",
                .disable_automated_backup = "DisableAutomatedBackup",
                .engine = "Engine",
                .engine_model = "EngineModel",
                .engine_version = "EngineVersion",
                .engine_attributes = "EngineAttributes",
                .backup_retention_count = "BackupRetentionCount",
                .server_name = "ServerName",
                .instance_profile_arn = "InstanceProfileArn",
                .instance_type = "InstanceType",
                .key_pair = "KeyPair",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .preferred_backup_window = "PreferredBackupWindow",
                .security_group_ids = "SecurityGroupIds",
                .service_role_arn = "ServiceRoleArn",
                .subnet_ids = "SubnetIds",
                .tags = "Tags",
                .backup_id = "BackupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_server) } {
            return .{ .service_metadata = service_metadata, .action = create_server };
        }
    },
    Response: type = struct {
        server: ?Server = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server = "Server",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_backup: struct {
    action_name: []const u8 = "DeleteBackup",
    Request: type = struct {
        backup_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_server: struct {
    action_name: []const u8 = "DeleteServer",
    Request: type = struct {
        server_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_name = "ServerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_server) } {
            return .{ .service_metadata = service_metadata, .action = delete_server };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_account_attributes: struct {
    action_name: []const u8 = "DescribeAccountAttributes",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            name: ?[]const u8 = null,
            maximum: ?i64 = null,
            used: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .maximum = "Maximum",
                    .used = "Used",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_backups: struct {
    action_name: []const u8 = "DescribeBackups",
    Request: type = struct {
        backup_id: ?[]const u8 = null,
        server_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
                .server_name = "ServerName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_backups) } {
            return .{ .service_metadata = service_metadata, .action = describe_backups };
        }
    },
    Response: type = struct {
        backups: ?[]Backup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backups = "Backups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        server_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_name = "ServerName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        server_events: ?[]struct {
            created_at: ?i64 = null,
            server_name: ?[]const u8 = null,
            message: ?[]const u8 = null,
            log_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_at = "CreatedAt",
                    .server_name = "ServerName",
                    .message = "Message",
                    .log_url = "LogUrl",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_events = "ServerEvents",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_node_association_status: struct {
    action_name: []const u8 = "DescribeNodeAssociationStatus",
    Request: type = struct {
        node_association_status_token: []const u8,
        server_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_association_status_token = "NodeAssociationStatusToken",
                .server_name = "ServerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_node_association_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_node_association_status };
        }
    },
    Response: type = struct {
        node_association_status: ?[]const u8 = null,
        engine_attributes: ?[]EngineAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_association_status = "NodeAssociationStatus",
                .engine_attributes = "EngineAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_servers: struct {
    action_name: []const u8 = "DescribeServers",
    Request: type = struct {
        server_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_name = "ServerName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_servers) } {
            return .{ .service_metadata = service_metadata, .action = describe_servers };
        }
    },
    Response: type = struct {
        servers: ?[]Server = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .servers = "Servers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const disassociate_node: struct {
    action_name: []const u8 = "DisassociateNode",
    Request: type = struct {
        server_name: []const u8,
        node_name: []const u8,
        engine_attributes: ?[]EngineAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_name = "ServerName",
                .node_name = "NodeName",
                .engine_attributes = "EngineAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_node) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_node };
        }
    },
    Response: type = struct {
        node_association_status_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_association_status_token = "NodeAssociationStatusToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const export_server_engine_attribute: struct {
    action_name: []const u8 = "ExportServerEngineAttribute",
    Request: type = struct {
        export_attribute_name: []const u8,
        server_name: []const u8,
        input_attributes: ?[]EngineAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_attribute_name = "ExportAttributeName",
                .server_name = "ServerName",
                .input_attributes = "InputAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_server_engine_attribute) } {
            return .{ .service_metadata = service_metadata, .action = export_server_engine_attribute };
        }
    },
    Response: type = struct {
        engine_attribute: ?EngineAttribute = null,
        server_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_attribute = "EngineAttribute",
                .server_name = "ServerName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const restore_server: struct {
    action_name: []const u8 = "RestoreServer",
    Request: type = struct {
        backup_id: []const u8,
        server_name: []const u8,
        instance_type: ?[]const u8 = null,
        key_pair: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
                .server_name = "ServerName",
                .instance_type = "InstanceType",
                .key_pair = "KeyPair",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_server) } {
            return .{ .service_metadata = service_metadata, .action = restore_server };
        }
    },
    Response: type = struct {
        server: ?Server = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server = "Server",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_maintenance: struct {
    action_name: []const u8 = "StartMaintenance",
    Request: type = struct {
        server_name: []const u8,
        engine_attributes: ?[]EngineAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_name = "ServerName",
                .engine_attributes = "EngineAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_maintenance) } {
            return .{ .service_metadata = service_metadata, .action = start_maintenance };
        }
    },
    Response: type = struct {
        server: ?Server = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server = "Server",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_server: struct {
    action_name: []const u8 = "UpdateServer",
    Request: type = struct {
        disable_automated_backup: ?bool = null,
        backup_retention_count: ?i64 = null,
        server_name: []const u8,
        preferred_maintenance_window: ?[]const u8 = null,
        preferred_backup_window: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .disable_automated_backup = "DisableAutomatedBackup",
                .backup_retention_count = "BackupRetentionCount",
                .server_name = "ServerName",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .preferred_backup_window = "PreferredBackupWindow",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_server) } {
            return .{ .service_metadata = service_metadata, .action = update_server };
        }
    },
    Response: type = struct {
        server: ?Server = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server = "Server",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_server_engine_attributes: struct {
    action_name: []const u8 = "UpdateServerEngineAttributes",
    Request: type = struct {
        server_name: []const u8,
        attribute_name: []const u8,
        attribute_value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_name = "ServerName",
                .attribute_name = "AttributeName",
                .attribute_value = "AttributeValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_server_engine_attributes) } {
            return .{ .service_metadata = service_metadata, .action = update_server_engine_attributes };
        }
    },
    Response: type = struct {
        server: ?Server = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server = "Server",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const Server = struct {
    associate_public_ip_address: ?bool = null,
    backup_retention_count: ?i64 = null,
    server_name: ?[]const u8 = null,
    created_at: ?i64 = null,
    cloud_formation_stack_arn: ?[]const u8 = null,
    custom_domain: ?[]const u8 = null,
    disable_automated_backup: ?bool = null,
    endpoint: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    engine_model: ?[]const u8 = null,
    engine_attributes: ?[]EngineAttribute = null,
    engine_version: ?[]const u8 = null,
    instance_profile_arn: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    key_pair: ?[]const u8 = null,
    maintenance_status: ?[]const u8 = null,
    preferred_maintenance_window: ?[]const u8 = null,
    preferred_backup_window: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    service_role_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_reason: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    server_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associate_public_ip_address = "AssociatePublicIpAddress",
            .backup_retention_count = "BackupRetentionCount",
            .server_name = "ServerName",
            .created_at = "CreatedAt",
            .cloud_formation_stack_arn = "CloudFormationStackArn",
            .custom_domain = "CustomDomain",
            .disable_automated_backup = "DisableAutomatedBackup",
            .endpoint = "Endpoint",
            .engine = "Engine",
            .engine_model = "EngineModel",
            .engine_attributes = "EngineAttributes",
            .engine_version = "EngineVersion",
            .instance_profile_arn = "InstanceProfileArn",
            .instance_type = "InstanceType",
            .key_pair = "KeyPair",
            .maintenance_status = "MaintenanceStatus",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .preferred_backup_window = "PreferredBackupWindow",
            .security_group_ids = "SecurityGroupIds",
            .service_role_arn = "ServiceRoleArn",
            .status = "Status",
            .status_reason = "StatusReason",
            .subnet_ids = "SubnetIds",
            .server_arn = "ServerArn",
        };
        return @field(mappings, field_name);
    }
};

pub const EngineAttribute = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Backup = struct {
    backup_arn: ?[]const u8 = null,
    backup_id: ?[]const u8 = null,
    backup_type: ?[]const u8 = null,
    created_at: ?i64 = null,
    description: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    engine_model: ?[]const u8 = null,
    engine_version: ?[]const u8 = null,
    instance_profile_arn: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    key_pair: ?[]const u8 = null,
    preferred_backup_window: ?[]const u8 = null,
    preferred_maintenance_window: ?[]const u8 = null,
    s3_data_size: ?i64 = null,
    s3_data_url: ?[]const u8 = null,
    s3_log_url: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    server_name: ?[]const u8 = null,
    service_role_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_description: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    tools_version: ?[]const u8 = null,
    user_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_arn = "BackupArn",
            .backup_id = "BackupId",
            .backup_type = "BackupType",
            .created_at = "CreatedAt",
            .description = "Description",
            .engine = "Engine",
            .engine_model = "EngineModel",
            .engine_version = "EngineVersion",
            .instance_profile_arn = "InstanceProfileArn",
            .instance_type = "InstanceType",
            .key_pair = "KeyPair",
            .preferred_backup_window = "PreferredBackupWindow",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .s3_data_size = "S3DataSize",
            .s3_data_url = "S3DataUrl",
            .s3_log_url = "S3LogUrl",
            .security_group_ids = "SecurityGroupIds",
            .server_name = "ServerName",
            .service_role_arn = "ServiceRoleArn",
            .status = "Status",
            .status_description = "StatusDescription",
            .subnet_ids = "SubnetIds",
            .tools_version = "ToolsVersion",
            .user_arn = "UserArn",
        };
        return @field(mappings, field_name);
    }
};
