const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-11-28";
pub const sdk_id: []const u8 = "Organizations";
pub const arn_namespace: ?[]const u8 = "organizations";
pub const endpoint_prefix: []const u8 = "organizations";
pub const sigv4_name: []const u8 = "organizations";
pub const name: []const u8 = "AWSOrganizationsV20161128";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-11-28",
    sdk_id: []const u8 = "Organizations",
    arn_namespace: ?[]const u8 = "organizations",
    endpoint_prefix: []const u8 = "organizations",
    sigv4_name: []const u8 = "organizations",
    name: []const u8 = "AWSOrganizationsV20161128",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const accept_handshake: struct {
    action_name: []const u8 = "AcceptHandshake",
    Request: type = struct {
        handshake_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshake_id = "HandshakeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_handshake) } {
            return .{ .service_metadata = service_metadata, .action = accept_handshake };
        }
    },
    Response: type = struct {
        handshake: ?Handshake = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshake = "Handshake",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AccessDeniedForDependency,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        HandshakeAlreadyInState,
        HandshakeConstraintViolation,
        HandshakeNotFound,
        InvalidHandshakeTransition,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const attach_policy: struct {
    action_name: []const u8 = "AttachPolicy",
    Request: type = struct {
        policy_id: []const u8,
        target_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
                .target_id = "TargetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_policy) } {
            return .{ .service_metadata = service_metadata, .action = attach_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        DuplicatePolicyAttachment,
        InvalidInput,
        PolicyChangesInProgress,
        PolicyNotFound,
        PolicyTypeNotEnabled,
        Service,
        TargetNotFound,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const cancel_handshake: struct {
    action_name: []const u8 = "CancelHandshake",
    Request: type = struct {
        handshake_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshake_id = "HandshakeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_handshake) } {
            return .{ .service_metadata = service_metadata, .action = cancel_handshake };
        }
    },
    Response: type = struct {
        handshake: ?Handshake = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshake = "Handshake",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        HandshakeAlreadyInState,
        HandshakeNotFound,
        InvalidHandshakeTransition,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const close_account: struct {
    action_name: []const u8 = "CloseAccount",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(close_account) } {
            return .{ .service_metadata = service_metadata, .action = close_account };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AccountAlreadyClosed,
        AccountNotFound,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        Conflict,
        ConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const create_account: struct {
    action_name: []const u8 = "CreateAccount",
    Request: type = struct {
        email: []const u8,
        account_name: []const u8,
        role_name: ?[]const u8 = null,
        iam_user_access_to_billing: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email = "Email",
                .account_name = "AccountName",
                .role_name = "RoleName",
                .iam_user_access_to_billing = "IamUserAccessToBilling",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_account) } {
            return .{ .service_metadata = service_metadata, .action = create_account };
        }
    },
    Response: type = struct {
        create_account_status: ?CreateAccountStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_account_status = "CreateAccountStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        FinalizingOrganization,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const create_gov_cloud_account: struct {
    action_name: []const u8 = "CreateGovCloudAccount",
    Request: type = struct {
        email: []const u8,
        account_name: []const u8,
        role_name: ?[]const u8 = null,
        iam_user_access_to_billing: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email = "Email",
                .account_name = "AccountName",
                .role_name = "RoleName",
                .iam_user_access_to_billing = "IamUserAccessToBilling",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_gov_cloud_account) } {
            return .{ .service_metadata = service_metadata, .action = create_gov_cloud_account };
        }
    },
    Response: type = struct {
        create_account_status: ?CreateAccountStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_account_status = "CreateAccountStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        FinalizingOrganization,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const create_organization: struct {
    action_name: []const u8 = "CreateOrganization",
    Request: type = struct {
        feature_set: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_set = "FeatureSet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_organization) } {
            return .{ .service_metadata = service_metadata, .action = create_organization };
        }
    },
    Response: type = struct {
        organization: ?Organization = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization = "Organization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AccessDeniedForDependency,
        AlreadyInOrganization,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const create_organizational_unit: struct {
    action_name: []const u8 = "CreateOrganizationalUnit",
    Request: type = struct {
        parent_id: []const u8,
        name: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parent_id = "ParentId",
                .name = "Name",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_organizational_unit) } {
            return .{ .service_metadata = service_metadata, .action = create_organizational_unit };
        }
    },
    Response: type = struct {
        organizational_unit: ?OrganizationalUnit = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organizational_unit = "OrganizationalUnit",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        DuplicateOrganizationalUnit,
        InvalidInput,
        ParentNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const create_policy: struct {
    action_name: []const u8 = "CreatePolicy",
    Request: type = struct {
        content: []const u8,
        description: []const u8,
        name: []const u8,
        type: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .description = "Description",
                .name = "Name",
                .type = "Type",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_policy };
        }
    },
    Response: type = struct {
        policy: ?Policy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        DuplicatePolicy,
        InvalidInput,
        MalformedPolicyDocument,
        PolicyTypeNotAvailableForOrganization,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const decline_handshake: struct {
    action_name: []const u8 = "DeclineHandshake",
    Request: type = struct {
        handshake_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshake_id = "HandshakeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decline_handshake) } {
            return .{ .service_metadata = service_metadata, .action = decline_handshake };
        }
    },
    Response: type = struct {
        handshake: ?Handshake = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshake = "Handshake",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        HandshakeAlreadyInState,
        HandshakeNotFound,
        InvalidHandshakeTransition,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_organization: struct {
    action_name: []const u8 = "DeleteOrganization",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_organization) } {
            return .{ .service_metadata = service_metadata, .action = delete_organization };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        InvalidInput,
        OrganizationNotEmpty,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_organizational_unit: struct {
    action_name: []const u8 = "DeleteOrganizationalUnit",
    Request: type = struct {
        organizational_unit_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organizational_unit_id = "OrganizationalUnitId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_organizational_unit) } {
            return .{ .service_metadata = service_metadata, .action = delete_organizational_unit };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        InvalidInput,
        OrganizationalUnitNotEmpty,
        OrganizationalUnitNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const delete_policy: struct {
    action_name: []const u8 = "DeletePolicy",
    Request: type = struct {
        policy_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        InvalidInput,
        PolicyInUse,
        PolicyNotFound,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        ResourcePolicyNotFound,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const deregister_delegated_administrator: struct {
    action_name: []const u8 = "DeregisterDelegatedAdministrator",
    Request: type = struct {
        account_id: []const u8,
        service_principal: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .service_principal = "ServicePrincipal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_delegated_administrator) } {
            return .{ .service_metadata = service_metadata, .action = deregister_delegated_administrator };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AccountNotFound,
        AccountNotRegistered,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const describe_account: struct {
    action_name: []const u8 = "DescribeAccount",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account) } {
            return .{ .service_metadata = service_metadata, .action = describe_account };
        }
    },
    Response: type = struct {
        account: ?Account = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account = "Account",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AccountNotFound,
        AWSOrganizationsNotInUse,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const describe_create_account_status: struct {
    action_name: []const u8 = "DescribeCreateAccountStatus",
    Request: type = struct {
        create_account_request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_account_request_id = "CreateAccountRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_create_account_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_create_account_status };
        }
    },
    Response: type = struct {
        create_account_status: ?CreateAccountStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_account_status = "CreateAccountStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        CreateAccountStatusNotFound,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const describe_effective_policy: struct {
    action_name: []const u8 = "DescribeEffectivePolicy",
    Request: type = struct {
        policy_type: []const u8,
        target_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_type = "PolicyType",
                .target_id = "TargetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_effective_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_effective_policy };
        }
    },
    Response: type = struct {
        effective_policy: ?struct {
            policy_content: ?[]const u8 = null,
            last_updated_timestamp: ?i64 = null,
            target_id: ?[]const u8 = null,
            policy_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_content = "PolicyContent",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .target_id = "TargetId",
                    .policy_type = "PolicyType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .effective_policy = "EffectivePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConstraintViolation,
        EffectivePolicyNotFound,
        InvalidInput,
        Service,
        TargetNotFound,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const describe_handshake: struct {
    action_name: []const u8 = "DescribeHandshake",
    Request: type = struct {
        handshake_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshake_id = "HandshakeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_handshake) } {
            return .{ .service_metadata = service_metadata, .action = describe_handshake };
        }
    },
    Response: type = struct {
        handshake: ?Handshake = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshake = "Handshake",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        HandshakeNotFound,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const describe_organization: struct {
    action_name: []const u8 = "DescribeOrganization",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization };
        }
    },
    Response: type = struct {
        organization: ?Organization = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization = "Organization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        Service,
        TooManyRequests,
    },
} = .{};
pub const describe_organizational_unit: struct {
    action_name: []const u8 = "DescribeOrganizationalUnit",
    Request: type = struct {
        organizational_unit_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organizational_unit_id = "OrganizationalUnitId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organizational_unit) } {
            return .{ .service_metadata = service_metadata, .action = describe_organizational_unit };
        }
    },
    Response: type = struct {
        organizational_unit: ?OrganizationalUnit = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organizational_unit = "OrganizationalUnit",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        OrganizationalUnitNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const describe_policy: struct {
    action_name: []const u8 = "DescribePolicy",
    Request: type = struct {
        policy_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_policy };
        }
    },
    Response: type = struct {
        policy: ?Policy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        PolicyNotFound,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const describe_resource_policy: struct {
    action_name: []const u8 = "DescribeResourcePolicy",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource_policy };
        }
    },
    Response: type = struct {
        resource_policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConstraintViolation,
        ResourcePolicyNotFound,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const detach_policy: struct {
    action_name: []const u8 = "DetachPolicy",
    Request: type = struct {
        policy_id: []const u8,
        target_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
                .target_id = "TargetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_policy) } {
            return .{ .service_metadata = service_metadata, .action = detach_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        PolicyChangesInProgress,
        PolicyNotAttached,
        PolicyNotFound,
        Service,
        TargetNotFound,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const disable_aws_service_access: struct {
    action_name: []const u8 = "DisableAWSServiceAccess",
    Request: type = struct {
        service_principal: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_principal = "ServicePrincipal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_aws_service_access) } {
            return .{ .service_metadata = service_metadata, .action = disable_aws_service_access };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const disable_policy_type: struct {
    action_name: []const u8 = "DisablePolicyType",
    Request: type = struct {
        root_id: []const u8,
        policy_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .root_id = "RootId",
                .policy_type = "PolicyType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_policy_type) } {
            return .{ .service_metadata = service_metadata, .action = disable_policy_type };
        }
    },
    Response: type = struct {
        root: ?Root = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .root = "Root",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        PolicyChangesInProgress,
        PolicyTypeNotEnabled,
        RootNotFound,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const enable_all_features: struct {
    action_name: []const u8 = "EnableAllFeatures",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_all_features) } {
            return .{ .service_metadata = service_metadata, .action = enable_all_features };
        }
    },
    Response: type = struct {
        handshake: ?Handshake = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshake = "Handshake",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        HandshakeConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const enable_aws_service_access: struct {
    action_name: []const u8 = "EnableAWSServiceAccess",
    Request: type = struct {
        service_principal: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_principal = "ServicePrincipal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_aws_service_access) } {
            return .{ .service_metadata = service_metadata, .action = enable_aws_service_access };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const enable_policy_type: struct {
    action_name: []const u8 = "EnablePolicyType",
    Request: type = struct {
        root_id: []const u8,
        policy_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .root_id = "RootId",
                .policy_type = "PolicyType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_policy_type) } {
            return .{ .service_metadata = service_metadata, .action = enable_policy_type };
        }
    },
    Response: type = struct {
        root: ?Root = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .root = "Root",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        PolicyChangesInProgress,
        PolicyTypeAlreadyEnabled,
        PolicyTypeNotAvailableForOrganization,
        RootNotFound,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const invite_account_to_organization: struct {
    action_name: []const u8 = "InviteAccountToOrganization",
    Request: type = struct {
        target: HandshakeParty,
        notes: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target = "Target",
                .notes = "Notes",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invite_account_to_organization) } {
            return .{ .service_metadata = service_metadata, .action = invite_account_to_organization };
        }
    },
    Response: type = struct {
        handshake: ?Handshake = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshake = "Handshake",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AccountOwnerNotVerified,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        DuplicateHandshake,
        FinalizingOrganization,
        HandshakeConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const leave_organization: struct {
    action_name: []const u8 = "LeaveOrganization",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(leave_organization) } {
            return .{ .service_metadata = service_metadata, .action = leave_organization };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AccountNotFound,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        MasterCannotLeaveOrganization,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_accounts: struct {
    action_name: []const u8 = "ListAccounts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_accounts };
        }
    },
    Response: type = struct {
        accounts: ?[]Account = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accounts = "Accounts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_accounts_for_parent: struct {
    action_name: []const u8 = "ListAccountsForParent",
    Request: type = struct {
        parent_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parent_id = "ParentId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accounts_for_parent) } {
            return .{ .service_metadata = service_metadata, .action = list_accounts_for_parent };
        }
    },
    Response: type = struct {
        accounts: ?[]Account = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accounts = "Accounts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        ParentNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_aws_service_access_for_organization: struct {
    action_name: []const u8 = "ListAWSServiceAccessForOrganization",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_aws_service_access_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = list_aws_service_access_for_organization };
        }
    },
    Response: type = struct {
        enabled_service_principals: ?[]struct {
            service_principal: ?[]const u8 = null,
            date_enabled: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_principal = "ServicePrincipal",
                    .date_enabled = "DateEnabled",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enabled_service_principals = "EnabledServicePrincipals",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const list_children: struct {
    action_name: []const u8 = "ListChildren",
    Request: type = struct {
        parent_id: []const u8,
        child_type: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parent_id = "ParentId",
                .child_type = "ChildType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_children) } {
            return .{ .service_metadata = service_metadata, .action = list_children };
        }
    },
    Response: type = struct {
        children: ?[]struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .children = "Children",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        ParentNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_create_account_status: struct {
    action_name: []const u8 = "ListCreateAccountStatus",
    Request: type = struct {
        states: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .states = "States",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_create_account_status) } {
            return .{ .service_metadata = service_metadata, .action = list_create_account_status };
        }
    },
    Response: type = struct {
        create_account_statuses: ?[]CreateAccountStatus = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .create_account_statuses = "CreateAccountStatuses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const list_delegated_administrators: struct {
    action_name: []const u8 = "ListDelegatedAdministrators",
    Request: type = struct {
        service_principal: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_principal = "ServicePrincipal",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_delegated_administrators) } {
            return .{ .service_metadata = service_metadata, .action = list_delegated_administrators };
        }
    },
    Response: type = struct {
        delegated_administrators: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            email: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            joined_method: ?[]const u8 = null,
            joined_timestamp: ?i64 = null,
            delegation_enabled_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .email = "Email",
                    .name = "Name",
                    .status = "Status",
                    .joined_method = "JoinedMethod",
                    .joined_timestamp = "JoinedTimestamp",
                    .delegation_enabled_date = "DelegationEnabledDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegated_administrators = "DelegatedAdministrators",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const list_delegated_services_for_account: struct {
    action_name: []const u8 = "ListDelegatedServicesForAccount",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_delegated_services_for_account) } {
            return .{ .service_metadata = service_metadata, .action = list_delegated_services_for_account };
        }
    },
    Response: type = struct {
        delegated_services: ?[]struct {
            service_principal: ?[]const u8 = null,
            delegation_enabled_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_principal = "ServicePrincipal",
                    .delegation_enabled_date = "DelegationEnabledDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegated_services = "DelegatedServices",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AccountNotFound,
        AccountNotRegistered,
        AWSOrganizationsNotInUse,
        ConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const list_handshakes_for_account: struct {
    action_name: []const u8 = "ListHandshakesForAccount",
    Request: type = struct {
        filter: ?HandshakeFilter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_handshakes_for_account) } {
            return .{ .service_metadata = service_metadata, .action = list_handshakes_for_account };
        }
    },
    Response: type = struct {
        handshakes: ?[]Handshake = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshakes = "Handshakes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_handshakes_for_organization: struct {
    action_name: []const u8 = "ListHandshakesForOrganization",
    Request: type = struct {
        filter: ?HandshakeFilter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_handshakes_for_organization) } {
            return .{ .service_metadata = service_metadata, .action = list_handshakes_for_organization };
        }
    },
    Response: type = struct {
        handshakes: ?[]Handshake = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .handshakes = "Handshakes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_organizational_units_for_parent: struct {
    action_name: []const u8 = "ListOrganizationalUnitsForParent",
    Request: type = struct {
        parent_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parent_id = "ParentId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organizational_units_for_parent) } {
            return .{ .service_metadata = service_metadata, .action = list_organizational_units_for_parent };
        }
    },
    Response: type = struct {
        organizational_units: ?[]OrganizationalUnit = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organizational_units = "OrganizationalUnits",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        ParentNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_parents: struct {
    action_name: []const u8 = "ListParents",
    Request: type = struct {
        child_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .child_id = "ChildId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_parents) } {
            return .{ .service_metadata = service_metadata, .action = list_parents };
        }
    },
    Response: type = struct {
        parents: ?[]struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .parents = "Parents",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ChildNotFound,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_policies: struct {
    action_name: []const u8 = "ListPolicies",
    Request: type = struct {
        filter: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_policies };
        }
    },
    Response: type = struct {
        policies: ?[]PolicySummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policies = "Policies",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const list_policies_for_target: struct {
    action_name: []const u8 = "ListPoliciesForTarget",
    Request: type = struct {
        target_id: []const u8,
        filter: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_id = "TargetId",
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_policies_for_target) } {
            return .{ .service_metadata = service_metadata, .action = list_policies_for_target };
        }
    },
    Response: type = struct {
        policies: ?[]PolicySummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policies = "Policies",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        Service,
        TargetNotFound,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const list_roots: struct {
    action_name: []const u8 = "ListRoots",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_roots) } {
            return .{ .service_metadata = service_metadata, .action = list_roots };
        }
    },
    Response: type = struct {
        roots: ?[]Root = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .roots = "Roots",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        Service,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_id: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        Service,
        TargetNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_targets_for_policy: struct {
    action_name: []const u8 = "ListTargetsForPolicy",
    Request: type = struct {
        policy_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_targets_for_policy) } {
            return .{ .service_metadata = service_metadata, .action = list_targets_for_policy };
        }
    },
    Response: type = struct {
        targets: ?[]struct {
            target_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .target_id = "TargetId",
                    .arn = "Arn",
                    .name = "Name",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .targets = "Targets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        InvalidInput,
        PolicyNotFound,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const move_account: struct {
    action_name: []const u8 = "MoveAccount",
    Request: type = struct {
        account_id: []const u8,
        source_parent_id: []const u8,
        destination_parent_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .source_parent_id = "SourceParentId",
                .destination_parent_id = "DestinationParentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(move_account) } {
            return .{ .service_metadata = service_metadata, .action = move_account };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AccountNotFound,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        DestinationParentNotFound,
        DuplicateAccount,
        InvalidInput,
        Service,
        SourceParentNotFound,
        TooManyRequests,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        content: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        resource_policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const register_delegated_administrator: struct {
    action_name: []const u8 = "RegisterDelegatedAdministrator",
    Request: type = struct {
        account_id: []const u8,
        service_principal: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .service_principal = "ServicePrincipal",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_delegated_administrator) } {
            return .{ .service_metadata = service_metadata, .action = register_delegated_administrator };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AccountAlreadyRegistered,
        AccountNotFound,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};
pub const remove_account_from_organization: struct {
    action_name: []const u8 = "RemoveAccountFromOrganization",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_account_from_organization) } {
            return .{ .service_metadata = service_metadata, .action = remove_account_from_organization };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AccountNotFound,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        MasterCannotLeaveOrganization,
        Service,
        TooManyRequests,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        Service,
        TargetNotFound,
        TooManyRequests,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        InvalidInput,
        Service,
        TargetNotFound,
        TooManyRequests,
    },
} = .{};
pub const update_organizational_unit: struct {
    action_name: []const u8 = "UpdateOrganizationalUnit",
    Request: type = struct {
        organizational_unit_id: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organizational_unit_id = "OrganizationalUnitId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_organizational_unit) } {
            return .{ .service_metadata = service_metadata, .action = update_organizational_unit };
        }
    },
    Response: type = struct {
        organizational_unit: ?OrganizationalUnit = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organizational_unit = "OrganizationalUnit",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        DuplicateOrganizationalUnit,
        InvalidInput,
        OrganizationalUnitNotFound,
        Service,
        TooManyRequests,
    },
} = .{};
pub const update_policy: struct {
    action_name: []const u8 = "UpdatePolicy",
    Request: type = struct {
        policy_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        content: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "PolicyId",
                .name = "Name",
                .description = "Description",
                .content = "Content",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_policy };
        }
    },
    Response: type = struct {
        policy: ?Policy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AWSOrganizationsNotInUse,
        ConcurrentModification,
        ConstraintViolation,
        DuplicatePolicy,
        InvalidInput,
        MalformedPolicyDocument,
        PolicyChangesInProgress,
        PolicyNotFound,
        Service,
        TooManyRequests,
        UnsupportedAPIEndpoint,
    },
} = .{};

pub const Policy = struct {
    policy_summary: ?PolicySummary = null,
    content: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_summary = "PolicySummary",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const PolicySummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    aws_managed: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
            .description = "Description",
            .type = "Type",
            .aws_managed = "AwsManaged",
        };
        return @field(mappings, field_name);
    }
};

pub const OrganizationalUnit = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePolicy = struct {
    resource_policy_summary: ?ResourcePolicySummary = null,
    content: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_policy_summary = "ResourcePolicySummary",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePolicySummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const Root = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    policy_types: ?[]PolicyTypeSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
            .policy_types = "PolicyTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const PolicyTypeSummary = struct {
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const Handshake = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    parties: ?[]HandshakeParty = null,
    state: ?[]const u8 = null,
    requested_timestamp: ?i64 = null,
    expiration_timestamp: ?i64 = null,
    action: ?[]const u8 = null,
    resources: ?[]HandshakeResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .parties = "Parties",
            .state = "State",
            .requested_timestamp = "RequestedTimestamp",
            .expiration_timestamp = "ExpirationTimestamp",
            .action = "Action",
            .resources = "Resources",
        };
        return @field(mappings, field_name);
    }
};

pub const HandshakeResource = struct {
    value: ?[]const u8 = null,
    type: ?[]const u8 = null,
    resources: ?[]HandshakeResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .type = "Type",
            .resources = "Resources",
        };
        return @field(mappings, field_name);
    }
};

pub const HandshakeParty = struct {
    id: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const HandshakeFilter = struct {
    action_type: ?[]const u8 = null,
    parent_handshake_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_type = "ActionType",
            .parent_handshake_id = "ParentHandshakeId",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateAccountStatus = struct {
    id: ?[]const u8 = null,
    account_name: ?[]const u8 = null,
    state: ?[]const u8 = null,
    requested_timestamp: ?i64 = null,
    completed_timestamp: ?i64 = null,
    account_id: ?[]const u8 = null,
    gov_cloud_account_id: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .account_name = "AccountName",
            .state = "State",
            .requested_timestamp = "RequestedTimestamp",
            .completed_timestamp = "CompletedTimestamp",
            .account_id = "AccountId",
            .gov_cloud_account_id = "GovCloudAccountId",
            .failure_reason = "FailureReason",
        };
        return @field(mappings, field_name);
    }
};

pub const Account = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    email: ?[]const u8 = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    joined_method: ?[]const u8 = null,
    joined_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .email = "Email",
            .name = "Name",
            .status = "Status",
            .joined_method = "JoinedMethod",
            .joined_timestamp = "JoinedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const Organization = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    feature_set: ?[]const u8 = null,
    master_account_arn: ?[]const u8 = null,
    master_account_id: ?[]const u8 = null,
    master_account_email: ?[]const u8 = null,
    available_policy_types: ?[]PolicyTypeSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .feature_set = "FeatureSet",
            .master_account_arn = "MasterAccountArn",
            .master_account_id = "MasterAccountId",
            .master_account_email = "MasterAccountEmail",
            .available_policy_types = "AvailablePolicyTypes",
        };
        return @field(mappings, field_name);
    }
};
