const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-01-01";
pub const sdk_id: []const u8 = "OSIS";
pub const arn_namespace: ?[]const u8 = "osis";
pub const endpoint_prefix: []const u8 = "osis";
pub const sigv4_name: []const u8 = "osis";
pub const name: []const u8 = "AmazonOpenSearchIngestionService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2022-01-01",
    sdk_id: []const u8 = "OSIS",
    arn_namespace: ?[]const u8 = "osis",
    endpoint_prefix: []const u8 = "osis",
    sigv4_name: []const u8 = "osis",
    name: []const u8 = "AmazonOpenSearchIngestionService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_pipeline: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2022-01-01/osis/createPipeline",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePipeline",
    Request: type = struct {
        pipeline_name: []const u8,
        min_units: i64,
        max_units: i64,
        pipeline_configuration_body: []const u8,
        log_publishing_options: ?LogPublishingOptions = null,
        vpc_options: ?VpcOptions = null,
        buffer_options: ?BufferOptions = null,
        encryption_at_rest_options: ?EncryptionAtRestOptions = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
                .min_units = "MinUnits",
                .max_units = "MaxUnits",
                .pipeline_configuration_body = "PipelineConfigurationBody",
                .log_publishing_options = "LogPublishingOptions",
                .vpc_options = "VpcOptions",
                .buffer_options = "BufferOptions",
                .encryption_at_rest_options = "EncryptionAtRestOptions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?Pipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "Pipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_pipeline: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2022-01-01/osis/deletePipeline/{PipelineName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePipeline",
    Request: type = struct {
        pipeline_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_pipeline };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_pipeline: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2022-01-01/osis/getPipeline/{PipelineName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPipeline",
    Request: type = struct {
        pipeline_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = get_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?Pipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "Pipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_pipeline_blueprint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2022-01-01/osis/getPipelineBlueprint/{BlueprintName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPipelineBlueprint",
    Request: type = struct {
        blueprint_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprint_name = "BlueprintName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pipeline_blueprint) } {
            return .{ .service_metadata = service_metadata, .action = get_pipeline_blueprint };
        }
    },
    Response: type = struct {
        blueprint: ?struct {
            blueprint_name: ?[]const u8 = null,
            pipeline_configuration_body: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .blueprint_name = "BlueprintName",
                    .pipeline_configuration_body = "PipelineConfigurationBody",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprint = "Blueprint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_pipeline_change_progress: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2022-01-01/osis/getPipelineChangeProgress/{PipelineName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPipelineChangeProgress",
    Request: type = struct {
        pipeline_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_pipeline_change_progress) } {
            return .{ .service_metadata = service_metadata, .action = get_pipeline_change_progress };
        }
    },
    Response: type = struct {
        change_progress_statuses: ?[]struct {
            start_time: ?i64 = null,
            status: ?[]const u8 = null,
            total_number_of_stages: ?i64 = null,
            change_progress_stages: ?[]struct {
                name: ?[]const u8 = null,
                status: ?[]const u8 = null,
                description: ?[]const u8 = null,
                last_updated_at: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .status = "Status",
                        .description = "Description",
                        .last_updated_at = "LastUpdatedAt",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_time = "StartTime",
                    .status = "Status",
                    .total_number_of_stages = "TotalNumberOfStages",
                    .change_progress_stages = "ChangeProgressStages",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_progress_statuses = "ChangeProgressStatuses",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_pipeline_blueprints: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2022-01-01/osis/listPipelineBlueprints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPipelineBlueprints",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipeline_blueprints) } {
            return .{ .service_metadata = service_metadata, .action = list_pipeline_blueprints };
        }
    },
    Response: type = struct {
        blueprints: ?[]struct {
            blueprint_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .blueprint_name = "BlueprintName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blueprints = "Blueprints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidPaginationToken,
        Validation,
    },
} = .{};
pub const list_pipelines: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2022-01-01/osis/listPipelines",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPipelines",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_pipelines };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        pipelines: ?[]struct {
            status: ?[]const u8 = null,
            status_reason: ?PipelineStatusReason = null,
            pipeline_name: ?[]const u8 = null,
            pipeline_arn: ?[]const u8 = null,
            min_units: ?i64 = null,
            max_units: ?i64 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "Status",
                    .status_reason = "StatusReason",
                    .pipeline_name = "PipelineName",
                    .pipeline_arn = "PipelineArn",
                    .min_units = "MinUnits",
                    .max_units = "MaxUnits",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .pipelines = "Pipelines",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidPaginationToken,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2022-01-01/osis/listTagsForResource",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        arn: []const u8,

        pub const http_query = .{
            .arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_pipeline: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2022-01-01/osis/startPipeline/{PipelineName}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartPipeline",
    Request: type = struct {
        pipeline_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = start_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?Pipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "Pipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const stop_pipeline: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2022-01-01/osis/stopPipeline/{PipelineName}",
        .success_code = 200,
    };

    action_name: []const u8 = "StopPipeline",
    Request: type = struct {
        pipeline_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = stop_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?Pipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "Pipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2022-01-01/osis/tagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        arn: []const u8,
        tags: []Tag,

        pub const http_query = .{
            .arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        LimitExceeded,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2022-01-01/osis/untagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_pipeline: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2022-01-01/osis/updatePipeline/{PipelineName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePipeline",
    Request: type = struct {
        pipeline_name: []const u8,
        min_units: ?i64 = null,
        max_units: ?i64 = null,
        pipeline_configuration_body: ?[]const u8 = null,
        log_publishing_options: ?LogPublishingOptions = null,
        buffer_options: ?BufferOptions = null,
        encryption_at_rest_options: ?EncryptionAtRestOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
                .min_units = "MinUnits",
                .max_units = "MaxUnits",
                .pipeline_configuration_body = "PipelineConfigurationBody",
                .log_publishing_options = "LogPublishingOptions",
                .buffer_options = "BufferOptions",
                .encryption_at_rest_options = "EncryptionAtRestOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = update_pipeline };
        }
    },
    Response: type = struct {
        pipeline: ?Pipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "Pipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        Internal,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const validate_pipeline: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2022-01-01/osis/validatePipeline",
        .success_code = 200,
    };

    action_name: []const u8 = "ValidatePipeline",
    Request: type = struct {
        pipeline_configuration_body: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_configuration_body = "PipelineConfigurationBody",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = validate_pipeline };
        }
    },
    Response: type = struct {
        is_valid: ?bool = null,
        errors: ?[]struct {
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_valid = "isValid",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        Validation,
    },
} = .{};

pub const Pipeline = struct {
    pipeline_name: ?[]const u8 = null,
    pipeline_arn: ?[]const u8 = null,
    min_units: ?i64 = null,
    max_units: ?i64 = null,
    status: ?[]const u8 = null,
    status_reason: ?PipelineStatusReason = null,
    pipeline_configuration_body: ?[]const u8 = null,
    created_at: ?i64 = null,
    last_updated_at: ?i64 = null,
    ingest_endpoint_urls: ?[][]const u8 = null,
    log_publishing_options: ?LogPublishingOptions = null,
    vpc_endpoints: ?[]VpcEndpoint = null,
    buffer_options: ?BufferOptions = null,
    encryption_at_rest_options: ?EncryptionAtRestOptions = null,
    service_vpc_endpoints: ?[]ServiceVpcEndpoint = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pipeline_name = "PipelineName",
            .pipeline_arn = "PipelineArn",
            .min_units = "MinUnits",
            .max_units = "MaxUnits",
            .status = "Status",
            .status_reason = "StatusReason",
            .pipeline_configuration_body = "PipelineConfigurationBody",
            .created_at = "CreatedAt",
            .last_updated_at = "LastUpdatedAt",
            .ingest_endpoint_urls = "IngestEndpointUrls",
            .log_publishing_options = "LogPublishingOptions",
            .vpc_endpoints = "VpcEndpoints",
            .buffer_options = "BufferOptions",
            .encryption_at_rest_options = "EncryptionAtRestOptions",
            .service_vpc_endpoints = "ServiceVpcEndpoints",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceVpcEndpoint = struct {
    service_name: ?[]const u8 = null,
    vpc_endpoint_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_name = "ServiceName",
            .vpc_endpoint_id = "VpcEndpointId",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionAtRestOptions = struct {
    kms_key_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const BufferOptions = struct {
    persistent_buffer_enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .persistent_buffer_enabled = "PersistentBufferEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcEndpoint = struct {
    vpc_endpoint_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    vpc_options: ?VpcOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_endpoint_id = "VpcEndpointId",
            .vpc_id = "VpcId",
            .vpc_options = "VpcOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcOptions = struct {
    subnet_ids: [][]const u8,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const LogPublishingOptions = struct {
    is_logging_enabled: ?bool = null,
    cloud_watch_log_destination: ?CloudWatchLogDestination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_logging_enabled = "IsLoggingEnabled",
            .cloud_watch_log_destination = "CloudWatchLogDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogDestination = struct {
    log_group: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group = "LogGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const PipelineStatusReason = struct {
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};
