const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-03";
pub const sdk_id: []const u8 = "Outposts";
pub const arn_namespace: ?[]const u8 = "outposts";
pub const endpoint_prefix: []const u8 = "outposts";
pub const sigv4_name: []const u8 = "outposts";
pub const name: []const u8 = "OutpostsOlafService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-03",
    sdk_id: []const u8 = "Outposts",
    arn_namespace: ?[]const u8 = "outposts",
    endpoint_prefix: []const u8 = "outposts",
    sigv4_name: []const u8 = "outposts",
    name: []const u8 = "OutpostsOlafService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_order: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/orders/{OrderId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelOrder",
    Request: type = struct {
        order_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .order_id = "OrderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_order) } {
            return .{ .service_metadata = service_metadata, .action = cancel_order };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const create_order: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/orders",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateOrder",
    Request: type = struct {
        outpost_identifier: []const u8,
        line_items: []struct {
            catalog_item_id: ?[]const u8 = null,
            quantity: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .catalog_item_id = "CatalogItemId",
                    .quantity = "Quantity",
                };
                return @field(mappings, field_name);
            }
        },
        payment_option: []const u8,
        payment_term: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost_identifier = "OutpostIdentifier",
                .line_items = "LineItems",
                .payment_option = "PaymentOption",
                .payment_term = "PaymentTerm",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_order) } {
            return .{ .service_metadata = service_metadata, .action = create_order };
        }
    },
    Response: type = struct {
        order: ?Order = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .order = "Order",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        NotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_outpost: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/outposts",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateOutpost",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        site_id: []const u8,
        availability_zone: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        supported_hardware_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .site_id = "SiteId",
                .availability_zone = "AvailabilityZone",
                .availability_zone_id = "AvailabilityZoneId",
                .tags = "Tags",
                .supported_hardware_type = "SupportedHardwareType",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_outpost) } {
            return .{ .service_metadata = service_metadata, .action = create_outpost };
        }
    },
    Response: type = struct {
        outpost: ?Outpost = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost = "Outpost",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        NotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_site: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sites",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSite",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        notes: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        operating_address: ?Address = null,
        shipping_address: ?Address = null,
        rack_physical_properties: ?RackPhysicalProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .notes = "Notes",
                .tags = "Tags",
                .operating_address = "OperatingAddress",
                .shipping_address = "ShippingAddress",
                .rack_physical_properties = "RackPhysicalProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_site) } {
            return .{ .service_metadata = service_metadata, .action = create_site };
        }
    },
    Response: type = struct {
        site: ?Site = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "Site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_outpost: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/outposts/{OutpostId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteOutpost",
    Request: type = struct {
        outpost_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost_id = "OutpostId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_outpost) } {
            return .{ .service_metadata = service_metadata, .action = delete_outpost };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const delete_site: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sites/{SiteId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSite",
    Request: type = struct {
        site_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site_id = "SiteId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_site) } {
            return .{ .service_metadata = service_metadata, .action = delete_site };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const get_catalog_item: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/catalog/item/{CatalogItemId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCatalogItem",
    Request: type = struct {
        catalog_item_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_item_id = "CatalogItemId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_catalog_item) } {
            return .{ .service_metadata = service_metadata, .action = get_catalog_item };
        }
    },
    Response: type = struct {
        catalog_item: ?CatalogItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_item = "CatalogItem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const get_connection: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/connections/{ConnectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConnection",
    Request: type = struct {
        connection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "ConnectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connection) } {
            return .{ .service_metadata = service_metadata, .action = get_connection };
        }
    },
    Response: type = struct {
        connection_id: ?[]const u8 = null,
        connection_details: ?struct {
            client_public_key: ?[]const u8 = null,
            server_public_key: ?[]const u8 = null,
            server_endpoint: ?[]const u8 = null,
            client_tunnel_address: ?[]const u8 = null,
            server_tunnel_address: ?[]const u8 = null,
            allowed_ips: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .client_public_key = "ClientPublicKey",
                    .server_public_key = "ServerPublicKey",
                    .server_endpoint = "ServerEndpoint",
                    .client_tunnel_address = "ClientTunnelAddress",
                    .server_tunnel_address = "ServerTunnelAddress",
                    .allowed_ips = "AllowedIps",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "ConnectionId",
                .connection_details = "ConnectionDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const get_order: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/orders/{OrderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOrder",
    Request: type = struct {
        order_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .order_id = "OrderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_order) } {
            return .{ .service_metadata = service_metadata, .action = get_order };
        }
    },
    Response: type = struct {
        order: ?Order = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .order = "Order",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const get_outpost: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/outposts/{OutpostId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOutpost",
    Request: type = struct {
        outpost_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost_id = "OutpostId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_outpost) } {
            return .{ .service_metadata = service_metadata, .action = get_outpost };
        }
    },
    Response: type = struct {
        outpost: ?Outpost = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost = "Outpost",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const get_outpost_instance_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/outposts/{OutpostId}/instanceTypes",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOutpostInstanceTypes",
    Request: type = struct {
        outpost_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost_id = "OutpostId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_outpost_instance_types) } {
            return .{ .service_metadata = service_metadata, .action = get_outpost_instance_types };
        }
    },
    Response: type = struct {
        instance_types: ?[]struct {
            instance_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_type = "InstanceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        outpost_id: ?[]const u8 = null,
        outpost_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_types = "InstanceTypes",
                .next_token = "NextToken",
                .outpost_id = "OutpostId",
                .outpost_arn = "OutpostArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const get_site: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sites/{SiteId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSite",
    Request: type = struct {
        site_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site_id = "SiteId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_site) } {
            return .{ .service_metadata = service_metadata, .action = get_site };
        }
    },
    Response: type = struct {
        site: ?Site = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "Site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const get_site_address: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sites/{SiteId}/address",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSiteAddress",
    Request: type = struct {
        site_id: []const u8,
        address_type: []const u8,

        pub const http_query = .{
            .address_type = "AddressType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site_id = "SiteId",
                .address_type = "AddressType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_site_address) } {
            return .{ .service_metadata = service_metadata, .action = get_site_address };
        }
    },
    Response: type = struct {
        site_id: ?[]const u8 = null,
        address_type: ?[]const u8 = null,
        address: ?Address = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site_id = "SiteId",
                .address_type = "AddressType",
                .address = "Address",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const list_assets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/outposts/{OutpostIdentifier}/assets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssets",
    Request: type = struct {
        outpost_identifier: []const u8,
        host_id_filter: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        status_filter: ?[][]const u8 = null,

        pub const http_query = .{
            .host_id_filter = "HostIdFilter",
            .max_results = "MaxResults",
            .next_token = "NextToken",
            .status_filter = "StatusFilter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost_identifier = "OutpostIdentifier",
                .host_id_filter = "HostIdFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .status_filter = "StatusFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_assets) } {
            return .{ .service_metadata = service_metadata, .action = list_assets };
        }
    },
    Response: type = struct {
        assets: ?[]struct {
            asset_id: ?[]const u8 = null,
            rack_id: ?[]const u8 = null,
            asset_type: ?[]const u8 = null,
            compute_attributes: ?struct {
                host_id: ?[]const u8 = null,
                state: ?[]const u8 = null,
                instance_families: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .host_id = "HostId",
                        .state = "State",
                        .instance_families = "InstanceFamilies",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            asset_location: ?struct {
                rack_elevation: ?f32 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .rack_elevation = "RackElevation",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .asset_id = "AssetId",
                    .rack_id = "RackId",
                    .asset_type = "AssetType",
                    .compute_attributes = "ComputeAttributes",
                    .asset_location = "AssetLocation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assets = "Assets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const list_catalog_items: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/catalog/items",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCatalogItems",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        item_class_filter: ?[][]const u8 = null,
        supported_storage_filter: ?[][]const u8 = null,
        ec2_family_filter: ?[][]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .item_class_filter = "ItemClassFilter",
            .supported_storage_filter = "SupportedStorageFilter",
            .ec2_family_filter = "EC2FamilyFilter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .item_class_filter = "ItemClassFilter",
                .supported_storage_filter = "SupportedStorageFilter",
                .ec2_family_filter = "EC2FamilyFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_catalog_items) } {
            return .{ .service_metadata = service_metadata, .action = list_catalog_items };
        }
    },
    Response: type = struct {
        catalog_items: ?[]CatalogItem = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_items = "CatalogItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const list_orders: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/list-orders",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrders",
    Request: type = struct {
        outpost_identifier_filter: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .outpost_identifier_filter = "OutpostIdentifierFilter",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost_identifier_filter = "OutpostIdentifierFilter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_orders) } {
            return .{ .service_metadata = service_metadata, .action = list_orders };
        }
    },
    Response: type = struct {
        orders: ?[]struct {
            outpost_id: ?[]const u8 = null,
            order_id: ?[]const u8 = null,
            order_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            line_item_counts_by_status: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            order_submission_date: ?i64 = null,
            order_fulfilled_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .outpost_id = "OutpostId",
                    .order_id = "OrderId",
                    .order_type = "OrderType",
                    .status = "Status",
                    .line_item_counts_by_status = "LineItemCountsByStatus",
                    .order_submission_date = "OrderSubmissionDate",
                    .order_fulfilled_date = "OrderFulfilledDate",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "line_item_counts_by_status", field_name))
                    return try serializeMap(self.line_item_counts_by_status, self.fieldNameFor("line_item_counts_by_status"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .orders = "Orders",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const list_outposts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/outposts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOutposts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        life_cycle_status_filter: ?[][]const u8 = null,
        availability_zone_filter: ?[][]const u8 = null,
        availability_zone_id_filter: ?[][]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .life_cycle_status_filter = "LifeCycleStatusFilter",
            .availability_zone_filter = "AvailabilityZoneFilter",
            .availability_zone_id_filter = "AvailabilityZoneIdFilter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .life_cycle_status_filter = "LifeCycleStatusFilter",
                .availability_zone_filter = "AvailabilityZoneFilter",
                .availability_zone_id_filter = "AvailabilityZoneIdFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_outposts) } {
            return .{ .service_metadata = service_metadata, .action = list_outposts };
        }
    },
    Response: type = struct {
        outposts: ?[]Outpost = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outposts = "Outposts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_sites: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sites",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSites",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        operating_address_country_code_filter: ?[][]const u8 = null,
        operating_address_state_or_region_filter: ?[][]const u8 = null,
        operating_address_city_filter: ?[][]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .operating_address_country_code_filter = "OperatingAddressCountryCodeFilter",
            .operating_address_state_or_region_filter = "OperatingAddressStateOrRegionFilter",
            .operating_address_city_filter = "OperatingAddressCityFilter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .operating_address_country_code_filter = "OperatingAddressCountryCodeFilter",
                .operating_address_state_or_region_filter = "OperatingAddressStateOrRegionFilter",
                .operating_address_city_filter = "OperatingAddressCityFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sites) } {
            return .{ .service_metadata = service_metadata, .action = list_sites };
        }
    },
    Response: type = struct {
        sites: ?[]Site = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sites = "Sites",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const start_connection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/connections",
        .success_code = 200,
    };

    action_name: []const u8 = "StartConnection",
    Request: type = struct {
        device_serial_number: ?[]const u8 = null,
        asset_id: []const u8,
        client_public_key: []const u8,
        network_interface_device_index: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_serial_number = "DeviceSerialNumber",
                .asset_id = "AssetId",
                .client_public_key = "ClientPublicKey",
                .network_interface_device_index = "NetworkInterfaceDeviceIndex",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_connection) } {
            return .{ .service_metadata = service_metadata, .action = start_connection };
        }
    },
    Response: type = struct {
        connection_id: ?[]const u8 = null,
        underlay_ip_address: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_id = "ConnectionId",
                .underlay_ip_address = "UnderlayIpAddress",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const update_outpost: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/outposts/{OutpostId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOutpost",
    Request: type = struct {
        outpost_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        supported_hardware_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost_id = "OutpostId",
                .name = "Name",
                .description = "Description",
                .supported_hardware_type = "SupportedHardwareType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_outpost) } {
            return .{ .service_metadata = service_metadata, .action = update_outpost };
        }
    },
    Response: type = struct {
        outpost: ?Outpost = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost = "Outpost",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const update_site: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/sites/{SiteId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSite",
    Request: type = struct {
        site_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        notes: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site_id = "SiteId",
                .name = "Name",
                .description = "Description",
                .notes = "Notes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_site) } {
            return .{ .service_metadata = service_metadata, .action = update_site };
        }
    },
    Response: type = struct {
        site: ?Site = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "Site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const update_site_address: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sites/{SiteId}/address",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSiteAddress",
    Request: type = struct {
        site_id: []const u8,
        address_type: []const u8,
        address: Address,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site_id = "SiteId",
                .address_type = "AddressType",
                .address = "Address",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_site_address) } {
            return .{ .service_metadata = service_metadata, .action = update_site_address };
        }
    },
    Response: type = struct {
        address_type: ?[]const u8 = null,
        address: ?Address = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address_type = "AddressType",
                .address = "Address",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};
pub const update_site_rack_physical_properties: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/sites/{SiteId}/rackPhysicalProperties",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSiteRackPhysicalProperties",
    Request: type = struct {
        site_id: []const u8,
        power_draw_kva: ?[]const u8 = null,
        power_phase: ?[]const u8 = null,
        power_connector: ?[]const u8 = null,
        power_feed_drop: ?[]const u8 = null,
        uplink_gbps: ?[]const u8 = null,
        uplink_count: ?[]const u8 = null,
        fiber_optic_cable_type: ?[]const u8 = null,
        optical_standard: ?[]const u8 = null,
        maximum_supported_weight_lbs: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site_id = "SiteId",
                .power_draw_kva = "PowerDrawKva",
                .power_phase = "PowerPhase",
                .power_connector = "PowerConnector",
                .power_feed_drop = "PowerFeedDrop",
                .uplink_gbps = "UplinkGbps",
                .uplink_count = "UplinkCount",
                .fiber_optic_cable_type = "FiberOpticCableType",
                .optical_standard = "OpticalStandard",
                .maximum_supported_weight_lbs = "MaximumSupportedWeightLbs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_site_rack_physical_properties) } {
            return .{ .service_metadata = service_metadata, .action = update_site_rack_physical_properties };
        }
    },
    Response: type = struct {
        site: ?Site = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .site = "Site",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        NotFound,
        Validation,
    },
} = .{};

pub const Site = struct {
    site_id: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    site_arn: ?[]const u8 = null,
    notes: ?[]const u8 = null,
    operating_address_country_code: ?[]const u8 = null,
    operating_address_state_or_region: ?[]const u8 = null,
    operating_address_city: ?[]const u8 = null,
    rack_physical_properties: ?RackPhysicalProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .site_id = "SiteId",
            .account_id = "AccountId",
            .name = "Name",
            .description = "Description",
            .tags = "Tags",
            .site_arn = "SiteArn",
            .notes = "Notes",
            .operating_address_country_code = "OperatingAddressCountryCode",
            .operating_address_state_or_region = "OperatingAddressStateOrRegion",
            .operating_address_city = "OperatingAddressCity",
            .rack_physical_properties = "RackPhysicalProperties",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const RackPhysicalProperties = struct {
    power_draw_kva: ?[]const u8 = null,
    power_phase: ?[]const u8 = null,
    power_connector: ?[]const u8 = null,
    power_feed_drop: ?[]const u8 = null,
    uplink_gbps: ?[]const u8 = null,
    uplink_count: ?[]const u8 = null,
    fiber_optic_cable_type: ?[]const u8 = null,
    optical_standard: ?[]const u8 = null,
    maximum_supported_weight_lbs: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .power_draw_kva = "PowerDrawKva",
            .power_phase = "PowerPhase",
            .power_connector = "PowerConnector",
            .power_feed_drop = "PowerFeedDrop",
            .uplink_gbps = "UplinkGbps",
            .uplink_count = "UplinkCount",
            .fiber_optic_cable_type = "FiberOpticCableType",
            .optical_standard = "OpticalStandard",
            .maximum_supported_weight_lbs = "MaximumSupportedWeightLbs",
        };
        return @field(mappings, field_name);
    }
};

pub const Address = struct {
    contact_name: ?[]const u8 = null,
    contact_phone_number: ?[]const u8 = null,
    address_line1: []const u8,
    address_line2: ?[]const u8 = null,
    address_line3: ?[]const u8 = null,
    city: []const u8,
    state_or_region: []const u8,
    district_or_county: ?[]const u8 = null,
    postal_code: []const u8,
    country_code: []const u8,
    municipality: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .contact_name = "ContactName",
            .contact_phone_number = "ContactPhoneNumber",
            .address_line1 = "AddressLine1",
            .address_line2 = "AddressLine2",
            .address_line3 = "AddressLine3",
            .city = "City",
            .state_or_region = "StateOrRegion",
            .district_or_county = "DistrictOrCounty",
            .postal_code = "PostalCode",
            .country_code = "CountryCode",
            .municipality = "Municipality",
        };
        return @field(mappings, field_name);
    }
};

pub const Outpost = struct {
    outpost_id: ?[]const u8 = null,
    owner_id: ?[]const u8 = null,
    outpost_arn: ?[]const u8 = null,
    site_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    life_cycle_status: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    availability_zone_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    site_arn: ?[]const u8 = null,
    supported_hardware_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .outpost_id = "OutpostId",
            .owner_id = "OwnerId",
            .outpost_arn = "OutpostArn",
            .site_id = "SiteId",
            .name = "Name",
            .description = "Description",
            .life_cycle_status = "LifeCycleStatus",
            .availability_zone = "AvailabilityZone",
            .availability_zone_id = "AvailabilityZoneId",
            .tags = "Tags",
            .site_arn = "SiteArn",
            .supported_hardware_type = "SupportedHardwareType",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const CatalogItem = struct {
    catalog_item_id: ?[]const u8 = null,
    item_status: ?[]const u8 = null,
    ec2_capacities: ?[]EC2Capacity = null,
    power_kva: ?f32 = null,
    weight_lbs: ?i64 = null,
    supported_uplink_gbps: ?[]i64 = null,
    supported_storage: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_item_id = "CatalogItemId",
            .item_status = "ItemStatus",
            .ec2_capacities = "EC2Capacities",
            .power_kva = "PowerKva",
            .weight_lbs = "WeightLbs",
            .supported_uplink_gbps = "SupportedUplinkGbps",
            .supported_storage = "SupportedStorage",
        };
        return @field(mappings, field_name);
    }
};

pub const EC2Capacity = struct {
    family: ?[]const u8 = null,
    max_size: ?[]const u8 = null,
    quantity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .family = "Family",
            .max_size = "MaxSize",
            .quantity = "Quantity",
        };
        return @field(mappings, field_name);
    }
};

pub const Order = struct {
    outpost_id: ?[]const u8 = null,
    order_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    line_items: ?[]LineItem = null,
    payment_option: ?[]const u8 = null,
    order_submission_date: ?i64 = null,
    order_fulfilled_date: ?i64 = null,
    payment_term: ?[]const u8 = null,
    order_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .outpost_id = "OutpostId",
            .order_id = "OrderId",
            .status = "Status",
            .line_items = "LineItems",
            .payment_option = "PaymentOption",
            .order_submission_date = "OrderSubmissionDate",
            .order_fulfilled_date = "OrderFulfilledDate",
            .payment_term = "PaymentTerm",
            .order_type = "OrderType",
        };
        return @field(mappings, field_name);
    }
};

pub const LineItem = struct {
    catalog_item_id: ?[]const u8 = null,
    line_item_id: ?[]const u8 = null,
    quantity: ?i64 = null,
    status: ?[]const u8 = null,
    shipment_information: ?ShipmentInformation = null,
    asset_information_list: ?[]LineItemAssetInformation = null,
    previous_line_item_id: ?[]const u8 = null,
    previous_order_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_item_id = "CatalogItemId",
            .line_item_id = "LineItemId",
            .quantity = "Quantity",
            .status = "Status",
            .shipment_information = "ShipmentInformation",
            .asset_information_list = "AssetInformationList",
            .previous_line_item_id = "PreviousLineItemId",
            .previous_order_id = "PreviousOrderId",
        };
        return @field(mappings, field_name);
    }
};

pub const LineItemAssetInformation = struct {
    asset_id: ?[]const u8 = null,
    mac_address_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asset_id = "AssetId",
            .mac_address_list = "MacAddressList",
        };
        return @field(mappings, field_name);
    }
};

pub const ShipmentInformation = struct {
    shipment_tracking_number: ?[]const u8 = null,
    shipment_carrier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .shipment_tracking_number = "ShipmentTrackingNumber",
            .shipment_carrier = "ShipmentCarrier",
        };
        return @field(mappings, field_name);
    }
};
