const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-07-24";
pub const sdk_id: []const u8 = "Panorama";
pub const arn_namespace: ?[]const u8 = "panorama";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "panorama";
pub const name: []const u8 = "OmniCloudServiceLambda";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-07-24",
    sdk_id: []const u8 = "Panorama",
    arn_namespace: ?[]const u8 = "panorama",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "panorama",
    name: []const u8 = "OmniCloudServiceLambda",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_application_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/application-instances",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateApplicationInstance",
    Request: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        manifest_payload: ManifestPayload,
        manifest_overrides_payload: ?ManifestOverridesPayload = null,
        application_instance_id_to_replace: ?[]const u8 = null,
        runtime_role_arn: ?[]const u8 = null,
        default_runtime_context_device: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .manifest_payload = "ManifestPayload",
                .manifest_overrides_payload = "ManifestOverridesPayload",
                .application_instance_id_to_replace = "ApplicationInstanceIdToReplace",
                .runtime_role_arn = "RuntimeRoleArn",
                .default_runtime_context_device = "DefaultRuntimeContextDevice",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_application_instance };
        }
    },
    Response: type = struct {
        application_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_instance_id = "ApplicationInstanceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const create_job_for_devices: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateJobForDevices",
    Request: type = struct {
        device_ids: [][]const u8,
        device_job_config: ?struct {
            ota_job_config: ?struct {
                image_version: []const u8,
                allow_major_version_update: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .image_version = "ImageVersion",
                        .allow_major_version_update = "AllowMajorVersionUpdate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ota_job_config = "OTAJobConfig",
                };
                return @field(mappings, field_name);
            }
        } = null,
        job_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_ids = "DeviceIds",
                .device_job_config = "DeviceJobConfig",
                .job_type = "JobType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job_for_devices) } {
            return .{ .service_metadata = service_metadata, .action = create_job_for_devices };
        }
    },
    Response: type = struct {
        jobs: []struct {
            job_id: ?[]const u8 = null,
            device_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .device_id = "DeviceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_node_from_template_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/packages/template-job",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateNodeFromTemplateJob",
    Request: type = struct {
        template_type: []const u8,
        output_package_name: []const u8,
        output_package_version: []const u8,
        node_name: []const u8,
        node_description: ?[]const u8 = null,
        template_parameters: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        job_tags: ?[]JobResourceTags = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_type = "TemplateType",
                .output_package_name = "OutputPackageName",
                .output_package_version = "OutputPackageVersion",
                .node_name = "NodeName",
                .node_description = "NodeDescription",
                .template_parameters = "TemplateParameters",
                .job_tags = "JobTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "template_parameters", field_name))
                return try serializeMap(self.template_parameters, self.fieldNameFor("template_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_node_from_template_job) } {
            return .{ .service_metadata = service_metadata, .action = create_node_from_template_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const create_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/packages",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePackage",
    Request: type = struct {
        package_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_name = "PackageName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_package) } {
            return .{ .service_metadata = service_metadata, .action = create_package };
        }
    },
    Response: type = struct {
        package_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        storage_location: StorageLocation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageId",
                .arn = "Arn",
                .storage_location = "StorageLocation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const create_package_import_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/packages/import-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePackageImportJob",
    Request: type = struct {
        job_type: []const u8,
        input_config: PackageImportJobInputConfig,
        output_config: PackageImportJobOutputConfig,
        client_token: []const u8,
        job_tags: ?[]JobResourceTags = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_type = "JobType",
                .input_config = "InputConfig",
                .output_config = "OutputConfig",
                .client_token = "ClientToken",
                .job_tags = "JobTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_package_import_job) } {
            return .{ .service_metadata = service_metadata, .action = create_package_import_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const delete_device: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/devices/{DeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDevice",
    Request: type = struct {
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_device) } {
            return .{ .service_metadata = service_metadata, .action = delete_device };
        }
    },
    Response: type = struct {
        device_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_package: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/packages/{PackageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePackage",
    Request: type = struct {
        package_id: []const u8,
        force_delete: ?bool = null,

        pub const http_query = .{
            .force_delete = "ForceDelete",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageId",
                .force_delete = "ForceDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_package) } {
            return .{ .service_metadata = service_metadata, .action = delete_package };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const deregister_package_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/packages/{PackageId}/versions/{PackageVersion}/patch/{PatchVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterPackageVersion",
    Request: type = struct {
        owner_account: ?[]const u8 = null,
        package_id: []const u8,
        package_version: []const u8,
        patch_version: []const u8,
        updated_latest_patch_version: ?[]const u8 = null,

        pub const http_query = .{
            .owner_account = "OwnerAccount",
            .updated_latest_patch_version = "UpdatedLatestPatchVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "OwnerAccount",
                .package_id = "PackageId",
                .package_version = "PackageVersion",
                .patch_version = "PatchVersion",
                .updated_latest_patch_version = "UpdatedLatestPatchVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_package_version) } {
            return .{ .service_metadata = service_metadata, .action = deregister_package_version };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_application_instance: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/application-instances/{ApplicationInstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeApplicationInstance",
    Request: type = struct {
        application_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_instance_id = "ApplicationInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application_instance) } {
            return .{ .service_metadata = service_metadata, .action = describe_application_instance };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        default_runtime_context_device: ?[]const u8 = null,
        default_runtime_context_device_name: ?[]const u8 = null,
        application_instance_id_to_replace: ?[]const u8 = null,
        runtime_role_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        health_status: ?[]const u8 = null,
        status_description: ?[]const u8 = null,
        created_time: ?i64 = null,
        last_updated_time: ?i64 = null,
        application_instance_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        runtime_context_states: ?[]ReportedRuntimeContextState = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .default_runtime_context_device = "DefaultRuntimeContextDevice",
                .default_runtime_context_device_name = "DefaultRuntimeContextDeviceName",
                .application_instance_id_to_replace = "ApplicationInstanceIdToReplace",
                .runtime_role_arn = "RuntimeRoleArn",
                .status = "Status",
                .health_status = "HealthStatus",
                .status_description = "StatusDescription",
                .created_time = "CreatedTime",
                .last_updated_time = "LastUpdatedTime",
                .application_instance_id = "ApplicationInstanceId",
                .arn = "Arn",
                .tags = "Tags",
                .runtime_context_states = "RuntimeContextStates",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_application_instance_details: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/application-instances/{ApplicationInstanceId}/details",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeApplicationInstanceDetails",
    Request: type = struct {
        application_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_instance_id = "ApplicationInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application_instance_details) } {
            return .{ .service_metadata = service_metadata, .action = describe_application_instance_details };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        default_runtime_context_device: ?[]const u8 = null,
        manifest_payload: ?ManifestPayload = null,
        manifest_overrides_payload: ?ManifestOverridesPayload = null,
        application_instance_id_to_replace: ?[]const u8 = null,
        created_time: ?i64 = null,
        application_instance_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .default_runtime_context_device = "DefaultRuntimeContextDevice",
                .manifest_payload = "ManifestPayload",
                .manifest_overrides_payload = "ManifestOverridesPayload",
                .application_instance_id_to_replace = "ApplicationInstanceIdToReplace",
                .created_time = "CreatedTime",
                .application_instance_id = "ApplicationInstanceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_device: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/devices/{DeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDevice",
    Request: type = struct {
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_device) } {
            return .{ .service_metadata = service_metadata, .action = describe_device };
        }
    },
    Response: type = struct {
        device_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        device_connection_status: ?[]const u8 = null,
        created_time: ?i64 = null,
        provisioning_status: ?[]const u8 = null,
        latest_software: ?[]const u8 = null,
        current_software: ?[]const u8 = null,
        serial_number: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        networking_configuration: ?NetworkPayload = null,
        current_networking_status: ?struct {
            ethernet0_status: ?EthernetStatus = null,
            ethernet1_status: ?EthernetStatus = null,
            ntp_status: ?struct {
                connection_status: ?[]const u8 = null,
                ip_address: ?[]const u8 = null,
                ntp_server_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .connection_status = "ConnectionStatus",
                        .ip_address = "IpAddress",
                        .ntp_server_name = "NtpServerName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ethernet0_status = "Ethernet0Status",
                    .ethernet1_status = "Ethernet1Status",
                    .ntp_status = "NtpStatus",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lease_expiration_time: ?i64 = null,
        alternate_softwares: ?[]struct {
            version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }
        } = null,
        latest_alternate_software: ?[]const u8 = null,
        brand: ?[]const u8 = null,
        latest_device_job: ?LatestDeviceJob = null,
        device_aggregated_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
                .name = "Name",
                .arn = "Arn",
                .description = "Description",
                .type = "Type",
                .device_connection_status = "DeviceConnectionStatus",
                .created_time = "CreatedTime",
                .provisioning_status = "ProvisioningStatus",
                .latest_software = "LatestSoftware",
                .current_software = "CurrentSoftware",
                .serial_number = "SerialNumber",
                .tags = "Tags",
                .networking_configuration = "NetworkingConfiguration",
                .current_networking_status = "CurrentNetworkingStatus",
                .lease_expiration_time = "LeaseExpirationTime",
                .alternate_softwares = "AlternateSoftwares",
                .latest_alternate_software = "LatestAlternateSoftware",
                .brand = "Brand",
                .latest_device_job = "LatestDeviceJob",
                .device_aggregated_status = "DeviceAggregatedStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_device_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDeviceJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_device_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_device_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        device_id: ?[]const u8 = null,
        device_arn: ?[]const u8 = null,
        device_name: ?[]const u8 = null,
        device_type: ?[]const u8 = null,
        image_version: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_time: ?i64 = null,
        job_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .device_id = "DeviceId",
                .device_arn = "DeviceArn",
                .device_name = "DeviceName",
                .device_type = "DeviceType",
                .image_version = "ImageVersion",
                .status = "Status",
                .created_time = "CreatedTime",
                .job_type = "JobType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_node: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/nodes/{NodeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeNode",
    Request: type = struct {
        node_id: []const u8,
        owner_account: ?[]const u8 = null,

        pub const http_query = .{
            .owner_account = "OwnerAccount",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_id = "NodeId",
                .owner_account = "OwnerAccount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_node) } {
            return .{ .service_metadata = service_metadata, .action = describe_node };
        }
    },
    Response: type = struct {
        node_id: []const u8,
        name: []const u8,
        category: []const u8,
        owner_account: []const u8,
        package_name: []const u8,
        package_id: []const u8,
        package_arn: ?[]const u8 = null,
        package_version: []const u8,
        patch_version: []const u8,
        node_interface: struct {
            inputs: []struct {
                name: ?[]const u8 = null,
                description: ?[]const u8 = null,
                type: ?[]const u8 = null,
                default_value: ?[]const u8 = null,
                max_connections: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .description = "Description",
                        .type = "Type",
                        .default_value = "DefaultValue",
                        .max_connections = "MaxConnections",
                    };
                    return @field(mappings, field_name);
                }
            },
            outputs: []struct {
                name: ?[]const u8 = null,
                description: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .description = "Description",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .inputs = "Inputs",
                    .outputs = "Outputs",
                };
                return @field(mappings, field_name);
            }
        },
        asset_name: ?[]const u8 = null,
        description: []const u8,
        created_time: i64,
        last_updated_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_id = "NodeId",
                .name = "Name",
                .category = "Category",
                .owner_account = "OwnerAccount",
                .package_name = "PackageName",
                .package_id = "PackageId",
                .package_arn = "PackageArn",
                .package_version = "PackageVersion",
                .patch_version = "PatchVersion",
                .node_interface = "NodeInterface",
                .asset_name = "AssetName",
                .description = "Description",
                .created_time = "CreatedTime",
                .last_updated_time = "LastUpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_node_from_template_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages/template-job/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeNodeFromTemplateJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_node_from_template_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_node_from_template_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        status: []const u8,
        status_message: []const u8,
        created_time: i64,
        last_updated_time: i64,
        output_package_name: []const u8,
        output_package_version: []const u8,
        node_name: []const u8,
        node_description: ?[]const u8 = null,
        template_type: []const u8,
        template_parameters: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        job_tags: ?[]JobResourceTags = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .status = "Status",
                .status_message = "StatusMessage",
                .created_time = "CreatedTime",
                .last_updated_time = "LastUpdatedTime",
                .output_package_name = "OutputPackageName",
                .output_package_version = "OutputPackageVersion",
                .node_name = "NodeName",
                .node_description = "NodeDescription",
                .template_type = "TemplateType",
                .template_parameters = "TemplateParameters",
                .job_tags = "JobTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "template_parameters", field_name))
                return try serializeMap(self.template_parameters, self.fieldNameFor("template_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const describe_package: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages/metadata/{PackageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePackage",
    Request: type = struct {
        package_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_package) } {
            return .{ .service_metadata = service_metadata, .action = describe_package };
        }
    },
    Response: type = struct {
        package_id: []const u8,
        package_name: []const u8,
        arn: []const u8,
        storage_location: StorageLocation,
        read_access_principal_arns: ?[][]const u8 = null,
        write_access_principal_arns: ?[][]const u8 = null,
        created_time: i64,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_id = "PackageId",
                .package_name = "PackageName",
                .arn = "Arn",
                .storage_location = "StorageLocation",
                .read_access_principal_arns = "ReadAccessPrincipalArns",
                .write_access_principal_arns = "WriteAccessPrincipalArns",
                .created_time = "CreatedTime",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_package_import_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages/import-jobs/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePackageImportJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_package_import_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_package_import_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        client_token: ?[]const u8 = null,
        job_type: []const u8,
        input_config: PackageImportJobInputConfig,
        output_config: PackageImportJobOutputConfig,
        output: struct {
            package_id: []const u8,
            package_version: []const u8,
            patch_version: []const u8,
            output_s3_location: struct {
                bucket_name: []const u8,
                object_key: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bucket_name = "BucketName",
                        .object_key = "ObjectKey",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .package_id = "PackageId",
                    .package_version = "PackageVersion",
                    .patch_version = "PatchVersion",
                    .output_s3_location = "OutputS3Location",
                };
                return @field(mappings, field_name);
            }
        },
        created_time: i64,
        last_updated_time: i64,
        status: []const u8,
        status_message: []const u8,
        job_tags: ?[]JobResourceTags = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .client_token = "ClientToken",
                .job_type = "JobType",
                .input_config = "InputConfig",
                .output_config = "OutputConfig",
                .output = "Output",
                .created_time = "CreatedTime",
                .last_updated_time = "LastUpdatedTime",
                .status = "Status",
                .status_message = "StatusMessage",
                .job_tags = "JobTags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const describe_package_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages/metadata/{PackageId}/versions/{PackageVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePackageVersion",
    Request: type = struct {
        owner_account: ?[]const u8 = null,
        package_id: []const u8,
        package_version: []const u8,
        patch_version: ?[]const u8 = null,

        pub const http_query = .{
            .owner_account = "OwnerAccount",
            .patch_version = "PatchVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "OwnerAccount",
                .package_id = "PackageId",
                .package_version = "PackageVersion",
                .patch_version = "PatchVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_package_version) } {
            return .{ .service_metadata = service_metadata, .action = describe_package_version };
        }
    },
    Response: type = struct {
        owner_account: ?[]const u8 = null,
        package_id: []const u8,
        package_arn: ?[]const u8 = null,
        package_name: []const u8,
        package_version: []const u8,
        patch_version: []const u8,
        is_latest_patch: bool,
        status: []const u8,
        status_description: ?[]const u8 = null,
        registered_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "OwnerAccount",
                .package_id = "PackageId",
                .package_arn = "PackageArn",
                .package_name = "PackageName",
                .package_version = "PackageVersion",
                .patch_version = "PatchVersion",
                .is_latest_patch = "IsLatestPatch",
                .status = "Status",
                .status_description = "StatusDescription",
                .registered_time = "RegisteredTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_application_instance_dependencies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/application-instances/{ApplicationInstanceId}/package-dependencies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplicationInstanceDependencies",
    Request: type = struct {
        application_instance_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_instance_id = "ApplicationInstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_instance_dependencies) } {
            return .{ .service_metadata = service_metadata, .action = list_application_instance_dependencies };
        }
    },
    Response: type = struct {
        package_objects: ?[]struct {
            name: []const u8,
            package_version: []const u8,
            patch_version: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .package_version = "PackageVersion",
                    .patch_version = "PatchVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_objects = "PackageObjects",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
    },
} = .{};
pub const list_application_instance_node_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/application-instances/{ApplicationInstanceId}/node-instances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplicationInstanceNodeInstances",
    Request: type = struct {
        application_instance_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_instance_id = "ApplicationInstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_instance_node_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_application_instance_node_instances };
        }
    },
    Response: type = struct {
        node_instances: ?[]struct {
            node_instance_id: []const u8,
            node_id: ?[]const u8 = null,
            package_name: ?[]const u8 = null,
            package_version: ?[]const u8 = null,
            package_patch_version: ?[]const u8 = null,
            node_name: ?[]const u8 = null,
            current_status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .node_instance_id = "NodeInstanceId",
                    .node_id = "NodeId",
                    .package_name = "PackageName",
                    .package_version = "PackageVersion",
                    .package_patch_version = "PackagePatchVersion",
                    .node_name = "NodeName",
                    .current_status = "CurrentStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_instances = "NodeInstances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
    },
} = .{};
pub const list_application_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/application-instances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplicationInstances",
    Request: type = struct {
        device_id: ?[]const u8 = null,
        status_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .device_id = "deviceId",
            .status_filter = "statusFilter",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
                .status_filter = "StatusFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_application_instances };
        }
    },
    Response: type = struct {
        application_instances: ?[]struct {
            name: ?[]const u8 = null,
            application_instance_id: ?[]const u8 = null,
            default_runtime_context_device: ?[]const u8 = null,
            default_runtime_context_device_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            health_status: ?[]const u8 = null,
            status_description: ?[]const u8 = null,
            created_time: ?i64 = null,
            arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            runtime_context_states: ?[]ReportedRuntimeContextState = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .application_instance_id = "ApplicationInstanceId",
                    .default_runtime_context_device = "DefaultRuntimeContextDevice",
                    .default_runtime_context_device_name = "DefaultRuntimeContextDeviceName",
                    .description = "Description",
                    .status = "Status",
                    .health_status = "HealthStatus",
                    .status_description = "StatusDescription",
                    .created_time = "CreatedTime",
                    .arn = "Arn",
                    .tags = "Tags",
                    .runtime_context_states = "RuntimeContextStates",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_instances = "ApplicationInstances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
    },
} = .{};
pub const list_devices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDevices",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        name_filter: ?[]const u8 = null,
        device_aggregated_status_filter: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .sort_by = "SortBy",
            .sort_order = "SortOrder",
            .name_filter = "NameFilter",
            .device_aggregated_status_filter = "DeviceAggregatedStatusFilter",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .name_filter = "NameFilter",
                .device_aggregated_status_filter = "DeviceAggregatedStatusFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_devices };
        }
    },
    Response: type = struct {
        devices: []struct {
            device_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            created_time: ?i64 = null,
            provisioning_status: ?[]const u8 = null,
            last_updated_time: ?i64 = null,
            lease_expiration_time: ?i64 = null,
            brand: ?[]const u8 = null,
            current_software: ?[]const u8 = null,
            description: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            type: ?[]const u8 = null,
            latest_device_job: ?LatestDeviceJob = null,
            device_aggregated_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_id = "DeviceId",
                    .name = "Name",
                    .created_time = "CreatedTime",
                    .provisioning_status = "ProvisioningStatus",
                    .last_updated_time = "LastUpdatedTime",
                    .lease_expiration_time = "LeaseExpirationTime",
                    .brand = "Brand",
                    .current_software = "CurrentSoftware",
                    .description = "Description",
                    .tags = "Tags",
                    .type = "Type",
                    .latest_device_job = "LatestDeviceJob",
                    .device_aggregated_status = "DeviceAggregatedStatus",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .devices = "Devices",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_devices_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDevicesJobs",
    Request: type = struct {
        device_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .device_id = "DeviceId",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_devices_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_devices_jobs };
        }
    },
    Response: type = struct {
        device_jobs: ?[]struct {
            device_name: ?[]const u8 = null,
            device_id: ?[]const u8 = null,
            job_id: ?[]const u8 = null,
            created_time: ?i64 = null,
            job_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_name = "DeviceName",
                    .device_id = "DeviceId",
                    .job_id = "JobId",
                    .created_time = "CreatedTime",
                    .job_type = "JobType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_jobs = "DeviceJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_node_from_template_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages/template-job",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNodeFromTemplateJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_node_from_template_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_node_from_template_jobs };
        }
    },
    Response: type = struct {
        node_from_template_jobs: []struct {
            job_id: ?[]const u8 = null,
            template_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            created_time: ?i64 = null,
            node_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .template_type = "TemplateType",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .created_time = "CreatedTime",
                    .node_name = "NodeName",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .node_from_template_jobs = "NodeFromTemplateJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_nodes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/nodes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNodes",
    Request: type = struct {
        category: ?[]const u8 = null,
        owner_account: ?[]const u8 = null,
        package_name: ?[]const u8 = null,
        package_version: ?[]const u8 = null,
        patch_version: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .category = "category",
            .owner_account = "ownerAccount",
            .package_name = "packageName",
            .package_version = "packageVersion",
            .patch_version = "patchVersion",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category = "Category",
                .owner_account = "OwnerAccount",
                .package_name = "PackageName",
                .package_version = "PackageVersion",
                .patch_version = "PatchVersion",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_nodes) } {
            return .{ .service_metadata = service_metadata, .action = list_nodes };
        }
    },
    Response: type = struct {
        nodes: ?[]struct {
            node_id: []const u8,
            name: []const u8,
            category: []const u8,
            owner_account: ?[]const u8 = null,
            package_name: []const u8,
            package_id: []const u8,
            package_arn: ?[]const u8 = null,
            package_version: []const u8,
            patch_version: []const u8,
            description: ?[]const u8 = null,
            created_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .node_id = "NodeId",
                    .name = "Name",
                    .category = "Category",
                    .owner_account = "OwnerAccount",
                    .package_name = "PackageName",
                    .package_id = "PackageId",
                    .package_arn = "PackageArn",
                    .package_version = "PackageVersion",
                    .patch_version = "PatchVersion",
                    .description = "Description",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nodes = "Nodes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_package_import_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages/import-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackageImportJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_package_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_package_import_jobs };
        }
    },
    Response: type = struct {
        package_import_jobs: []struct {
            job_id: ?[]const u8 = null,
            job_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .job_type = "JobType",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .package_import_jobs = "PackageImportJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_packages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/packages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPackages",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_packages) } {
            return .{ .service_metadata = service_metadata, .action = list_packages };
        }
    },
    Response: type = struct {
        packages: ?[]struct {
            package_id: ?[]const u8 = null,
            package_name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            created_time: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .package_id = "PackageId",
                    .package_name = "PackageName",
                    .arn = "Arn",
                    .created_time = "CreatedTime",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .packages = "Packages",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const provision_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "ProvisionDevice",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        networking_configuration: ?NetworkPayload = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .tags = "Tags",
                .networking_configuration = "NetworkingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(provision_device) } {
            return .{ .service_metadata = service_metadata, .action = provision_device };
        }
    },
    Response: type = struct {
        device_id: ?[]const u8 = null,
        arn: []const u8,
        status: []const u8,
        certificates: ?[]const u8 = null,
        iot_thing_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
                .arn = "Arn",
                .status = "Status",
                .certificates = "Certificates",
                .iot_thing_name = "IotThingName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const register_package_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/packages/{PackageId}/versions/{PackageVersion}/patch/{PatchVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterPackageVersion",
    Request: type = struct {
        owner_account: ?[]const u8 = null,
        package_id: []const u8,
        package_version: []const u8,
        patch_version: []const u8,
        mark_latest: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner_account = "OwnerAccount",
                .package_id = "PackageId",
                .package_version = "PackageVersion",
                .patch_version = "PatchVersion",
                .mark_latest = "MarkLatest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_package_version) } {
            return .{ .service_metadata = service_metadata, .action = register_package_version };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const remove_application_instance: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/application-instances/{ApplicationInstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveApplicationInstance",
    Request: type = struct {
        application_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_instance_id = "ApplicationInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_application_instance) } {
            return .{ .service_metadata = service_metadata, .action = remove_application_instance };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const signal_application_instance_node_instances: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/application-instances/{ApplicationInstanceId}/node-signals",
        .success_code = 200,
    };

    action_name: []const u8 = "SignalApplicationInstanceNodeInstances",
    Request: type = struct {
        application_instance_id: []const u8,
        node_signals: []struct {
            node_instance_id: []const u8,
            signal: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .node_instance_id = "NodeInstanceId",
                    .signal = "Signal",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_instance_id = "ApplicationInstanceId",
                .node_signals = "NodeSignals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(signal_application_instance_node_instances) } {
            return .{ .service_metadata = service_metadata, .action = signal_application_instance_node_instances };
        }
    },
    Response: type = struct {
        application_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_instance_id = "ApplicationInstanceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_device_metadata: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/devices/{DeviceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDeviceMetadata",
    Request: type = struct {
        device_id: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_device_metadata };
        }
    },
    Response: type = struct {
        device_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const NetworkPayload = struct {
    ethernet0: ?EthernetPayload = null,
    ethernet1: ?EthernetPayload = null,
    ntp: ?NtpPayload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ethernet0 = "Ethernet0",
            .ethernet1 = "Ethernet1",
            .ntp = "Ntp",
        };
        return @field(mappings, field_name);
    }
};

pub const NtpPayload = struct {
    ntp_servers: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ntp_servers = "NtpServers",
        };
        return @field(mappings, field_name);
    }
};

pub const EthernetPayload = struct {
    connection_type: []const u8,
    static_ip_connection_info: ?StaticIpConnectionInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_type = "ConnectionType",
            .static_ip_connection_info = "StaticIpConnectionInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const StaticIpConnectionInfo = struct {
    ip_address: []const u8,
    mask: []const u8,
    dns: [][]const u8,
    default_gateway: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address = "IpAddress",
            .mask = "Mask",
            .dns = "Dns",
            .default_gateway = "DefaultGateway",
        };
        return @field(mappings, field_name);
    }
};

pub const LatestDeviceJob = struct {
    image_version: ?[]const u8 = null,
    status: ?[]const u8 = null,
    job_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_version = "ImageVersion",
            .status = "Status",
            .job_type = "JobType",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportedRuntimeContextState = struct {
    desired_state: []const u8,
    runtime_context_name: []const u8,
    device_reported_status: []const u8,
    device_reported_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .desired_state = "DesiredState",
            .runtime_context_name = "RuntimeContextName",
            .device_reported_status = "DeviceReportedStatus",
            .device_reported_time = "DeviceReportedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const JobResourceTags = struct {
    resource_type: []const u8,
    tags: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "ResourceType",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const PackageImportJobOutputConfig = struct {
    package_version_output_config: ?PackageVersionOutputConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_version_output_config = "PackageVersionOutputConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageVersionOutputConfig = struct {
    package_name: []const u8,
    package_version: []const u8,
    mark_latest: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_name = "PackageName",
            .package_version = "PackageVersion",
            .mark_latest = "MarkLatest",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageImportJobInputConfig = struct {
    package_version_input_config: ?PackageVersionInputConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_version_input_config = "PackageVersionInputConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const PackageVersionInputConfig = struct {
    s3_location: S3Location,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_location = "S3Location",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    region: ?[]const u8 = null,
    bucket_name: []const u8,
    object_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "Region",
            .bucket_name = "BucketName",
            .object_key = "ObjectKey",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLocation = struct {
    bucket: []const u8,
    repo_prefix_location: []const u8,
    generated_prefix_location: []const u8,
    binary_prefix_location: []const u8,
    manifest_prefix_location: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .repo_prefix_location = "RepoPrefixLocation",
            .generated_prefix_location = "GeneratedPrefixLocation",
            .binary_prefix_location = "BinaryPrefixLocation",
            .manifest_prefix_location = "ManifestPrefixLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const EthernetStatus = struct {
    ip_address: ?[]const u8 = null,
    connection_status: ?[]const u8 = null,
    hw_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address = "IpAddress",
            .connection_status = "ConnectionStatus",
            .hw_address = "HwAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const ManifestOverridesPayload = union {
    payload_data: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .payload_data = "PayloadData",
        };
        return @field(mappings, field_name);
    }
};

pub const ManifestPayload = union {
    payload_data: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .payload_data = "PayloadData",
        };
        return @field(mappings, field_name);
    }
};
