const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-09-14";
pub const sdk_id: []const u8 = "Payment Cryptography";
pub const arn_namespace: ?[]const u8 = "payment-cryptography";
pub const endpoint_prefix: []const u8 = "controlplane.payment-cryptography";
pub const sigv4_name: []const u8 = "payment-cryptography";
pub const name: []const u8 = "PaymentCryptographyControlPlane";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2021-09-14",
    sdk_id: []const u8 = "Payment Cryptography",
    arn_namespace: ?[]const u8 = "payment-cryptography",
    endpoint_prefix: []const u8 = "controlplane.payment-cryptography",
    sigv4_name: []const u8 = "payment-cryptography",
    name: []const u8 = "PaymentCryptographyControlPlane",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const export_key: struct {
    action_name: []const u8 = "ExportKey",
    Request: type = struct {
        key_material: union {
            tr31_key_block: ?struct {
                wrapping_key_identifier: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .wrapping_key_identifier = "WrappingKeyIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            },
            tr34_key_block: ?struct {
                certificate_authority_public_key_identifier: []const u8,
                wrapping_key_certificate: []const u8,
                export_token: []const u8,
                key_block_format: []const u8,
                random_nonce: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .certificate_authority_public_key_identifier = "CertificateAuthorityPublicKeyIdentifier",
                        .wrapping_key_certificate = "WrappingKeyCertificate",
                        .export_token = "ExportToken",
                        .key_block_format = "KeyBlockFormat",
                        .random_nonce = "RandomNonce",
                    };
                    return @field(mappings, field_name);
                }
            },
            key_cryptogram: ?struct {
                certificate_authority_public_key_identifier: []const u8,
                wrapping_key_certificate: []const u8,
                wrapping_spec: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .certificate_authority_public_key_identifier = "CertificateAuthorityPublicKeyIdentifier",
                        .wrapping_key_certificate = "WrappingKeyCertificate",
                        .wrapping_spec = "WrappingSpec",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tr31_key_block = "Tr31KeyBlock",
                    .tr34_key_block = "Tr34KeyBlock",
                    .key_cryptogram = "KeyCryptogram",
                };
                return @field(mappings, field_name);
            }
        },
        export_key_identifier: []const u8,
        export_attributes: ?struct {
            export_dukpt_initial_key: ?struct {
                key_serial_number: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key_serial_number = "KeySerialNumber",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            key_check_value_algorithm: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .export_dukpt_initial_key = "ExportDukptInitialKey",
                    .key_check_value_algorithm = "KeyCheckValueAlgorithm",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_material = "KeyMaterial",
                .export_key_identifier = "ExportKeyIdentifier",
                .export_attributes = "ExportAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_key) } {
            return .{ .service_metadata = service_metadata, .action = export_key };
        }
    },
    Response: type = struct {
        wrapped_key: ?struct {
            wrapping_key_arn: []const u8,
            wrapped_key_material_format: []const u8,
            key_material: []const u8,
            key_check_value: ?[]const u8 = null,
            key_check_value_algorithm: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .wrapping_key_arn = "WrappingKeyArn",
                    .wrapped_key_material_format = "WrappedKeyMaterialFormat",
                    .key_material = "KeyMaterial",
                    .key_check_value = "KeyCheckValue",
                    .key_check_value_algorithm = "KeyCheckValueAlgorithm",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wrapped_key = "WrappedKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const get_parameters_for_export: struct {
    action_name: []const u8 = "GetParametersForExport",
    Request: type = struct {
        key_material_type: []const u8,
        signing_key_algorithm: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_material_type = "KeyMaterialType",
                .signing_key_algorithm = "SigningKeyAlgorithm",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_parameters_for_export) } {
            return .{ .service_metadata = service_metadata, .action = get_parameters_for_export };
        }
    },
    Response: type = struct {
        signing_key_certificate: []const u8,
        signing_key_certificate_chain: []const u8,
        signing_key_algorithm: []const u8,
        export_token: []const u8,
        parameters_valid_until_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .signing_key_certificate = "SigningKeyCertificate",
                .signing_key_certificate_chain = "SigningKeyCertificateChain",
                .signing_key_algorithm = "SigningKeyAlgorithm",
                .export_token = "ExportToken",
                .parameters_valid_until_timestamp = "ParametersValidUntilTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const get_parameters_for_import: struct {
    action_name: []const u8 = "GetParametersForImport",
    Request: type = struct {
        key_material_type: []const u8,
        wrapping_key_algorithm: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_material_type = "KeyMaterialType",
                .wrapping_key_algorithm = "WrappingKeyAlgorithm",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_parameters_for_import) } {
            return .{ .service_metadata = service_metadata, .action = get_parameters_for_import };
        }
    },
    Response: type = struct {
        wrapping_key_certificate: []const u8,
        wrapping_key_certificate_chain: []const u8,
        wrapping_key_algorithm: []const u8,
        import_token: []const u8,
        parameters_valid_until_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wrapping_key_certificate = "WrappingKeyCertificate",
                .wrapping_key_certificate_chain = "WrappingKeyCertificateChain",
                .wrapping_key_algorithm = "WrappingKeyAlgorithm",
                .import_token = "ImportToken",
                .parameters_valid_until_timestamp = "ParametersValidUntilTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const get_public_key_certificate: struct {
    action_name: []const u8 = "GetPublicKeyCertificate",
    Request: type = struct {
        key_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_identifier = "KeyIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_public_key_certificate) } {
            return .{ .service_metadata = service_metadata, .action = get_public_key_certificate };
        }
    },
    Response: type = struct {
        key_certificate: []const u8,
        key_certificate_chain: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_certificate = "KeyCertificate",
                .key_certificate_chain = "KeyCertificateChain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const import_key: struct {
    action_name: []const u8 = "ImportKey",
    Request: type = struct {
        key_material: union {
            root_certificate_public_key: ?struct {
                key_attributes: KeyAttributes,
                public_key_certificate: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key_attributes = "KeyAttributes",
                        .public_key_certificate = "PublicKeyCertificate",
                    };
                    return @field(mappings, field_name);
                }
            },
            trusted_certificate_public_key: ?struct {
                key_attributes: KeyAttributes,
                public_key_certificate: []const u8,
                certificate_authority_public_key_identifier: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key_attributes = "KeyAttributes",
                        .public_key_certificate = "PublicKeyCertificate",
                        .certificate_authority_public_key_identifier = "CertificateAuthorityPublicKeyIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            },
            tr31_key_block: ?struct {
                wrapping_key_identifier: []const u8,
                wrapped_key_block: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .wrapping_key_identifier = "WrappingKeyIdentifier",
                        .wrapped_key_block = "WrappedKeyBlock",
                    };
                    return @field(mappings, field_name);
                }
            },
            tr34_key_block: ?struct {
                certificate_authority_public_key_identifier: []const u8,
                signing_key_certificate: []const u8,
                import_token: []const u8,
                wrapped_key_block: []const u8,
                key_block_format: []const u8,
                random_nonce: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .certificate_authority_public_key_identifier = "CertificateAuthorityPublicKeyIdentifier",
                        .signing_key_certificate = "SigningKeyCertificate",
                        .import_token = "ImportToken",
                        .wrapped_key_block = "WrappedKeyBlock",
                        .key_block_format = "KeyBlockFormat",
                        .random_nonce = "RandomNonce",
                    };
                    return @field(mappings, field_name);
                }
            },
            key_cryptogram: ?struct {
                key_attributes: KeyAttributes,
                exportable: bool,
                wrapped_key_cryptogram: []const u8,
                import_token: []const u8,
                wrapping_spec: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key_attributes = "KeyAttributes",
                        .exportable = "Exportable",
                        .wrapped_key_cryptogram = "WrappedKeyCryptogram",
                        .import_token = "ImportToken",
                        .wrapping_spec = "WrappingSpec",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .root_certificate_public_key = "RootCertificatePublicKey",
                    .trusted_certificate_public_key = "TrustedCertificatePublicKey",
                    .tr31_key_block = "Tr31KeyBlock",
                    .tr34_key_block = "Tr34KeyBlock",
                    .key_cryptogram = "KeyCryptogram",
                };
                return @field(mappings, field_name);
            }
        },
        key_check_value_algorithm: ?[]const u8 = null,
        enabled: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_material = "KeyMaterial",
                .key_check_value_algorithm = "KeyCheckValueAlgorithm",
                .enabled = "Enabled",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_key) } {
            return .{ .service_metadata = service_metadata, .action = import_key };
        }
    },
    Response: type = struct {
        key: struct {
            key_arn: []const u8,
            key_attributes: KeyAttributes,
            key_check_value: []const u8,
            key_check_value_algorithm: []const u8,
            enabled: bool,
            exportable: bool,
            key_state: []const u8,
            key_origin: []const u8,
            create_timestamp: i64,
            usage_start_timestamp: ?i64 = null,
            usage_stop_timestamp: ?i64 = null,
            delete_pending_timestamp: ?i64 = null,
            delete_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key_arn = "KeyArn",
                    .key_attributes = "KeyAttributes",
                    .key_check_value = "KeyCheckValue",
                    .key_check_value_algorithm = "KeyCheckValueAlgorithm",
                    .enabled = "Enabled",
                    .exportable = "Exportable",
                    .key_state = "KeyState",
                    .key_origin = "KeyOrigin",
                    .create_timestamp = "CreateTimestamp",
                    .usage_start_timestamp = "UsageStartTimestamp",
                    .usage_stop_timestamp = "UsageStopTimestamp",
                    .delete_pending_timestamp = "DeletePendingTimestamp",
                    .delete_timestamp = "DeleteTimestamp",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key = "Key",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []Tag,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyAttributes = struct {
    key_usage: []const u8,
    key_class: []const u8,
    key_algorithm: []const u8,
    key_modes_of_use: KeyModesOfUse,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_usage = "KeyUsage",
            .key_class = "KeyClass",
            .key_algorithm = "KeyAlgorithm",
            .key_modes_of_use = "KeyModesOfUse",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyModesOfUse = struct {
    encrypt: ?bool = null,
    decrypt: ?bool = null,
    wrap: ?bool = null,
    unwrap: ?bool = null,
    generate: ?bool = null,
    sign: ?bool = null,
    verify: ?bool = null,
    derive_key: ?bool = null,
    no_restrictions: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encrypt = "Encrypt",
            .decrypt = "Decrypt",
            .wrap = "Wrap",
            .unwrap = "Unwrap",
            .generate = "Generate",
            .sign = "Sign",
            .verify = "Verify",
            .derive_key = "DeriveKey",
            .no_restrictions = "NoRestrictions",
        };
        return @field(mappings, field_name);
    }
};
