const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-02-03";
pub const sdk_id: []const u8 = "Payment Cryptography Data";
pub const arn_namespace: ?[]const u8 = null;
pub const endpoint_prefix: []const u8 = "dataplane.payment-cryptography";
pub const sigv4_name: []const u8 = "payment-cryptography";
pub const name: []const u8 = "PaymentCryptographyDataPlane";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2022-02-03",
    sdk_id: []const u8 = "Payment Cryptography Data",
    arn_namespace: ?[]const u8 = null,
    endpoint_prefix: []const u8 = "dataplane.payment-cryptography",
    sigv4_name: []const u8 = "payment-cryptography",
    name: []const u8 = "PaymentCryptographyDataPlane",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const decrypt_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/keys/{KeyIdentifier}/decrypt",
        .success_code = 200,
    };

    action_name: []const u8 = "DecryptData",
    Request: type = struct {
        key_identifier: []const u8,
        cipher_text: []const u8,
        decryption_attributes: EncryptionDecryptionAttributes,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_identifier = "KeyIdentifier",
                .cipher_text = "CipherText",
                .decryption_attributes = "DecryptionAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decrypt_data) } {
            return .{ .service_metadata = service_metadata, .action = decrypt_data };
        }
    },
    Response: type = struct {
        key_arn: []const u8,
        key_check_value: []const u8,
        plain_text: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_arn = "KeyArn",
                .key_check_value = "KeyCheckValue",
                .plain_text = "PlainText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const encrypt_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/keys/{KeyIdentifier}/encrypt",
        .success_code = 200,
    };

    action_name: []const u8 = "EncryptData",
    Request: type = struct {
        key_identifier: []const u8,
        plain_text: []const u8,
        encryption_attributes: EncryptionDecryptionAttributes,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_identifier = "KeyIdentifier",
                .plain_text = "PlainText",
                .encryption_attributes = "EncryptionAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(encrypt_data) } {
            return .{ .service_metadata = service_metadata, .action = encrypt_data };
        }
    },
    Response: type = struct {
        key_arn: []const u8,
        key_check_value: ?[]const u8 = null,
        cipher_text: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_arn = "KeyArn",
                .key_check_value = "KeyCheckValue",
                .cipher_text = "CipherText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const generate_card_validation_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cardvalidationdata/generate",
        .success_code = 200,
    };

    action_name: []const u8 = "GenerateCardValidationData",
    Request: type = struct {
        key_identifier: []const u8,
        primary_account_number: []const u8,
        generation_attributes: union {
            amex_card_security_code_version1: ?AmexCardSecurityCodeVersion1,
            amex_card_security_code_version2: ?AmexCardSecurityCodeVersion2,
            card_verification_value1: ?CardVerificationValue1,
            card_verification_value2: ?CardVerificationValue2,
            card_holder_verification_value: ?CardHolderVerificationValue,
            dynamic_card_verification_code: ?DynamicCardVerificationCode,
            dynamic_card_verification_value: ?DynamicCardVerificationValue,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .amex_card_security_code_version1 = "AmexCardSecurityCodeVersion1",
                    .amex_card_security_code_version2 = "AmexCardSecurityCodeVersion2",
                    .card_verification_value1 = "CardVerificationValue1",
                    .card_verification_value2 = "CardVerificationValue2",
                    .card_holder_verification_value = "CardHolderVerificationValue",
                    .dynamic_card_verification_code = "DynamicCardVerificationCode",
                    .dynamic_card_verification_value = "DynamicCardVerificationValue",
                };
                return @field(mappings, field_name);
            }
        },
        validation_data_length: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_identifier = "KeyIdentifier",
                .primary_account_number = "PrimaryAccountNumber",
                .generation_attributes = "GenerationAttributes",
                .validation_data_length = "ValidationDataLength",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_card_validation_data) } {
            return .{ .service_metadata = service_metadata, .action = generate_card_validation_data };
        }
    },
    Response: type = struct {
        key_arn: []const u8,
        key_check_value: []const u8,
        validation_data: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_arn = "KeyArn",
                .key_check_value = "KeyCheckValue",
                .validation_data = "ValidationData",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const generate_mac: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/mac/generate",
        .success_code = 200,
    };

    action_name: []const u8 = "GenerateMac",
    Request: type = struct {
        key_identifier: []const u8,
        message_data: []const u8,
        generation_attributes: MacAttributes,
        mac_length: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_identifier = "KeyIdentifier",
                .message_data = "MessageData",
                .generation_attributes = "GenerationAttributes",
                .mac_length = "MacLength",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_mac) } {
            return .{ .service_metadata = service_metadata, .action = generate_mac };
        }
    },
    Response: type = struct {
        key_arn: []const u8,
        key_check_value: []const u8,
        mac: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_arn = "KeyArn",
                .key_check_value = "KeyCheckValue",
                .mac = "Mac",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const generate_pin_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/pindata/generate",
        .success_code = 200,
    };

    action_name: []const u8 = "GeneratePinData",
    Request: type = struct {
        generation_key_identifier: []const u8,
        encryption_key_identifier: []const u8,
        generation_attributes: union {
            visa_pin: ?struct {
                pin_verification_key_index: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pin_verification_key_index = "PinVerificationKeyIndex",
                    };
                    return @field(mappings, field_name);
                }
            },
            visa_pin_verification_value: ?struct {
                encrypted_pin_block: []const u8,
                pin_verification_key_index: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .encrypted_pin_block = "EncryptedPinBlock",
                        .pin_verification_key_index = "PinVerificationKeyIndex",
                    };
                    return @field(mappings, field_name);
                }
            },
            ibm3624_pin_offset: ?struct {
                encrypted_pin_block: []const u8,
                decimalization_table: []const u8,
                pin_validation_data_pad_character: []const u8,
                pin_validation_data: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .encrypted_pin_block = "EncryptedPinBlock",
                        .decimalization_table = "DecimalizationTable",
                        .pin_validation_data_pad_character = "PinValidationDataPadCharacter",
                        .pin_validation_data = "PinValidationData",
                    };
                    return @field(mappings, field_name);
                }
            },
            ibm3624_natural_pin: ?struct {
                decimalization_table: []const u8,
                pin_validation_data_pad_character: []const u8,
                pin_validation_data: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .decimalization_table = "DecimalizationTable",
                        .pin_validation_data_pad_character = "PinValidationDataPadCharacter",
                        .pin_validation_data = "PinValidationData",
                    };
                    return @field(mappings, field_name);
                }
            },
            ibm3624_random_pin: ?struct {
                decimalization_table: []const u8,
                pin_validation_data_pad_character: []const u8,
                pin_validation_data: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .decimalization_table = "DecimalizationTable",
                        .pin_validation_data_pad_character = "PinValidationDataPadCharacter",
                        .pin_validation_data = "PinValidationData",
                    };
                    return @field(mappings, field_name);
                }
            },
            ibm3624_pin_from_offset: ?struct {
                decimalization_table: []const u8,
                pin_validation_data_pad_character: []const u8,
                pin_validation_data: []const u8,
                pin_offset: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .decimalization_table = "DecimalizationTable",
                        .pin_validation_data_pad_character = "PinValidationDataPadCharacter",
                        .pin_validation_data = "PinValidationData",
                        .pin_offset = "PinOffset",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .visa_pin = "VisaPin",
                    .visa_pin_verification_value = "VisaPinVerificationValue",
                    .ibm3624_pin_offset = "Ibm3624PinOffset",
                    .ibm3624_natural_pin = "Ibm3624NaturalPin",
                    .ibm3624_random_pin = "Ibm3624RandomPin",
                    .ibm3624_pin_from_offset = "Ibm3624PinFromOffset",
                };
                return @field(mappings, field_name);
            }
        },
        pin_data_length: ?i64 = null,
        primary_account_number: []const u8,
        pin_block_format: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .generation_key_identifier = "GenerationKeyIdentifier",
                .encryption_key_identifier = "EncryptionKeyIdentifier",
                .generation_attributes = "GenerationAttributes",
                .pin_data_length = "PinDataLength",
                .primary_account_number = "PrimaryAccountNumber",
                .pin_block_format = "PinBlockFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_pin_data) } {
            return .{ .service_metadata = service_metadata, .action = generate_pin_data };
        }
    },
    Response: type = struct {
        generation_key_arn: []const u8,
        generation_key_check_value: []const u8,
        encryption_key_arn: []const u8,
        encryption_key_check_value: []const u8,
        encrypted_pin_block: []const u8,
        pin_data: union {
            pin_offset: ?[]const u8,
            verification_value: ?[]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pin_offset = "PinOffset",
                    .verification_value = "VerificationValue",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .generation_key_arn = "GenerationKeyArn",
                .generation_key_check_value = "GenerationKeyCheckValue",
                .encryption_key_arn = "EncryptionKeyArn",
                .encryption_key_check_value = "EncryptionKeyCheckValue",
                .encrypted_pin_block = "EncryptedPinBlock",
                .pin_data = "PinData",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const re_encrypt_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/keys/{IncomingKeyIdentifier}/reencrypt",
        .success_code = 200,
    };

    action_name: []const u8 = "ReEncryptData",
    Request: type = struct {
        incoming_key_identifier: []const u8,
        outgoing_key_identifier: []const u8,
        cipher_text: []const u8,
        incoming_encryption_attributes: ReEncryptionAttributes,
        outgoing_encryption_attributes: ReEncryptionAttributes,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incoming_key_identifier = "IncomingKeyIdentifier",
                .outgoing_key_identifier = "OutgoingKeyIdentifier",
                .cipher_text = "CipherText",
                .incoming_encryption_attributes = "IncomingEncryptionAttributes",
                .outgoing_encryption_attributes = "OutgoingEncryptionAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(re_encrypt_data) } {
            return .{ .service_metadata = service_metadata, .action = re_encrypt_data };
        }
    },
    Response: type = struct {
        key_arn: []const u8,
        key_check_value: []const u8,
        cipher_text: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_arn = "KeyArn",
                .key_check_value = "KeyCheckValue",
                .cipher_text = "CipherText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const translate_pin_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/pindata/translate",
        .success_code = 200,
    };

    action_name: []const u8 = "TranslatePinData",
    Request: type = struct {
        incoming_key_identifier: []const u8,
        outgoing_key_identifier: []const u8,
        incoming_translation_attributes: TranslationIsoFormats,
        outgoing_translation_attributes: TranslationIsoFormats,
        encrypted_pin_block: []const u8,
        incoming_dukpt_attributes: ?DukptDerivationAttributes = null,
        outgoing_dukpt_attributes: ?DukptDerivationAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incoming_key_identifier = "IncomingKeyIdentifier",
                .outgoing_key_identifier = "OutgoingKeyIdentifier",
                .incoming_translation_attributes = "IncomingTranslationAttributes",
                .outgoing_translation_attributes = "OutgoingTranslationAttributes",
                .encrypted_pin_block = "EncryptedPinBlock",
                .incoming_dukpt_attributes = "IncomingDukptAttributes",
                .outgoing_dukpt_attributes = "OutgoingDukptAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(translate_pin_data) } {
            return .{ .service_metadata = service_metadata, .action = translate_pin_data };
        }
    },
    Response: type = struct {
        pin_block: []const u8,
        key_arn: []const u8,
        key_check_value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pin_block = "PinBlock",
                .key_arn = "KeyArn",
                .key_check_value = "KeyCheckValue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const verify_auth_request_cryptogram: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cryptogram/verify",
        .success_code = 200,
    };

    action_name: []const u8 = "VerifyAuthRequestCryptogram",
    Request: type = struct {
        key_identifier: []const u8,
        transaction_data: []const u8,
        auth_request_cryptogram: []const u8,
        major_key_derivation_mode: []const u8,
        session_key_derivation_attributes: union {
            emv_common: ?struct {
                primary_account_number: []const u8,
                pan_sequence_number: []const u8,
                application_transaction_counter: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .primary_account_number = "PrimaryAccountNumber",
                        .pan_sequence_number = "PanSequenceNumber",
                        .application_transaction_counter = "ApplicationTransactionCounter",
                    };
                    return @field(mappings, field_name);
                }
            },
            mastercard: ?struct {
                primary_account_number: []const u8,
                pan_sequence_number: []const u8,
                application_transaction_counter: []const u8,
                unpredictable_number: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .primary_account_number = "PrimaryAccountNumber",
                        .pan_sequence_number = "PanSequenceNumber",
                        .application_transaction_counter = "ApplicationTransactionCounter",
                        .unpredictable_number = "UnpredictableNumber",
                    };
                    return @field(mappings, field_name);
                }
            },
            emv2000: ?struct {
                primary_account_number: []const u8,
                pan_sequence_number: []const u8,
                application_transaction_counter: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .primary_account_number = "PrimaryAccountNumber",
                        .pan_sequence_number = "PanSequenceNumber",
                        .application_transaction_counter = "ApplicationTransactionCounter",
                    };
                    return @field(mappings, field_name);
                }
            },
            amex: ?struct {
                primary_account_number: []const u8,
                pan_sequence_number: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .primary_account_number = "PrimaryAccountNumber",
                        .pan_sequence_number = "PanSequenceNumber",
                    };
                    return @field(mappings, field_name);
                }
            },
            visa: ?struct {
                primary_account_number: []const u8,
                pan_sequence_number: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .primary_account_number = "PrimaryAccountNumber",
                        .pan_sequence_number = "PanSequenceNumber",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .emv_common = "EmvCommon",
                    .mastercard = "Mastercard",
                    .emv2000 = "Emv2000",
                    .amex = "Amex",
                    .visa = "Visa",
                };
                return @field(mappings, field_name);
            }
        },
        auth_response_attributes: ?union {
            arpc_method1: ?struct {
                auth_response_code: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .auth_response_code = "AuthResponseCode",
                    };
                    return @field(mappings, field_name);
                }
            },
            arpc_method2: ?struct {
                card_status_update: []const u8,
                proprietary_authentication_data: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .card_status_update = "CardStatusUpdate",
                        .proprietary_authentication_data = "ProprietaryAuthenticationData",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arpc_method1 = "ArpcMethod1",
                    .arpc_method2 = "ArpcMethod2",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_identifier = "KeyIdentifier",
                .transaction_data = "TransactionData",
                .auth_request_cryptogram = "AuthRequestCryptogram",
                .major_key_derivation_mode = "MajorKeyDerivationMode",
                .session_key_derivation_attributes = "SessionKeyDerivationAttributes",
                .auth_response_attributes = "AuthResponseAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_auth_request_cryptogram) } {
            return .{ .service_metadata = service_metadata, .action = verify_auth_request_cryptogram };
        }
    },
    Response: type = struct {
        key_arn: []const u8,
        key_check_value: []const u8,
        auth_response_value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_arn = "KeyArn",
                .key_check_value = "KeyCheckValue",
                .auth_response_value = "AuthResponseValue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
        VerificationFailed,
    },
} = .{};
pub const verify_card_validation_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cardvalidationdata/verify",
        .success_code = 200,
    };

    action_name: []const u8 = "VerifyCardValidationData",
    Request: type = struct {
        key_identifier: []const u8,
        primary_account_number: []const u8,
        verification_attributes: union {
            amex_card_security_code_version1: ?AmexCardSecurityCodeVersion1,
            amex_card_security_code_version2: ?AmexCardSecurityCodeVersion2,
            card_verification_value1: ?CardVerificationValue1,
            card_verification_value2: ?CardVerificationValue2,
            card_holder_verification_value: ?CardHolderVerificationValue,
            dynamic_card_verification_code: ?DynamicCardVerificationCode,
            dynamic_card_verification_value: ?DynamicCardVerificationValue,
            discover_dynamic_card_verification_code: ?struct {
                card_expiry_date: []const u8,
                unpredictable_number: []const u8,
                application_transaction_counter: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .card_expiry_date = "CardExpiryDate",
                        .unpredictable_number = "UnpredictableNumber",
                        .application_transaction_counter = "ApplicationTransactionCounter",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .amex_card_security_code_version1 = "AmexCardSecurityCodeVersion1",
                    .amex_card_security_code_version2 = "AmexCardSecurityCodeVersion2",
                    .card_verification_value1 = "CardVerificationValue1",
                    .card_verification_value2 = "CardVerificationValue2",
                    .card_holder_verification_value = "CardHolderVerificationValue",
                    .dynamic_card_verification_code = "DynamicCardVerificationCode",
                    .dynamic_card_verification_value = "DynamicCardVerificationValue",
                    .discover_dynamic_card_verification_code = "DiscoverDynamicCardVerificationCode",
                };
                return @field(mappings, field_name);
            }
        },
        validation_data: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_identifier = "KeyIdentifier",
                .primary_account_number = "PrimaryAccountNumber",
                .verification_attributes = "VerificationAttributes",
                .validation_data = "ValidationData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_card_validation_data) } {
            return .{ .service_metadata = service_metadata, .action = verify_card_validation_data };
        }
    },
    Response: type = struct {
        key_arn: []const u8,
        key_check_value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_arn = "KeyArn",
                .key_check_value = "KeyCheckValue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
        VerificationFailed,
    },
} = .{};
pub const verify_mac: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/mac/verify",
        .success_code = 200,
    };

    action_name: []const u8 = "VerifyMac",
    Request: type = struct {
        key_identifier: []const u8,
        message_data: []const u8,
        mac: []const u8,
        verification_attributes: MacAttributes,
        mac_length: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_identifier = "KeyIdentifier",
                .message_data = "MessageData",
                .mac = "Mac",
                .verification_attributes = "VerificationAttributes",
                .mac_length = "MacLength",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_mac) } {
            return .{ .service_metadata = service_metadata, .action = verify_mac };
        }
    },
    Response: type = struct {
        key_arn: []const u8,
        key_check_value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_arn = "KeyArn",
                .key_check_value = "KeyCheckValue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
        VerificationFailed,
    },
} = .{};
pub const verify_pin_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/pindata/verify",
        .success_code = 200,
    };

    action_name: []const u8 = "VerifyPinData",
    Request: type = struct {
        verification_key_identifier: []const u8,
        encryption_key_identifier: []const u8,
        verification_attributes: union {
            visa_pin: ?struct {
                pin_verification_key_index: i64,
                verification_value: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pin_verification_key_index = "PinVerificationKeyIndex",
                        .verification_value = "VerificationValue",
                    };
                    return @field(mappings, field_name);
                }
            },
            ibm3624_pin: ?struct {
                decimalization_table: []const u8,
                pin_validation_data_pad_character: []const u8,
                pin_validation_data: []const u8,
                pin_offset: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .decimalization_table = "DecimalizationTable",
                        .pin_validation_data_pad_character = "PinValidationDataPadCharacter",
                        .pin_validation_data = "PinValidationData",
                        .pin_offset = "PinOffset",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .visa_pin = "VisaPin",
                    .ibm3624_pin = "Ibm3624Pin",
                };
                return @field(mappings, field_name);
            }
        },
        encrypted_pin_block: []const u8,
        primary_account_number: []const u8,
        pin_block_format: []const u8,
        pin_data_length: ?i64 = null,
        dukpt_attributes: ?struct {
            key_serial_number: []const u8,
            dukpt_derivation_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key_serial_number = "KeySerialNumber",
                    .dukpt_derivation_type = "DukptDerivationType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verification_key_identifier = "VerificationKeyIdentifier",
                .encryption_key_identifier = "EncryptionKeyIdentifier",
                .verification_attributes = "VerificationAttributes",
                .encrypted_pin_block = "EncryptedPinBlock",
                .primary_account_number = "PrimaryAccountNumber",
                .pin_block_format = "PinBlockFormat",
                .pin_data_length = "PinDataLength",
                .dukpt_attributes = "DukptAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_pin_data) } {
            return .{ .service_metadata = service_metadata, .action = verify_pin_data };
        }
    },
    Response: type = struct {
        verification_key_arn: []const u8,
        verification_key_check_value: []const u8,
        encryption_key_arn: []const u8,
        encryption_key_check_value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verification_key_arn = "VerificationKeyArn",
                .verification_key_check_value = "VerificationKeyCheckValue",
                .encryption_key_arn = "EncryptionKeyArn",
                .encryption_key_check_value = "EncryptionKeyCheckValue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
        VerificationFailed,
    },
} = .{};

pub const MacAttributes = union {
    algorithm: ?[]const u8,
    emv_mac: ?MacAlgorithmEmv,
    dukpt_iso9797_algorithm1: ?MacAlgorithmDukpt,
    dukpt_iso9797_algorithm3: ?MacAlgorithmDukpt,
    dukpt_cmac: ?MacAlgorithmDukpt,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .algorithm = "Algorithm",
            .emv_mac = "EmvMac",
            .dukpt_iso9797_algorithm1 = "DukptIso9797Algorithm1",
            .dukpt_iso9797_algorithm3 = "DukptIso9797Algorithm3",
            .dukpt_cmac = "DukptCmac",
        };
        return @field(mappings, field_name);
    }
};

pub const MacAlgorithmDukpt = struct {
    key_serial_number: []const u8,
    dukpt_key_variant: []const u8,
    dukpt_derivation_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_serial_number = "KeySerialNumber",
            .dukpt_key_variant = "DukptKeyVariant",
            .dukpt_derivation_type = "DukptDerivationType",
        };
        return @field(mappings, field_name);
    }
};

pub const MacAlgorithmEmv = struct {
    major_key_derivation_mode: []const u8,
    primary_account_number: []const u8,
    pan_sequence_number: []const u8,
    session_key_derivation_mode: []const u8,
    session_key_derivation_value: SessionKeyDerivationValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .major_key_derivation_mode = "MajorKeyDerivationMode",
            .primary_account_number = "PrimaryAccountNumber",
            .pan_sequence_number = "PanSequenceNumber",
            .session_key_derivation_mode = "SessionKeyDerivationMode",
            .session_key_derivation_value = "SessionKeyDerivationValue",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionKeyDerivationValue = union {
    application_cryptogram: ?[]const u8,
    application_transaction_counter: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_cryptogram = "ApplicationCryptogram",
            .application_transaction_counter = "ApplicationTransactionCounter",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamicCardVerificationValue = struct {
    pan_sequence_number: []const u8,
    card_expiry_date: []const u8,
    service_code: []const u8,
    application_transaction_counter: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pan_sequence_number = "PanSequenceNumber",
            .card_expiry_date = "CardExpiryDate",
            .service_code = "ServiceCode",
            .application_transaction_counter = "ApplicationTransactionCounter",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamicCardVerificationCode = struct {
    unpredictable_number: []const u8,
    pan_sequence_number: []const u8,
    application_transaction_counter: []const u8,
    track_data: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unpredictable_number = "UnpredictableNumber",
            .pan_sequence_number = "PanSequenceNumber",
            .application_transaction_counter = "ApplicationTransactionCounter",
            .track_data = "TrackData",
        };
        return @field(mappings, field_name);
    }
};

pub const CardHolderVerificationValue = struct {
    unpredictable_number: []const u8,
    pan_sequence_number: []const u8,
    application_transaction_counter: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unpredictable_number = "UnpredictableNumber",
            .pan_sequence_number = "PanSequenceNumber",
            .application_transaction_counter = "ApplicationTransactionCounter",
        };
        return @field(mappings, field_name);
    }
};

pub const CardVerificationValue2 = struct {
    card_expiry_date: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .card_expiry_date = "CardExpiryDate",
        };
        return @field(mappings, field_name);
    }
};

pub const CardVerificationValue1 = struct {
    card_expiry_date: []const u8,
    service_code: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .card_expiry_date = "CardExpiryDate",
            .service_code = "ServiceCode",
        };
        return @field(mappings, field_name);
    }
};

pub const AmexCardSecurityCodeVersion2 = struct {
    card_expiry_date: []const u8,
    service_code: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .card_expiry_date = "CardExpiryDate",
            .service_code = "ServiceCode",
        };
        return @field(mappings, field_name);
    }
};

pub const AmexCardSecurityCodeVersion1 = struct {
    card_expiry_date: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .card_expiry_date = "CardExpiryDate",
        };
        return @field(mappings, field_name);
    }
};

pub const DukptDerivationAttributes = struct {
    key_serial_number: []const u8,
    dukpt_key_derivation_type: ?[]const u8 = null,
    dukpt_key_variant: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_serial_number = "KeySerialNumber",
            .dukpt_key_derivation_type = "DukptKeyDerivationType",
            .dukpt_key_variant = "DukptKeyVariant",
        };
        return @field(mappings, field_name);
    }
};

pub const TranslationIsoFormats = union {
    iso_format0: ?TranslationPinDataIsoFormat034,
    iso_format1: ?TranslationPinDataIsoFormat1,
    iso_format3: ?TranslationPinDataIsoFormat034,
    iso_format4: ?TranslationPinDataIsoFormat034,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iso_format0 = "IsoFormat0",
            .iso_format1 = "IsoFormat1",
            .iso_format3 = "IsoFormat3",
            .iso_format4 = "IsoFormat4",
        };
        return @field(mappings, field_name);
    }
};

pub const TranslationPinDataIsoFormat034 = struct {
    primary_account_number: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_account_number = "PrimaryAccountNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const TranslationPinDataIsoFormat1 = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const ReEncryptionAttributes = union {
    symmetric: ?SymmetricEncryptionAttributes,
    dukpt: ?DukptEncryptionAttributes,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .symmetric = "Symmetric",
            .dukpt = "Dukpt",
        };
        return @field(mappings, field_name);
    }
};

pub const DukptEncryptionAttributes = struct {
    key_serial_number: []const u8,
    mode: ?[]const u8 = null,
    dukpt_key_derivation_type: ?[]const u8 = null,
    dukpt_key_variant: ?[]const u8 = null,
    initialization_vector: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_serial_number = "KeySerialNumber",
            .mode = "Mode",
            .dukpt_key_derivation_type = "DukptKeyDerivationType",
            .dukpt_key_variant = "DukptKeyVariant",
            .initialization_vector = "InitializationVector",
        };
        return @field(mappings, field_name);
    }
};

pub const SymmetricEncryptionAttributes = struct {
    mode: []const u8,
    initialization_vector: ?[]const u8 = null,
    padding_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
            .initialization_vector = "InitializationVector",
            .padding_type = "PaddingType",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionDecryptionAttributes = union {
    symmetric: ?SymmetricEncryptionAttributes,
    asymmetric: ?AsymmetricEncryptionAttributes,
    dukpt: ?DukptEncryptionAttributes,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .symmetric = "Symmetric",
            .asymmetric = "Asymmetric",
            .dukpt = "Dukpt",
        };
        return @field(mappings, field_name);
    }
};

pub const AsymmetricEncryptionAttributes = struct {
    padding_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .padding_type = "PaddingType",
        };
        return @field(mappings, field_name);
    }
};
