const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-22";
pub const sdk_id: []const u8 = "Personalize";
pub const arn_namespace: ?[]const u8 = "personalize";
pub const endpoint_prefix: []const u8 = "personalize";
pub const sigv4_name: []const u8 = "personalize";
pub const name: []const u8 = "AmazonPersonalize";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-22",
    sdk_id: []const u8 = "Personalize",
    arn_namespace: ?[]const u8 = "personalize",
    endpoint_prefix: []const u8 = "personalize",
    sigv4_name: []const u8 = "personalize",
    name: []const u8 = "AmazonPersonalize",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_batch_inference_job: struct {
    action_name: []const u8 = "CreateBatchInferenceJob",
    Request: type = struct {
        job_name: []const u8,
        solution_version_arn: []const u8,
        filter_arn: ?[]const u8 = null,
        num_results: ?i64 = null,
        job_input: BatchInferenceJobInput,
        job_output: BatchInferenceJobOutput,
        role_arn: []const u8,
        batch_inference_job_config: ?BatchInferenceJobConfig = null,
        tags: ?[]Tag = null,
        batch_inference_job_mode: ?[]const u8 = null,
        theme_generation_config: ?ThemeGenerationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "jobName",
                .solution_version_arn = "solutionVersionArn",
                .filter_arn = "filterArn",
                .num_results = "numResults",
                .job_input = "jobInput",
                .job_output = "jobOutput",
                .role_arn = "roleArn",
                .batch_inference_job_config = "batchInferenceJobConfig",
                .tags = "tags",
                .batch_inference_job_mode = "batchInferenceJobMode",
                .theme_generation_config = "themeGenerationConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_batch_inference_job) } {
            return .{ .service_metadata = service_metadata, .action = create_batch_inference_job };
        }
    },
    Response: type = struct {
        batch_inference_job_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_inference_job_arn = "batchInferenceJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const create_batch_segment_job: struct {
    action_name: []const u8 = "CreateBatchSegmentJob",
    Request: type = struct {
        job_name: []const u8,
        solution_version_arn: []const u8,
        filter_arn: ?[]const u8 = null,
        num_results: ?i64 = null,
        job_input: BatchSegmentJobInput,
        job_output: BatchSegmentJobOutput,
        role_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "jobName",
                .solution_version_arn = "solutionVersionArn",
                .filter_arn = "filterArn",
                .num_results = "numResults",
                .job_input = "jobInput",
                .job_output = "jobOutput",
                .role_arn = "roleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_batch_segment_job) } {
            return .{ .service_metadata = service_metadata, .action = create_batch_segment_job };
        }
    },
    Response: type = struct {
        batch_segment_job_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_segment_job_arn = "batchSegmentJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const create_campaign: struct {
    action_name: []const u8 = "CreateCampaign",
    Request: type = struct {
        name: []const u8,
        solution_version_arn: []const u8,
        min_provisioned_tps: ?i64 = null,
        campaign_config: ?CampaignConfig = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .solution_version_arn = "solutionVersionArn",
                .min_provisioned_tps = "minProvisionedTPS",
                .campaign_config = "campaignConfig",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_campaign) } {
            return .{ .service_metadata = service_metadata, .action = create_campaign };
        }
    },
    Response: type = struct {
        campaign_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_arn = "campaignArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const create_dataset: struct {
    action_name: []const u8 = "CreateDataset",
    Request: type = struct {
        name: []const u8,
        schema_arn: []const u8,
        dataset_group_arn: []const u8,
        dataset_type: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .schema_arn = "schemaArn",
                .dataset_group_arn = "datasetGroupArn",
                .dataset_type = "datasetType",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset };
        }
    },
    Response: type = struct {
        dataset_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "datasetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const create_dataset_export_job: struct {
    action_name: []const u8 = "CreateDatasetExportJob",
    Request: type = struct {
        job_name: []const u8,
        dataset_arn: []const u8,
        ingestion_mode: ?[]const u8 = null,
        role_arn: []const u8,
        job_output: DatasetExportJobOutput,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "jobName",
                .dataset_arn = "datasetArn",
                .ingestion_mode = "ingestionMode",
                .role_arn = "roleArn",
                .job_output = "jobOutput",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset_export_job) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset_export_job };
        }
    },
    Response: type = struct {
        dataset_export_job_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_export_job_arn = "datasetExportJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const create_dataset_group: struct {
    action_name: []const u8 = "CreateDatasetGroup",
    Request: type = struct {
        name: []const u8,
        role_arn: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .role_arn = "roleArn",
                .kms_key_arn = "kmsKeyArn",
                .domain = "domain",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset_group) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset_group };
        }
    },
    Response: type = struct {
        dataset_group_arn: ?[]const u8 = null,
        domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "datasetGroupArn",
                .domain = "domain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        TooManyTags,
    },
} = .{};
pub const create_dataset_import_job: struct {
    action_name: []const u8 = "CreateDatasetImportJob",
    Request: type = struct {
        job_name: []const u8,
        dataset_arn: []const u8,
        data_source: DataSource,
        role_arn: []const u8,
        tags: ?[]Tag = null,
        import_mode: ?[]const u8 = null,
        publish_attribution_metrics_to_s3: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "jobName",
                .dataset_arn = "datasetArn",
                .data_source = "dataSource",
                .role_arn = "roleArn",
                .tags = "tags",
                .import_mode = "importMode",
                .publish_attribution_metrics_to_s3 = "publishAttributionMetricsToS3",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset_import_job) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset_import_job };
        }
    },
    Response: type = struct {
        dataset_import_job_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_import_job_arn = "datasetImportJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const create_event_tracker: struct {
    action_name: []const u8 = "CreateEventTracker",
    Request: type = struct {
        name: []const u8,
        dataset_group_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .dataset_group_arn = "datasetGroupArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_tracker) } {
            return .{ .service_metadata = service_metadata, .action = create_event_tracker };
        }
    },
    Response: type = struct {
        event_tracker_arn: ?[]const u8 = null,
        tracking_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_tracker_arn = "eventTrackerArn",
                .tracking_id = "trackingId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const create_filter: struct {
    action_name: []const u8 = "CreateFilter",
    Request: type = struct {
        name: []const u8,
        dataset_group_arn: []const u8,
        filter_expression: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .dataset_group_arn = "datasetGroupArn",
                .filter_expression = "filterExpression",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_filter) } {
            return .{ .service_metadata = service_metadata, .action = create_filter };
        }
    },
    Response: type = struct {
        filter_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_arn = "filterArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const create_metric_attribution: struct {
    action_name: []const u8 = "CreateMetricAttribution",
    Request: type = struct {
        name: []const u8,
        dataset_group_arn: []const u8,
        metrics: []MetricAttribute,
        metrics_output_config: MetricAttributionOutput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .dataset_group_arn = "datasetGroupArn",
                .metrics = "metrics",
                .metrics_output_config = "metricsOutputConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_metric_attribution) } {
            return .{ .service_metadata = service_metadata, .action = create_metric_attribution };
        }
    },
    Response: type = struct {
        metric_attribution_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_attribution_arn = "metricAttributionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const create_recommender: struct {
    action_name: []const u8 = "CreateRecommender",
    Request: type = struct {
        name: []const u8,
        dataset_group_arn: []const u8,
        recipe_arn: []const u8,
        recommender_config: ?RecommenderConfig = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .dataset_group_arn = "datasetGroupArn",
                .recipe_arn = "recipeArn",
                .recommender_config = "recommenderConfig",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_recommender) } {
            return .{ .service_metadata = service_metadata, .action = create_recommender };
        }
    },
    Response: type = struct {
        recommender_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_arn = "recommenderArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const create_schema: struct {
    action_name: []const u8 = "CreateSchema",
    Request: type = struct {
        name: []const u8,
        schema: []const u8,
        domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .schema = "schema",
                .domain = "domain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_schema) } {
            return .{ .service_metadata = service_metadata, .action = create_schema };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "schemaArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
    },
} = .{};
pub const create_solution: struct {
    action_name: []const u8 = "CreateSolution",
    Request: type = struct {
        name: []const u8,
        perform_hpo: ?bool = null,
        perform_auto_ml: ?bool = null,
        recipe_arn: ?[]const u8 = null,
        dataset_group_arn: []const u8,
        event_type: ?[]const u8 = null,
        solution_config: ?SolutionConfig = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .perform_hpo = "performHPO",
                .perform_auto_ml = "performAutoML",
                .recipe_arn = "recipeArn",
                .dataset_group_arn = "datasetGroupArn",
                .event_type = "eventType",
                .solution_config = "solutionConfig",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_solution) } {
            return .{ .service_metadata = service_metadata, .action = create_solution };
        }
    },
    Response: type = struct {
        solution_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_arn = "solutionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const create_solution_version: struct {
    action_name: []const u8 = "CreateSolutionVersion",
    Request: type = struct {
        name: ?[]const u8 = null,
        solution_arn: []const u8,
        training_mode: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .solution_arn = "solutionArn",
                .training_mode = "trainingMode",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_solution_version) } {
            return .{ .service_metadata = service_metadata, .action = create_solution_version };
        }
    },
    Response: type = struct {
        solution_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_version_arn = "solutionVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const delete_campaign: struct {
    action_name: []const u8 = "DeleteCampaign",
    Request: type = struct {
        campaign_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_arn = "campaignArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_campaign) } {
            return .{ .service_metadata = service_metadata, .action = delete_campaign };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_dataset: struct {
    action_name: []const u8 = "DeleteDataset",
    Request: type = struct {
        dataset_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "datasetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_dataset_group: struct {
    action_name: []const u8 = "DeleteDatasetGroup",
    Request: type = struct {
        dataset_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "datasetGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_event_tracker: struct {
    action_name: []const u8 = "DeleteEventTracker",
    Request: type = struct {
        event_tracker_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_tracker_arn = "eventTrackerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_tracker) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_tracker };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_filter: struct {
    action_name: []const u8 = "DeleteFilter",
    Request: type = struct {
        filter_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_arn = "filterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_filter) } {
            return .{ .service_metadata = service_metadata, .action = delete_filter };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_metric_attribution: struct {
    action_name: []const u8 = "DeleteMetricAttribution",
    Request: type = struct {
        metric_attribution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_attribution_arn = "metricAttributionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_metric_attribution) } {
            return .{ .service_metadata = service_metadata, .action = delete_metric_attribution };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_recommender: struct {
    action_name: []const u8 = "DeleteRecommender",
    Request: type = struct {
        recommender_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_arn = "recommenderArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_recommender) } {
            return .{ .service_metadata = service_metadata, .action = delete_recommender };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_schema: struct {
    action_name: []const u8 = "DeleteSchema",
    Request: type = struct {
        schema_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "schemaArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schema) } {
            return .{ .service_metadata = service_metadata, .action = delete_schema };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_solution: struct {
    action_name: []const u8 = "DeleteSolution",
    Request: type = struct {
        solution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_arn = "solutionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_solution) } {
            return .{ .service_metadata = service_metadata, .action = delete_solution };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const describe_algorithm: struct {
    action_name: []const u8 = "DescribeAlgorithm",
    Request: type = struct {
        algorithm_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .algorithm_arn = "algorithmArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_algorithm) } {
            return .{ .service_metadata = service_metadata, .action = describe_algorithm };
        }
    },
    Response: type = struct {
        algorithm: ?struct {
            name: ?[]const u8 = null,
            algorithm_arn: ?[]const u8 = null,
            algorithm_image: ?struct {
                name: ?[]const u8 = null,
                docker_uri: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .docker_uri = "dockerURI",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            default_hyper_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            default_hyper_parameter_ranges: ?struct {
                integer_hyper_parameter_ranges: ?[]struct {
                    name: ?[]const u8 = null,
                    min_value: ?i64 = null,
                    max_value: ?i64 = null,
                    is_tunable: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .min_value = "minValue",
                            .max_value = "maxValue",
                            .is_tunable = "isTunable",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                continuous_hyper_parameter_ranges: ?[]struct {
                    name: ?[]const u8 = null,
                    min_value: ?f64 = null,
                    max_value: ?f64 = null,
                    is_tunable: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .min_value = "minValue",
                            .max_value = "maxValue",
                            .is_tunable = "isTunable",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                categorical_hyper_parameter_ranges: ?[]struct {
                    name: ?[]const u8 = null,
                    values: ?[][]const u8 = null,
                    is_tunable: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .values = "values",
                            .is_tunable = "isTunable",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .integer_hyper_parameter_ranges = "integerHyperParameterRanges",
                        .continuous_hyper_parameter_ranges = "continuousHyperParameterRanges",
                        .categorical_hyper_parameter_ranges = "categoricalHyperParameterRanges",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            default_resource_config: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            training_input_mode: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .algorithm_arn = "algorithmArn",
                    .algorithm_image = "algorithmImage",
                    .default_hyper_parameters = "defaultHyperParameters",
                    .default_hyper_parameter_ranges = "defaultHyperParameterRanges",
                    .default_resource_config = "defaultResourceConfig",
                    .training_input_mode = "trainingInputMode",
                    .role_arn = "roleArn",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "default_hyper_parameters", field_name))
                    return try serializeMap(self.default_hyper_parameters, self.fieldNameFor("default_hyper_parameters"), options, out_stream);
                if (std.mem.eql(u8, "default_resource_config", field_name))
                    return try serializeMap(self.default_resource_config, self.fieldNameFor("default_resource_config"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .algorithm = "algorithm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_batch_inference_job: struct {
    action_name: []const u8 = "DescribeBatchInferenceJob",
    Request: type = struct {
        batch_inference_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_inference_job_arn = "batchInferenceJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_batch_inference_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_batch_inference_job };
        }
    },
    Response: type = struct {
        batch_inference_job: ?struct {
            job_name: ?[]const u8 = null,
            batch_inference_job_arn: ?[]const u8 = null,
            filter_arn: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            solution_version_arn: ?[]const u8 = null,
            num_results: ?i64 = null,
            job_input: ?BatchInferenceJobInput = null,
            job_output: ?BatchInferenceJobOutput = null,
            batch_inference_job_config: ?BatchInferenceJobConfig = null,
            role_arn: ?[]const u8 = null,
            batch_inference_job_mode: ?[]const u8 = null,
            theme_generation_config: ?ThemeGenerationConfig = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "jobName",
                    .batch_inference_job_arn = "batchInferenceJobArn",
                    .filter_arn = "filterArn",
                    .failure_reason = "failureReason",
                    .solution_version_arn = "solutionVersionArn",
                    .num_results = "numResults",
                    .job_input = "jobInput",
                    .job_output = "jobOutput",
                    .batch_inference_job_config = "batchInferenceJobConfig",
                    .role_arn = "roleArn",
                    .batch_inference_job_mode = "batchInferenceJobMode",
                    .theme_generation_config = "themeGenerationConfig",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_inference_job = "batchInferenceJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_batch_segment_job: struct {
    action_name: []const u8 = "DescribeBatchSegmentJob",
    Request: type = struct {
        batch_segment_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_segment_job_arn = "batchSegmentJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_batch_segment_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_batch_segment_job };
        }
    },
    Response: type = struct {
        batch_segment_job: ?struct {
            job_name: ?[]const u8 = null,
            batch_segment_job_arn: ?[]const u8 = null,
            filter_arn: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            solution_version_arn: ?[]const u8 = null,
            num_results: ?i64 = null,
            job_input: ?BatchSegmentJobInput = null,
            job_output: ?BatchSegmentJobOutput = null,
            role_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "jobName",
                    .batch_segment_job_arn = "batchSegmentJobArn",
                    .filter_arn = "filterArn",
                    .failure_reason = "failureReason",
                    .solution_version_arn = "solutionVersionArn",
                    .num_results = "numResults",
                    .job_input = "jobInput",
                    .job_output = "jobOutput",
                    .role_arn = "roleArn",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_segment_job = "batchSegmentJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_campaign: struct {
    action_name: []const u8 = "DescribeCampaign",
    Request: type = struct {
        campaign_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_arn = "campaignArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_campaign) } {
            return .{ .service_metadata = service_metadata, .action = describe_campaign };
        }
    },
    Response: type = struct {
        campaign: ?struct {
            name: ?[]const u8 = null,
            campaign_arn: ?[]const u8 = null,
            solution_version_arn: ?[]const u8 = null,
            min_provisioned_tps: ?i64 = null,
            campaign_config: ?CampaignConfig = null,
            status: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            latest_campaign_update: ?struct {
                solution_version_arn: ?[]const u8 = null,
                min_provisioned_tps: ?i64 = null,
                campaign_config: ?CampaignConfig = null,
                status: ?[]const u8 = null,
                failure_reason: ?[]const u8 = null,
                creation_date_time: ?i64 = null,
                last_updated_date_time: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .solution_version_arn = "solutionVersionArn",
                        .min_provisioned_tps = "minProvisionedTPS",
                        .campaign_config = "campaignConfig",
                        .status = "status",
                        .failure_reason = "failureReason",
                        .creation_date_time = "creationDateTime",
                        .last_updated_date_time = "lastUpdatedDateTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .campaign_arn = "campaignArn",
                    .solution_version_arn = "solutionVersionArn",
                    .min_provisioned_tps = "minProvisionedTPS",
                    .campaign_config = "campaignConfig",
                    .status = "status",
                    .failure_reason = "failureReason",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .latest_campaign_update = "latestCampaignUpdate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign = "campaign",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_dataset: struct {
    action_name: []const u8 = "DescribeDataset",
    Request: type = struct {
        dataset_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "datasetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset };
        }
    },
    Response: type = struct {
        dataset: ?struct {
            name: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            dataset_type: ?[]const u8 = null,
            schema_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            latest_dataset_update: ?struct {
                schema_arn: ?[]const u8 = null,
                status: ?[]const u8 = null,
                failure_reason: ?[]const u8 = null,
                creation_date_time: ?i64 = null,
                last_updated_date_time: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .schema_arn = "schemaArn",
                        .status = "status",
                        .failure_reason = "failureReason",
                        .creation_date_time = "creationDateTime",
                        .last_updated_date_time = "lastUpdatedDateTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tracking_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .dataset_arn = "datasetArn",
                    .dataset_group_arn = "datasetGroupArn",
                    .dataset_type = "datasetType",
                    .schema_arn = "schemaArn",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .latest_dataset_update = "latestDatasetUpdate",
                    .tracking_id = "trackingId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset = "dataset",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_dataset_export_job: struct {
    action_name: []const u8 = "DescribeDatasetExportJob",
    Request: type = struct {
        dataset_export_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_export_job_arn = "datasetExportJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset_export_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset_export_job };
        }
    },
    Response: type = struct {
        dataset_export_job: ?struct {
            job_name: ?[]const u8 = null,
            dataset_export_job_arn: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            ingestion_mode: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            job_output: ?DatasetExportJobOutput = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "jobName",
                    .dataset_export_job_arn = "datasetExportJobArn",
                    .dataset_arn = "datasetArn",
                    .ingestion_mode = "ingestionMode",
                    .role_arn = "roleArn",
                    .status = "status",
                    .job_output = "jobOutput",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_export_job = "datasetExportJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_dataset_group: struct {
    action_name: []const u8 = "DescribeDatasetGroup",
    Request: type = struct {
        dataset_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "datasetGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset_group };
        }
    },
    Response: type = struct {
        dataset_group: ?struct {
            name: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            kms_key_arn: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,
            domain: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .dataset_group_arn = "datasetGroupArn",
                    .status = "status",
                    .role_arn = "roleArn",
                    .kms_key_arn = "kmsKeyArn",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                    .domain = "domain",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group = "datasetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_dataset_import_job: struct {
    action_name: []const u8 = "DescribeDatasetImportJob",
    Request: type = struct {
        dataset_import_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_import_job_arn = "datasetImportJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset_import_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset_import_job };
        }
    },
    Response: type = struct {
        dataset_import_job: ?struct {
            job_name: ?[]const u8 = null,
            dataset_import_job_arn: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            data_source: ?DataSource = null,
            role_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,
            import_mode: ?[]const u8 = null,
            publish_attribution_metrics_to_s3: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "jobName",
                    .dataset_import_job_arn = "datasetImportJobArn",
                    .dataset_arn = "datasetArn",
                    .data_source = "dataSource",
                    .role_arn = "roleArn",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                    .import_mode = "importMode",
                    .publish_attribution_metrics_to_s3 = "publishAttributionMetricsToS3",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_import_job = "datasetImportJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_event_tracker: struct {
    action_name: []const u8 = "DescribeEventTracker",
    Request: type = struct {
        event_tracker_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_tracker_arn = "eventTrackerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_tracker) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_tracker };
        }
    },
    Response: type = struct {
        event_tracker: ?struct {
            name: ?[]const u8 = null,
            event_tracker_arn: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            tracking_id: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .event_tracker_arn = "eventTrackerArn",
                    .account_id = "accountId",
                    .tracking_id = "trackingId",
                    .dataset_group_arn = "datasetGroupArn",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_tracker = "eventTracker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_feature_transformation: struct {
    action_name: []const u8 = "DescribeFeatureTransformation",
    Request: type = struct {
        feature_transformation_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_transformation_arn = "featureTransformationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_feature_transformation) } {
            return .{ .service_metadata = service_metadata, .action = describe_feature_transformation };
        }
    },
    Response: type = struct {
        feature_transformation: ?struct {
            name: ?[]const u8 = null,
            feature_transformation_arn: ?[]const u8 = null,
            default_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .feature_transformation_arn = "featureTransformationArn",
                    .default_parameters = "defaultParameters",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "default_parameters", field_name))
                    return try serializeMap(self.default_parameters, self.fieldNameFor("default_parameters"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_transformation = "featureTransformation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_filter: struct {
    action_name: []const u8 = "DescribeFilter",
    Request: type = struct {
        filter_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_arn = "filterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_filter) } {
            return .{ .service_metadata = service_metadata, .action = describe_filter };
        }
    },
    Response: type = struct {
        filter: ?struct {
            name: ?[]const u8 = null,
            filter_arn: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            dataset_group_arn: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            filter_expression: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .filter_arn = "filterArn",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .dataset_group_arn = "datasetGroupArn",
                    .failure_reason = "failureReason",
                    .filter_expression = "filterExpression",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "filter",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_metric_attribution: struct {
    action_name: []const u8 = "DescribeMetricAttribution",
    Request: type = struct {
        metric_attribution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_attribution_arn = "metricAttributionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_metric_attribution) } {
            return .{ .service_metadata = service_metadata, .action = describe_metric_attribution };
        }
    },
    Response: type = struct {
        metric_attribution: ?struct {
            name: ?[]const u8 = null,
            metric_attribution_arn: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            metrics_output_config: ?MetricAttributionOutput = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .metric_attribution_arn = "metricAttributionArn",
                    .dataset_group_arn = "datasetGroupArn",
                    .metrics_output_config = "metricsOutputConfig",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_attribution = "metricAttribution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_recipe: struct {
    action_name: []const u8 = "DescribeRecipe",
    Request: type = struct {
        recipe_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recipe_arn = "recipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_recipe) } {
            return .{ .service_metadata = service_metadata, .action = describe_recipe };
        }
    },
    Response: type = struct {
        recipe: ?struct {
            name: ?[]const u8 = null,
            recipe_arn: ?[]const u8 = null,
            algorithm_arn: ?[]const u8 = null,
            feature_transformation_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            description: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            recipe_type: ?[]const u8 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .recipe_arn = "recipeArn",
                    .algorithm_arn = "algorithmArn",
                    .feature_transformation_arn = "featureTransformationArn",
                    .status = "status",
                    .description = "description",
                    .creation_date_time = "creationDateTime",
                    .recipe_type = "recipeType",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recipe = "recipe",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_recommender: struct {
    action_name: []const u8 = "DescribeRecommender",
    Request: type = struct {
        recommender_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_arn = "recommenderArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_recommender) } {
            return .{ .service_metadata = service_metadata, .action = describe_recommender };
        }
    },
    Response: type = struct {
        recommender: ?struct {
            recommender_arn: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            recipe_arn: ?[]const u8 = null,
            recommender_config: ?RecommenderConfig = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            status: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            latest_recommender_update: ?struct {
                recommender_config: ?RecommenderConfig = null,
                creation_date_time: ?i64 = null,
                last_updated_date_time: ?i64 = null,
                status: ?[]const u8 = null,
                failure_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .recommender_config = "recommenderConfig",
                        .creation_date_time = "creationDateTime",
                        .last_updated_date_time = "lastUpdatedDateTime",
                        .status = "status",
                        .failure_reason = "failureReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            model_metrics: ?[]struct {
                key: ?[]const u8 = null,
                value: ?f64 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommender_arn = "recommenderArn",
                    .dataset_group_arn = "datasetGroupArn",
                    .name = "name",
                    .recipe_arn = "recipeArn",
                    .recommender_config = "recommenderConfig",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .status = "status",
                    .failure_reason = "failureReason",
                    .latest_recommender_update = "latestRecommenderUpdate",
                    .model_metrics = "modelMetrics",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "model_metrics", field_name))
                    return try serializeMap(self.model_metrics, self.fieldNameFor("model_metrics"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender = "recommender",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_schema: struct {
    action_name: []const u8 = "DescribeSchema",
    Request: type = struct {
        schema_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "schemaArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_schema) } {
            return .{ .service_metadata = service_metadata, .action = describe_schema };
        }
    },
    Response: type = struct {
        schema: ?struct {
            name: ?[]const u8 = null,
            schema_arn: ?[]const u8 = null,
            schema: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            domain: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .schema_arn = "schemaArn",
                    .schema = "schema",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .domain = "domain",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema = "schema",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_solution: struct {
    action_name: []const u8 = "DescribeSolution",
    Request: type = struct {
        solution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_arn = "solutionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_solution) } {
            return .{ .service_metadata = service_metadata, .action = describe_solution };
        }
    },
    Response: type = struct {
        solution: ?struct {
            name: ?[]const u8 = null,
            solution_arn: ?[]const u8 = null,
            perform_hpo: ?bool = null,
            perform_auto_ml: ?bool = null,
            recipe_arn: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            event_type: ?[]const u8 = null,
            solution_config: ?SolutionConfig = null,
            auto_ml_result: ?struct {
                best_recipe_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .best_recipe_arn = "bestRecipeArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            latest_solution_version: ?SolutionVersionSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .solution_arn = "solutionArn",
                    .perform_hpo = "performHPO",
                    .perform_auto_ml = "performAutoML",
                    .recipe_arn = "recipeArn",
                    .dataset_group_arn = "datasetGroupArn",
                    .event_type = "eventType",
                    .solution_config = "solutionConfig",
                    .auto_ml_result = "autoMLResult",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .latest_solution_version = "latestSolutionVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution = "solution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_solution_version: struct {
    action_name: []const u8 = "DescribeSolutionVersion",
    Request: type = struct {
        solution_version_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_version_arn = "solutionVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_solution_version) } {
            return .{ .service_metadata = service_metadata, .action = describe_solution_version };
        }
    },
    Response: type = struct {
        solution_version: ?struct {
            name: ?[]const u8 = null,
            solution_version_arn: ?[]const u8 = null,
            solution_arn: ?[]const u8 = null,
            perform_hpo: ?bool = null,
            perform_auto_ml: ?bool = null,
            recipe_arn: ?[]const u8 = null,
            event_type: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            solution_config: ?SolutionConfig = null,
            training_hours: ?f64 = null,
            training_mode: ?[]const u8 = null,
            tuned_hpo_params: ?struct {
                algorithm_hyper_parameters: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .algorithm_hyper_parameters = "algorithmHyperParameters",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "algorithm_hyper_parameters", field_name))
                        return try serializeMap(self.algorithm_hyper_parameters, self.fieldNameFor("algorithm_hyper_parameters"), options, out_stream);
                    return false;
                }
            } = null,
            status: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .solution_version_arn = "solutionVersionArn",
                    .solution_arn = "solutionArn",
                    .perform_hpo = "performHPO",
                    .perform_auto_ml = "performAutoML",
                    .recipe_arn = "recipeArn",
                    .event_type = "eventType",
                    .dataset_group_arn = "datasetGroupArn",
                    .solution_config = "solutionConfig",
                    .training_hours = "trainingHours",
                    .training_mode = "trainingMode",
                    .tuned_hpo_params = "tunedHPOParams",
                    .status = "status",
                    .failure_reason = "failureReason",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_version = "solutionVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const get_solution_metrics: struct {
    action_name: []const u8 = "GetSolutionMetrics",
    Request: type = struct {
        solution_version_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_version_arn = "solutionVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_solution_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_solution_metrics };
        }
    },
    Response: type = struct {
        solution_version_arn: ?[]const u8 = null,
        metrics: ?[]struct {
            key: ?[]const u8 = null,
            value: ?f64 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_version_arn = "solutionVersionArn",
                .metrics = "metrics",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metrics", field_name))
                return try serializeMap(self.metrics, self.fieldNameFor("metrics"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const list_batch_inference_jobs: struct {
    action_name: []const u8 = "ListBatchInferenceJobs",
    Request: type = struct {
        solution_version_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_version_arn = "solutionVersionArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_batch_inference_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_batch_inference_jobs };
        }
    },
    Response: type = struct {
        batch_inference_jobs: ?[]struct {
            batch_inference_job_arn: ?[]const u8 = null,
            job_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,
            solution_version_arn: ?[]const u8 = null,
            batch_inference_job_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .batch_inference_job_arn = "batchInferenceJobArn",
                    .job_name = "jobName",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                    .solution_version_arn = "solutionVersionArn",
                    .batch_inference_job_mode = "batchInferenceJobMode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_inference_jobs = "batchInferenceJobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_batch_segment_jobs: struct {
    action_name: []const u8 = "ListBatchSegmentJobs",
    Request: type = struct {
        solution_version_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_version_arn = "solutionVersionArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_batch_segment_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_batch_segment_jobs };
        }
    },
    Response: type = struct {
        batch_segment_jobs: ?[]struct {
            batch_segment_job_arn: ?[]const u8 = null,
            job_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,
            solution_version_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .batch_segment_job_arn = "batchSegmentJobArn",
                    .job_name = "jobName",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                    .solution_version_arn = "solutionVersionArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_segment_jobs = "batchSegmentJobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_campaigns: struct {
    action_name: []const u8 = "ListCampaigns",
    Request: type = struct {
        solution_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_arn = "solutionArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_campaigns) } {
            return .{ .service_metadata = service_metadata, .action = list_campaigns };
        }
    },
    Response: type = struct {
        campaigns: ?[]struct {
            name: ?[]const u8 = null,
            campaign_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .campaign_arn = "campaignArn",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaigns = "campaigns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_dataset_export_jobs: struct {
    action_name: []const u8 = "ListDatasetExportJobs",
    Request: type = struct {
        dataset_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "datasetArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dataset_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_dataset_export_jobs };
        }
    },
    Response: type = struct {
        dataset_export_jobs: ?[]struct {
            dataset_export_job_arn: ?[]const u8 = null,
            job_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dataset_export_job_arn = "datasetExportJobArn",
                    .job_name = "jobName",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_export_jobs = "datasetExportJobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_dataset_groups: struct {
    action_name: []const u8 = "ListDatasetGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dataset_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_dataset_groups };
        }
    },
    Response: type = struct {
        dataset_groups: ?[]struct {
            name: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,
            domain: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .dataset_group_arn = "datasetGroupArn",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                    .domain = "domain",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_groups = "datasetGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
    },
} = .{};
pub const list_dataset_import_jobs: struct {
    action_name: []const u8 = "ListDatasetImportJobs",
    Request: type = struct {
        dataset_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "datasetArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dataset_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_dataset_import_jobs };
        }
    },
    Response: type = struct {
        dataset_import_jobs: ?[]struct {
            dataset_import_job_arn: ?[]const u8 = null,
            job_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,
            import_mode: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dataset_import_job_arn = "datasetImportJobArn",
                    .job_name = "jobName",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                    .import_mode = "importMode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_import_jobs = "datasetImportJobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_datasets: struct {
    action_name: []const u8 = "ListDatasets",
    Request: type = struct {
        dataset_group_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "datasetGroupArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_datasets) } {
            return .{ .service_metadata = service_metadata, .action = list_datasets };
        }
    },
    Response: type = struct {
        datasets: ?[]struct {
            name: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            dataset_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .dataset_arn = "datasetArn",
                    .dataset_type = "datasetType",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datasets = "datasets",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_event_trackers: struct {
    action_name: []const u8 = "ListEventTrackers",
    Request: type = struct {
        dataset_group_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "datasetGroupArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_event_trackers) } {
            return .{ .service_metadata = service_metadata, .action = list_event_trackers };
        }
    },
    Response: type = struct {
        event_trackers: ?[]struct {
            name: ?[]const u8 = null,
            event_tracker_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .event_tracker_arn = "eventTrackerArn",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_trackers = "eventTrackers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_filters: struct {
    action_name: []const u8 = "ListFilters",
    Request: type = struct {
        dataset_group_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "datasetGroupArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_filters) } {
            return .{ .service_metadata = service_metadata, .action = list_filters };
        }
    },
    Response: type = struct {
        filters: ?[]struct {
            name: ?[]const u8 = null,
            filter_arn: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            dataset_group_arn: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .filter_arn = "filterArn",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .dataset_group_arn = "datasetGroupArn",
                    .failure_reason = "failureReason",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_metric_attribution_metrics: struct {
    action_name: []const u8 = "ListMetricAttributionMetrics",
    Request: type = struct {
        metric_attribution_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_attribution_arn = "metricAttributionArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_metric_attribution_metrics) } {
            return .{ .service_metadata = service_metadata, .action = list_metric_attribution_metrics };
        }
    },
    Response: type = struct {
        metrics: ?[]MetricAttribute = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metrics = "metrics",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_metric_attributions: struct {
    action_name: []const u8 = "ListMetricAttributions",
    Request: type = struct {
        dataset_group_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "datasetGroupArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_metric_attributions) } {
            return .{ .service_metadata = service_metadata, .action = list_metric_attributions };
        }
    },
    Response: type = struct {
        metric_attributions: ?[]struct {
            name: ?[]const u8 = null,
            metric_attribution_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .metric_attribution_arn = "metricAttributionArn",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_attributions = "metricAttributions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_recipes: struct {
    action_name: []const u8 = "ListRecipes",
    Request: type = struct {
        recipe_provider: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recipe_provider = "recipeProvider",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .domain = "domain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recipes) } {
            return .{ .service_metadata = service_metadata, .action = list_recipes };
        }
    },
    Response: type = struct {
        recipes: ?[]struct {
            name: ?[]const u8 = null,
            recipe_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            domain: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .recipe_arn = "recipeArn",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .domain = "domain",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recipes = "recipes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_recommenders: struct {
    action_name: []const u8 = "ListRecommenders",
    Request: type = struct {
        dataset_group_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "datasetGroupArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommenders) } {
            return .{ .service_metadata = service_metadata, .action = list_recommenders };
        }
    },
    Response: type = struct {
        recommenders: ?[]struct {
            name: ?[]const u8 = null,
            recommender_arn: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            recipe_arn: ?[]const u8 = null,
            recommender_config: ?RecommenderConfig = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .recommender_arn = "recommenderArn",
                    .dataset_group_arn = "datasetGroupArn",
                    .recipe_arn = "recipeArn",
                    .recommender_config = "recommenderConfig",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommenders = "recommenders",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_schemas: struct {
    action_name: []const u8 = "ListSchemas",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schemas) } {
            return .{ .service_metadata = service_metadata, .action = list_schemas };
        }
    },
    Response: type = struct {
        schemas: ?[]struct {
            name: ?[]const u8 = null,
            schema_arn: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            domain: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .schema_arn = "schemaArn",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .domain = "domain",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schemas = "schemas",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
    },
} = .{};
pub const list_solutions: struct {
    action_name: []const u8 = "ListSolutions",
    Request: type = struct {
        dataset_group_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "datasetGroupArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_solutions) } {
            return .{ .service_metadata = service_metadata, .action = list_solutions };
        }
    },
    Response: type = struct {
        solutions: ?[]struct {
            name: ?[]const u8 = null,
            solution_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,
            recipe_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .solution_arn = "solutionArn",
                    .status = "status",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .recipe_arn = "recipeArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solutions = "solutions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_solution_versions: struct {
    action_name: []const u8 = "ListSolutionVersions",
    Request: type = struct {
        solution_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_arn = "solutionArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_solution_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_solution_versions };
        }
    },
    Response: type = struct {
        solution_versions: ?[]SolutionVersionSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_versions = "solutionVersions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
        ResourceNotFound,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const start_recommender: struct {
    action_name: []const u8 = "StartRecommender",
    Request: type = struct {
        recommender_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_arn = "recommenderArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_recommender) } {
            return .{ .service_metadata = service_metadata, .action = start_recommender };
        }
    },
    Response: type = struct {
        recommender_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_arn = "recommenderArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const stop_recommender: struct {
    action_name: []const u8 = "StopRecommender",
    Request: type = struct {
        recommender_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_arn = "recommenderArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_recommender) } {
            return .{ .service_metadata = service_metadata, .action = stop_recommender };
        }
    },
    Response: type = struct {
        recommender_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_arn = "recommenderArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const stop_solution_version_creation: struct {
    action_name: []const u8 = "StopSolutionVersionCreation",
    Request: type = struct {
        solution_version_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .solution_version_arn = "solutionVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_solution_version_creation) } {
            return .{ .service_metadata = service_metadata, .action = stop_solution_version_creation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceInUse,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
        TooManyTagKeys,
    },
} = .{};
pub const update_campaign: struct {
    action_name: []const u8 = "UpdateCampaign",
    Request: type = struct {
        campaign_arn: []const u8,
        solution_version_arn: ?[]const u8 = null,
        min_provisioned_tps: ?i64 = null,
        campaign_config: ?CampaignConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_arn = "campaignArn",
                .solution_version_arn = "solutionVersionArn",
                .min_provisioned_tps = "minProvisionedTPS",
                .campaign_config = "campaignConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_campaign) } {
            return .{ .service_metadata = service_metadata, .action = update_campaign };
        }
    },
    Response: type = struct {
        campaign_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_arn = "campaignArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_dataset: struct {
    action_name: []const u8 = "UpdateDataset",
    Request: type = struct {
        dataset_arn: []const u8,
        schema_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "datasetArn",
                .schema_arn = "schemaArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dataset) } {
            return .{ .service_metadata = service_metadata, .action = update_dataset };
        }
    },
    Response: type = struct {
        dataset_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "datasetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_metric_attribution: struct {
    action_name: []const u8 = "UpdateMetricAttribution",
    Request: type = struct {
        add_metrics: ?[]MetricAttribute = null,
        remove_metrics: ?[][]const u8 = null,
        metrics_output_config: ?MetricAttributionOutput = null,
        metric_attribution_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .add_metrics = "addMetrics",
                .remove_metrics = "removeMetrics",
                .metrics_output_config = "metricsOutputConfig",
                .metric_attribution_arn = "metricAttributionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_metric_attribution) } {
            return .{ .service_metadata = service_metadata, .action = update_metric_attribution };
        }
    },
    Response: type = struct {
        metric_attribution_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_attribution_arn = "metricAttributionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_recommender: struct {
    action_name: []const u8 = "UpdateRecommender",
    Request: type = struct {
        recommender_arn: []const u8,
        recommender_config: RecommenderConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_arn = "recommenderArn",
                .recommender_config = "recommenderConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_recommender) } {
            return .{ .service_metadata = service_metadata, .action = update_recommender };
        }
    },
    Response: type = struct {
        recommender_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommender_arn = "recommenderArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};

pub const RecommenderConfig = struct {
    item_exploration_config: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    min_recommendation_requests_per_second: ?i64 = null,
    training_data_config: ?TrainingDataConfig = null,
    enable_metadata_with_recommendations: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item_exploration_config = "itemExplorationConfig",
            .min_recommendation_requests_per_second = "minRecommendationRequestsPerSecond",
            .training_data_config = "trainingDataConfig",
            .enable_metadata_with_recommendations = "enableMetadataWithRecommendations",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "item_exploration_config", field_name))
            return try serializeMap(self.item_exploration_config, self.fieldNameFor("item_exploration_config"), options, out_stream);
        return false;
    }
};

pub const TrainingDataConfig = struct {
    excluded_dataset_columns: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .excluded_dataset_columns = "excludedDatasetColumns",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "excluded_dataset_columns", field_name))
            return try serializeMap(self.excluded_dataset_columns, self.fieldNameFor("excluded_dataset_columns"), options, out_stream);
        return false;
    }
};

pub const MetricAttributionOutput = struct {
    s3_data_destination: ?S3DataConfig = null,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_destination = "s3DataDestination",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DataConfig = struct {
    path: []const u8,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "path",
            .kms_key_arn = "kmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricAttribute = struct {
    event_type: []const u8,
    metric_name: []const u8,
    expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_type = "eventType",
            .metric_name = "metricName",
            .expression = "expression",
        };
        return @field(mappings, field_name);
    }
};

pub const CampaignConfig = struct {
    item_exploration_config: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    enable_metadata_with_recommendations: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item_exploration_config = "itemExplorationConfig",
            .enable_metadata_with_recommendations = "enableMetadataWithRecommendations",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "item_exploration_config", field_name))
            return try serializeMap(self.item_exploration_config, self.fieldNameFor("item_exploration_config"), options, out_stream);
        return false;
    }
};

pub const Tag = struct {
    tag_key: []const u8,
    tag_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_key = "tagKey",
            .tag_value = "tagValue",
        };
        return @field(mappings, field_name);
    }
};

pub const SolutionVersionSummary = struct {
    solution_version_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    creation_date_time: ?i64 = null,
    last_updated_date_time: ?i64 = null,
    failure_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .solution_version_arn = "solutionVersionArn",
            .status = "status",
            .creation_date_time = "creationDateTime",
            .last_updated_date_time = "lastUpdatedDateTime",
            .failure_reason = "failureReason",
        };
        return @field(mappings, field_name);
    }
};

pub const SolutionConfig = struct {
    event_value_threshold: ?[]const u8 = null,
    hpo_config: ?HPOConfig = null,
    algorithm_hyper_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    feature_transformation_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    auto_ml_config: ?AutoMLConfig = null,
    optimization_objective: ?OptimizationObjective = null,
    training_data_config: ?TrainingDataConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_value_threshold = "eventValueThreshold",
            .hpo_config = "hpoConfig",
            .algorithm_hyper_parameters = "algorithmHyperParameters",
            .feature_transformation_parameters = "featureTransformationParameters",
            .auto_ml_config = "autoMLConfig",
            .optimization_objective = "optimizationObjective",
            .training_data_config = "trainingDataConfig",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "algorithm_hyper_parameters", field_name))
            return try serializeMap(self.algorithm_hyper_parameters, self.fieldNameFor("algorithm_hyper_parameters"), options, out_stream);
        if (std.mem.eql(u8, "feature_transformation_parameters", field_name))
            return try serializeMap(self.feature_transformation_parameters, self.fieldNameFor("feature_transformation_parameters"), options, out_stream);
        return false;
    }
};

pub const OptimizationObjective = struct {
    item_attribute: ?[]const u8 = null,
    objective_sensitivity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item_attribute = "itemAttribute",
            .objective_sensitivity = "objectiveSensitivity",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLConfig = struct {
    metric_name: ?[]const u8 = null,
    recipe_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "metricName",
            .recipe_list = "recipeList",
        };
        return @field(mappings, field_name);
    }
};

pub const HPOConfig = struct {
    hpo_objective: ?HPOObjective = null,
    hpo_resource_config: ?HPOResourceConfig = null,
    algorithm_hyper_parameter_ranges: ?HyperParameterRanges = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hpo_objective = "hpoObjective",
            .hpo_resource_config = "hpoResourceConfig",
            .algorithm_hyper_parameter_ranges = "algorithmHyperParameterRanges",
        };
        return @field(mappings, field_name);
    }
};

pub const HyperParameterRanges = struct {
    integer_hyper_parameter_ranges: ?[]IntegerHyperParameterRange = null,
    continuous_hyper_parameter_ranges: ?[]ContinuousHyperParameterRange = null,
    categorical_hyper_parameter_ranges: ?[]CategoricalHyperParameterRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .integer_hyper_parameter_ranges = "integerHyperParameterRanges",
            .continuous_hyper_parameter_ranges = "continuousHyperParameterRanges",
            .categorical_hyper_parameter_ranges = "categoricalHyperParameterRanges",
        };
        return @field(mappings, field_name);
    }
};

pub const CategoricalHyperParameterRange = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const ContinuousHyperParameterRange = struct {
    name: ?[]const u8 = null,
    min_value: ?f64 = null,
    max_value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .min_value = "minValue",
            .max_value = "maxValue",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerHyperParameterRange = struct {
    name: ?[]const u8 = null,
    min_value: ?i64 = null,
    max_value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .min_value = "minValue",
            .max_value = "maxValue",
        };
        return @field(mappings, field_name);
    }
};

pub const HPOResourceConfig = struct {
    max_number_of_training_jobs: ?[]const u8 = null,
    max_parallel_training_jobs: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_number_of_training_jobs = "maxNumberOfTrainingJobs",
            .max_parallel_training_jobs = "maxParallelTrainingJobs",
        };
        return @field(mappings, field_name);
    }
};

pub const HPOObjective = struct {
    type: ?[]const u8 = null,
    metric_name: ?[]const u8 = null,
    metric_regex: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .metric_name = "metricName",
            .metric_regex = "metricRegex",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSource = struct {
    data_location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_location = "dataLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetExportJobOutput = struct {
    s3_data_destination: S3DataConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_destination = "s3DataDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchSegmentJobOutput = struct {
    s3_data_destination: S3DataConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_destination = "s3DataDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchSegmentJobInput = struct {
    s3_data_source: S3DataConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_source = "s3DataSource",
        };
        return @field(mappings, field_name);
    }
};

pub const ThemeGenerationConfig = struct {
    fields_for_theme_generation: FieldsForThemeGeneration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fields_for_theme_generation = "fieldsForThemeGeneration",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldsForThemeGeneration = struct {
    item_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item_name = "itemName",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchInferenceJobConfig = struct {
    item_exploration_config: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item_exploration_config = "itemExplorationConfig",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "item_exploration_config", field_name))
            return try serializeMap(self.item_exploration_config, self.fieldNameFor("item_exploration_config"), options, out_stream);
        return false;
    }
};

pub const BatchInferenceJobOutput = struct {
    s3_data_destination: S3DataConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_destination = "s3DataDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchInferenceJobInput = struct {
    s3_data_source: S3DataConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_source = "s3DataSource",
        };
        return @field(mappings, field_name);
    }
};
