const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-03-22";
pub const sdk_id: []const u8 = "Personalize Events";
pub const arn_namespace: ?[]const u8 = "personalize";
pub const endpoint_prefix: []const u8 = "personalize-events";
pub const sigv4_name: []const u8 = "personalize";
pub const name: []const u8 = "AmazonPersonalizeEvents";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-03-22",
    sdk_id: []const u8 = "Personalize Events",
    arn_namespace: ?[]const u8 = "personalize",
    endpoint_prefix: []const u8 = "personalize-events",
    sigv4_name: []const u8 = "personalize",
    name: []const u8 = "AmazonPersonalizeEvents",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const put_action_interactions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/action-interactions",
        .success_code = 200,
    };

    action_name: []const u8 = "PutActionInteractions",
    Request: type = struct {
        tracking_id: []const u8,
        action_interactions: []struct {
            action_id: []const u8,
            user_id: ?[]const u8 = null,
            session_id: []const u8,
            timestamp: i64,
            event_type: []const u8,
            event_id: ?[]const u8 = null,
            recommendation_id: ?[]const u8 = null,
            impression: ?[][]const u8 = null,
            properties: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_id = "actionId",
                    .user_id = "userId",
                    .session_id = "sessionId",
                    .timestamp = "timestamp",
                    .event_type = "eventType",
                    .event_id = "eventId",
                    .recommendation_id = "recommendationId",
                    .impression = "impression",
                    .properties = "properties",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tracking_id = "trackingId",
                .action_interactions = "actionInteractions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_action_interactions) } {
            return .{ .service_metadata = service_metadata, .action = put_action_interactions };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const put_actions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/actions",
        .success_code = 200,
    };

    action_name: []const u8 = "PutActions",
    Request: type = struct {
        dataset_arn: []const u8,
        actions: []struct {
            action_id: []const u8,
            properties: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_id = "actionId",
                    .properties = "properties",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "datasetArn",
                .actions = "actions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_actions) } {
            return .{ .service_metadata = service_metadata, .action = put_actions };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const put_events: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/events",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEvents",
    Request: type = struct {
        tracking_id: []const u8,
        user_id: ?[]const u8 = null,
        session_id: []const u8,
        event_list: []struct {
            event_id: ?[]const u8 = null,
            event_type: []const u8,
            event_value: ?f32 = null,
            item_id: ?[]const u8 = null,
            properties: ?[]const u8 = null,
            sent_at: i64,
            recommendation_id: ?[]const u8 = null,
            impression: ?[][]const u8 = null,
            metric_attribution: ?struct {
                event_attribution_source: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .event_attribution_source = "eventAttributionSource",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_id = "eventId",
                    .event_type = "eventType",
                    .event_value = "eventValue",
                    .item_id = "itemId",
                    .properties = "properties",
                    .sent_at = "sentAt",
                    .recommendation_id = "recommendationId",
                    .impression = "impression",
                    .metric_attribution = "metricAttribution",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tracking_id = "trackingId",
                .user_id = "userId",
                .session_id = "sessionId",
                .event_list = "eventList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_events) } {
            return .{ .service_metadata = service_metadata, .action = put_events };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
    },
} = .{};
pub const put_items: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/items",
        .success_code = 200,
    };

    action_name: []const u8 = "PutItems",
    Request: type = struct {
        dataset_arn: []const u8,
        items: []struct {
            item_id: []const u8,
            properties: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item_id = "itemId",
                    .properties = "properties",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "datasetArn",
                .items = "items",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_items) } {
            return .{ .service_metadata = service_metadata, .action = put_items };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const put_users: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users",
        .success_code = 200,
    };

    action_name: []const u8 = "PutUsers",
    Request: type = struct {
        dataset_arn: []const u8,
        users: []struct {
            user_id: []const u8,
            properties: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_id = "userId",
                    .properties = "properties",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "datasetArn",
                .users = "users",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_users) } {
            return .{ .service_metadata = service_metadata, .action = put_users };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
