const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-22";
pub const sdk_id: []const u8 = "Personalize Runtime";
pub const arn_namespace: ?[]const u8 = "personalize";
pub const endpoint_prefix: []const u8 = "personalize-runtime";
pub const sigv4_name: []const u8 = "personalize";
pub const name: []const u8 = "AmazonPersonalizeRuntime";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-22",
    sdk_id: []const u8 = "Personalize Runtime",
    arn_namespace: ?[]const u8 = "personalize",
    endpoint_prefix: []const u8 = "personalize-runtime",
    sigv4_name: []const u8 = "personalize",
    name: []const u8 = "AmazonPersonalizeRuntime",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const get_action_recommendations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/action-recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetActionRecommendations",
    Request: type = struct {
        campaign_arn: ?[]const u8 = null,
        user_id: ?[]const u8 = null,
        num_results: ?i64 = null,
        filter_arn: ?[]const u8 = null,
        filter_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_arn = "campaignArn",
                .user_id = "userId",
                .num_results = "numResults",
                .filter_arn = "filterArn",
                .filter_values = "filterValues",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filter_values", field_name))
                return try serializeMap(self.filter_values, self.fieldNameFor("filter_values"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_action_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_action_recommendations };
        }
    },
    Response: type = struct {
        action_list: ?[]struct {
            action_id: ?[]const u8 = null,
            score: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_id = "actionId",
                    .score = "score",
                };
                return @field(mappings, field_name);
            }
        } = null,
        recommendation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_list = "actionList",
                .recommendation_id = "recommendationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const get_personalized_ranking: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/personalize-ranking",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPersonalizedRanking",
    Request: type = struct {
        campaign_arn: []const u8,
        input_list: [][]const u8,
        user_id: []const u8,
        context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        filter_arn: ?[]const u8 = null,
        filter_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        metadata_columns: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_arn = "campaignArn",
                .input_list = "inputList",
                .user_id = "userId",
                .context = "context",
                .filter_arn = "filterArn",
                .filter_values = "filterValues",
                .metadata_columns = "metadataColumns",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "context", field_name))
                return try serializeMap(self.context, self.fieldNameFor("context"), options, out_stream);
            if (std.mem.eql(u8, "filter_values", field_name))
                return try serializeMap(self.filter_values, self.fieldNameFor("filter_values"), options, out_stream);
            if (std.mem.eql(u8, "metadata_columns", field_name))
                return try serializeMap(self.metadata_columns, self.fieldNameFor("metadata_columns"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_personalized_ranking) } {
            return .{ .service_metadata = service_metadata, .action = get_personalized_ranking };
        }
    },
    Response: type = struct {
        personalized_ranking: ?[]PredictedItem = null,
        recommendation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .personalized_ranking = "personalizedRanking",
                .recommendation_id = "recommendationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const get_recommendations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecommendations",
    Request: type = struct {
        campaign_arn: ?[]const u8 = null,
        item_id: ?[]const u8 = null,
        user_id: ?[]const u8 = null,
        num_results: ?i64 = null,
        context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        filter_arn: ?[]const u8 = null,
        filter_values: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        recommender_arn: ?[]const u8 = null,
        promotions: ?[]struct {
            name: ?[]const u8 = null,
            percent_promoted_items: ?i64 = null,
            filter_arn: ?[]const u8 = null,
            filter_values: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .percent_promoted_items = "percentPromotedItems",
                    .filter_arn = "filterArn",
                    .filter_values = "filterValues",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "filter_values", field_name))
                    return try serializeMap(self.filter_values, self.fieldNameFor("filter_values"), options, out_stream);
                return false;
            }
        } = null,
        metadata_columns: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_arn = "campaignArn",
                .item_id = "itemId",
                .user_id = "userId",
                .num_results = "numResults",
                .context = "context",
                .filter_arn = "filterArn",
                .filter_values = "filterValues",
                .recommender_arn = "recommenderArn",
                .promotions = "promotions",
                .metadata_columns = "metadataColumns",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "context", field_name))
                return try serializeMap(self.context, self.fieldNameFor("context"), options, out_stream);
            if (std.mem.eql(u8, "filter_values", field_name))
                return try serializeMap(self.filter_values, self.fieldNameFor("filter_values"), options, out_stream);
            if (std.mem.eql(u8, "metadata_columns", field_name))
                return try serializeMap(self.metadata_columns, self.fieldNameFor("metadata_columns"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_recommendations };
        }
    },
    Response: type = struct {
        item_list: ?[]PredictedItem = null,
        recommendation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .item_list = "itemList",
                .recommendation_id = "recommendationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};

pub const PredictedItem = struct {
    item_id: ?[]const u8 = null,
    score: ?f64 = null,
    promotion_name: ?[]const u8 = null,
    metadata: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .item_id = "itemId",
            .score = "score",
            .promotion_name = "promotionName",
            .metadata = "metadata",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "metadata", field_name))
            return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
        return false;
    }
};
