const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-02-27";
pub const sdk_id: []const u8 = "PI";
pub const arn_namespace: ?[]const u8 = "pi";
pub const endpoint_prefix: []const u8 = "pi";
pub const sigv4_name: []const u8 = "pi";
pub const name: []const u8 = "PerformanceInsightsv20180227";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-02-27",
    sdk_id: []const u8 = "PI",
    arn_namespace: ?[]const u8 = "pi",
    endpoint_prefix: []const u8 = "pi",
    sigv4_name: []const u8 = "pi",
    name: []const u8 = "PerformanceInsightsv20180227",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_performance_analysis_report: struct {
    action_name: []const u8 = "CreatePerformanceAnalysisReport",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        start_time: i64,
        end_time: i64,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_performance_analysis_report) } {
            return .{ .service_metadata = service_metadata, .action = create_performance_analysis_report };
        }
    },
    Response: type = struct {
        analysis_report_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_report_id = "AnalysisReportId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const delete_performance_analysis_report: struct {
    action_name: []const u8 = "DeletePerformanceAnalysisReport",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        analysis_report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .analysis_report_id = "AnalysisReportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_performance_analysis_report) } {
            return .{ .service_metadata = service_metadata, .action = delete_performance_analysis_report };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const describe_dimension_keys: struct {
    action_name: []const u8 = "DescribeDimensionKeys",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        start_time: i64,
        end_time: i64,
        metric: []const u8,
        period_in_seconds: ?i64 = null,
        group_by: DimensionGroup,
        additional_metrics: ?[][]const u8 = null,
        partition_by: ?DimensionGroup = null,
        filter: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .metric = "Metric",
                .period_in_seconds = "PeriodInSeconds",
                .group_by = "GroupBy",
                .additional_metrics = "AdditionalMetrics",
                .partition_by = "PartitionBy",
                .filter = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filter", field_name))
                return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dimension_keys) } {
            return .{ .service_metadata = service_metadata, .action = describe_dimension_keys };
        }
    },
    Response: type = struct {
        aligned_start_time: ?i64 = null,
        aligned_end_time: ?i64 = null,
        partition_keys: ?[]struct {
            dimensions: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dimensions = "Dimensions",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "dimensions", field_name))
                    return try serializeMap(self.dimensions, self.fieldNameFor("dimensions"), options, out_stream);
                return false;
            }
        } = null,
        keys: ?[]struct {
            dimensions: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            total: ?f64 = null,
            additional_metrics: ?[]struct {
                key: ?[]const u8 = null,
                value: ?f64 = null,
            } = null,
            partitions: ?[]f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dimensions = "Dimensions",
                    .total = "Total",
                    .additional_metrics = "AdditionalMetrics",
                    .partitions = "Partitions",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "dimensions", field_name))
                    return try serializeMap(self.dimensions, self.fieldNameFor("dimensions"), options, out_stream);
                if (std.mem.eql(u8, "additional_metrics", field_name))
                    return try serializeMap(self.additional_metrics, self.fieldNameFor("additional_metrics"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aligned_start_time = "AlignedStartTime",
                .aligned_end_time = "AlignedEndTime",
                .partition_keys = "PartitionKeys",
                .keys = "Keys",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const get_dimension_key_details: struct {
    action_name: []const u8 = "GetDimensionKeyDetails",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        group: []const u8,
        group_identifier: []const u8,
        requested_dimensions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .group = "Group",
                .group_identifier = "GroupIdentifier",
                .requested_dimensions = "RequestedDimensions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dimension_key_details) } {
            return .{ .service_metadata = service_metadata, .action = get_dimension_key_details };
        }
    },
    Response: type = struct {
        dimensions: ?[]struct {
            value: ?[]const u8 = null,
            dimension: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .value = "Value",
                    .dimension = "Dimension",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dimensions = "Dimensions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const get_performance_analysis_report: struct {
    action_name: []const u8 = "GetPerformanceAnalysisReport",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        analysis_report_id: []const u8,
        text_format: ?[]const u8 = null,
        accept_language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .analysis_report_id = "AnalysisReportId",
                .text_format = "TextFormat",
                .accept_language = "AcceptLanguage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_performance_analysis_report) } {
            return .{ .service_metadata = service_metadata, .action = get_performance_analysis_report };
        }
    },
    Response: type = struct {
        analysis_report: ?struct {
            analysis_report_id: []const u8,
            identifier: ?[]const u8 = null,
            service_type: ?[]const u8 = null,
            create_time: ?i64 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            status: ?[]const u8 = null,
            insights: ?[]struct {
                insight_id: []const u8,
                insight_type: ?[]const u8 = null,
                context: ?[]const u8 = null,
                start_time: ?i64 = null,
                end_time: ?i64 = null,
                severity: ?[]const u8 = null,
                supporting_insights: ?[]struct {
                    insight_id: []const u8,
                    insight_type: ?[]const u8 = null,
                    context: ?[]const u8 = null,
                    start_time: ?i64 = null,
                    end_time: ?i64 = null,
                    severity: ?[]const u8 = null,
                    supporting_insights: ?[]struct {
                        insight_id: []const u8,
                        insight_type: ?[]const u8 = null,
                        context: ?[]const u8 = null,
                        start_time: ?i64 = null,
                        end_time: ?i64 = null,
                        severity: ?[]const u8 = null,
                        supporting_insights: ?[]const u8 = null,
                        description: ?[]const u8 = null,
                        recommendations: ?[]struct {
                            recommendation_id: ?[]const u8 = null,
                            recommendation_description: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .recommendation_id = "RecommendationId",
                                    .recommendation_description = "RecommendationDescription",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        insight_data: ?[]Data = null,
                        baseline_data: ?[]Data = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .insight_id = "InsightId",
                                .insight_type = "InsightType",
                                .context = "Context",
                                .start_time = "StartTime",
                                .end_time = "EndTime",
                                .severity = "Severity",
                                .supporting_insights = "SupportingInsights",
                                .description = "Description",
                                .recommendations = "Recommendations",
                                .insight_data = "InsightData",
                                .baseline_data = "BaselineData",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    description: ?[]const u8 = null,
                    recommendations: ?[]struct {
                        recommendation_id: ?[]const u8 = null,
                        recommendation_description: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .recommendation_id = "RecommendationId",
                                .recommendation_description = "RecommendationDescription",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    insight_data: ?[]Data = null,
                    baseline_data: ?[]Data = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .insight_id = "InsightId",
                            .insight_type = "InsightType",
                            .context = "Context",
                            .start_time = "StartTime",
                            .end_time = "EndTime",
                            .severity = "Severity",
                            .supporting_insights = "SupportingInsights",
                            .description = "Description",
                            .recommendations = "Recommendations",
                            .insight_data = "InsightData",
                            .baseline_data = "BaselineData",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                description: ?[]const u8 = null,
                recommendations: ?[]struct {
                    recommendation_id: ?[]const u8 = null,
                    recommendation_description: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .recommendation_id = "RecommendationId",
                            .recommendation_description = "RecommendationDescription",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                insight_data: ?[]Data = null,
                baseline_data: ?[]Data = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .insight_id = "InsightId",
                        .insight_type = "InsightType",
                        .context = "Context",
                        .start_time = "StartTime",
                        .end_time = "EndTime",
                        .severity = "Severity",
                        .supporting_insights = "SupportingInsights",
                        .description = "Description",
                        .recommendations = "Recommendations",
                        .insight_data = "InsightData",
                        .baseline_data = "BaselineData",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .analysis_report_id = "AnalysisReportId",
                    .identifier = "Identifier",
                    .service_type = "ServiceType",
                    .create_time = "CreateTime",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .status = "Status",
                    .insights = "Insights",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_report = "AnalysisReport",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const get_resource_metadata: struct {
    action_name: []const u8 = "GetResourceMetadata",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_metadata };
        }
    },
    Response: type = struct {
        identifier: ?[]const u8 = null,
        features: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "Status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .features = "Features",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "features", field_name))
                return try serializeMap(self.features, self.fieldNameFor("features"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const get_resource_metrics: struct {
    action_name: []const u8 = "GetResourceMetrics",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        metric_queries: []struct {
            metric: []const u8,
            group_by: ?DimensionGroup = null,
            filter: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .metric = "Metric",
                    .group_by = "GroupBy",
                    .filter = "Filter",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "filter", field_name))
                    return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
                return false;
            }
        },
        start_time: i64,
        end_time: i64,
        period_in_seconds: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        period_alignment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .metric_queries = "MetricQueries",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .period_in_seconds = "PeriodInSeconds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .period_alignment = "PeriodAlignment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_metrics };
        }
    },
    Response: type = struct {
        aligned_start_time: ?i64 = null,
        aligned_end_time: ?i64 = null,
        identifier: ?[]const u8 = null,
        metric_list: ?[]struct {
            key: ?struct {
                metric: []const u8,
                dimensions: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metric = "Metric",
                        .dimensions = "Dimensions",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "dimensions", field_name))
                        return try serializeMap(self.dimensions, self.fieldNameFor("dimensions"), options, out_stream);
                    return false;
                }
            } = null,
            data_points: ?[]struct {
                timestamp: i64,
                value: f64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .timestamp = "Timestamp",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .data_points = "DataPoints",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aligned_start_time = "AlignedStartTime",
                .aligned_end_time = "AlignedEndTime",
                .identifier = "Identifier",
                .metric_list = "MetricList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const list_available_resource_dimensions: struct {
    action_name: []const u8 = "ListAvailableResourceDimensions",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        metrics: [][]const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .metrics = "Metrics",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_available_resource_dimensions) } {
            return .{ .service_metadata = service_metadata, .action = list_available_resource_dimensions };
        }
    },
    Response: type = struct {
        metric_dimensions: ?[]struct {
            metric: ?[]const u8 = null,
            groups: ?[]struct {
                group: ?[]const u8 = null,
                dimensions: ?[]struct {
                    identifier: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .identifier = "Identifier",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .group = "Group",
                        .dimensions = "Dimensions",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .metric = "Metric",
                    .groups = "Groups",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metric_dimensions = "MetricDimensions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const list_available_resource_metrics: struct {
    action_name: []const u8 = "ListAvailableResourceMetrics",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        metric_types: [][]const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .metric_types = "MetricTypes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_available_resource_metrics) } {
            return .{ .service_metadata = service_metadata, .action = list_available_resource_metrics };
        }
    },
    Response: type = struct {
        metrics: ?[]struct {
            metric: ?[]const u8 = null,
            description: ?[]const u8 = null,
            unit: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .metric = "Metric",
                    .description = "Description",
                    .unit = "Unit",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metrics = "Metrics",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const list_performance_analysis_reports: struct {
    action_name: []const u8 = "ListPerformanceAnalysisReports",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        list_tags: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .list_tags = "ListTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_performance_analysis_reports) } {
            return .{ .service_metadata = service_metadata, .action = list_performance_analysis_reports };
        }
    },
    Response: type = struct {
        analysis_reports: ?[]struct {
            analysis_report_id: ?[]const u8 = null,
            create_time: ?i64 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            status: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .analysis_report_id = "AnalysisReportId",
                    .create_time = "CreateTime",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .status = "Status",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_reports = "AnalysisReports",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        service_type: []const u8,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        service_type: []const u8,
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        service_type: []const u8,
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DimensionGroup = struct {
    group: []const u8,
    dimensions: ?[][]const u8 = null,
    limit: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group = "Group",
            .dimensions = "Dimensions",
            .limit = "Limit",
        };
        return @field(mappings, field_name);
    }
};

pub const Data = struct {
    performance_insights_metric: ?PerformanceInsightsMetric = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .performance_insights_metric = "PerformanceInsightsMetric",
        };
        return @field(mappings, field_name);
    }
};

pub const PerformanceInsightsMetric = struct {
    metric: ?[]const u8 = null,
    display_name: ?[]const u8 = null,
    dimensions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric = "Metric",
            .display_name = "DisplayName",
            .dimensions = "Dimensions",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "dimensions", field_name))
            return try serializeMap(self.dimensions, self.fieldNameFor("dimensions"), options, out_stream);
        return false;
    }
};
