const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-07-26";
pub const sdk_id: []const u8 = "Pinpoint Email";
pub const arn_namespace: ?[]const u8 = "ses";
pub const endpoint_prefix: []const u8 = "email";
pub const sigv4_name: []const u8 = "ses";
pub const name: []const u8 = "AmazonPinpointEmailService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-07-26",
    sdk_id: []const u8 = "Pinpoint Email",
    arn_namespace: ?[]const u8 = "ses",
    endpoint_prefix: []const u8 = "email",
    sigv4_name: []const u8 = "ses",
    name: []const u8 = "AmazonPinpointEmailService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_configuration_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/email/configuration-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,
        tracking_options: ?TrackingOptions = null,
        delivery_options: ?DeliveryOptions = null,
        reputation_options: ?ReputationOptions = null,
        sending_options: ?SendingOptions = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .tracking_options = "TrackingOptions",
                .delivery_options = "DeliveryOptions",
                .reputation_options = "ReputationOptions",
                .sending_options = "SendingOptions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        ConcurrentModification,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_configuration_set_event_destination: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/email/configuration-sets/{ConfigurationSetName}/event-destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,
        event_destination: EventDestinationDefinition,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
                .event_destination = "EventDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_dedicated_ip_pool: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/email/dedicated-ip-pools",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDedicatedIpPool",
    Request: type = struct {
        pool_name: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_name = "PoolName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dedicated_ip_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_dedicated_ip_pool };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        ConcurrentModification,
        LimitExceeded,
        TooManyRequests,
    },
} = .{};
pub const create_deliverability_test_report: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/email/deliverability-dashboard/test",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDeliverabilityTestReport",
    Request: type = struct {
        report_name: ?[]const u8 = null,
        from_email_address: []const u8,
        content: EmailContent,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_name = "ReportName",
                .from_email_address = "FromEmailAddress",
                .content = "Content",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_deliverability_test_report) } {
            return .{ .service_metadata = service_metadata, .action = create_deliverability_test_report };
        }
    },
    Response: type = struct {
        report_id: []const u8,
        deliverability_test_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "ReportId",
                .deliverability_test_status = "DeliverabilityTestStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountSuspended,
        BadRequest,
        ConcurrentModification,
        LimitExceeded,
        MailFromDomainNotVerified,
        MessageRejected,
        NotFound,
        SendingPaused,
        TooManyRequests,
    },
} = .{};
pub const create_email_identity: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/email/identities",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEmailIdentity",
    Request: type = struct {
        email_identity: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_email_identity) } {
            return .{ .service_metadata = service_metadata, .action = create_email_identity };
        }
    },
    Response: type = struct {
        identity_type: ?[]const u8 = null,
        verified_for_sending_status: ?bool = null,
        dkim_attributes: ?DkimAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_type = "IdentityType",
                .verified_for_sending_status = "VerifiedForSendingStatus",
                .dkim_attributes = "DkimAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        LimitExceeded,
        TooManyRequests,
    },
} = .{};
pub const delete_configuration_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/email/configuration-sets/{ConfigurationSetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_configuration_set_event_destination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/email/configuration-sets/{ConfigurationSetName}/event-destinations/{EventDestinationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_dedicated_ip_pool: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/email/dedicated-ip-pools/{PoolName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDedicatedIpPool",
    Request: type = struct {
        pool_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_name = "PoolName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dedicated_ip_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_dedicated_ip_pool };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_email_identity: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/email/identities/{EmailIdentity}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEmailIdentity",
    Request: type = struct {
        email_identity: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_email_identity) } {
            return .{ .service_metadata = service_metadata, .action = delete_email_identity };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/account",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account) } {
            return .{ .service_metadata = service_metadata, .action = get_account };
        }
    },
    Response: type = struct {
        send_quota: ?struct {
            max24_hour_send: ?f64 = null,
            max_send_rate: ?f64 = null,
            sent_last24_hours: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .max24_hour_send = "Max24HourSend",
                    .max_send_rate = "MaxSendRate",
                    .sent_last24_hours = "SentLast24Hours",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sending_enabled: ?bool = null,
        dedicated_ip_auto_warmup_enabled: ?bool = null,
        enforcement_status: ?[]const u8 = null,
        production_access_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .send_quota = "SendQuota",
                .sending_enabled = "SendingEnabled",
                .dedicated_ip_auto_warmup_enabled = "DedicatedIpAutoWarmupEnabled",
                .enforcement_status = "EnforcementStatus",
                .production_access_enabled = "ProductionAccessEnabled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const get_blacklist_reports: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/deliverability-dashboard/blacklist-report",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBlacklistReports",
    Request: type = struct {
        blacklist_item_names: [][]const u8,

        pub const http_query = .{
            .blacklist_item_names = "BlacklistItemNames",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blacklist_item_names = "BlacklistItemNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_blacklist_reports) } {
            return .{ .service_metadata = service_metadata, .action = get_blacklist_reports };
        }
    },
    Response: type = struct {
        blacklist_report: []struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                rbl_name: ?[]const u8 = null,
                listing_time: ?i64 = null,
                description: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .rbl_name = "RblName",
                        .listing_time = "ListingTime",
                        .description = "Description",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blacklist_report = "BlacklistReport",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "blacklist_report", field_name))
                return try serializeMap(self.blacklist_report, self.fieldNameFor("blacklist_report"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_configuration_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/configuration-sets/{ConfigurationSetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration_set };
        }
    },
    Response: type = struct {
        configuration_set_name: ?[]const u8 = null,
        tracking_options: ?TrackingOptions = null,
        delivery_options: ?DeliveryOptions = null,
        reputation_options: ?ReputationOptions = null,
        sending_options: ?SendingOptions = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .tracking_options = "TrackingOptions",
                .delivery_options = "DeliveryOptions",
                .reputation_options = "ReputationOptions",
                .sending_options = "SendingOptions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_configuration_set_event_destinations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/configuration-sets/{ConfigurationSetName}/event-destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfigurationSetEventDestinations",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration_set_event_destinations) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration_set_event_destinations };
        }
    },
    Response: type = struct {
        event_destinations: ?[]struct {
            name: []const u8,
            enabled: ?bool = null,
            matching_event_types: [][]const u8,
            kinesis_firehose_destination: ?KinesisFirehoseDestination = null,
            cloud_watch_destination: ?CloudWatchDestination = null,
            sns_destination: ?SnsDestination = null,
            pinpoint_destination: ?PinpointDestination = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .enabled = "Enabled",
                    .matching_event_types = "MatchingEventTypes",
                    .kinesis_firehose_destination = "KinesisFirehoseDestination",
                    .cloud_watch_destination = "CloudWatchDestination",
                    .sns_destination = "SnsDestination",
                    .pinpoint_destination = "PinpointDestination",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_destinations = "EventDestinations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_dedicated_ip: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/dedicated-ips/{Ip}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDedicatedIp",
    Request: type = struct {
        ip: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip = "Ip",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dedicated_ip) } {
            return .{ .service_metadata = service_metadata, .action = get_dedicated_ip };
        }
    },
    Response: type = struct {
        dedicated_ip: ?DedicatedIp = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_ip = "DedicatedIp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_dedicated_ips: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/dedicated-ips",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDedicatedIps",
    Request: type = struct {
        pool_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .pool_name = "PoolName",
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_name = "PoolName",
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dedicated_ips) } {
            return .{ .service_metadata = service_metadata, .action = get_dedicated_ips };
        }
    },
    Response: type = struct {
        dedicated_ips: ?[]DedicatedIp = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_ips = "DedicatedIps",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_deliverability_dashboard_options: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/deliverability-dashboard",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeliverabilityDashboardOptions",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deliverability_dashboard_options) } {
            return .{ .service_metadata = service_metadata, .action = get_deliverability_dashboard_options };
        }
    },
    Response: type = struct {
        dashboard_enabled: bool,
        subscription_expiry_date: ?i64 = null,
        account_status: ?[]const u8 = null,
        active_subscribed_domains: ?[]DomainDeliverabilityTrackingOption = null,
        pending_expiration_subscribed_domains: ?[]DomainDeliverabilityTrackingOption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_enabled = "DashboardEnabled",
                .subscription_expiry_date = "SubscriptionExpiryDate",
                .account_status = "AccountStatus",
                .active_subscribed_domains = "ActiveSubscribedDomains",
                .pending_expiration_subscribed_domains = "PendingExpirationSubscribedDomains",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        LimitExceeded,
        TooManyRequests,
    },
} = .{};
pub const get_deliverability_test_report: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/deliverability-dashboard/test-reports/{ReportId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeliverabilityTestReport",
    Request: type = struct {
        report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "ReportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deliverability_test_report) } {
            return .{ .service_metadata = service_metadata, .action = get_deliverability_test_report };
        }
    },
    Response: type = struct {
        deliverability_test_report: DeliverabilityTestReport,
        overall_placement: PlacementStatistics,
        isp_placements: []struct {
            isp_name: ?[]const u8 = null,
            placement_statistics: ?PlacementStatistics = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .isp_name = "IspName",
                    .placement_statistics = "PlacementStatistics",
                };
                return @field(mappings, field_name);
            }
        },
        message: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deliverability_test_report = "DeliverabilityTestReport",
                .overall_placement = "OverallPlacement",
                .isp_placements = "IspPlacements",
                .message = "Message",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_domain_deliverability_campaign: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/deliverability-dashboard/campaigns/{CampaignId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainDeliverabilityCampaign",
    Request: type = struct {
        campaign_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_id = "CampaignId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_deliverability_campaign) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_deliverability_campaign };
        }
    },
    Response: type = struct {
        domain_deliverability_campaign: DomainDeliverabilityCampaign,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_deliverability_campaign = "DomainDeliverabilityCampaign",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_domain_statistics_report: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/deliverability-dashboard/statistics-report/{Domain}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainStatisticsReport",
    Request: type = struct {
        domain: []const u8,
        start_date: i64,
        end_date: i64,

        pub const http_query = .{
            .start_date = "StartDate",
            .end_date = "EndDate",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "Domain",
                .start_date = "StartDate",
                .end_date = "EndDate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_statistics_report) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_statistics_report };
        }
    },
    Response: type = struct {
        overall_volume: struct {
            volume_statistics: ?VolumeStatistics = null,
            read_rate_percent: ?f64 = null,
            domain_isp_placements: ?[]DomainIspPlacement = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .volume_statistics = "VolumeStatistics",
                    .read_rate_percent = "ReadRatePercent",
                    .domain_isp_placements = "DomainIspPlacements",
                };
                return @field(mappings, field_name);
            }
        },
        daily_volumes: []struct {
            start_date: ?i64 = null,
            volume_statistics: ?VolumeStatistics = null,
            domain_isp_placements: ?[]DomainIspPlacement = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_date = "StartDate",
                    .volume_statistics = "VolumeStatistics",
                    .domain_isp_placements = "DomainIspPlacements",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .overall_volume = "OverallVolume",
                .daily_volumes = "DailyVolumes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_email_identity: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/identities/{EmailIdentity}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEmailIdentity",
    Request: type = struct {
        email_identity: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_email_identity) } {
            return .{ .service_metadata = service_metadata, .action = get_email_identity };
        }
    },
    Response: type = struct {
        identity_type: ?[]const u8 = null,
        feedback_forwarding_status: ?bool = null,
        verified_for_sending_status: ?bool = null,
        dkim_attributes: ?DkimAttributes = null,
        mail_from_attributes: ?struct {
            mail_from_domain: []const u8,
            mail_from_domain_status: []const u8,
            behavior_on_mx_failure: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mail_from_domain = "MailFromDomain",
                    .mail_from_domain_status = "MailFromDomainStatus",
                    .behavior_on_mx_failure = "BehaviorOnMxFailure",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_type = "IdentityType",
                .feedback_forwarding_status = "FeedbackForwardingStatus",
                .verified_for_sending_status = "VerifiedForSendingStatus",
                .dkim_attributes = "DkimAttributes",
                .mail_from_attributes = "MailFromAttributes",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_configuration_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/configuration-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConfigurationSets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configuration_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_configuration_sets };
        }
    },
    Response: type = struct {
        configuration_sets: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_sets = "ConfigurationSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_dedicated_ip_pools: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/dedicated-ip-pools",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDedicatedIpPools",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dedicated_ip_pools) } {
            return .{ .service_metadata = service_metadata, .action = list_dedicated_ip_pools };
        }
    },
    Response: type = struct {
        dedicated_ip_pools: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_ip_pools = "DedicatedIpPools",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_deliverability_test_reports: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/deliverability-dashboard/test-reports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeliverabilityTestReports",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_deliverability_test_reports) } {
            return .{ .service_metadata = service_metadata, .action = list_deliverability_test_reports };
        }
    },
    Response: type = struct {
        deliverability_test_reports: []DeliverabilityTestReport,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deliverability_test_reports = "DeliverabilityTestReports",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_domain_deliverability_campaigns: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/deliverability-dashboard/domains/{SubscribedDomain}/campaigns",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomainDeliverabilityCampaigns",
    Request: type = struct {
        start_date: i64,
        end_date: i64,
        subscribed_domain: []const u8,
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .start_date = "StartDate",
            .end_date = "EndDate",
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_date = "StartDate",
                .end_date = "EndDate",
                .subscribed_domain = "SubscribedDomain",
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domain_deliverability_campaigns) } {
            return .{ .service_metadata = service_metadata, .action = list_domain_deliverability_campaigns };
        }
    },
    Response: type = struct {
        domain_deliverability_campaigns: []DomainDeliverabilityCampaign,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_deliverability_campaigns = "DomainDeliverabilityCampaigns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_email_identities: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/identities",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEmailIdentities",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_email_identities) } {
            return .{ .service_metadata = service_metadata, .action = list_email_identities };
        }
    },
    Response: type = struct {
        email_identities: ?[]struct {
            identity_type: ?[]const u8 = null,
            identity_name: ?[]const u8 = null,
            sending_enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identity_type = "IdentityType",
                    .identity_name = "IdentityName",
                    .sending_enabled = "SendingEnabled",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identities = "EmailIdentities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/email/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "ResourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_account_dedicated_ip_warmup_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/account/dedicated-ips/warmup",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccountDedicatedIpWarmupAttributes",
    Request: type = struct {
        auto_warmup_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_warmup_enabled = "AutoWarmupEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_dedicated_ip_warmup_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_account_dedicated_ip_warmup_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const put_account_sending_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/account/sending",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccountSendingAttributes",
    Request: type = struct {
        sending_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sending_enabled = "SendingEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_sending_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_account_sending_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const put_configuration_set_delivery_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/configuration-sets/{ConfigurationSetName}/delivery-options",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfigurationSetDeliveryOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        tls_policy: ?[]const u8 = null,
        sending_pool_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .tls_policy = "TlsPolicy",
                .sending_pool_name = "SendingPoolName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_delivery_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_delivery_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_configuration_set_reputation_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/configuration-sets/{ConfigurationSetName}/reputation-options",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfigurationSetReputationOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        reputation_metrics_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .reputation_metrics_enabled = "ReputationMetricsEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_reputation_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_reputation_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_configuration_set_sending_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/configuration-sets/{ConfigurationSetName}/sending",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfigurationSetSendingOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        sending_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .sending_enabled = "SendingEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_sending_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_sending_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_configuration_set_tracking_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/configuration-sets/{ConfigurationSetName}/tracking-options",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfigurationSetTrackingOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        custom_redirect_domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .custom_redirect_domain = "CustomRedirectDomain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_tracking_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_tracking_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_dedicated_ip_in_pool: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/dedicated-ips/{Ip}/pool",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDedicatedIpInPool",
    Request: type = struct {
        ip: []const u8,
        destination_pool_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip = "Ip",
                .destination_pool_name = "DestinationPoolName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_dedicated_ip_in_pool) } {
            return .{ .service_metadata = service_metadata, .action = put_dedicated_ip_in_pool };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_dedicated_ip_warmup_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/dedicated-ips/{Ip}/warmup",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDedicatedIpWarmupAttributes",
    Request: type = struct {
        ip: []const u8,
        warmup_percentage: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip = "Ip",
                .warmup_percentage = "WarmupPercentage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_dedicated_ip_warmup_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_dedicated_ip_warmup_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_deliverability_dashboard_option: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/deliverability-dashboard",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDeliverabilityDashboardOption",
    Request: type = struct {
        dashboard_enabled: bool,
        subscribed_domains: ?[]DomainDeliverabilityTrackingOption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_enabled = "DashboardEnabled",
                .subscribed_domains = "SubscribedDomains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_deliverability_dashboard_option) } {
            return .{ .service_metadata = service_metadata, .action = put_deliverability_dashboard_option };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_email_identity_dkim_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/identities/{EmailIdentity}/dkim",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEmailIdentityDkimAttributes",
    Request: type = struct {
        email_identity: []const u8,
        signing_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .signing_enabled = "SigningEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_email_identity_dkim_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_email_identity_dkim_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_email_identity_feedback_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/identities/{EmailIdentity}/feedback",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEmailIdentityFeedbackAttributes",
    Request: type = struct {
        email_identity: []const u8,
        email_forwarding_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .email_forwarding_enabled = "EmailForwardingEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_email_identity_feedback_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_email_identity_feedback_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_email_identity_mail_from_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/identities/{EmailIdentity}/mail-from",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEmailIdentityMailFromAttributes",
    Request: type = struct {
        email_identity: []const u8,
        mail_from_domain: ?[]const u8 = null,
        behavior_on_mx_failure: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .mail_from_domain = "MailFromDomain",
                .behavior_on_mx_failure = "BehaviorOnMxFailure",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_email_identity_mail_from_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_email_identity_mail_from_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const send_email: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/email/outbound-emails",
        .success_code = 200,
    };

    action_name: []const u8 = "SendEmail",
    Request: type = struct {
        from_email_address: ?[]const u8 = null,
        destination: struct {
            to_addresses: ?[][]const u8 = null,
            cc_addresses: ?[][]const u8 = null,
            bcc_addresses: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .to_addresses = "ToAddresses",
                    .cc_addresses = "CcAddresses",
                    .bcc_addresses = "BccAddresses",
                };
                return @field(mappings, field_name);
            }
        },
        reply_to_addresses: ?[][]const u8 = null,
        feedback_forwarding_email_address: ?[]const u8 = null,
        content: EmailContent,
        email_tags: ?[]struct {
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        configuration_set_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .from_email_address = "FromEmailAddress",
                .destination = "Destination",
                .reply_to_addresses = "ReplyToAddresses",
                .feedback_forwarding_email_address = "FeedbackForwardingEmailAddress",
                .content = "Content",
                .email_tags = "EmailTags",
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_email) } {
            return .{ .service_metadata = service_metadata, .action = send_email };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountSuspended,
        BadRequest,
        LimitExceeded,
        MailFromDomainNotVerified,
        MessageRejected,
        NotFound,
        SendingPaused,
        TooManyRequests,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/email/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/email/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "ResourceArn",
            .tag_keys = "TagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_configuration_set_event_destination: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/configuration-sets/{ConfigurationSetName}/event-destinations/{EventDestinationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,
        event_destination: EventDestinationDefinition,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
                .event_destination = "EventDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const EventDestinationDefinition = struct {
    enabled: ?bool = null,
    matching_event_types: ?[][]const u8 = null,
    kinesis_firehose_destination: ?KinesisFirehoseDestination = null,
    cloud_watch_destination: ?CloudWatchDestination = null,
    sns_destination: ?SnsDestination = null,
    pinpoint_destination: ?PinpointDestination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .matching_event_types = "MatchingEventTypes",
            .kinesis_firehose_destination = "KinesisFirehoseDestination",
            .cloud_watch_destination = "CloudWatchDestination",
            .sns_destination = "SnsDestination",
            .pinpoint_destination = "PinpointDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const PinpointDestination = struct {
    application_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_arn = "ApplicationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SnsDestination = struct {
    topic_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchDestination = struct {
    dimension_configurations: []CloudWatchDimensionConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_configurations = "DimensionConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchDimensionConfiguration = struct {
    dimension_name: []const u8,
    dimension_value_source: []const u8,
    default_dimension_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_name = "DimensionName",
            .dimension_value_source = "DimensionValueSource",
            .default_dimension_value = "DefaultDimensionValue",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisFirehoseDestination = struct {
    iam_role_arn: []const u8,
    delivery_stream_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iam_role_arn = "IamRoleArn",
            .delivery_stream_arn = "DeliveryStreamArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const EmailContent = struct {
    simple: ?Message = null,
    raw: ?RawMessage = null,
    template: ?Template = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple = "Simple",
            .raw = "Raw",
            .template = "Template",
        };
        return @field(mappings, field_name);
    }
};

pub const Template = struct {
    template_arn: ?[]const u8 = null,
    template_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .template_arn = "TemplateArn",
            .template_data = "TemplateData",
        };
        return @field(mappings, field_name);
    }
};

pub const RawMessage = struct {
    data: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
        };
        return @field(mappings, field_name);
    }
};

pub const Message = struct {
    subject: Content,
    body: Body,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subject = "Subject",
            .body = "Body",
        };
        return @field(mappings, field_name);
    }
};

pub const Body = struct {
    text: ?Content = null,
    html: ?Content = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .html = "Html",
        };
        return @field(mappings, field_name);
    }
};

pub const Content = struct {
    data: []const u8,
    charset: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
            .charset = "Charset",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainDeliverabilityTrackingOption = struct {
    domain: ?[]const u8 = null,
    subscription_start_date: ?i64 = null,
    inbox_placement_tracking_option: ?InboxPlacementTrackingOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
            .subscription_start_date = "SubscriptionStartDate",
            .inbox_placement_tracking_option = "InboxPlacementTrackingOption",
        };
        return @field(mappings, field_name);
    }
};

pub const InboxPlacementTrackingOption = struct {
    global: ?bool = null,
    tracked_isps: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global = "Global",
            .tracked_isps = "TrackedIsps",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainDeliverabilityCampaign = struct {
    campaign_id: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    subject: ?[]const u8 = null,
    from_address: ?[]const u8 = null,
    sending_ips: ?[][]const u8 = null,
    first_seen_date_time: ?i64 = null,
    last_seen_date_time: ?i64 = null,
    inbox_count: ?i64 = null,
    spam_count: ?i64 = null,
    read_rate: ?f64 = null,
    delete_rate: ?f64 = null,
    read_delete_rate: ?f64 = null,
    projected_volume: ?i64 = null,
    esps: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .campaign_id = "CampaignId",
            .image_url = "ImageUrl",
            .subject = "Subject",
            .from_address = "FromAddress",
            .sending_ips = "SendingIps",
            .first_seen_date_time = "FirstSeenDateTime",
            .last_seen_date_time = "LastSeenDateTime",
            .inbox_count = "InboxCount",
            .spam_count = "SpamCount",
            .read_rate = "ReadRate",
            .delete_rate = "DeleteRate",
            .read_delete_rate = "ReadDeleteRate",
            .projected_volume = "ProjectedVolume",
            .esps = "Esps",
        };
        return @field(mappings, field_name);
    }
};

pub const DeliverabilityTestReport = struct {
    report_id: ?[]const u8 = null,
    report_name: ?[]const u8 = null,
    subject: ?[]const u8 = null,
    from_email_address: ?[]const u8 = null,
    create_date: ?i64 = null,
    deliverability_test_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report_id = "ReportId",
            .report_name = "ReportName",
            .subject = "Subject",
            .from_email_address = "FromEmailAddress",
            .create_date = "CreateDate",
            .deliverability_test_status = "DeliverabilityTestStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const DkimAttributes = struct {
    signing_enabled: ?bool = null,
    status: ?[]const u8 = null,
    tokens: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signing_enabled = "SigningEnabled",
            .status = "Status",
            .tokens = "Tokens",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainIspPlacement = struct {
    isp_name: ?[]const u8 = null,
    inbox_raw_count: ?i64 = null,
    spam_raw_count: ?i64 = null,
    inbox_percentage: ?f64 = null,
    spam_percentage: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .isp_name = "IspName",
            .inbox_raw_count = "InboxRawCount",
            .spam_raw_count = "SpamRawCount",
            .inbox_percentage = "InboxPercentage",
            .spam_percentage = "SpamPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeStatistics = struct {
    inbox_raw_count: ?i64 = null,
    spam_raw_count: ?i64 = null,
    projected_inbox: ?i64 = null,
    projected_spam: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inbox_raw_count = "InboxRawCount",
            .spam_raw_count = "SpamRawCount",
            .projected_inbox = "ProjectedInbox",
            .projected_spam = "ProjectedSpam",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacementStatistics = struct {
    inbox_percentage: ?f64 = null,
    spam_percentage: ?f64 = null,
    missing_percentage: ?f64 = null,
    spf_percentage: ?f64 = null,
    dkim_percentage: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inbox_percentage = "InboxPercentage",
            .spam_percentage = "SpamPercentage",
            .missing_percentage = "MissingPercentage",
            .spf_percentage = "SpfPercentage",
            .dkim_percentage = "DkimPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const DedicatedIp = struct {
    ip: []const u8,
    warmup_status: []const u8,
    warmup_percentage: i64,
    pool_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip = "Ip",
            .warmup_status = "WarmupStatus",
            .warmup_percentage = "WarmupPercentage",
            .pool_name = "PoolName",
        };
        return @field(mappings, field_name);
    }
};

pub const SendingOptions = struct {
    sending_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sending_enabled = "SendingEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ReputationOptions = struct {
    reputation_metrics_enabled: ?bool = null,
    last_fresh_start: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reputation_metrics_enabled = "ReputationMetricsEnabled",
            .last_fresh_start = "LastFreshStart",
        };
        return @field(mappings, field_name);
    }
};

pub const DeliveryOptions = struct {
    tls_policy: ?[]const u8 = null,
    sending_pool_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tls_policy = "TlsPolicy",
            .sending_pool_name = "SendingPoolName",
        };
        return @field(mappings, field_name);
    }
};

pub const TrackingOptions = struct {
    custom_redirect_domain: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_redirect_domain = "CustomRedirectDomain",
        };
        return @field(mappings, field_name);
    }
};
