const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-09-05";
pub const sdk_id: []const u8 = "Pinpoint SMS Voice";
pub const arn_namespace: ?[]const u8 = "sms-voice";
pub const endpoint_prefix: []const u8 = "sms-voice.pinpoint";
pub const sigv4_name: []const u8 = "sms-voice";
pub const name: []const u8 = "PinpointSMSVoice";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-09-05",
    sdk_id: []const u8 = "Pinpoint SMS Voice",
    arn_namespace: ?[]const u8 = "sms-voice",
    endpoint_prefix: []const u8 = "sms-voice.pinpoint",
    sigv4_name: []const u8 = "sms-voice",
    name: []const u8 = "PinpointSMSVoice",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_configuration_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/sms-voice/configuration-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConfigurationSet",
    Request: type = struct {
        configuration_set_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        InternalServiceError,
        LimitExceeded,
        TooManyRequests,
    },
} = .{};
pub const create_configuration_set_event_destination: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/sms-voice/configuration-sets/{ConfigurationSetName}/event-destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination: ?EventDestinationDefinition = null,
        event_destination_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination = "EventDestination",
                .event_destination_name = "EventDestinationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        InternalServiceError,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_configuration_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/sms-voice/configuration-sets/{ConfigurationSetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServiceError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_configuration_set_event_destination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/sms-voice/configuration-sets/{ConfigurationSetName}/event-destinations/{EventDestinationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServiceError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_configuration_set_event_destinations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/sms-voice/configuration-sets/{ConfigurationSetName}/event-destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfigurationSetEventDestinations",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration_set_event_destinations) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration_set_event_destinations };
        }
    },
    Response: type = struct {
        event_destinations: ?[]struct {
            cloud_watch_logs_destination: ?CloudWatchLogsDestination = null,
            enabled: ?bool = null,
            kinesis_firehose_destination: ?KinesisFirehoseDestination = null,
            matching_event_types: ?[][]const u8 = null,
            name: ?[]const u8 = null,
            sns_destination: ?SnsDestination = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cloud_watch_logs_destination = "CloudWatchLogsDestination",
                    .enabled = "Enabled",
                    .kinesis_firehose_destination = "KinesisFirehoseDestination",
                    .matching_event_types = "MatchingEventTypes",
                    .name = "Name",
                    .sns_destination = "SnsDestination",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_destinations = "EventDestinations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServiceError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_configuration_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/sms-voice/configuration-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConfigurationSets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configuration_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_configuration_sets };
        }
    },
    Response: type = struct {
        configuration_sets: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_sets = "ConfigurationSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServiceError,
        TooManyRequests,
    },
} = .{};
pub const send_voice_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/sms-voice/voice/message",
        .success_code = 200,
    };

    action_name: []const u8 = "SendVoiceMessage",
    Request: type = struct {
        caller_id: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        content: ?struct {
            call_instructions_message: ?struct {
                text: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .text = "Text",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            plain_text_message: ?struct {
                language_code: ?[]const u8 = null,
                text: ?[]const u8 = null,
                voice_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .language_code = "LanguageCode",
                        .text = "Text",
                        .voice_id = "VoiceId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            ssml_message: ?struct {
                language_code: ?[]const u8 = null,
                text: ?[]const u8 = null,
                voice_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .language_code = "LanguageCode",
                        .text = "Text",
                        .voice_id = "VoiceId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .call_instructions_message = "CallInstructionsMessage",
                    .plain_text_message = "PlainTextMessage",
                    .ssml_message = "SSMLMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        destination_phone_number: ?[]const u8 = null,
        origination_phone_number: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .caller_id = "CallerId",
                .configuration_set_name = "ConfigurationSetName",
                .content = "Content",
                .destination_phone_number = "DestinationPhoneNumber",
                .origination_phone_number = "OriginationPhoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_voice_message) } {
            return .{ .service_metadata = service_metadata, .action = send_voice_message };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServiceError,
        TooManyRequests,
    },
} = .{};
pub const update_configuration_set_event_destination: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/sms-voice/configuration-sets/{ConfigurationSetName}/event-destinations/{EventDestinationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination: ?EventDestinationDefinition = null,
        event_destination_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination = "EventDestination",
                .event_destination_name = "EventDestinationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServiceError,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const EventDestinationDefinition = struct {
    cloud_watch_logs_destination: ?CloudWatchLogsDestination = null,
    enabled: ?bool = null,
    kinesis_firehose_destination: ?KinesisFirehoseDestination = null,
    matching_event_types: ?[][]const u8 = null,
    sns_destination: ?SnsDestination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_destination = "CloudWatchLogsDestination",
            .enabled = "Enabled",
            .kinesis_firehose_destination = "KinesisFirehoseDestination",
            .matching_event_types = "MatchingEventTypes",
            .sns_destination = "SnsDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const SnsDestination = struct {
    topic_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisFirehoseDestination = struct {
    delivery_stream_arn: ?[]const u8 = null,
    iam_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_stream_arn = "DeliveryStreamArn",
            .iam_role_arn = "IamRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogsDestination = struct {
    iam_role_arn: ?[]const u8 = null,
    log_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iam_role_arn = "IamRoleArn",
            .log_group_arn = "LogGroupArn",
        };
        return @field(mappings, field_name);
    }
};
