const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-03-31";
pub const sdk_id: []const u8 = "Pinpoint SMS Voice V2";
pub const arn_namespace: ?[]const u8 = "sms-voice";
pub const endpoint_prefix: []const u8 = "sms-voice";
pub const sigv4_name: []const u8 = "sms-voice";
pub const name: []const u8 = "PinpointSMSVoiceV2";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2022-03-31",
    sdk_id: []const u8 = "Pinpoint SMS Voice V2",
    arn_namespace: ?[]const u8 = "sms-voice",
    endpoint_prefix: []const u8 = "sms-voice",
    sigv4_name: []const u8 = "sms-voice",
    name: []const u8 = "PinpointSMSVoiceV2",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const associate_origination_identity: struct {
    action_name: []const u8 = "AssociateOriginationIdentity",
    Request: type = struct {
        pool_id: []const u8,
        origination_identity: []const u8,
        iso_country_code: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_id = "PoolId",
                .origination_identity = "OriginationIdentity",
                .iso_country_code = "IsoCountryCode",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_origination_identity) } {
            return .{ .service_metadata = service_metadata, .action = associate_origination_identity };
        }
    },
    Response: type = struct {
        pool_arn: ?[]const u8 = null,
        pool_id: ?[]const u8 = null,
        origination_identity_arn: ?[]const u8 = null,
        origination_identity: ?[]const u8 = null,
        iso_country_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_arn = "PoolArn",
                .pool_id = "PoolId",
                .origination_identity_arn = "OriginationIdentityArn",
                .origination_identity = "OriginationIdentity",
                .iso_country_code = "IsoCountryCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_configuration_set: struct {
    action_name: []const u8 = "CreateConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_set };
        }
    },
    Response: type = struct {
        configuration_set_arn: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        tags: ?[]Tag = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_arn = "ConfigurationSetArn",
                .configuration_set_name = "ConfigurationSetName",
                .tags = "Tags",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_event_destination: struct {
    action_name: []const u8 = "CreateEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,
        matching_event_types: [][]const u8,
        cloud_watch_logs_destination: ?CloudWatchLogsDestination = null,
        kinesis_firehose_destination: ?KinesisFirehoseDestination = null,
        sns_destination: ?SnsDestination = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
                .matching_event_types = "MatchingEventTypes",
                .cloud_watch_logs_destination = "CloudWatchLogsDestination",
                .kinesis_firehose_destination = "KinesisFirehoseDestination",
                .sns_destination = "SnsDestination",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_event_destination };
        }
    },
    Response: type = struct {
        configuration_set_arn: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        event_destination: ?EventDestination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_arn = "ConfigurationSetArn",
                .configuration_set_name = "ConfigurationSetName",
                .event_destination = "EventDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_opt_out_list: struct {
    action_name: []const u8 = "CreateOptOutList",
    Request: type = struct {
        opt_out_list_name: []const u8,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_name = "OptOutListName",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_opt_out_list) } {
            return .{ .service_metadata = service_metadata, .action = create_opt_out_list };
        }
    },
    Response: type = struct {
        opt_out_list_arn: ?[]const u8 = null,
        opt_out_list_name: ?[]const u8 = null,
        tags: ?[]Tag = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_arn = "OptOutListArn",
                .opt_out_list_name = "OptOutListName",
                .tags = "Tags",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_pool: struct {
    action_name: []const u8 = "CreatePool",
    Request: type = struct {
        origination_identity: []const u8,
        iso_country_code: []const u8,
        message_type: []const u8,
        deletion_protection_enabled: ?bool = null,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination_identity = "OriginationIdentity",
                .iso_country_code = "IsoCountryCode",
                .message_type = "MessageType",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_pool };
        }
    },
    Response: type = struct {
        pool_arn: ?[]const u8 = null,
        pool_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        message_type: ?[]const u8 = null,
        two_way_enabled: ?bool = null,
        two_way_channel_arn: ?[]const u8 = null,
        two_way_channel_role: ?[]const u8 = null,
        self_managed_opt_outs_enabled: ?bool = null,
        opt_out_list_name: ?[]const u8 = null,
        shared_routes_enabled: ?bool = null,
        deletion_protection_enabled: ?bool = null,
        tags: ?[]Tag = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_arn = "PoolArn",
                .pool_id = "PoolId",
                .status = "Status",
                .message_type = "MessageType",
                .two_way_enabled = "TwoWayEnabled",
                .two_way_channel_arn = "TwoWayChannelArn",
                .two_way_channel_role = "TwoWayChannelRole",
                .self_managed_opt_outs_enabled = "SelfManagedOptOutsEnabled",
                .opt_out_list_name = "OptOutListName",
                .shared_routes_enabled = "SharedRoutesEnabled",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
                .tags = "Tags",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_registration: struct {
    action_name: []const u8 = "CreateRegistration",
    Request: type = struct {
        registration_type: []const u8,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_type = "RegistrationType",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_registration) } {
            return .{ .service_metadata = service_metadata, .action = create_registration };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        registration_type: []const u8,
        registration_status: []const u8,
        current_version_number: i64,
        additional_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]Tag = null,
        created_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .registration_type = "RegistrationType",
                .registration_status = "RegistrationStatus",
                .current_version_number = "CurrentVersionNumber",
                .additional_attributes = "AdditionalAttributes",
                .tags = "Tags",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_attributes", field_name))
                return try serializeMap(self.additional_attributes, self.fieldNameFor("additional_attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_registration_association: struct {
    action_name: []const u8 = "CreateRegistrationAssociation",
    Request: type = struct {
        registration_id: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_id = "RegistrationId",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_registration_association) } {
            return .{ .service_metadata = service_metadata, .action = create_registration_association };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        registration_type: []const u8,
        resource_arn: []const u8,
        resource_id: []const u8,
        resource_type: []const u8,
        iso_country_code: ?[]const u8 = null,
        phone_number: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .registration_type = "RegistrationType",
                .resource_arn = "ResourceArn",
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
                .iso_country_code = "IsoCountryCode",
                .phone_number = "PhoneNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_registration_attachment: struct {
    action_name: []const u8 = "CreateRegistrationAttachment",
    Request: type = struct {
        attachment_body: ?[]const u8 = null,
        attachment_url: ?[]const u8 = null,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_body = "AttachmentBody",
                .attachment_url = "AttachmentUrl",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_registration_attachment) } {
            return .{ .service_metadata = service_metadata, .action = create_registration_attachment };
        }
    },
    Response: type = struct {
        registration_attachment_arn: []const u8,
        registration_attachment_id: []const u8,
        attachment_status: []const u8,
        tags: ?[]Tag = null,
        created_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_attachment_arn = "RegistrationAttachmentArn",
                .registration_attachment_id = "RegistrationAttachmentId",
                .attachment_status = "AttachmentStatus",
                .tags = "Tags",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_registration_version: struct {
    action_name: []const u8 = "CreateRegistrationVersion",
    Request: type = struct {
        registration_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_id = "RegistrationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_registration_version) } {
            return .{ .service_metadata = service_metadata, .action = create_registration_version };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        version_number: i64,
        registration_version_status: []const u8,
        registration_version_status_history: RegistrationVersionStatusHistory,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .version_number = "VersionNumber",
                .registration_version_status = "RegistrationVersionStatus",
                .registration_version_status_history = "RegistrationVersionStatusHistory",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_verified_destination_number: struct {
    action_name: []const u8 = "CreateVerifiedDestinationNumber",
    Request: type = struct {
        destination_phone_number: []const u8,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_phone_number = "DestinationPhoneNumber",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_verified_destination_number) } {
            return .{ .service_metadata = service_metadata, .action = create_verified_destination_number };
        }
    },
    Response: type = struct {
        verified_destination_number_arn: []const u8,
        verified_destination_number_id: []const u8,
        destination_phone_number: []const u8,
        status: []const u8,
        tags: ?[]Tag = null,
        created_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_destination_number_arn = "VerifiedDestinationNumberArn",
                .verified_destination_number_id = "VerifiedDestinationNumberId",
                .destination_phone_number = "DestinationPhoneNumber",
                .status = "Status",
                .tags = "Tags",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_configuration_set: struct {
    action_name: []const u8 = "DeleteConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_set };
        }
    },
    Response: type = struct {
        configuration_set_arn: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        event_destinations: ?[]EventDestination = null,
        default_message_type: ?[]const u8 = null,
        default_sender_id: ?[]const u8 = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_arn = "ConfigurationSetArn",
                .configuration_set_name = "ConfigurationSetName",
                .event_destinations = "EventDestinations",
                .default_message_type = "DefaultMessageType",
                .default_sender_id = "DefaultSenderId",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_default_message_type: struct {
    action_name: []const u8 = "DeleteDefaultMessageType",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_default_message_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_default_message_type };
        }
    },
    Response: type = struct {
        configuration_set_arn: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        message_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_arn = "ConfigurationSetArn",
                .configuration_set_name = "ConfigurationSetName",
                .message_type = "MessageType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_default_sender_id: struct {
    action_name: []const u8 = "DeleteDefaultSenderId",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_default_sender_id) } {
            return .{ .service_metadata = service_metadata, .action = delete_default_sender_id };
        }
    },
    Response: type = struct {
        configuration_set_arn: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        sender_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_arn = "ConfigurationSetArn",
                .configuration_set_name = "ConfigurationSetName",
                .sender_id = "SenderId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_event_destination: struct {
    action_name: []const u8 = "DeleteEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_destination };
        }
    },
    Response: type = struct {
        configuration_set_arn: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        event_destination: ?EventDestination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_arn = "ConfigurationSetArn",
                .configuration_set_name = "ConfigurationSetName",
                .event_destination = "EventDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_keyword: struct {
    action_name: []const u8 = "DeleteKeyword",
    Request: type = struct {
        origination_identity: []const u8,
        keyword: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination_identity = "OriginationIdentity",
                .keyword = "Keyword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_keyword) } {
            return .{ .service_metadata = service_metadata, .action = delete_keyword };
        }
    },
    Response: type = struct {
        origination_identity_arn: ?[]const u8 = null,
        origination_identity: ?[]const u8 = null,
        keyword: ?[]const u8 = null,
        keyword_message: ?[]const u8 = null,
        keyword_action: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination_identity_arn = "OriginationIdentityArn",
                .origination_identity = "OriginationIdentity",
                .keyword = "Keyword",
                .keyword_message = "KeywordMessage",
                .keyword_action = "KeywordAction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_opted_out_number: struct {
    action_name: []const u8 = "DeleteOptedOutNumber",
    Request: type = struct {
        opt_out_list_name: []const u8,
        opted_out_number: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_name = "OptOutListName",
                .opted_out_number = "OptedOutNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_opted_out_number) } {
            return .{ .service_metadata = service_metadata, .action = delete_opted_out_number };
        }
    },
    Response: type = struct {
        opt_out_list_arn: ?[]const u8 = null,
        opt_out_list_name: ?[]const u8 = null,
        opted_out_number: ?[]const u8 = null,
        opted_out_timestamp: ?i64 = null,
        end_user_opted_out: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_arn = "OptOutListArn",
                .opt_out_list_name = "OptOutListName",
                .opted_out_number = "OptedOutNumber",
                .opted_out_timestamp = "OptedOutTimestamp",
                .end_user_opted_out = "EndUserOptedOut",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_opt_out_list: struct {
    action_name: []const u8 = "DeleteOptOutList",
    Request: type = struct {
        opt_out_list_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_name = "OptOutListName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_opt_out_list) } {
            return .{ .service_metadata = service_metadata, .action = delete_opt_out_list };
        }
    },
    Response: type = struct {
        opt_out_list_arn: ?[]const u8 = null,
        opt_out_list_name: ?[]const u8 = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_arn = "OptOutListArn",
                .opt_out_list_name = "OptOutListName",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_pool: struct {
    action_name: []const u8 = "DeletePool",
    Request: type = struct {
        pool_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_id = "PoolId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_pool };
        }
    },
    Response: type = struct {
        pool_arn: ?[]const u8 = null,
        pool_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        message_type: ?[]const u8 = null,
        two_way_enabled: ?bool = null,
        two_way_channel_arn: ?[]const u8 = null,
        two_way_channel_role: ?[]const u8 = null,
        self_managed_opt_outs_enabled: ?bool = null,
        opt_out_list_name: ?[]const u8 = null,
        shared_routes_enabled: ?bool = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_arn = "PoolArn",
                .pool_id = "PoolId",
                .status = "Status",
                .message_type = "MessageType",
                .two_way_enabled = "TwoWayEnabled",
                .two_way_channel_arn = "TwoWayChannelArn",
                .two_way_channel_role = "TwoWayChannelRole",
                .self_managed_opt_outs_enabled = "SelfManagedOptOutsEnabled",
                .opt_out_list_name = "OptOutListName",
                .shared_routes_enabled = "SharedRoutesEnabled",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_registration: struct {
    action_name: []const u8 = "DeleteRegistration",
    Request: type = struct {
        registration_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_id = "RegistrationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_registration) } {
            return .{ .service_metadata = service_metadata, .action = delete_registration };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        registration_type: []const u8,
        registration_status: []const u8,
        current_version_number: i64,
        approved_version_number: ?i64 = null,
        latest_denied_version_number: ?i64 = null,
        additional_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        created_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .registration_type = "RegistrationType",
                .registration_status = "RegistrationStatus",
                .current_version_number = "CurrentVersionNumber",
                .approved_version_number = "ApprovedVersionNumber",
                .latest_denied_version_number = "LatestDeniedVersionNumber",
                .additional_attributes = "AdditionalAttributes",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_attributes", field_name))
                return try serializeMap(self.additional_attributes, self.fieldNameFor("additional_attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_registration_attachment: struct {
    action_name: []const u8 = "DeleteRegistrationAttachment",
    Request: type = struct {
        registration_attachment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_attachment_id = "RegistrationAttachmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_registration_attachment) } {
            return .{ .service_metadata = service_metadata, .action = delete_registration_attachment };
        }
    },
    Response: type = struct {
        registration_attachment_arn: []const u8,
        registration_attachment_id: []const u8,
        attachment_status: []const u8,
        attachment_upload_error_reason: ?[]const u8 = null,
        created_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_attachment_arn = "RegistrationAttachmentArn",
                .registration_attachment_id = "RegistrationAttachmentId",
                .attachment_status = "AttachmentStatus",
                .attachment_upload_error_reason = "AttachmentUploadErrorReason",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_registration_field_value: struct {
    action_name: []const u8 = "DeleteRegistrationFieldValue",
    Request: type = struct {
        registration_id: []const u8,
        field_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_id = "RegistrationId",
                .field_path = "FieldPath",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_registration_field_value) } {
            return .{ .service_metadata = service_metadata, .action = delete_registration_field_value };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        version_number: i64,
        field_path: []const u8,
        select_choices: ?[][]const u8 = null,
        text_value: ?[]const u8 = null,
        registration_attachment_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .version_number = "VersionNumber",
                .field_path = "FieldPath",
                .select_choices = "SelectChoices",
                .text_value = "TextValue",
                .registration_attachment_id = "RegistrationAttachmentId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_text_message_spend_limit_override: struct {
    action_name: []const u8 = "DeleteTextMessageSpendLimitOverride",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_text_message_spend_limit_override) } {
            return .{ .service_metadata = service_metadata, .action = delete_text_message_spend_limit_override };
        }
    },
    Response: type = struct {
        monthly_limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monthly_limit = "MonthlyLimit",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_verified_destination_number: struct {
    action_name: []const u8 = "DeleteVerifiedDestinationNumber",
    Request: type = struct {
        verified_destination_number_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_destination_number_id = "VerifiedDestinationNumberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_verified_destination_number) } {
            return .{ .service_metadata = service_metadata, .action = delete_verified_destination_number };
        }
    },
    Response: type = struct {
        verified_destination_number_arn: []const u8,
        verified_destination_number_id: []const u8,
        destination_phone_number: []const u8,
        created_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_destination_number_arn = "VerifiedDestinationNumberArn",
                .verified_destination_number_id = "VerifiedDestinationNumberId",
                .destination_phone_number = "DestinationPhoneNumber",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_voice_message_spend_limit_override: struct {
    action_name: []const u8 = "DeleteVoiceMessageSpendLimitOverride",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_message_spend_limit_override) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_message_spend_limit_override };
        }
    },
    Response: type = struct {
        monthly_limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monthly_limit = "MonthlyLimit",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_account_attributes: struct {
    action_name: []const u8 = "DescribeAccountAttributes",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_attributes };
        }
    },
    Response: type = struct {
        account_attributes: ?[]struct {
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_attributes = "AccountAttributes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_account_limits: struct {
    action_name: []const u8 = "DescribeAccountLimits",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_limits) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_limits };
        }
    },
    Response: type = struct {
        account_limits: ?[]struct {
            name: []const u8,
            used: i64,
            max: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .used = "Used",
                    .max = "Max",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_limits = "AccountLimits",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_configuration_sets: struct {
    action_name: []const u8 = "DescribeConfigurationSets",
    Request: type = struct {
        configuration_set_names: ?[][]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_names = "ConfigurationSetNames",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration_sets) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration_sets };
        }
    },
    Response: type = struct {
        configuration_sets: ?[]struct {
            configuration_set_arn: []const u8,
            configuration_set_name: []const u8,
            event_destinations: []EventDestination,
            default_message_type: ?[]const u8 = null,
            default_sender_id: ?[]const u8 = null,
            created_timestamp: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .configuration_set_arn = "ConfigurationSetArn",
                    .configuration_set_name = "ConfigurationSetName",
                    .event_destinations = "EventDestinations",
                    .default_message_type = "DefaultMessageType",
                    .default_sender_id = "DefaultSenderId",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_sets = "ConfigurationSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_keywords: struct {
    action_name: []const u8 = "DescribeKeywords",
    Request: type = struct {
        origination_identity: []const u8,
        keywords: ?[][]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination_identity = "OriginationIdentity",
                .keywords = "Keywords",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_keywords) } {
            return .{ .service_metadata = service_metadata, .action = describe_keywords };
        }
    },
    Response: type = struct {
        origination_identity_arn: ?[]const u8 = null,
        origination_identity: ?[]const u8 = null,
        keywords: ?[]struct {
            keyword: []const u8,
            keyword_message: []const u8,
            keyword_action: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .keyword = "Keyword",
                    .keyword_message = "KeywordMessage",
                    .keyword_action = "KeywordAction",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination_identity_arn = "OriginationIdentityArn",
                .origination_identity = "OriginationIdentity",
                .keywords = "Keywords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_opted_out_numbers: struct {
    action_name: []const u8 = "DescribeOptedOutNumbers",
    Request: type = struct {
        opt_out_list_name: []const u8,
        opted_out_numbers: ?[][]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_name = "OptOutListName",
                .opted_out_numbers = "OptedOutNumbers",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_opted_out_numbers) } {
            return .{ .service_metadata = service_metadata, .action = describe_opted_out_numbers };
        }
    },
    Response: type = struct {
        opt_out_list_arn: ?[]const u8 = null,
        opt_out_list_name: ?[]const u8 = null,
        opted_out_numbers: ?[]struct {
            opted_out_number: []const u8,
            opted_out_timestamp: i64,
            end_user_opted_out: bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .opted_out_number = "OptedOutNumber",
                    .opted_out_timestamp = "OptedOutTimestamp",
                    .end_user_opted_out = "EndUserOptedOut",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_arn = "OptOutListArn",
                .opt_out_list_name = "OptOutListName",
                .opted_out_numbers = "OptedOutNumbers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_opt_out_lists: struct {
    action_name: []const u8 = "DescribeOptOutLists",
    Request: type = struct {
        opt_out_list_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_names = "OptOutListNames",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_opt_out_lists) } {
            return .{ .service_metadata = service_metadata, .action = describe_opt_out_lists };
        }
    },
    Response: type = struct {
        opt_out_lists: ?[]struct {
            opt_out_list_arn: []const u8,
            opt_out_list_name: []const u8,
            created_timestamp: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .opt_out_list_arn = "OptOutListArn",
                    .opt_out_list_name = "OptOutListName",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_lists = "OptOutLists",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_phone_numbers: struct {
    action_name: []const u8 = "DescribePhoneNumbers",
    Request: type = struct {
        phone_number_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_ids = "PhoneNumberIds",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_phone_numbers) } {
            return .{ .service_metadata = service_metadata, .action = describe_phone_numbers };
        }
    },
    Response: type = struct {
        phone_numbers: ?[]struct {
            phone_number_arn: []const u8,
            phone_number_id: ?[]const u8 = null,
            phone_number: []const u8,
            status: []const u8,
            iso_country_code: []const u8,
            message_type: []const u8,
            number_capabilities: [][]const u8,
            number_type: []const u8,
            monthly_leasing_price: []const u8,
            two_way_enabled: bool,
            two_way_channel_arn: ?[]const u8 = null,
            two_way_channel_role: ?[]const u8 = null,
            self_managed_opt_outs_enabled: bool,
            opt_out_list_name: []const u8,
            deletion_protection_enabled: bool,
            pool_id: ?[]const u8 = null,
            registration_id: ?[]const u8 = null,
            created_timestamp: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .phone_number_arn = "PhoneNumberArn",
                    .phone_number_id = "PhoneNumberId",
                    .phone_number = "PhoneNumber",
                    .status = "Status",
                    .iso_country_code = "IsoCountryCode",
                    .message_type = "MessageType",
                    .number_capabilities = "NumberCapabilities",
                    .number_type = "NumberType",
                    .monthly_leasing_price = "MonthlyLeasingPrice",
                    .two_way_enabled = "TwoWayEnabled",
                    .two_way_channel_arn = "TwoWayChannelArn",
                    .two_way_channel_role = "TwoWayChannelRole",
                    .self_managed_opt_outs_enabled = "SelfManagedOptOutsEnabled",
                    .opt_out_list_name = "OptOutListName",
                    .deletion_protection_enabled = "DeletionProtectionEnabled",
                    .pool_id = "PoolId",
                    .registration_id = "RegistrationId",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_numbers = "PhoneNumbers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_pools: struct {
    action_name: []const u8 = "DescribePools",
    Request: type = struct {
        pool_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_ids = "PoolIds",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pools) } {
            return .{ .service_metadata = service_metadata, .action = describe_pools };
        }
    },
    Response: type = struct {
        pools: ?[]struct {
            pool_arn: []const u8,
            pool_id: []const u8,
            status: []const u8,
            message_type: []const u8,
            two_way_enabled: bool,
            two_way_channel_arn: ?[]const u8 = null,
            two_way_channel_role: ?[]const u8 = null,
            self_managed_opt_outs_enabled: bool,
            opt_out_list_name: []const u8,
            shared_routes_enabled: bool,
            deletion_protection_enabled: bool,
            created_timestamp: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pool_arn = "PoolArn",
                    .pool_id = "PoolId",
                    .status = "Status",
                    .message_type = "MessageType",
                    .two_way_enabled = "TwoWayEnabled",
                    .two_way_channel_arn = "TwoWayChannelArn",
                    .two_way_channel_role = "TwoWayChannelRole",
                    .self_managed_opt_outs_enabled = "SelfManagedOptOutsEnabled",
                    .opt_out_list_name = "OptOutListName",
                    .shared_routes_enabled = "SharedRoutesEnabled",
                    .deletion_protection_enabled = "DeletionProtectionEnabled",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pools = "Pools",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_registration_attachments: struct {
    action_name: []const u8 = "DescribeRegistrationAttachments",
    Request: type = struct {
        registration_attachment_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_attachment_ids = "RegistrationAttachmentIds",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_registration_attachments) } {
            return .{ .service_metadata = service_metadata, .action = describe_registration_attachments };
        }
    },
    Response: type = struct {
        registration_attachments: []struct {
            registration_attachment_arn: []const u8,
            registration_attachment_id: []const u8,
            attachment_status: []const u8,
            attachment_upload_error_reason: ?[]const u8 = null,
            created_timestamp: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registration_attachment_arn = "RegistrationAttachmentArn",
                    .registration_attachment_id = "RegistrationAttachmentId",
                    .attachment_status = "AttachmentStatus",
                    .attachment_upload_error_reason = "AttachmentUploadErrorReason",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_attachments = "RegistrationAttachments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_registration_field_definitions: struct {
    action_name: []const u8 = "DescribeRegistrationFieldDefinitions",
    Request: type = struct {
        registration_type: []const u8,
        section_path: ?[]const u8 = null,
        field_paths: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_type = "RegistrationType",
                .section_path = "SectionPath",
                .field_paths = "FieldPaths",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_registration_field_definitions) } {
            return .{ .service_metadata = service_metadata, .action = describe_registration_field_definitions };
        }
    },
    Response: type = struct {
        registration_type: []const u8,
        registration_field_definitions: []struct {
            section_path: []const u8,
            field_path: []const u8,
            field_type: []const u8,
            field_requirement: []const u8,
            select_validation: ?struct {
                min_choices: i64,
                max_choices: i64,
                options: [][]const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .min_choices = "MinChoices",
                        .max_choices = "MaxChoices",
                        .options = "Options",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            text_validation: ?struct {
                min_length: i64,
                max_length: i64,
                pattern: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .min_length = "MinLength",
                        .max_length = "MaxLength",
                        .pattern = "Pattern",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            display_hints: struct {
                title: []const u8,
                short_description: []const u8,
                long_description: ?[]const u8 = null,
                documentation_title: ?[]const u8 = null,
                documentation_link: ?[]const u8 = null,
                select_option_descriptions: ?[]struct {
                    option: []const u8,
                    title: ?[]const u8 = null,
                    description: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .option = "Option",
                            .title = "Title",
                            .description = "Description",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                text_validation_description: ?[]const u8 = null,
                example_text_value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .title = "Title",
                        .short_description = "ShortDescription",
                        .long_description = "LongDescription",
                        .documentation_title = "DocumentationTitle",
                        .documentation_link = "DocumentationLink",
                        .select_option_descriptions = "SelectOptionDescriptions",
                        .text_validation_description = "TextValidationDescription",
                        .example_text_value = "ExampleTextValue",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .section_path = "SectionPath",
                    .field_path = "FieldPath",
                    .field_type = "FieldType",
                    .field_requirement = "FieldRequirement",
                    .select_validation = "SelectValidation",
                    .text_validation = "TextValidation",
                    .display_hints = "DisplayHints",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_type = "RegistrationType",
                .registration_field_definitions = "RegistrationFieldDefinitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_registration_field_values: struct {
    action_name: []const u8 = "DescribeRegistrationFieldValues",
    Request: type = struct {
        registration_id: []const u8,
        version_number: ?i64 = null,
        section_path: ?[]const u8 = null,
        field_paths: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_id = "RegistrationId",
                .version_number = "VersionNumber",
                .section_path = "SectionPath",
                .field_paths = "FieldPaths",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_registration_field_values) } {
            return .{ .service_metadata = service_metadata, .action = describe_registration_field_values };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        version_number: i64,
        registration_field_values: []struct {
            field_path: []const u8,
            select_choices: ?[][]const u8 = null,
            text_value: ?[]const u8 = null,
            registration_attachment_id: ?[]const u8 = null,
            denied_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field_path = "FieldPath",
                    .select_choices = "SelectChoices",
                    .text_value = "TextValue",
                    .registration_attachment_id = "RegistrationAttachmentId",
                    .denied_reason = "DeniedReason",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .version_number = "VersionNumber",
                .registration_field_values = "RegistrationFieldValues",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_registrations: struct {
    action_name: []const u8 = "DescribeRegistrations",
    Request: type = struct {
        registration_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_ids = "RegistrationIds",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_registrations) } {
            return .{ .service_metadata = service_metadata, .action = describe_registrations };
        }
    },
    Response: type = struct {
        registrations: []struct {
            registration_arn: []const u8,
            registration_id: []const u8,
            registration_type: []const u8,
            registration_status: []const u8,
            current_version_number: i64,
            approved_version_number: ?i64 = null,
            latest_denied_version_number: ?i64 = null,
            additional_attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            created_timestamp: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registration_arn = "RegistrationArn",
                    .registration_id = "RegistrationId",
                    .registration_type = "RegistrationType",
                    .registration_status = "RegistrationStatus",
                    .current_version_number = "CurrentVersionNumber",
                    .approved_version_number = "ApprovedVersionNumber",
                    .latest_denied_version_number = "LatestDeniedVersionNumber",
                    .additional_attributes = "AdditionalAttributes",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "additional_attributes", field_name))
                    return try serializeMap(self.additional_attributes, self.fieldNameFor("additional_attributes"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registrations = "Registrations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_registration_section_definitions: struct {
    action_name: []const u8 = "DescribeRegistrationSectionDefinitions",
    Request: type = struct {
        registration_type: []const u8,
        section_paths: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_type = "RegistrationType",
                .section_paths = "SectionPaths",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_registration_section_definitions) } {
            return .{ .service_metadata = service_metadata, .action = describe_registration_section_definitions };
        }
    },
    Response: type = struct {
        registration_type: []const u8,
        registration_section_definitions: []struct {
            section_path: []const u8,
            display_hints: struct {
                title: []const u8,
                short_description: []const u8,
                long_description: ?[]const u8 = null,
                documentation_title: ?[]const u8 = null,
                documentation_link: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .title = "Title",
                        .short_description = "ShortDescription",
                        .long_description = "LongDescription",
                        .documentation_title = "DocumentationTitle",
                        .documentation_link = "DocumentationLink",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .section_path = "SectionPath",
                    .display_hints = "DisplayHints",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_type = "RegistrationType",
                .registration_section_definitions = "RegistrationSectionDefinitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_registration_type_definitions: struct {
    action_name: []const u8 = "DescribeRegistrationTypeDefinitions",
    Request: type = struct {
        registration_types: ?[][]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_types = "RegistrationTypes",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_registration_type_definitions) } {
            return .{ .service_metadata = service_metadata, .action = describe_registration_type_definitions };
        }
    },
    Response: type = struct {
        registration_type_definitions: []struct {
            registration_type: []const u8,
            supported_associations: ?[]struct {
                resource_type: []const u8,
                iso_country_code: ?[]const u8 = null,
                association_behavior: []const u8,
                disassociation_behavior: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "ResourceType",
                        .iso_country_code = "IsoCountryCode",
                        .association_behavior = "AssociationBehavior",
                        .disassociation_behavior = "DisassociationBehavior",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            display_hints: struct {
                title: []const u8,
                short_description: ?[]const u8 = null,
                long_description: ?[]const u8 = null,
                documentation_title: ?[]const u8 = null,
                documentation_link: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .title = "Title",
                        .short_description = "ShortDescription",
                        .long_description = "LongDescription",
                        .documentation_title = "DocumentationTitle",
                        .documentation_link = "DocumentationLink",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registration_type = "RegistrationType",
                    .supported_associations = "SupportedAssociations",
                    .display_hints = "DisplayHints",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_type_definitions = "RegistrationTypeDefinitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_registration_versions: struct {
    action_name: []const u8 = "DescribeRegistrationVersions",
    Request: type = struct {
        registration_id: []const u8,
        version_numbers: ?[]i64 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_id = "RegistrationId",
                .version_numbers = "VersionNumbers",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_registration_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_registration_versions };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        registration_versions: []struct {
            version_number: i64,
            registration_version_status: []const u8,
            registration_version_status_history: RegistrationVersionStatusHistory,
            denied_reasons: ?[]struct {
                reason: []const u8,
                short_description: []const u8,
                long_description: ?[]const u8 = null,
                documentation_title: ?[]const u8 = null,
                documentation_link: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .reason = "Reason",
                        .short_description = "ShortDescription",
                        .long_description = "LongDescription",
                        .documentation_title = "DocumentationTitle",
                        .documentation_link = "DocumentationLink",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version_number = "VersionNumber",
                    .registration_version_status = "RegistrationVersionStatus",
                    .registration_version_status_history = "RegistrationVersionStatusHistory",
                    .denied_reasons = "DeniedReasons",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .registration_versions = "RegistrationVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_sender_ids: struct {
    action_name: []const u8 = "DescribeSenderIds",
    Request: type = struct {
        sender_ids: ?[]struct {
            sender_id: []const u8,
            iso_country_code: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sender_id = "SenderId",
                    .iso_country_code = "IsoCountryCode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sender_ids = "SenderIds",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_sender_ids) } {
            return .{ .service_metadata = service_metadata, .action = describe_sender_ids };
        }
    },
    Response: type = struct {
        sender_ids: ?[]struct {
            sender_id_arn: []const u8,
            sender_id: []const u8,
            iso_country_code: []const u8,
            message_types: [][]const u8,
            monthly_leasing_price: []const u8,
            deletion_protection_enabled: bool,
            registered: bool,
            registration_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sender_id_arn = "SenderIdArn",
                    .sender_id = "SenderId",
                    .iso_country_code = "IsoCountryCode",
                    .message_types = "MessageTypes",
                    .monthly_leasing_price = "MonthlyLeasingPrice",
                    .deletion_protection_enabled = "DeletionProtectionEnabled",
                    .registered = "Registered",
                    .registration_id = "RegistrationId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sender_ids = "SenderIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_spend_limits: struct {
    action_name: []const u8 = "DescribeSpendLimits",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_spend_limits) } {
            return .{ .service_metadata = service_metadata, .action = describe_spend_limits };
        }
    },
    Response: type = struct {
        spend_limits: ?[]struct {
            name: []const u8,
            enforced_limit: i64,
            max_limit: i64,
            overridden: bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .enforced_limit = "EnforcedLimit",
                    .max_limit = "MaxLimit",
                    .overridden = "Overridden",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .spend_limits = "SpendLimits",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_verified_destination_numbers: struct {
    action_name: []const u8 = "DescribeVerifiedDestinationNumbers",
    Request: type = struct {
        verified_destination_number_ids: ?[][]const u8 = null,
        destination_phone_numbers: ?[][]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_destination_number_ids = "VerifiedDestinationNumberIds",
                .destination_phone_numbers = "DestinationPhoneNumbers",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_verified_destination_numbers) } {
            return .{ .service_metadata = service_metadata, .action = describe_verified_destination_numbers };
        }
    },
    Response: type = struct {
        verified_destination_numbers: []struct {
            verified_destination_number_arn: []const u8,
            verified_destination_number_id: []const u8,
            destination_phone_number: []const u8,
            status: []const u8,
            created_timestamp: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .verified_destination_number_arn = "VerifiedDestinationNumberArn",
                    .verified_destination_number_id = "VerifiedDestinationNumberId",
                    .destination_phone_number = "DestinationPhoneNumber",
                    .status = "Status",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_destination_numbers = "VerifiedDestinationNumbers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_origination_identity: struct {
    action_name: []const u8 = "DisassociateOriginationIdentity",
    Request: type = struct {
        pool_id: []const u8,
        origination_identity: []const u8,
        iso_country_code: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_id = "PoolId",
                .origination_identity = "OriginationIdentity",
                .iso_country_code = "IsoCountryCode",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_origination_identity) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_origination_identity };
        }
    },
    Response: type = struct {
        pool_arn: ?[]const u8 = null,
        pool_id: ?[]const u8 = null,
        origination_identity_arn: ?[]const u8 = null,
        origination_identity: ?[]const u8 = null,
        iso_country_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_arn = "PoolArn",
                .pool_id = "PoolId",
                .origination_identity_arn = "OriginationIdentityArn",
                .origination_identity = "OriginationIdentity",
                .iso_country_code = "IsoCountryCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const discard_registration_version: struct {
    action_name: []const u8 = "DiscardRegistrationVersion",
    Request: type = struct {
        registration_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_id = "RegistrationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(discard_registration_version) } {
            return .{ .service_metadata = service_metadata, .action = discard_registration_version };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        version_number: i64,
        registration_version_status: []const u8,
        registration_version_status_history: RegistrationVersionStatusHistory,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .version_number = "VersionNumber",
                .registration_version_status = "RegistrationVersionStatus",
                .registration_version_status_history = "RegistrationVersionStatusHistory",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_pool_origination_identities: struct {
    action_name: []const u8 = "ListPoolOriginationIdentities",
    Request: type = struct {
        pool_id: []const u8,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_id = "PoolId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pool_origination_identities) } {
            return .{ .service_metadata = service_metadata, .action = list_pool_origination_identities };
        }
    },
    Response: type = struct {
        pool_arn: ?[]const u8 = null,
        pool_id: ?[]const u8 = null,
        origination_identities: ?[]struct {
            origination_identity_arn: []const u8,
            origination_identity: []const u8,
            iso_country_code: []const u8,
            number_capabilities: [][]const u8,
            phone_number: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .origination_identity_arn = "OriginationIdentityArn",
                    .origination_identity = "OriginationIdentity",
                    .iso_country_code = "IsoCountryCode",
                    .number_capabilities = "NumberCapabilities",
                    .phone_number = "PhoneNumber",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_arn = "PoolArn",
                .pool_id = "PoolId",
                .origination_identities = "OriginationIdentities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_registration_associations: struct {
    action_name: []const u8 = "ListRegistrationAssociations",
    Request: type = struct {
        registration_id: []const u8,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_id = "RegistrationId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_registration_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_registration_associations };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        registration_type: []const u8,
        registration_associations: []struct {
            resource_arn: []const u8,
            resource_id: []const u8,
            resource_type: []const u8,
            iso_country_code: ?[]const u8 = null,
            phone_number: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "ResourceArn",
                    .resource_id = "ResourceId",
                    .resource_type = "ResourceType",
                    .iso_country_code = "IsoCountryCode",
                    .phone_number = "PhoneNumber",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .registration_type = "RegistrationType",
                .registration_associations = "RegistrationAssociations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_keyword: struct {
    action_name: []const u8 = "PutKeyword",
    Request: type = struct {
        origination_identity: []const u8,
        keyword: []const u8,
        keyword_message: []const u8,
        keyword_action: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination_identity = "OriginationIdentity",
                .keyword = "Keyword",
                .keyword_message = "KeywordMessage",
                .keyword_action = "KeywordAction",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_keyword) } {
            return .{ .service_metadata = service_metadata, .action = put_keyword };
        }
    },
    Response: type = struct {
        origination_identity_arn: ?[]const u8 = null,
        origination_identity: ?[]const u8 = null,
        keyword: ?[]const u8 = null,
        keyword_message: ?[]const u8 = null,
        keyword_action: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination_identity_arn = "OriginationIdentityArn",
                .origination_identity = "OriginationIdentity",
                .keyword = "Keyword",
                .keyword_message = "KeywordMessage",
                .keyword_action = "KeywordAction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const put_opted_out_number: struct {
    action_name: []const u8 = "PutOptedOutNumber",
    Request: type = struct {
        opt_out_list_name: []const u8,
        opted_out_number: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_name = "OptOutListName",
                .opted_out_number = "OptedOutNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_opted_out_number) } {
            return .{ .service_metadata = service_metadata, .action = put_opted_out_number };
        }
    },
    Response: type = struct {
        opt_out_list_arn: ?[]const u8 = null,
        opt_out_list_name: ?[]const u8 = null,
        opted_out_number: ?[]const u8 = null,
        opted_out_timestamp: ?i64 = null,
        end_user_opted_out: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .opt_out_list_arn = "OptOutListArn",
                .opt_out_list_name = "OptOutListName",
                .opted_out_number = "OptedOutNumber",
                .opted_out_timestamp = "OptedOutTimestamp",
                .end_user_opted_out = "EndUserOptedOut",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_registration_field_value: struct {
    action_name: []const u8 = "PutRegistrationFieldValue",
    Request: type = struct {
        registration_id: []const u8,
        field_path: []const u8,
        select_choices: ?[][]const u8 = null,
        text_value: ?[]const u8 = null,
        registration_attachment_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_id = "RegistrationId",
                .field_path = "FieldPath",
                .select_choices = "SelectChoices",
                .text_value = "TextValue",
                .registration_attachment_id = "RegistrationAttachmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_registration_field_value) } {
            return .{ .service_metadata = service_metadata, .action = put_registration_field_value };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        version_number: i64,
        field_path: []const u8,
        select_choices: ?[][]const u8 = null,
        text_value: ?[]const u8 = null,
        registration_attachment_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .version_number = "VersionNumber",
                .field_path = "FieldPath",
                .select_choices = "SelectChoices",
                .text_value = "TextValue",
                .registration_attachment_id = "RegistrationAttachmentId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const release_phone_number: struct {
    action_name: []const u8 = "ReleasePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(release_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = release_phone_number };
        }
    },
    Response: type = struct {
        phone_number_arn: ?[]const u8 = null,
        phone_number_id: ?[]const u8 = null,
        phone_number: ?[]const u8 = null,
        status: ?[]const u8 = null,
        iso_country_code: ?[]const u8 = null,
        message_type: ?[]const u8 = null,
        number_capabilities: ?[][]const u8 = null,
        number_type: ?[]const u8 = null,
        monthly_leasing_price: ?[]const u8 = null,
        two_way_enabled: ?bool = null,
        two_way_channel_arn: ?[]const u8 = null,
        two_way_channel_role: ?[]const u8 = null,
        self_managed_opt_outs_enabled: ?bool = null,
        opt_out_list_name: ?[]const u8 = null,
        registration_id: ?[]const u8 = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_arn = "PhoneNumberArn",
                .phone_number_id = "PhoneNumberId",
                .phone_number = "PhoneNumber",
                .status = "Status",
                .iso_country_code = "IsoCountryCode",
                .message_type = "MessageType",
                .number_capabilities = "NumberCapabilities",
                .number_type = "NumberType",
                .monthly_leasing_price = "MonthlyLeasingPrice",
                .two_way_enabled = "TwoWayEnabled",
                .two_way_channel_arn = "TwoWayChannelArn",
                .two_way_channel_role = "TwoWayChannelRole",
                .self_managed_opt_outs_enabled = "SelfManagedOptOutsEnabled",
                .opt_out_list_name = "OptOutListName",
                .registration_id = "RegistrationId",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const release_sender_id: struct {
    action_name: []const u8 = "ReleaseSenderId",
    Request: type = struct {
        sender_id: []const u8,
        iso_country_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sender_id = "SenderId",
                .iso_country_code = "IsoCountryCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(release_sender_id) } {
            return .{ .service_metadata = service_metadata, .action = release_sender_id };
        }
    },
    Response: type = struct {
        sender_id_arn: []const u8,
        sender_id: []const u8,
        iso_country_code: []const u8,
        message_types: [][]const u8,
        monthly_leasing_price: []const u8,
        registered: bool,
        registration_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sender_id_arn = "SenderIdArn",
                .sender_id = "SenderId",
                .iso_country_code = "IsoCountryCode",
                .message_types = "MessageTypes",
                .monthly_leasing_price = "MonthlyLeasingPrice",
                .registered = "Registered",
                .registration_id = "RegistrationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const request_phone_number: struct {
    action_name: []const u8 = "RequestPhoneNumber",
    Request: type = struct {
        iso_country_code: []const u8,
        message_type: []const u8,
        number_capabilities: [][]const u8,
        number_type: []const u8,
        opt_out_list_name: ?[]const u8 = null,
        pool_id: ?[]const u8 = null,
        registration_id: ?[]const u8 = null,
        deletion_protection_enabled: ?bool = null,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iso_country_code = "IsoCountryCode",
                .message_type = "MessageType",
                .number_capabilities = "NumberCapabilities",
                .number_type = "NumberType",
                .opt_out_list_name = "OptOutListName",
                .pool_id = "PoolId",
                .registration_id = "RegistrationId",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(request_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = request_phone_number };
        }
    },
    Response: type = struct {
        phone_number_arn: ?[]const u8 = null,
        phone_number_id: ?[]const u8 = null,
        phone_number: ?[]const u8 = null,
        status: ?[]const u8 = null,
        iso_country_code: ?[]const u8 = null,
        message_type: ?[]const u8 = null,
        number_capabilities: ?[][]const u8 = null,
        number_type: ?[]const u8 = null,
        monthly_leasing_price: ?[]const u8 = null,
        two_way_enabled: ?bool = null,
        two_way_channel_arn: ?[]const u8 = null,
        two_way_channel_role: ?[]const u8 = null,
        self_managed_opt_outs_enabled: ?bool = null,
        opt_out_list_name: ?[]const u8 = null,
        deletion_protection_enabled: ?bool = null,
        pool_id: ?[]const u8 = null,
        registration_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_arn = "PhoneNumberArn",
                .phone_number_id = "PhoneNumberId",
                .phone_number = "PhoneNumber",
                .status = "Status",
                .iso_country_code = "IsoCountryCode",
                .message_type = "MessageType",
                .number_capabilities = "NumberCapabilities",
                .number_type = "NumberType",
                .monthly_leasing_price = "MonthlyLeasingPrice",
                .two_way_enabled = "TwoWayEnabled",
                .two_way_channel_arn = "TwoWayChannelArn",
                .two_way_channel_role = "TwoWayChannelRole",
                .self_managed_opt_outs_enabled = "SelfManagedOptOutsEnabled",
                .opt_out_list_name = "OptOutListName",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
                .pool_id = "PoolId",
                .registration_id = "RegistrationId",
                .tags = "Tags",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const request_sender_id: struct {
    action_name: []const u8 = "RequestSenderId",
    Request: type = struct {
        sender_id: []const u8,
        iso_country_code: []const u8,
        message_types: ?[][]const u8 = null,
        deletion_protection_enabled: ?bool = null,
        tags: ?[]Tag = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sender_id = "SenderId",
                .iso_country_code = "IsoCountryCode",
                .message_types = "MessageTypes",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(request_sender_id) } {
            return .{ .service_metadata = service_metadata, .action = request_sender_id };
        }
    },
    Response: type = struct {
        sender_id_arn: []const u8,
        sender_id: []const u8,
        iso_country_code: []const u8,
        message_types: [][]const u8,
        monthly_leasing_price: []const u8,
        deletion_protection_enabled: bool,
        registered: bool,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sender_id_arn = "SenderIdArn",
                .sender_id = "SenderId",
                .iso_country_code = "IsoCountryCode",
                .message_types = "MessageTypes",
                .monthly_leasing_price = "MonthlyLeasingPrice",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
                .registered = "Registered",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const send_destination_number_verification_code: struct {
    action_name: []const u8 = "SendDestinationNumberVerificationCode",
    Request: type = struct {
        verified_destination_number_id: []const u8,
        verification_channel: []const u8,
        language_code: ?[]const u8 = null,
        origination_identity: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        destination_country_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_destination_number_id = "VerifiedDestinationNumberId",
                .verification_channel = "VerificationChannel",
                .language_code = "LanguageCode",
                .origination_identity = "OriginationIdentity",
                .configuration_set_name = "ConfigurationSetName",
                .context = "Context",
                .destination_country_parameters = "DestinationCountryParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "context", field_name))
                return try serializeMap(self.context, self.fieldNameFor("context"), options, out_stream);
            if (std.mem.eql(u8, "destination_country_parameters", field_name))
                return try serializeMap(self.destination_country_parameters, self.fieldNameFor("destination_country_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_destination_number_verification_code) } {
            return .{ .service_metadata = service_metadata, .action = send_destination_number_verification_code };
        }
    },
    Response: type = struct {
        message_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const send_text_message: struct {
    action_name: []const u8 = "SendTextMessage",
    Request: type = struct {
        destination_phone_number: []const u8,
        origination_identity: ?[]const u8 = null,
        message_body: ?[]const u8 = null,
        message_type: ?[]const u8 = null,
        keyword: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        max_price: ?[]const u8 = null,
        time_to_live: ?i64 = null,
        context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        destination_country_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_phone_number = "DestinationPhoneNumber",
                .origination_identity = "OriginationIdentity",
                .message_body = "MessageBody",
                .message_type = "MessageType",
                .keyword = "Keyword",
                .configuration_set_name = "ConfigurationSetName",
                .max_price = "MaxPrice",
                .time_to_live = "TimeToLive",
                .context = "Context",
                .destination_country_parameters = "DestinationCountryParameters",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "context", field_name))
                return try serializeMap(self.context, self.fieldNameFor("context"), options, out_stream);
            if (std.mem.eql(u8, "destination_country_parameters", field_name))
                return try serializeMap(self.destination_country_parameters, self.fieldNameFor("destination_country_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_text_message) } {
            return .{ .service_metadata = service_metadata, .action = send_text_message };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const send_voice_message: struct {
    action_name: []const u8 = "SendVoiceMessage",
    Request: type = struct {
        destination_phone_number: []const u8,
        origination_identity: []const u8,
        message_body: ?[]const u8 = null,
        message_body_text_type: ?[]const u8 = null,
        voice_id: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        max_price_per_minute: ?[]const u8 = null,
        time_to_live: ?i64 = null,
        context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        dry_run: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .destination_phone_number = "DestinationPhoneNumber",
                .origination_identity = "OriginationIdentity",
                .message_body = "MessageBody",
                .message_body_text_type = "MessageBodyTextType",
                .voice_id = "VoiceId",
                .configuration_set_name = "ConfigurationSetName",
                .max_price_per_minute = "MaxPricePerMinute",
                .time_to_live = "TimeToLive",
                .context = "Context",
                .dry_run = "DryRun",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "context", field_name))
                return try serializeMap(self.context, self.fieldNameFor("context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_voice_message) } {
            return .{ .service_metadata = service_metadata, .action = send_voice_message };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const set_default_message_type: struct {
    action_name: []const u8 = "SetDefaultMessageType",
    Request: type = struct {
        configuration_set_name: []const u8,
        message_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .message_type = "MessageType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_default_message_type) } {
            return .{ .service_metadata = service_metadata, .action = set_default_message_type };
        }
    },
    Response: type = struct {
        configuration_set_arn: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        message_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_arn = "ConfigurationSetArn",
                .configuration_set_name = "ConfigurationSetName",
                .message_type = "MessageType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const set_default_sender_id: struct {
    action_name: []const u8 = "SetDefaultSenderId",
    Request: type = struct {
        configuration_set_name: []const u8,
        sender_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .sender_id = "SenderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_default_sender_id) } {
            return .{ .service_metadata = service_metadata, .action = set_default_sender_id };
        }
    },
    Response: type = struct {
        configuration_set_arn: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        sender_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_arn = "ConfigurationSetArn",
                .configuration_set_name = "ConfigurationSetName",
                .sender_id = "SenderId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const set_text_message_spend_limit_override: struct {
    action_name: []const u8 = "SetTextMessageSpendLimitOverride",
    Request: type = struct {
        monthly_limit: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monthly_limit = "MonthlyLimit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_text_message_spend_limit_override) } {
            return .{ .service_metadata = service_metadata, .action = set_text_message_spend_limit_override };
        }
    },
    Response: type = struct {
        monthly_limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monthly_limit = "MonthlyLimit",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const set_voice_message_spend_limit_override: struct {
    action_name: []const u8 = "SetVoiceMessageSpendLimitOverride",
    Request: type = struct {
        monthly_limit: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monthly_limit = "MonthlyLimit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_voice_message_spend_limit_override) } {
            return .{ .service_metadata = service_metadata, .action = set_voice_message_spend_limit_override };
        }
    },
    Response: type = struct {
        monthly_limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monthly_limit = "MonthlyLimit",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const submit_registration_version: struct {
    action_name: []const u8 = "SubmitRegistrationVersion",
    Request: type = struct {
        registration_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_id = "RegistrationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(submit_registration_version) } {
            return .{ .service_metadata = service_metadata, .action = submit_registration_version };
        }
    },
    Response: type = struct {
        registration_arn: []const u8,
        registration_id: []const u8,
        version_number: i64,
        registration_version_status: []const u8,
        registration_version_status_history: RegistrationVersionStatusHistory,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registration_arn = "RegistrationArn",
                .registration_id = "RegistrationId",
                .version_number = "VersionNumber",
                .registration_version_status = "RegistrationVersionStatus",
                .registration_version_status_history = "RegistrationVersionStatusHistory",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_event_destination: struct {
    action_name: []const u8 = "UpdateEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,
        enabled: ?bool = null,
        matching_event_types: ?[][]const u8 = null,
        cloud_watch_logs_destination: ?CloudWatchLogsDestination = null,
        kinesis_firehose_destination: ?KinesisFirehoseDestination = null,
        sns_destination: ?SnsDestination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
                .enabled = "Enabled",
                .matching_event_types = "MatchingEventTypes",
                .cloud_watch_logs_destination = "CloudWatchLogsDestination",
                .kinesis_firehose_destination = "KinesisFirehoseDestination",
                .sns_destination = "SnsDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_event_destination };
        }
    },
    Response: type = struct {
        configuration_set_arn: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        event_destination: ?EventDestination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_arn = "ConfigurationSetArn",
                .configuration_set_name = "ConfigurationSetName",
                .event_destination = "EventDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_phone_number: struct {
    action_name: []const u8 = "UpdatePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,
        two_way_enabled: ?bool = null,
        two_way_channel_arn: ?[]const u8 = null,
        two_way_channel_role: ?[]const u8 = null,
        self_managed_opt_outs_enabled: ?bool = null,
        opt_out_list_name: ?[]const u8 = null,
        deletion_protection_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .two_way_enabled = "TwoWayEnabled",
                .two_way_channel_arn = "TwoWayChannelArn",
                .two_way_channel_role = "TwoWayChannelRole",
                .self_managed_opt_outs_enabled = "SelfManagedOptOutsEnabled",
                .opt_out_list_name = "OptOutListName",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = update_phone_number };
        }
    },
    Response: type = struct {
        phone_number_arn: ?[]const u8 = null,
        phone_number_id: ?[]const u8 = null,
        phone_number: ?[]const u8 = null,
        status: ?[]const u8 = null,
        iso_country_code: ?[]const u8 = null,
        message_type: ?[]const u8 = null,
        number_capabilities: ?[][]const u8 = null,
        number_type: ?[]const u8 = null,
        monthly_leasing_price: ?[]const u8 = null,
        two_way_enabled: ?bool = null,
        two_way_channel_arn: ?[]const u8 = null,
        two_way_channel_role: ?[]const u8 = null,
        self_managed_opt_outs_enabled: ?bool = null,
        opt_out_list_name: ?[]const u8 = null,
        deletion_protection_enabled: ?bool = null,
        registration_id: ?[]const u8 = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_arn = "PhoneNumberArn",
                .phone_number_id = "PhoneNumberId",
                .phone_number = "PhoneNumber",
                .status = "Status",
                .iso_country_code = "IsoCountryCode",
                .message_type = "MessageType",
                .number_capabilities = "NumberCapabilities",
                .number_type = "NumberType",
                .monthly_leasing_price = "MonthlyLeasingPrice",
                .two_way_enabled = "TwoWayEnabled",
                .two_way_channel_arn = "TwoWayChannelArn",
                .two_way_channel_role = "TwoWayChannelRole",
                .self_managed_opt_outs_enabled = "SelfManagedOptOutsEnabled",
                .opt_out_list_name = "OptOutListName",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
                .registration_id = "RegistrationId",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_pool: struct {
    action_name: []const u8 = "UpdatePool",
    Request: type = struct {
        pool_id: []const u8,
        two_way_enabled: ?bool = null,
        two_way_channel_arn: ?[]const u8 = null,
        two_way_channel_role: ?[]const u8 = null,
        self_managed_opt_outs_enabled: ?bool = null,
        opt_out_list_name: ?[]const u8 = null,
        shared_routes_enabled: ?bool = null,
        deletion_protection_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_id = "PoolId",
                .two_way_enabled = "TwoWayEnabled",
                .two_way_channel_arn = "TwoWayChannelArn",
                .two_way_channel_role = "TwoWayChannelRole",
                .self_managed_opt_outs_enabled = "SelfManagedOptOutsEnabled",
                .opt_out_list_name = "OptOutListName",
                .shared_routes_enabled = "SharedRoutesEnabled",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pool) } {
            return .{ .service_metadata = service_metadata, .action = update_pool };
        }
    },
    Response: type = struct {
        pool_arn: ?[]const u8 = null,
        pool_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        message_type: ?[]const u8 = null,
        two_way_enabled: ?bool = null,
        two_way_channel_arn: ?[]const u8 = null,
        two_way_channel_role: ?[]const u8 = null,
        self_managed_opt_outs_enabled: ?bool = null,
        opt_out_list_name: ?[]const u8 = null,
        shared_routes_enabled: ?bool = null,
        deletion_protection_enabled: ?bool = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_arn = "PoolArn",
                .pool_id = "PoolId",
                .status = "Status",
                .message_type = "MessageType",
                .two_way_enabled = "TwoWayEnabled",
                .two_way_channel_arn = "TwoWayChannelArn",
                .two_way_channel_role = "TwoWayChannelRole",
                .self_managed_opt_outs_enabled = "SelfManagedOptOutsEnabled",
                .opt_out_list_name = "OptOutListName",
                .shared_routes_enabled = "SharedRoutesEnabled",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_sender_id: struct {
    action_name: []const u8 = "UpdateSenderId",
    Request: type = struct {
        sender_id: []const u8,
        iso_country_code: []const u8,
        deletion_protection_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sender_id = "SenderId",
                .iso_country_code = "IsoCountryCode",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sender_id) } {
            return .{ .service_metadata = service_metadata, .action = update_sender_id };
        }
    },
    Response: type = struct {
        sender_id_arn: []const u8,
        sender_id: []const u8,
        iso_country_code: []const u8,
        message_types: [][]const u8,
        monthly_leasing_price: []const u8,
        deletion_protection_enabled: bool,
        registered: bool,
        registration_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sender_id_arn = "SenderIdArn",
                .sender_id = "SenderId",
                .iso_country_code = "IsoCountryCode",
                .message_types = "MessageTypes",
                .monthly_leasing_price = "MonthlyLeasingPrice",
                .deletion_protection_enabled = "DeletionProtectionEnabled",
                .registered = "Registered",
                .registration_id = "RegistrationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const verify_destination_number: struct {
    action_name: []const u8 = "VerifyDestinationNumber",
    Request: type = struct {
        verified_destination_number_id: []const u8,
        verification_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_destination_number_id = "VerifiedDestinationNumberId",
                .verification_code = "VerificationCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_destination_number) } {
            return .{ .service_metadata = service_metadata, .action = verify_destination_number };
        }
    },
    Response: type = struct {
        verified_destination_number_arn: []const u8,
        verified_destination_number_id: []const u8,
        destination_phone_number: []const u8,
        status: []const u8,
        created_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_destination_number_arn = "VerifiedDestinationNumberArn",
                .verified_destination_number_id = "VerifiedDestinationNumberId",
                .destination_phone_number = "DestinationPhoneNumber",
                .status = "Status",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const EventDestination = struct {
    event_destination_name: []const u8,
    enabled: bool,
    matching_event_types: [][]const u8,
    cloud_watch_logs_destination: ?CloudWatchLogsDestination = null,
    kinesis_firehose_destination: ?KinesisFirehoseDestination = null,
    sns_destination: ?SnsDestination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_destination_name = "EventDestinationName",
            .enabled = "Enabled",
            .matching_event_types = "MatchingEventTypes",
            .cloud_watch_logs_destination = "CloudWatchLogsDestination",
            .kinesis_firehose_destination = "KinesisFirehoseDestination",
            .sns_destination = "SnsDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const SnsDestination = struct {
    topic_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisFirehoseDestination = struct {
    iam_role_arn: []const u8,
    delivery_stream_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iam_role_arn = "IamRoleArn",
            .delivery_stream_arn = "DeliveryStreamArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogsDestination = struct {
    iam_role_arn: []const u8,
    log_group_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iam_role_arn = "IamRoleArn",
            .log_group_arn = "LogGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RegistrationVersionStatusHistory = struct {
    draft_timestamp: i64,
    submitted_timestamp: ?i64 = null,
    reviewing_timestamp: ?i64 = null,
    approved_timestamp: ?i64 = null,
    discarded_timestamp: ?i64 = null,
    denied_timestamp: ?i64 = null,
    revoked_timestamp: ?i64 = null,
    archived_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .draft_timestamp = "DraftTimestamp",
            .submitted_timestamp = "SubmittedTimestamp",
            .reviewing_timestamp = "ReviewingTimestamp",
            .approved_timestamp = "ApprovedTimestamp",
            .discarded_timestamp = "DiscardedTimestamp",
            .denied_timestamp = "DeniedTimestamp",
            .revoked_timestamp = "RevokedTimestamp",
            .archived_timestamp = "ArchivedTimestamp",
        };
        return @field(mappings, field_name);
    }
};
