const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-06-10";
pub const sdk_id: []const u8 = "Polly";
pub const arn_namespace: ?[]const u8 = "polly";
pub const endpoint_prefix: []const u8 = "polly";
pub const sigv4_name: []const u8 = "polly";
pub const name: []const u8 = "Parrot_v1";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-06-10",
    sdk_id: []const u8 = "Polly",
    arn_namespace: ?[]const u8 = "polly",
    endpoint_prefix: []const u8 = "polly",
    sigv4_name: []const u8 = "polly",
    name: []const u8 = "Parrot_v1",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_lexicon: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/lexicons/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLexicon",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lexicon) } {
            return .{ .service_metadata = service_metadata, .action = delete_lexicon };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LexiconNotFound,
        ServiceFailure,
    },
} = .{};
pub const describe_voices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/voices",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeVoices",
    Request: type = struct {
        engine: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        include_additional_language_codes: ?bool = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .engine = "Engine",
            .language_code = "LanguageCode",
            .include_additional_language_codes = "IncludeAdditionalLanguageCodes",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine = "Engine",
                .language_code = "LanguageCode",
                .include_additional_language_codes = "IncludeAdditionalLanguageCodes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_voices) } {
            return .{ .service_metadata = service_metadata, .action = describe_voices };
        }
    },
    Response: type = struct {
        voices: ?[]struct {
            gender: ?[]const u8 = null,
            id: ?[]const u8 = null,
            language_code: ?[]const u8 = null,
            language_name: ?[]const u8 = null,
            name: ?[]const u8 = null,
            additional_language_codes: ?[][]const u8 = null,
            supported_engines: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .gender = "Gender",
                    .id = "Id",
                    .language_code = "LanguageCode",
                    .language_name = "LanguageName",
                    .name = "Name",
                    .additional_language_codes = "AdditionalLanguageCodes",
                    .supported_engines = "SupportedEngines",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voices = "Voices",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        ServiceFailure,
    },
} = .{};
pub const get_lexicon: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/lexicons/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLexicon",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lexicon) } {
            return .{ .service_metadata = service_metadata, .action = get_lexicon };
        }
    },
    Response: type = struct {
        lexicon: ?struct {
            content: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .content = "Content",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lexicon_attributes: ?LexiconAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lexicon = "Lexicon",
                .lexicon_attributes = "LexiconAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LexiconNotFound,
        ServiceFailure,
    },
} = .{};
pub const get_speech_synthesis_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/synthesisTasks/{TaskId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSpeechSynthesisTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "TaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_speech_synthesis_task) } {
            return .{ .service_metadata = service_metadata, .action = get_speech_synthesis_task };
        }
    },
    Response: type = struct {
        synthesis_task: ?SynthesisTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .synthesis_task = "SynthesisTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTaskId,
        ServiceFailure,
        SynthesisTaskNotFound,
    },
} = .{};
pub const list_lexicons: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/lexicons",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLexicons",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lexicons) } {
            return .{ .service_metadata = service_metadata, .action = list_lexicons };
        }
    },
    Response: type = struct {
        lexicons: ?[]struct {
            name: ?[]const u8 = null,
            attributes: ?LexiconAttributes = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lexicons = "Lexicons",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        ServiceFailure,
    },
} = .{};
pub const list_speech_synthesis_tasks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/synthesisTasks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSpeechSynthesisTasks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
            .status = "Status",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_speech_synthesis_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_speech_synthesis_tasks };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        synthesis_tasks: ?[]SynthesisTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .synthesis_tasks = "SynthesisTasks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        ServiceFailure,
    },
} = .{};
pub const put_lexicon: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/lexicons/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutLexicon",
    Request: type = struct {
        name: []const u8,
        content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .content = "Content",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_lexicon) } {
            return .{ .service_metadata = service_metadata, .action = put_lexicon };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLexicon,
        LexiconSizeExceeded,
        MaxLexemeLengthExceeded,
        MaxLexiconsNumberExceeded,
        ServiceFailure,
        UnsupportedPlsAlphabet,
        UnsupportedPlsLanguage,
    },
} = .{};
pub const start_speech_synthesis_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/synthesisTasks",
        .success_code = 200,
    };

    action_name: []const u8 = "StartSpeechSynthesisTask",
    Request: type = struct {
        engine: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        lexicon_names: ?[][]const u8 = null,
        output_format: []const u8,
        output_s3_bucket_name: []const u8,
        output_s3_key_prefix: ?[]const u8 = null,
        sample_rate: ?[]const u8 = null,
        sns_topic_arn: ?[]const u8 = null,
        speech_mark_types: ?[][]const u8 = null,
        text: []const u8,
        text_type: ?[]const u8 = null,
        voice_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine = "Engine",
                .language_code = "LanguageCode",
                .lexicon_names = "LexiconNames",
                .output_format = "OutputFormat",
                .output_s3_bucket_name = "OutputS3BucketName",
                .output_s3_key_prefix = "OutputS3KeyPrefix",
                .sample_rate = "SampleRate",
                .sns_topic_arn = "SnsTopicArn",
                .speech_mark_types = "SpeechMarkTypes",
                .text = "Text",
                .text_type = "TextType",
                .voice_id = "VoiceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_speech_synthesis_task) } {
            return .{ .service_metadata = service_metadata, .action = start_speech_synthesis_task };
        }
    },
    Response: type = struct {
        synthesis_task: ?SynthesisTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .synthesis_task = "SynthesisTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EngineNotSupported,
        InvalidS3Bucket,
        InvalidS3Key,
        InvalidSampleRate,
        InvalidSnsTopicArn,
        InvalidSsml,
        LanguageNotSupported,
        LexiconNotFound,
        MarksNotSupportedForFormat,
        ServiceFailure,
        SsmlMarksNotSupportedForTextType,
        TextLengthExceeded,
    },
} = .{};
pub const synthesize_speech: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/speech",
        .success_code = 200,
    };

    action_name: []const u8 = "SynthesizeSpeech",
    Request: type = struct {
        engine: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        lexicon_names: ?[][]const u8 = null,
        output_format: []const u8,
        sample_rate: ?[]const u8 = null,
        speech_mark_types: ?[][]const u8 = null,
        text: []const u8,
        text_type: ?[]const u8 = null,
        voice_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine = "Engine",
                .language_code = "LanguageCode",
                .lexicon_names = "LexiconNames",
                .output_format = "OutputFormat",
                .sample_rate = "SampleRate",
                .speech_mark_types = "SpeechMarkTypes",
                .text = "Text",
                .text_type = "TextType",
                .voice_id = "VoiceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(synthesize_speech) } {
            return .{ .service_metadata = service_metadata, .action = synthesize_speech };
        }
    },
    Response: type = struct {
        audio_stream: ?[]const u8 = null,
        content_type: ?[]const u8 = null,
        request_characters: ?i64 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .request_characters = "x-amzn-RequestCharacters",
        };

        pub const http_payload: []const u8 = "audio_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .audio_stream = "AudioStream",
                .content_type = "ContentType",
                .request_characters = "RequestCharacters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EngineNotSupported,
        InvalidSampleRate,
        InvalidSsml,
        LanguageNotSupported,
        LexiconNotFound,
        MarksNotSupportedForFormat,
        ServiceFailure,
        SsmlMarksNotSupportedForTextType,
        TextLengthExceeded,
    },
} = .{};

pub const SynthesisTask = struct {
    engine: ?[]const u8 = null,
    task_id: ?[]const u8 = null,
    task_status: ?[]const u8 = null,
    task_status_reason: ?[]const u8 = null,
    output_uri: ?[]const u8 = null,
    creation_time: ?i64 = null,
    request_characters: ?i64 = null,
    sns_topic_arn: ?[]const u8 = null,
    lexicon_names: ?[][]const u8 = null,
    output_format: ?[]const u8 = null,
    sample_rate: ?[]const u8 = null,
    speech_mark_types: ?[][]const u8 = null,
    text_type: ?[]const u8 = null,
    voice_id: ?[]const u8 = null,
    language_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .engine = "Engine",
            .task_id = "TaskId",
            .task_status = "TaskStatus",
            .task_status_reason = "TaskStatusReason",
            .output_uri = "OutputUri",
            .creation_time = "CreationTime",
            .request_characters = "RequestCharacters",
            .sns_topic_arn = "SnsTopicArn",
            .lexicon_names = "LexiconNames",
            .output_format = "OutputFormat",
            .sample_rate = "SampleRate",
            .speech_mark_types = "SpeechMarkTypes",
            .text_type = "TextType",
            .voice_id = "VoiceId",
            .language_code = "LanguageCode",
        };
        return @field(mappings, field_name);
    }
};

pub const LexiconAttributes = struct {
    alphabet: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    last_modified: ?i64 = null,
    lexicon_arn: ?[]const u8 = null,
    lexemes_count: ?i64 = null,
    size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alphabet = "Alphabet",
            .language_code = "LanguageCode",
            .last_modified = "LastModified",
            .lexicon_arn = "LexiconArn",
            .lexemes_count = "LexemesCount",
            .size = "Size",
        };
        return @field(mappings, field_name);
    }
};
