const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-10-15";
pub const sdk_id: []const u8 = "Pricing";
pub const arn_namespace: ?[]const u8 = "pricing";
pub const endpoint_prefix: []const u8 = "api.pricing";
pub const sigv4_name: []const u8 = "pricing";
pub const name: []const u8 = "AWSPriceListService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-10-15",
    sdk_id: []const u8 = "Pricing",
    arn_namespace: ?[]const u8 = "pricing",
    endpoint_prefix: []const u8 = "api.pricing",
    sigv4_name: []const u8 = "pricing",
    name: []const u8 = "AWSPriceListService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const describe_services: struct {
    action_name: []const u8 = "DescribeServices",
    Request: type = struct {
        service_code: ?[]const u8 = null,
        format_version: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_code = "ServiceCode",
                .format_version = "FormatVersion",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_services) } {
            return .{ .service_metadata = service_metadata, .action = describe_services };
        }
    },
    Response: type = struct {
        services: ?[]struct {
            service_code: []const u8,
            attribute_names: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_code = "ServiceCode",
                    .attribute_names = "AttributeNames",
                };
                return @field(mappings, field_name);
            }
        } = null,
        format_version: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .services = "Services",
                .format_version = "FormatVersion",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExpiredNextToken,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const get_attribute_values: struct {
    action_name: []const u8 = "GetAttributeValues",
    Request: type = struct {
        service_code: []const u8,
        attribute_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_code = "ServiceCode",
                .attribute_name = "AttributeName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_attribute_values) } {
            return .{ .service_metadata = service_metadata, .action = get_attribute_values };
        }
    },
    Response: type = struct {
        attribute_values: ?[]struct {
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_values = "AttributeValues",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExpiredNextToken,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const get_price_list_file_url: struct {
    action_name: []const u8 = "GetPriceListFileUrl",
    Request: type = struct {
        price_list_arn: []const u8,
        file_format: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .price_list_arn = "PriceListArn",
                .file_format = "FileFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_price_list_file_url) } {
            return .{ .service_metadata = service_metadata, .action = get_price_list_file_url };
        }
    },
    Response: type = struct {
        url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .url = "Url",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalError,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const get_products: struct {
    action_name: []const u8 = "GetProducts",
    Request: type = struct {
        service_code: []const u8,
        filters: ?[]struct {
            type: []const u8,
            field: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .field = "Field",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        format_version: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_code = "ServiceCode",
                .filters = "Filters",
                .format_version = "FormatVersion",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_products) } {
            return .{ .service_metadata = service_metadata, .action = get_products };
        }
    },
    Response: type = struct {
        format_version: ?[]const u8 = null,
        price_list: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .format_version = "FormatVersion",
                .price_list = "PriceList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExpiredNextToken,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
pub const list_price_lists: struct {
    action_name: []const u8 = "ListPriceLists",
    Request: type = struct {
        service_code: []const u8,
        effective_date: i64,
        region_code: ?[]const u8 = null,
        currency_code: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_code = "ServiceCode",
                .effective_date = "EffectiveDate",
                .region_code = "RegionCode",
                .currency_code = "CurrencyCode",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_price_lists) } {
            return .{ .service_metadata = service_metadata, .action = list_price_lists };
        }
    },
    Response: type = struct {
        price_lists: ?[]struct {
            price_list_arn: ?[]const u8 = null,
            region_code: ?[]const u8 = null,
            currency_code: ?[]const u8 = null,
            file_formats: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .price_list_arn = "PriceListArn",
                    .region_code = "RegionCode",
                    .currency_code = "CurrencyCode",
                    .file_formats = "FileFormats",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .price_lists = "PriceLists",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ExpiredNextToken,
        InternalError,
        InvalidNextToken,
        InvalidParameter,
        NotFound,
        Throttling,
    },
} = .{};
