const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-12-03";
pub const sdk_id: []const u8 = "PrivateNetworks";
pub const arn_namespace: ?[]const u8 = "private-networks";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "private-networks";
pub const name: []const u8 = "E5GNetworkControllerLambda";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-12-03",
    sdk_id: []const u8 = "PrivateNetworks",
    arn_namespace: ?[]const u8 = "private-networks",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "private-networks",
    name: []const u8 = "E5GNetworkControllerLambda",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const acknowledge_order_receipt: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/orders/acknowledge",
        .success_code = 200,
    };

    action_name: []const u8 = "AcknowledgeOrderReceipt",
    Request: type = struct {
        order_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .order_arn = "orderArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(acknowledge_order_receipt) } {
            return .{ .service_metadata = service_metadata, .action = acknowledge_order_receipt };
        }
    },
    Response: type = struct {
        order: Order,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .order = "order",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const activate_device_identifier: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/device-identifiers/activate",
        .success_code = 200,
    };

    action_name: []const u8 = "ActivateDeviceIdentifier",
    Request: type = struct {
        device_identifier_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_identifier_arn = "deviceIdentifierArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(activate_device_identifier) } {
            return .{ .service_metadata = service_metadata, .action = activate_device_identifier };
        }
    },
    Response: type = struct {
        device_identifier: DeviceIdentifier,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_identifier = "deviceIdentifier",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const activate_network_site: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/network-sites/activate",
        .success_code = 200,
    };

    action_name: []const u8 = "ActivateNetworkSite",
    Request: type = struct {
        network_site_arn: []const u8,
        shipping_address: Address,
        client_token: ?[]const u8 = null,
        commitment_configuration: ?CommitmentConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site_arn = "networkSiteArn",
                .shipping_address = "shippingAddress",
                .client_token = "clientToken",
                .commitment_configuration = "commitmentConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(activate_network_site) } {
            return .{ .service_metadata = service_metadata, .action = activate_network_site };
        }
    },
    Response: type = struct {
        network_site: ?NetworkSite = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site = "networkSite",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const configure_access_point: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/network-resources/configure",
        .success_code = 200,
    };

    action_name: []const u8 = "ConfigureAccessPoint",
    Request: type = struct {
        access_point_arn: []const u8,
        position: ?Position = null,
        cpi_username: ?[]const u8 = null,
        cpi_user_id: ?[]const u8 = null,
        cpi_user_password: ?[]const u8 = null,
        cpi_secret_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_point_arn = "accessPointArn",
                .position = "position",
                .cpi_username = "cpiUsername",
                .cpi_user_id = "cpiUserId",
                .cpi_user_password = "cpiUserPassword",
                .cpi_secret_key = "cpiSecretKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(configure_access_point) } {
            return .{ .service_metadata = service_metadata, .action = configure_access_point };
        }
    },
    Response: type = struct {
        access_point: NetworkResource,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_point = "accessPoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const create_network: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/networks",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateNetwork",
    Request: type = struct {
        network_name: []const u8,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_name = "networkName",
                .description = "description",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network) } {
            return .{ .service_metadata = service_metadata, .action = create_network };
        }
    },
    Response: type = struct {
        network: Network,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network = "network",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        LimitExceeded,
        Validation,
    },
} = .{};
pub const create_network_site: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/network-sites",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateNetworkSite",
    Request: type = struct {
        network_site_name: []const u8,
        description: ?[]const u8 = null,
        network_arn: []const u8,
        pending_plan: ?SitePlan = null,
        client_token: ?[]const u8 = null,
        availability_zone: ?[]const u8 = null,
        availability_zone_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site_name = "networkSiteName",
                .description = "description",
                .network_arn = "networkArn",
                .pending_plan = "pendingPlan",
                .client_token = "clientToken",
                .availability_zone = "availabilityZone",
                .availability_zone_id = "availabilityZoneId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_network_site) } {
            return .{ .service_metadata = service_metadata, .action = create_network_site };
        }
    },
    Response: type = struct {
        network_site: ?NetworkSite = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site = "networkSite",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const deactivate_device_identifier: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/device-identifiers/deactivate",
        .success_code = 200,
    };

    action_name: []const u8 = "DeactivateDeviceIdentifier",
    Request: type = struct {
        device_identifier_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_identifier_arn = "deviceIdentifierArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deactivate_device_identifier) } {
            return .{ .service_metadata = service_metadata, .action = deactivate_device_identifier };
        }
    },
    Response: type = struct {
        device_identifier: DeviceIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_identifier = "deviceIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_network: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/networks/{networkArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteNetwork",
    Request: type = struct {
        network_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_arn = "networkArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network) } {
            return .{ .service_metadata = service_metadata, .action = delete_network };
        }
    },
    Response: type = struct {
        network: Network,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network = "network",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_network_site: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/network-sites/{networkSiteArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteNetworkSite",
    Request: type = struct {
        network_site_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site_arn = "networkSiteArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_network_site) } {
            return .{ .service_metadata = service_metadata, .action = delete_network_site };
        }
    },
    Response: type = struct {
        network_site: ?NetworkSite = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site = "networkSite",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_device_identifier: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/device-identifiers/{deviceIdentifierArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeviceIdentifier",
    Request: type = struct {
        device_identifier_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_identifier_arn = "deviceIdentifierArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_identifier) } {
            return .{ .service_metadata = service_metadata, .action = get_device_identifier };
        }
    },
    Response: type = struct {
        device_identifier: ?DeviceIdentifier = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_identifier = "deviceIdentifier",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_network: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/networks/{networkArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNetwork",
    Request: type = struct {
        network_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_arn = "networkArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network) } {
            return .{ .service_metadata = service_metadata, .action = get_network };
        }
    },
    Response: type = struct {
        network: Network,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network = "network",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_network_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/network-resources/{networkResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNetworkResource",
    Request: type = struct {
        network_resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_resource_arn = "networkResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_resource) } {
            return .{ .service_metadata = service_metadata, .action = get_network_resource };
        }
    },
    Response: type = struct {
        network_resource: NetworkResource,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_resource = "networkResource",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_network_site: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/network-sites/{networkSiteArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetNetworkSite",
    Request: type = struct {
        network_site_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site_arn = "networkSiteArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_network_site) } {
            return .{ .service_metadata = service_metadata, .action = get_network_site };
        }
    },
    Response: type = struct {
        network_site: ?NetworkSite = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site = "networkSite",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_order: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/orders/{orderArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOrder",
    Request: type = struct {
        order_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .order_arn = "orderArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_order) } {
            return .{ .service_metadata = service_metadata, .action = get_order };
        }
    },
    Response: type = struct {
        order: Order,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .order = "order",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_device_identifiers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/device-identifiers/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeviceIdentifiers",
    Request: type = struct {
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        network_arn: []const u8,
        start_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .network_arn = "networkArn",
                .start_token = "startToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_device_identifiers) } {
            return .{ .service_metadata = service_metadata, .action = list_device_identifiers };
        }
    },
    Response: type = struct {
        device_identifiers: ?[]DeviceIdentifier = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_identifiers = "deviceIdentifiers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_network_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/network-resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNetworkResources",
    Request: type = struct {
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        network_arn: []const u8,
        start_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .network_arn = "networkArn",
                .start_token = "startToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_network_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_network_resources };
        }
    },
    Response: type = struct {
        network_resources: ?[]NetworkResource = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_resources = "networkResources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_networks: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/networks/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNetworks",
    Request: type = struct {
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        start_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .start_token = "startToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_networks) } {
            return .{ .service_metadata = service_metadata, .action = list_networks };
        }
    },
    Response: type = struct {
        networks: ?[]Network = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .networks = "networks",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_network_sites: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/network-sites/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNetworkSites",
    Request: type = struct {
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        network_arn: []const u8,
        start_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .network_arn = "networkArn",
                .start_token = "startToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_network_sites) } {
            return .{ .service_metadata = service_metadata, .action = list_network_sites };
        }
    },
    Response: type = struct {
        network_sites: ?[]NetworkSite = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_sites = "networkSites",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_orders: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/orders/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrders",
    Request: type = struct {
        network_arn: []const u8,
        start_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_arn = "networkArn",
                .start_token = "startToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_orders) } {
            return .{ .service_metadata = service_metadata, .action = list_orders };
        }
    },
    Response: type = struct {
        orders: ?[]Order = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .orders = "orders",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const ping: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ping",
        .success_code = 200,
    };

    action_name: []const u8 = "Ping",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(ping) } {
            return .{ .service_metadata = service_metadata, .action = ping };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
    },
} = .{};
pub const start_network_resource_update: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/network-resources/update",
        .success_code = 200,
    };

    action_name: []const u8 = "StartNetworkResourceUpdate",
    Request: type = struct {
        network_resource_arn: []const u8,
        update_type: []const u8,
        shipping_address: ?Address = null,
        return_reason: ?[]const u8 = null,
        commitment_configuration: ?CommitmentConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_resource_arn = "networkResourceArn",
                .update_type = "updateType",
                .shipping_address = "shippingAddress",
                .return_reason = "returnReason",
                .commitment_configuration = "commitmentConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_network_resource_update) } {
            return .{ .service_metadata = service_metadata, .action = start_network_resource_update };
        }
    },
    Response: type = struct {
        network_resource: ?NetworkResource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_resource = "networkResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_network_site: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/network-sites/site",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateNetworkSite",
    Request: type = struct {
        network_site_arn: []const u8,
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site_arn = "networkSiteArn",
                .client_token = "clientToken",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_network_site) } {
            return .{ .service_metadata = service_metadata, .action = update_network_site };
        }
    },
    Response: type = struct {
        network_site: ?NetworkSite = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site = "networkSite",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_network_site_plan: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/network-sites/plan",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateNetworkSitePlan",
    Request: type = struct {
        network_site_arn: []const u8,
        pending_plan: SitePlan,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site_arn = "networkSiteArn",
                .pending_plan = "pendingPlan",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_network_site_plan) } {
            return .{ .service_metadata = service_metadata, .action = update_network_site_plan };
        }
    },
    Response: type = struct {
        network_site: ?NetworkSite = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .network_site = "networkSite",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const NetworkSite = struct {
    network_site_arn: []const u8,
    network_site_name: []const u8,
    description: ?[]const u8 = null,
    status: []const u8,
    status_reason: ?[]const u8 = null,
    network_arn: []const u8,
    pending_plan: ?SitePlan = null,
    current_plan: ?SitePlan = null,
    created_at: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    availability_zone_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_site_arn = "networkSiteArn",
            .network_site_name = "networkSiteName",
            .description = "description",
            .status = "status",
            .status_reason = "statusReason",
            .network_arn = "networkArn",
            .pending_plan = "pendingPlan",
            .current_plan = "currentPlan",
            .created_at = "createdAt",
            .availability_zone = "availabilityZone",
            .availability_zone_id = "availabilityZoneId",
        };
        return @field(mappings, field_name);
    }
};

pub const SitePlan = struct {
    resource_definitions: ?[]NetworkResourceDefinition = null,
    options: ?[]NameValuePair = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_definitions = "resourceDefinitions",
            .options = "options",
        };
        return @field(mappings, field_name);
    }
};

pub const NameValuePair = struct {
    name: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkResourceDefinition = struct {
    type: []const u8,
    options: ?[]NameValuePair = null,
    count: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .options = "options",
            .count = "count",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkResource = struct {
    network_resource_arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_reason: ?[]const u8 = null,
    vendor: ?[]const u8 = null,
    model: ?[]const u8 = null,
    serial_number: ?[]const u8 = null,
    health: ?[]const u8 = null,
    network_arn: ?[]const u8 = null,
    network_site_arn: ?[]const u8 = null,
    order_arn: ?[]const u8 = null,
    attributes: ?[]NameValuePair = null,
    position: ?Position = null,
    created_at: ?i64 = null,
    return_information: ?ReturnInformation = null,
    commitment_information: ?CommitmentInformation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_resource_arn = "networkResourceArn",
            .description = "description",
            .type = "type",
            .status = "status",
            .status_reason = "statusReason",
            .vendor = "vendor",
            .model = "model",
            .serial_number = "serialNumber",
            .health = "health",
            .network_arn = "networkArn",
            .network_site_arn = "networkSiteArn",
            .order_arn = "orderArn",
            .attributes = "attributes",
            .position = "position",
            .created_at = "createdAt",
            .return_information = "returnInformation",
            .commitment_information = "commitmentInformation",
        };
        return @field(mappings, field_name);
    }
};

pub const CommitmentInformation = struct {
    commitment_configuration: CommitmentConfiguration,
    start_at: ?i64 = null,
    expires_on: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .commitment_configuration = "commitmentConfiguration",
            .start_at = "startAt",
            .expires_on = "expiresOn",
        };
        return @field(mappings, field_name);
    }
};

pub const CommitmentConfiguration = struct {
    commitment_length: []const u8,
    automatic_renewal: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .commitment_length = "commitmentLength",
            .automatic_renewal = "automaticRenewal",
        };
        return @field(mappings, field_name);
    }
};

pub const ReturnInformation = struct {
    shipping_address: ?Address = null,
    return_reason: ?[]const u8 = null,
    replacement_order_arn: ?[]const u8 = null,
    shipping_label: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .shipping_address = "shippingAddress",
            .return_reason = "returnReason",
            .replacement_order_arn = "replacementOrderArn",
            .shipping_label = "shippingLabel",
        };
        return @field(mappings, field_name);
    }
};

pub const Address = struct {
    city: []const u8,
    company: ?[]const u8 = null,
    country: []const u8,
    name: []const u8,
    phone_number: ?[]const u8 = null,
    postal_code: []const u8,
    state_or_province: []const u8,
    street1: []const u8,
    street2: ?[]const u8 = null,
    street3: ?[]const u8 = null,
    email_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .city = "city",
            .company = "company",
            .country = "country",
            .name = "name",
            .phone_number = "phoneNumber",
            .postal_code = "postalCode",
            .state_or_province = "stateOrProvince",
            .street1 = "street1",
            .street2 = "street2",
            .street3 = "street3",
            .email_address = "emailAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const Position = struct {
    latitude: ?f64 = null,
    longitude: ?f64 = null,
    elevation: ?f64 = null,
    elevation_unit: ?[]const u8 = null,
    elevation_reference: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .latitude = "latitude",
            .longitude = "longitude",
            .elevation = "elevation",
            .elevation_unit = "elevationUnit",
            .elevation_reference = "elevationReference",
        };
        return @field(mappings, field_name);
    }
};

pub const Order = struct {
    order_arn: ?[]const u8 = null,
    shipping_address: ?Address = null,
    network_arn: ?[]const u8 = null,
    network_site_arn: ?[]const u8 = null,
    tracking_information: ?[]TrackingInformation = null,
    acknowledgment_status: ?[]const u8 = null,
    created_at: ?i64 = null,
    ordered_resources: ?[]OrderedResourceDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .order_arn = "orderArn",
            .shipping_address = "shippingAddress",
            .network_arn = "networkArn",
            .network_site_arn = "networkSiteArn",
            .tracking_information = "trackingInformation",
            .acknowledgment_status = "acknowledgmentStatus",
            .created_at = "createdAt",
            .ordered_resources = "orderedResources",
        };
        return @field(mappings, field_name);
    }
};

pub const OrderedResourceDefinition = struct {
    type: []const u8,
    count: i64,
    commitment_configuration: ?CommitmentConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .count = "count",
            .commitment_configuration = "commitmentConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TrackingInformation = struct {
    tracking_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tracking_number = "trackingNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const Network = struct {
    network_arn: []const u8,
    network_name: []const u8,
    description: ?[]const u8 = null,
    status: []const u8,
    status_reason: ?[]const u8 = null,
    created_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_arn = "networkArn",
            .network_name = "networkName",
            .description = "description",
            .status = "status",
            .status_reason = "statusReason",
            .created_at = "createdAt",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceIdentifier = struct {
    device_identifier_arn: ?[]const u8 = null,
    traffic_group_arn: ?[]const u8 = null,
    network_arn: ?[]const u8 = null,
    imsi: ?[]const u8 = null,
    iccid: ?[]const u8 = null,
    vendor: ?[]const u8 = null,
    status: ?[]const u8 = null,
    order_arn: ?[]const u8 = null,
    created_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_identifier_arn = "deviceIdentifierArn",
            .traffic_group_arn = "trafficGroupArn",
            .network_arn = "networkArn",
            .imsi = "imsi",
            .iccid = "iccid",
            .vendor = "vendor",
            .status = "status",
            .order_arn = "orderArn",
            .created_at = "createdAt",
        };
        return @field(mappings, field_name);
    }
};
