const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-20";
pub const sdk_id: []const u8 = "Proton";
pub const arn_namespace: ?[]const u8 = null;
pub const endpoint_prefix: []const u8 = "proton";
pub const sigv4_name: []const u8 = "proton";
pub const name: []const u8 = "AwsProton20200720";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-20",
    sdk_id: []const u8 = "Proton",
    arn_namespace: ?[]const u8 = null,
    endpoint_prefix: []const u8 = "proton",
    sigv4_name: []const u8 = "proton",
    name: []const u8 = "AwsProton20200720",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const cancel_component_deployment: struct {
    action_name: []const u8 = "CancelComponentDeployment",
    Request: type = struct {
        component_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_name = "componentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_component_deployment) } {
            return .{ .service_metadata = service_metadata, .action = cancel_component_deployment };
        }
    },
    Response: type = struct {
        component: struct {
            name: []const u8,
            description: ?[]const u8 = null,
            arn: []const u8,
            environment_name: []const u8,
            service_name: ?[]const u8 = null,
            service_instance_name: ?[]const u8 = null,
            created_at: i64,
            last_modified_at: i64,
            last_deployment_attempted_at: ?i64 = null,
            last_deployment_succeeded_at: ?i64 = null,
            deployment_status: []const u8,
            deployment_status_message: ?[]const u8 = null,
            service_spec: ?[]const u8 = null,
            last_client_request_token: ?[]const u8 = null,
            last_attempted_deployment_id: ?[]const u8 = null,
            last_succeeded_deployment_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .description = "description",
                    .arn = "arn",
                    .environment_name = "environmentName",
                    .service_name = "serviceName",
                    .service_instance_name = "serviceInstanceName",
                    .created_at = "createdAt",
                    .last_modified_at = "lastModifiedAt",
                    .last_deployment_attempted_at = "lastDeploymentAttemptedAt",
                    .last_deployment_succeeded_at = "lastDeploymentSucceededAt",
                    .deployment_status = "deploymentStatus",
                    .deployment_status_message = "deploymentStatusMessage",
                    .service_spec = "serviceSpec",
                    .last_client_request_token = "lastClientRequestToken",
                    .last_attempted_deployment_id = "lastAttemptedDeploymentId",
                    .last_succeeded_deployment_id = "lastSucceededDeploymentId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component = "component",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const cancel_environment_deployment: struct {
    action_name: []const u8 = "CancelEnvironmentDeployment",
    Request: type = struct {
        environment_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_name = "environmentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_environment_deployment) } {
            return .{ .service_metadata = service_metadata, .action = cancel_environment_deployment };
        }
    },
    Response: type = struct {
        environment: struct {
            name: []const u8,
            description: ?[]const u8 = null,
            created_at: i64,
            last_deployment_attempted_at: i64,
            last_deployment_succeeded_at: i64,
            arn: []const u8,
            template_name: []const u8,
            template_major_version: []const u8,
            template_minor_version: []const u8,
            deployment_status: []const u8,
            deployment_status_message: ?[]const u8 = null,
            proton_service_role_arn: ?[]const u8 = null,
            environment_account_connection_id: ?[]const u8 = null,
            environment_account_id: ?[]const u8 = null,
            spec: ?[]const u8 = null,
            provisioning: ?[]const u8 = null,
            provisioning_repository: ?struct {
                arn: []const u8,
                provider: []const u8,
                name: []const u8,
                branch: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .arn = "arn",
                        .provider = "provider",
                        .name = "name",
                        .branch = "branch",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            component_role_arn: ?[]const u8 = null,
            codebuild_role_arn: ?[]const u8 = null,
            last_attempted_deployment_id: ?[]const u8 = null,
            last_succeeded_deployment_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .description = "description",
                    .created_at = "createdAt",
                    .last_deployment_attempted_at = "lastDeploymentAttemptedAt",
                    .last_deployment_succeeded_at = "lastDeploymentSucceededAt",
                    .arn = "arn",
                    .template_name = "templateName",
                    .template_major_version = "templateMajorVersion",
                    .template_minor_version = "templateMinorVersion",
                    .deployment_status = "deploymentStatus",
                    .deployment_status_message = "deploymentStatusMessage",
                    .proton_service_role_arn = "protonServiceRoleArn",
                    .environment_account_connection_id = "environmentAccountConnectionId",
                    .environment_account_id = "environmentAccountId",
                    .spec = "spec",
                    .provisioning = "provisioning",
                    .provisioning_repository = "provisioningRepository",
                    .component_role_arn = "componentRoleArn",
                    .codebuild_role_arn = "codebuildRoleArn",
                    .last_attempted_deployment_id = "lastAttemptedDeploymentId",
                    .last_succeeded_deployment_id = "lastSucceededDeploymentId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const cancel_service_instance_deployment: struct {
    action_name: []const u8 = "CancelServiceInstanceDeployment",
    Request: type = struct {
        service_instance_name: []const u8,
        service_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_instance_name = "serviceInstanceName",
                .service_name = "serviceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_service_instance_deployment) } {
            return .{ .service_metadata = service_metadata, .action = cancel_service_instance_deployment };
        }
    },
    Response: type = struct {
        service_instance: struct {
            name: []const u8,
            arn: []const u8,
            created_at: i64,
            last_deployment_attempted_at: i64,
            last_deployment_succeeded_at: i64,
            service_name: []const u8,
            environment_name: []const u8,
            template_name: []const u8,
            template_major_version: []const u8,
            template_minor_version: []const u8,
            deployment_status: []const u8,
            deployment_status_message: ?[]const u8 = null,
            spec: ?[]const u8 = null,
            last_client_request_token: ?[]const u8 = null,
            last_attempted_deployment_id: ?[]const u8 = null,
            last_succeeded_deployment_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                    .created_at = "createdAt",
                    .last_deployment_attempted_at = "lastDeploymentAttemptedAt",
                    .last_deployment_succeeded_at = "lastDeploymentSucceededAt",
                    .service_name = "serviceName",
                    .environment_name = "environmentName",
                    .template_name = "templateName",
                    .template_major_version = "templateMajorVersion",
                    .template_minor_version = "templateMinorVersion",
                    .deployment_status = "deploymentStatus",
                    .deployment_status_message = "deploymentStatusMessage",
                    .spec = "spec",
                    .last_client_request_token = "lastClientRequestToken",
                    .last_attempted_deployment_id = "lastAttemptedDeploymentId",
                    .last_succeeded_deployment_id = "lastSucceededDeploymentId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_instance = "serviceInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const cancel_service_pipeline_deployment: struct {
    action_name: []const u8 = "CancelServicePipelineDeployment",
    Request: type = struct {
        service_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_name = "serviceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_service_pipeline_deployment) } {
            return .{ .service_metadata = service_metadata, .action = cancel_service_pipeline_deployment };
        }
    },
    Response: type = struct {
        pipeline: struct {
            arn: []const u8,
            created_at: i64,
            last_deployment_attempted_at: i64,
            last_deployment_succeeded_at: i64,
            template_name: []const u8,
            template_major_version: []const u8,
            template_minor_version: []const u8,
            deployment_status: []const u8,
            deployment_status_message: ?[]const u8 = null,
            spec: ?[]const u8 = null,
            last_attempted_deployment_id: ?[]const u8 = null,
            last_succeeded_deployment_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .created_at = "createdAt",
                    .last_deployment_attempted_at = "lastDeploymentAttemptedAt",
                    .last_deployment_succeeded_at = "lastDeploymentSucceededAt",
                    .template_name = "templateName",
                    .template_major_version = "templateMajorVersion",
                    .template_minor_version = "templateMinorVersion",
                    .deployment_status = "deploymentStatus",
                    .deployment_status_message = "deploymentStatusMessage",
                    .spec = "spec",
                    .last_attempted_deployment_id = "lastAttemptedDeploymentId",
                    .last_succeeded_deployment_id = "lastSucceededDeploymentId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline = "pipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_repository_sync_status: struct {
    action_name: []const u8 = "GetRepositorySyncStatus",
    Request: type = struct {
        repository_name: []const u8,
        repository_provider: []const u8,
        branch: []const u8,
        sync_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .repository_provider = "repositoryProvider",
                .branch = "branch",
                .sync_type = "syncType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_repository_sync_status) } {
            return .{ .service_metadata = service_metadata, .action = get_repository_sync_status };
        }
    },
    Response: type = struct {
        latest_sync: ?struct {
            started_at: i64,
            status: []const u8,
            events: []struct {
                type: []const u8,
                external_id: ?[]const u8 = null,
                time: i64,
                event: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                        .external_id = "externalId",
                        .time = "time",
                        .event = "event",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .started_at = "startedAt",
                    .status = "status",
                    .events = "events",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .latest_sync = "latestSync",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resources_summary: struct {
    action_name: []const u8 = "GetResourcesSummary",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resources_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_resources_summary };
        }
    },
    Response: type = struct {
        counts: struct {
            components: ?ResourceCountsSummary = null,
            environments: ?ResourceCountsSummary = null,
            environment_templates: ?ResourceCountsSummary = null,
            service_instances: ?ResourceCountsSummary = null,
            services: ?ResourceCountsSummary = null,
            service_templates: ?ResourceCountsSummary = null,
            pipelines: ?ResourceCountsSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .components = "components",
                    .environments = "environments",
                    .environment_templates = "environmentTemplates",
                    .service_instances = "serviceInstances",
                    .services = "services",
                    .service_templates = "serviceTemplates",
                    .pipelines = "pipelines",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .counts = "counts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_service_instance_sync_status: struct {
    action_name: []const u8 = "GetServiceInstanceSyncStatus",
    Request: type = struct {
        service_name: []const u8,
        service_instance_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_name = "serviceName",
                .service_instance_name = "serviceInstanceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service_instance_sync_status) } {
            return .{ .service_metadata = service_metadata, .action = get_service_instance_sync_status };
        }
    },
    Response: type = struct {
        latest_sync: ?ResourceSyncAttempt = null,
        latest_successful_sync: ?ResourceSyncAttempt = null,
        desired_state: ?Revision = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .latest_sync = "latestSync",
                .latest_successful_sync = "latestSuccessfulSync",
                .desired_state = "desiredState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_template_sync_status: struct {
    action_name: []const u8 = "GetTemplateSyncStatus",
    Request: type = struct {
        template_name: []const u8,
        template_type: []const u8,
        template_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "templateName",
                .template_type = "templateType",
                .template_version = "templateVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_template_sync_status) } {
            return .{ .service_metadata = service_metadata, .action = get_template_sync_status };
        }
    },
    Response: type = struct {
        latest_sync: ?ResourceSyncAttempt = null,
        latest_successful_sync: ?ResourceSyncAttempt = null,
        desired_state: ?Revision = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .latest_sync = "latestSync",
                .latest_successful_sync = "latestSuccessfulSync",
                .desired_state = "desiredState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_repository_sync_definitions: struct {
    action_name: []const u8 = "ListRepositorySyncDefinitions",
    Request: type = struct {
        repository_name: []const u8,
        repository_provider: []const u8,
        sync_type: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .repository_provider = "repositoryProvider",
                .sync_type = "syncType",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_repository_sync_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_repository_sync_definitions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        sync_definitions: []struct {
            target: []const u8,
            parent: []const u8,
            branch: []const u8,
            directory: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .target = "target",
                    .parent = "parent",
                    .branch = "branch",
                    .directory = "directory",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .sync_definitions = "syncDefinitions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .resource_arn = "resourceArn",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []Tag,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const notify_resource_deployment_status_change: struct {
    action_name: []const u8 = "NotifyResourceDeploymentStatusChange",
    Request: type = struct {
        resource_arn: []const u8,
        status: ?[]const u8 = null,
        outputs: ?[]struct {
            key: ?[]const u8 = null,
            value_string: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .value_string = "valueString",
                };
                return @field(mappings, field_name);
            }
        } = null,
        deployment_id: ?[]const u8 = null,
        status_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .status = "status",
                .outputs = "outputs",
                .deployment_id = "deploymentId",
                .status_message = "statusMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(notify_resource_deployment_status_change) } {
            return .{ .service_metadata = service_metadata, .action = notify_resource_deployment_status_change };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Revision = struct {
    repository_name: []const u8,
    repository_provider: []const u8,
    sha: []const u8,
    directory: []const u8,
    branch: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_name = "repositoryName",
            .repository_provider = "repositoryProvider",
            .sha = "sha",
            .directory = "directory",
            .branch = "branch",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceSyncAttempt = struct {
    initial_revision: Revision,
    target_revision: Revision,
    target: []const u8,
    started_at: i64,
    status: []const u8,
    events: []ResourceSyncEvent,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .initial_revision = "initialRevision",
            .target_revision = "targetRevision",
            .target = "target",
            .started_at = "startedAt",
            .status = "status",
            .events = "events",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceSyncEvent = struct {
    type: []const u8,
    external_id: ?[]const u8 = null,
    time: i64,
    event: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .external_id = "externalId",
            .time = "time",
            .event = "event",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceCountsSummary = struct {
    total: i64,
    failed: ?i64 = null,
    up_to_date: ?i64 = null,
    behind_major: ?i64 = null,
    behind_minor: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total = "total",
            .failed = "failed",
            .up_to_date = "upToDate",
            .behind_major = "behindMajor",
            .behind_minor = "behindMinor",
        };
        return @field(mappings, field_name);
    }
};
