const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2023-11-27";
pub const sdk_id: []const u8 = "QBusiness";
pub const arn_namespace: ?[]const u8 = "qbusiness";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "qbusiness";
pub const name: []const u8 = "ExpertQ";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2023-11-27",
    sdk_id: []const u8 = "QBusiness",
    arn_namespace: ?[]const u8 = "qbusiness",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "qbusiness",
    name: []const u8 = "ExpertQ",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_delete_document: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{applicationId}/indices/{indexId}/documents/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDeleteDocument",
    Request: type = struct {
        application_id: []const u8,
        index_id: []const u8,
        documents: []struct {
            document_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_id = "documentId",
                };
                return @field(mappings, field_name);
            }
        },
        data_source_sync_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .index_id = "indexId",
                .documents = "documents",
                .data_source_sync_id = "dataSourceSyncId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_document) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_document };
        }
    },
    Response: type = struct {
        failed_documents: ?[]FailedDocument = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_documents = "failedDocuments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_put_document: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{applicationId}/indices/{indexId}/documents",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchPutDocument",
    Request: type = struct {
        application_id: []const u8,
        index_id: []const u8,
        documents: []struct {
            id: []const u8,
            attributes: ?[]DocumentAttribute = null,
            content: ?union {
                blob: ?[]const u8,
                s3: ?struct {
                    bucket: []const u8,
                    key: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bucket = "bucket",
                            .key = "key",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .blob = "blob",
                        .s3 = "s3",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            content_type: ?[]const u8 = null,
            title: ?[]const u8 = null,
            access_configuration: ?struct {
                access_controls: []struct {
                    principals: []union {
                        user: ?struct {
                            id: ?[]const u8 = null,
                            access: []const u8,
                            membership_type: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .id = "id",
                                    .access = "access",
                                    .membership_type = "membershipType",
                                };
                                return @field(mappings, field_name);
                            }
                        },
                        group: ?struct {
                            name: ?[]const u8 = null,
                            access: []const u8,
                            membership_type: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .name = "name",
                                    .access = "access",
                                    .membership_type = "membershipType",
                                };
                                return @field(mappings, field_name);
                            }
                        },

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .user = "user",
                                .group = "group",
                            };
                            return @field(mappings, field_name);
                        }
                    },
                    member_relation: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .principals = "principals",
                            .member_relation = "memberRelation",
                        };
                        return @field(mappings, field_name);
                    }
                },
                member_relation: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .access_controls = "accessControls",
                        .member_relation = "memberRelation",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            document_enrichment_configuration: ?struct {
                inline_configurations: ?[]struct {
                    condition: ?DocumentAttributeCondition = null,
                    target: ?struct {
                        key: []const u8,
                        value: ?DocumentAttributeValue = null,
                        attribute_value_operator: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .key = "key",
                                .value = "value",
                                .attribute_value_operator = "attributeValueOperator",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    document_content_operator: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .condition = "condition",
                            .target = "target",
                            .document_content_operator = "documentContentOperator",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                pre_extraction_hook_configuration: ?HookConfiguration = null,
                post_extraction_hook_configuration: ?HookConfiguration = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .inline_configurations = "inlineConfigurations",
                        .pre_extraction_hook_configuration = "preExtractionHookConfiguration",
                        .post_extraction_hook_configuration = "postExtractionHookConfiguration",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .attributes = "attributes",
                    .content = "content",
                    .content_type = "contentType",
                    .title = "title",
                    .access_configuration = "accessConfiguration",
                    .document_enrichment_configuration = "documentEnrichmentConfiguration",
                };
                return @field(mappings, field_name);
            }
        },
        role_arn: ?[]const u8 = null,
        data_source_sync_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .index_id = "indexId",
                .documents = "documents",
                .role_arn = "roleArn",
                .data_source_sync_id = "dataSourceSyncId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_put_document) } {
            return .{ .service_metadata = service_metadata, .action = batch_put_document };
        }
    },
    Response: type = struct {
        failed_documents: ?[]FailedDocument = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_documents = "failedDocuments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const chat_sync: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{applicationId}/conversations?sync",
        .success_code = 200,
    };

    action_name: []const u8 = "ChatSync",
    Request: type = struct {
        application_id: []const u8,
        user_id: []const u8,
        user_groups: ?[][]const u8 = null,
        user_message: ?[]const u8 = null,
        attachments: ?[]struct {
            name: []const u8,
            data: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .data = "data",
                };
                return @field(mappings, field_name);
            }
        } = null,
        action_execution: ?ActionExecution = null,
        conversation_id: ?[]const u8 = null,
        parent_message_id: ?[]const u8 = null,
        attribute_filter: ?AttributeFilter = null,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .user_id = "userId",
            .user_groups = "userGroups",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .user_id = "userId",
                .user_groups = "userGroups",
                .user_message = "userMessage",
                .attachments = "attachments",
                .action_execution = "actionExecution",
                .conversation_id = "conversationId",
                .parent_message_id = "parentMessageId",
                .attribute_filter = "attributeFilter",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(chat_sync) } {
            return .{ .service_metadata = service_metadata, .action = chat_sync };
        }
    },
    Response: type = struct {
        conversation_id: ?[]const u8 = null,
        system_message: ?[]const u8 = null,
        system_message_id: ?[]const u8 = null,
        user_message_id: ?[]const u8 = null,
        action_review: ?ActionReview = null,
        source_attributions: ?[]SourceAttribution = null,
        failed_attachments: ?[]AttachmentOutput = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conversation_id = "conversationId",
                .system_message = "systemMessage",
                .system_message_id = "systemMessageId",
                .user_message_id = "userMessageId",
                .action_review = "actionReview",
                .source_attributions = "sourceAttributions",
                .failed_attachments = "failedAttachments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        LicenseNotFound,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{applicationId}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        application_id: []const u8,
        user_id: []const u8,
        user_aliases: ?[]UserAlias = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .user_id = "userId",
                .user_aliases = "userAliases",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_chat_controls_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{applicationId}/chatcontrols",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteChatControlsConfiguration",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_chat_controls_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_chat_controls_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_conversation: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{applicationId}/conversations/{conversationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConversation",
    Request: type = struct {
        conversation_id: []const u8,
        application_id: []const u8,
        user_id: []const u8,

        pub const http_query = .{
            .user_id = "userId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conversation_id = "conversationId",
                .application_id = "applicationId",
                .user_id = "userId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_conversation) } {
            return .{ .service_metadata = service_metadata, .action = delete_conversation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        LicenseNotFound,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{applicationId}/indices/{indexId}/groups/{groupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGroup",
    Request: type = struct {
        application_id: []const u8,
        index_id: []const u8,
        group_name: []const u8,
        data_source_id: ?[]const u8 = null,

        pub const http_query = .{
            .data_source_id = "dataSourceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .index_id = "indexId",
                .group_name = "groupName",
                .data_source_id = "dataSourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{applicationId}/users/{userId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        application_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .user_id = "userId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_chat_controls_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{applicationId}/chatcontrols",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChatControlsConfiguration",
    Request: type = struct {
        application_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_chat_controls_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_chat_controls_configuration };
        }
    },
    Response: type = struct {
        response_scope: ?[]const u8 = null,
        blocked_phrases: ?struct {
            blocked_phrases: ?[][]const u8 = null,
            system_message_override: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .blocked_phrases = "blockedPhrases",
                    .system_message_override = "systemMessageOverride",
                };
                return @field(mappings, field_name);
            }
        } = null,
        topic_configurations: ?[]TopicConfiguration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .response_scope = "responseScope",
                .blocked_phrases = "blockedPhrases",
                .topic_configurations = "topicConfigurations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{applicationId}/indices/{indexId}/groups/{groupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroup",
    Request: type = struct {
        application_id: []const u8,
        index_id: []const u8,
        group_name: []const u8,
        data_source_id: ?[]const u8 = null,

        pub const http_query = .{
            .data_source_id = "dataSourceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .index_id = "indexId",
                .group_name = "groupName",
                .data_source_id = "dataSourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group) } {
            return .{ .service_metadata = service_metadata, .action = get_group };
        }
    },
    Response: type = struct {
        status: ?GroupStatusDetail = null,
        status_history: ?[]GroupStatusDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .status_history = "statusHistory",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{applicationId}/users/{userId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUser",
    Request: type = struct {
        application_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .user_id = "userId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user) } {
            return .{ .service_metadata = service_metadata, .action = get_user };
        }
    },
    Response: type = struct {
        user_aliases: ?[]UserAlias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_aliases = "userAliases",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_conversations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{applicationId}/conversations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConversations",
    Request: type = struct {
        application_id: []const u8,
        user_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .user_id = "userId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .user_id = "userId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_conversations) } {
            return .{ .service_metadata = service_metadata, .action = list_conversations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        conversations: ?[]struct {
            conversation_id: ?[]const u8 = null,
            title: ?[]const u8 = null,
            start_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .conversation_id = "conversationId",
                    .title = "title",
                    .start_time = "startTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .conversations = "conversations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        LicenseNotFound,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_source_sync_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{applicationId}/indices/{indexId}/datasources/{dataSourceId}/syncjobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataSourceSyncJobs",
    Request: type = struct {
        data_source_id: []const u8,
        application_id: []const u8,
        index_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        status_filter: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .start_time = "startTime",
            .end_time = "endTime",
            .status_filter = "syncStatus",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "dataSourceId",
                .application_id = "applicationId",
                .index_id = "indexId",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .start_time = "startTime",
                .end_time = "endTime",
                .status_filter = "statusFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_source_sync_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_data_source_sync_jobs };
        }
    },
    Response: type = struct {
        history: ?[]struct {
            execution_id: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            status: ?[]const u8 = null,
            @"error": ?ErrorDetail = null,
            data_source_error_code: ?[]const u8 = null,
            metrics: ?struct {
                documents_added: ?[]const u8 = null,
                documents_modified: ?[]const u8 = null,
                documents_deleted: ?[]const u8 = null,
                documents_failed: ?[]const u8 = null,
                documents_scanned: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .documents_added = "documentsAdded",
                        .documents_modified = "documentsModified",
                        .documents_deleted = "documentsDeleted",
                        .documents_failed = "documentsFailed",
                        .documents_scanned = "documentsScanned",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .execution_id = "executionId",
                    .start_time = "startTime",
                    .end_time = "endTime",
                    .status = "status",
                    .@"error" = "error",
                    .data_source_error_code = "dataSourceErrorCode",
                    .metrics = "metrics",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .history = "history",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_documents: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{applicationId}/index/{indexId}/documents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDocuments",
    Request: type = struct {
        application_id: []const u8,
        index_id: []const u8,
        data_source_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .data_source_ids = "dataSourceIds",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .index_id = "indexId",
                .data_source_ids = "dataSourceIds",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_documents) } {
            return .{ .service_metadata = service_metadata, .action = list_documents };
        }
    },
    Response: type = struct {
        document_detail_list: ?[]struct {
            document_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            @"error": ?ErrorDetail = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_id = "documentId",
                    .status = "status",
                    .@"error" = "error",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_detail_list = "documentDetailList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{applicationId}/indices/{indexId}/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGroups",
    Request: type = struct {
        application_id: []const u8,
        index_id: []const u8,
        updated_earlier_than: i64,
        data_source_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .updated_earlier_than = "updatedEarlierThan",
            .data_source_id = "dataSourceId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .index_id = "indexId",
                .updated_earlier_than = "updatedEarlierThan",
                .data_source_id = "dataSourceId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        items: ?[]struct {
            group_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_name = "groupName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .items = "items",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_messages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{applicationId}/conversations/{conversationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMessages",
    Request: type = struct {
        conversation_id: []const u8,
        application_id: []const u8,
        user_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .user_id = "userId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .conversation_id = "conversationId",
                .application_id = "applicationId",
                .user_id = "userId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_messages) } {
            return .{ .service_metadata = service_metadata, .action = list_messages };
        }
    },
    Response: type = struct {
        messages: ?[]struct {
            message_id: ?[]const u8 = null,
            body: ?[]const u8 = null,
            time: ?i64 = null,
            type: ?[]const u8 = null,
            attachments: ?[]AttachmentOutput = null,
            source_attribution: ?[]SourceAttribution = null,
            action_review: ?ActionReview = null,
            action_execution: ?ActionExecution = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .body = "body",
                    .time = "time",
                    .type = "type",
                    .attachments = "attachments",
                    .source_attribution = "sourceAttribution",
                    .action_review = "actionReview",
                    .action_execution = "actionExecution",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .messages = "messages",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        LicenseNotFound,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/tags/{resourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_feedback: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{applicationId}/conversations/{conversationId}/messages/{messageId}/feedback",
        .success_code = 200,
    };

    action_name: []const u8 = "PutFeedback",
    Request: type = struct {
        application_id: []const u8,
        user_id: []const u8,
        conversation_id: []const u8,
        message_id: []const u8,
        message_copied_at: ?i64 = null,
        message_usefulness: ?struct {
            usefulness: []const u8,
            reason: ?[]const u8 = null,
            comment: ?[]const u8 = null,
            submitted_at: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .usefulness = "usefulness",
                    .reason = "reason",
                    .comment = "comment",
                    .submitted_at = "submittedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub const http_query = .{
            .user_id = "userId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .user_id = "userId",
                .conversation_id = "conversationId",
                .message_id = "messageId",
                .message_copied_at = "messageCopiedAt",
                .message_usefulness = "messageUsefulness",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_feedback) } {
            return .{ .service_metadata = service_metadata, .action = put_feedback };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/applications/{applicationId}/indices/{indexId}/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "PutGroup",
    Request: type = struct {
        application_id: []const u8,
        index_id: []const u8,
        group_name: []const u8,
        data_source_id: ?[]const u8 = null,
        type: []const u8,
        group_members: struct {
            member_groups: ?[]struct {
                group_name: []const u8,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .group_name = "groupName",
                        .type = "type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            member_users: ?[]struct {
                user_id: []const u8,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .user_id = "userId",
                        .type = "type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member_groups = "memberGroups",
                    .member_users = "memberUsers",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .index_id = "indexId",
                .group_name = "groupName",
                .data_source_id = "dataSourceId",
                .type = "type",
                .group_members = "groupMembers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_group) } {
            return .{ .service_metadata = service_metadata, .action = put_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_data_source_sync_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{applicationId}/indices/{indexId}/datasources/{dataSourceId}/startsync",
        .success_code = 200,
    };

    action_name: []const u8 = "StartDataSourceSyncJob",
    Request: type = struct {
        data_source_id: []const u8,
        application_id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "dataSourceId",
                .application_id = "applicationId",
                .index_id = "indexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_data_source_sync_job) } {
            return .{ .service_metadata = service_metadata, .action = start_data_source_sync_job };
        }
    },
    Response: type = struct {
        execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_id = "executionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_data_source_sync_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{applicationId}/indices/{indexId}/datasources/{dataSourceId}/stopsync",
        .success_code = 200,
    };

    action_name: []const u8 = "StopDataSourceSyncJob",
    Request: type = struct {
        data_source_id: []const u8,
        application_id: []const u8,
        index_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_id = "dataSourceId",
                .application_id = "applicationId",
                .index_id = "indexId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_data_source_sync_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_data_source_sync_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tags/{resourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/tags/{resourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_chat_controls_configuration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/applications/{applicationId}/chatcontrols",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChatControlsConfiguration",
    Request: type = struct {
        application_id: []const u8,
        client_token: ?[]const u8 = null,
        response_scope: ?[]const u8 = null,
        blocked_phrases_configuration_update: ?struct {
            blocked_phrases_to_create_or_update: ?[][]const u8 = null,
            blocked_phrases_to_delete: ?[][]const u8 = null,
            system_message_override: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .blocked_phrases_to_create_or_update = "blockedPhrasesToCreateOrUpdate",
                    .blocked_phrases_to_delete = "blockedPhrasesToDelete",
                    .system_message_override = "systemMessageOverride",
                };
                return @field(mappings, field_name);
            }
        } = null,
        topic_configurations_to_create_or_update: ?[]TopicConfiguration = null,
        topic_configurations_to_delete: ?[]TopicConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .client_token = "clientToken",
                .response_scope = "responseScope",
                .blocked_phrases_configuration_update = "blockedPhrasesConfigurationUpdate",
                .topic_configurations_to_create_or_update = "topicConfigurationsToCreateOrUpdate",
                .topic_configurations_to_delete = "topicConfigurationsToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_chat_controls_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_chat_controls_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/applications/{applicationId}/users/{userId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        application_id: []const u8,
        user_id: []const u8,
        user_aliases_to_update: ?[]UserAlias = null,
        user_aliases_to_delete: ?[]UserAlias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .user_id = "userId",
                .user_aliases_to_update = "userAliasesToUpdate",
                .user_aliases_to_delete = "userAliasesToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {
        user_aliases_added: ?[]UserAlias = null,
        user_aliases_updated: ?[]UserAlias = null,
        user_aliases_deleted: ?[]UserAlias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_aliases_added = "userAliasesAdded",
                .user_aliases_updated = "userAliasesUpdated",
                .user_aliases_deleted = "userAliasesDeleted",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const UserAlias = struct {
    index_id: ?[]const u8 = null,
    data_source_id: ?[]const u8 = null,
    user_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_id = "indexId",
            .data_source_id = "dataSourceId",
            .user_id = "userId",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicConfiguration = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    example_chat_messages: ?[][]const u8 = null,
    rules: []Rule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .example_chat_messages = "exampleChatMessages",
            .rules = "rules",
        };
        return @field(mappings, field_name);
    }
};

pub const Rule = struct {
    included_users_and_groups: ?UsersAndGroups = null,
    excluded_users_and_groups: ?UsersAndGroups = null,
    rule_type: []const u8,
    rule_configuration: ?RuleConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .included_users_and_groups = "includedUsersAndGroups",
            .excluded_users_and_groups = "excludedUsersAndGroups",
            .rule_type = "ruleType",
            .rule_configuration = "ruleConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleConfiguration = union {
    content_blocker_rule: ?ContentBlockerRule,
    content_retrieval_rule: ?ContentRetrievalRule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_blocker_rule = "contentBlockerRule",
            .content_retrieval_rule = "contentRetrievalRule",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentRetrievalRule = struct {
    eligible_data_sources: ?[]EligibleDataSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .eligible_data_sources = "eligibleDataSources",
        };
        return @field(mappings, field_name);
    }
};

pub const EligibleDataSource = struct {
    index_id: ?[]const u8 = null,
    data_source_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index_id = "indexId",
            .data_source_id = "dataSourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentBlockerRule = struct {
    system_message_override: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .system_message_override = "systemMessageOverride",
        };
        return @field(mappings, field_name);
    }
};

pub const UsersAndGroups = struct {
    user_ids: ?[][]const u8 = null,
    user_groups: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_ids = "userIds",
            .user_groups = "userGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionExecution = struct {
    plugin_id: []const u8,
    payload: []struct {
        key: ?[]const u8 = null,
        value: ?ActionExecutionPayloadField = null,
    },
    payload_field_name_separator: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .plugin_id = "pluginId",
            .payload = "payload",
            .payload_field_name_separator = "payloadFieldNameSeparator",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "payload", field_name))
            return try serializeMap(self.payload, self.fieldNameFor("payload"), options, out_stream);
        return false;
    }
};

pub const ActionExecutionPayloadField = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionReview = struct {
    plugin_id: ?[]const u8 = null,
    plugin_type: ?[]const u8 = null,
    payload: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ActionReviewPayloadField = null,
    } = null,
    payload_field_name_separator: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .plugin_id = "pluginId",
            .plugin_type = "pluginType",
            .payload = "payload",
            .payload_field_name_separator = "payloadFieldNameSeparator",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "payload", field_name))
            return try serializeMap(self.payload, self.fieldNameFor("payload"), options, out_stream);
        return false;
    }
};

pub const ActionReviewPayloadField = struct {
    display_name: ?[]const u8 = null,
    display_order: ?i64 = null,
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,
    allowed_values: ?[]ActionReviewPayloadFieldAllowedValue = null,
    required: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .display_name = "displayName",
            .display_order = "displayOrder",
            .type = "type",
            .value = "value",
            .allowed_values = "allowedValues",
            .required = "required",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionReviewPayloadFieldAllowedValue = struct {
    value: ?[]const u8 = null,
    display_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .display_value = "displayValue",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceAttribution = struct {
    title: ?[]const u8 = null,
    snippet: ?[]const u8 = null,
    url: ?[]const u8 = null,
    citation_number: ?i64 = null,
    updated_at: ?i64 = null,
    text_message_segments: ?[]TextSegment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title = "title",
            .snippet = "snippet",
            .url = "url",
            .citation_number = "citationNumber",
            .updated_at = "updatedAt",
            .text_message_segments = "textMessageSegments",
        };
        return @field(mappings, field_name);
    }
};

pub const TextSegment = struct {
    begin_offset: ?i64 = null,
    end_offset: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .begin_offset = "beginOffset",
            .end_offset = "endOffset",
        };
        return @field(mappings, field_name);
    }
};

pub const AttachmentOutput = struct {
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    @"error": ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .status = "status",
            .@"error" = "error",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetail = struct {
    error_message: ?[]const u8 = null,
    error_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_message = "errorMessage",
            .error_code = "errorCode",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupStatusDetail = struct {
    status: ?[]const u8 = null,
    last_updated_at: ?i64 = null,
    error_detail: ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .last_updated_at = "lastUpdatedAt",
            .error_detail = "errorDetail",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeFilter = struct {
    and_all_filters: ?[]AttributeFilter = null,
    or_all_filters: ?[]AttributeFilter = null,
    not_filter: ?AttributeFilter = null,
    equals_to: ?DocumentAttribute = null,
    contains_all: ?DocumentAttribute = null,
    contains_any: ?DocumentAttribute = null,
    greater_than: ?DocumentAttribute = null,
    greater_than_or_equals: ?DocumentAttribute = null,
    less_than: ?DocumentAttribute = null,
    less_than_or_equals: ?DocumentAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .and_all_filters = "andAllFilters",
            .or_all_filters = "orAllFilters",
            .not_filter = "notFilter",
            .equals_to = "equalsTo",
            .contains_all = "containsAll",
            .contains_any = "containsAny",
            .greater_than = "greaterThan",
            .greater_than_or_equals = "greaterThanOrEquals",
            .less_than = "lessThan",
            .less_than_or_equals = "lessThanOrEquals",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentAttribute = struct {
    name: []const u8,
    value: DocumentAttributeValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentAttributeValue = union {
    string_value: ?[]const u8,
    string_list_value: ?[][]const u8,
    long_value: ?i64,
    date_value: ?i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "stringValue",
            .string_list_value = "stringListValue",
            .long_value = "longValue",
            .date_value = "dateValue",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedDocument = struct {
    id: ?[]const u8 = null,
    @"error": ?ErrorDetail = null,
    data_source_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .@"error" = "error",
            .data_source_id = "dataSourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const HookConfiguration = struct {
    invocation_condition: ?DocumentAttributeCondition = null,
    lambda_arn: ?[]const u8 = null,
    s3_bucket_name: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .invocation_condition = "invocationCondition",
            .lambda_arn = "lambdaArn",
            .s3_bucket_name = "s3BucketName",
            .role_arn = "roleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentAttributeCondition = struct {
    key: []const u8,
    operator: []const u8,
    value: ?DocumentAttributeValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .operator = "operator",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};
