const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-01-02";
pub const sdk_id: []const u8 = "QLDB";
pub const arn_namespace: ?[]const u8 = "qldb";
pub const endpoint_prefix: []const u8 = "qldb";
pub const sigv4_name: []const u8 = "qldb";
pub const name: []const u8 = "AmazonQLDB";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-01-02",
    sdk_id: []const u8 = "QLDB",
    arn_namespace: ?[]const u8 = "qldb",
    endpoint_prefix: []const u8 = "qldb",
    sigv4_name: []const u8 = "qldb",
    name: []const u8 = "AmazonQLDB",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_journal_kinesis_stream: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/ledgers/{LedgerName}/journal-kinesis-streams/{StreamId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelJournalKinesisStream",
    Request: type = struct {
        ledger_name: []const u8,
        stream_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ledger_name = "LedgerName",
                .stream_id = "StreamId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_journal_kinesis_stream) } {
            return .{ .service_metadata = service_metadata, .action = cancel_journal_kinesis_stream };
        }
    },
    Response: type = struct {
        stream_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_id = "StreamId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        ResourcePreconditionNotMet,
    },
} = .{};
pub const create_ledger: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ledgers",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLedger",
    Request: type = struct {
        name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        permissions_mode: []const u8,
        deletion_protection: ?bool = null,
        kms_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .tags = "Tags",
                .permissions_mode = "PermissionsMode",
                .deletion_protection = "DeletionProtection",
                .kms_key = "KmsKey",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ledger) } {
            return .{ .service_metadata = service_metadata, .action = create_ledger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        permissions_mode: ?[]const u8 = null,
        deletion_protection: ?bool = null,
        kms_key_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .state = "State",
                .creation_date_time = "CreationDateTime",
                .permissions_mode = "PermissionsMode",
                .deletion_protection = "DeletionProtection",
                .kms_key_arn = "KmsKeyArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
    },
} = .{};
pub const delete_ledger: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/ledgers/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLedger",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ledger) } {
            return .{ .service_metadata = service_metadata, .action = delete_ledger };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameter,
        ResourceInUse,
        ResourceNotFound,
        ResourcePreconditionNotMet,
    },
} = .{};
pub const describe_journal_kinesis_stream: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ledgers/{LedgerName}/journal-kinesis-streams/{StreamId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJournalKinesisStream",
    Request: type = struct {
        ledger_name: []const u8,
        stream_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ledger_name = "LedgerName",
                .stream_id = "StreamId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_journal_kinesis_stream) } {
            return .{ .service_metadata = service_metadata, .action = describe_journal_kinesis_stream };
        }
    },
    Response: type = struct {
        stream: ?JournalKinesisStreamDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream = "Stream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        ResourcePreconditionNotMet,
    },
} = .{};
pub const describe_journal_s3_export: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ledgers/{Name}/journal-s3-exports/{ExportId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJournalS3Export",
    Request: type = struct {
        name: []const u8,
        export_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .export_id = "ExportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_journal_s3_export) } {
            return .{ .service_metadata = service_metadata, .action = describe_journal_s3_export };
        }
    },
    Response: type = struct {
        export_description: JournalS3ExportDescription,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_description = "ExportDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_ledger: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ledgers/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeLedger",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ledger) } {
            return .{ .service_metadata = service_metadata, .action = describe_ledger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        permissions_mode: ?[]const u8 = null,
        deletion_protection: ?bool = null,
        encryption_description: ?LedgerEncryptionDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .state = "State",
                .creation_date_time = "CreationDateTime",
                .permissions_mode = "PermissionsMode",
                .deletion_protection = "DeletionProtection",
                .encryption_description = "EncryptionDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const export_journal_to_s3: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ledgers/{Name}/journal-s3-exports",
        .success_code = 200,
    };

    action_name: []const u8 = "ExportJournalToS3",
    Request: type = struct {
        name: []const u8,
        inclusive_start_time: i64,
        exclusive_end_time: i64,
        s3_export_configuration: S3ExportConfiguration,
        role_arn: []const u8,
        output_format: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .inclusive_start_time = "InclusiveStartTime",
                .exclusive_end_time = "ExclusiveEndTime",
                .s3_export_configuration = "S3ExportConfiguration",
                .role_arn = "RoleArn",
                .output_format = "OutputFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_journal_to_s3) } {
            return .{ .service_metadata = service_metadata, .action = export_journal_to_s3 };
        }
    },
    Response: type = struct {
        export_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "ExportId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ResourcePreconditionNotMet,
    },
} = .{};
pub const get_block: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ledgers/{Name}/block",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBlock",
    Request: type = struct {
        name: []const u8,
        block_address: ValueHolder,
        digest_tip_address: ?ValueHolder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .block_address = "BlockAddress",
                .digest_tip_address = "DigestTipAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_block) } {
            return .{ .service_metadata = service_metadata, .action = get_block };
        }
    },
    Response: type = struct {
        block: ValueHolder,
        proof: ?ValueHolder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .block = "Block",
                .proof = "Proof",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        ResourcePreconditionNotMet,
    },
} = .{};
pub const get_digest: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ledgers/{Name}/digest",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDigest",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_digest) } {
            return .{ .service_metadata = service_metadata, .action = get_digest };
        }
    },
    Response: type = struct {
        digest: []const u8,
        digest_tip_address: ValueHolder,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .digest = "Digest",
                .digest_tip_address = "DigestTipAddress",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        ResourcePreconditionNotMet,
    },
} = .{};
pub const get_revision: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ledgers/{Name}/revision",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRevision",
    Request: type = struct {
        name: []const u8,
        block_address: ValueHolder,
        document_id: []const u8,
        digest_tip_address: ?ValueHolder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .block_address = "BlockAddress",
                .document_id = "DocumentId",
                .digest_tip_address = "DigestTipAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_revision) } {
            return .{ .service_metadata = service_metadata, .action = get_revision };
        }
    },
    Response: type = struct {
        proof: ?ValueHolder = null,
        revision: ValueHolder,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proof = "Proof",
                .revision = "Revision",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        ResourcePreconditionNotMet,
    },
} = .{};
pub const list_journal_kinesis_streams_for_ledger: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ledgers/{LedgerName}/journal-kinesis-streams",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJournalKinesisStreamsForLedger",
    Request: type = struct {
        ledger_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ledger_name = "LedgerName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_journal_kinesis_streams_for_ledger) } {
            return .{ .service_metadata = service_metadata, .action = list_journal_kinesis_streams_for_ledger };
        }
    },
    Response: type = struct {
        streams: ?[]JournalKinesisStreamDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streams = "Streams",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        ResourcePreconditionNotMet,
    },
} = .{};
pub const list_journal_s3_exports: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/journal-s3-exports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJournalS3Exports",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_journal_s3_exports) } {
            return .{ .service_metadata = service_metadata, .action = list_journal_s3_exports };
        }
    },
    Response: type = struct {
        journal_s3_exports: ?[]JournalS3ExportDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journal_s3_exports = "JournalS3Exports",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_journal_s3_exports_for_ledger: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ledgers/{Name}/journal-s3-exports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJournalS3ExportsForLedger",
    Request: type = struct {
        name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_journal_s3_exports_for_ledger) } {
            return .{ .service_metadata = service_metadata, .action = list_journal_s3_exports_for_ledger };
        }
    },
    Response: type = struct {
        journal_s3_exports: ?[]JournalS3ExportDescription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .journal_s3_exports = "JournalS3Exports",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_ledgers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/ledgers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLedgers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "next_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ledgers) } {
            return .{ .service_metadata = service_metadata, .action = list_ledgers };
        }
    },
    Response: type = struct {
        ledgers: ?[]struct {
            name: ?[]const u8 = null,
            state: ?[]const u8 = null,
            creation_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .state = "State",
                    .creation_date_time = "CreationDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ledgers = "Ledgers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const stream_journal_to_kinesis: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ledgers/{LedgerName}/journal-kinesis-streams",
        .success_code = 200,
    };

    action_name: []const u8 = "StreamJournalToKinesis",
    Request: type = struct {
        ledger_name: []const u8,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        inclusive_start_time: i64,
        exclusive_end_time: ?i64 = null,
        kinesis_configuration: KinesisConfiguration,
        stream_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ledger_name = "LedgerName",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .inclusive_start_time = "InclusiveStartTime",
                .exclusive_end_time = "ExclusiveEndTime",
                .kinesis_configuration = "KinesisConfiguration",
                .stream_name = "StreamName",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stream_journal_to_kinesis) } {
            return .{ .service_metadata = service_metadata, .action = stream_journal_to_kinesis };
        }
    },
    Response: type = struct {
        stream_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_id = "StreamId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        ResourcePreconditionNotMet,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const update_ledger: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/ledgers/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLedger",
    Request: type = struct {
        name: []const u8,
        deletion_protection: ?bool = null,
        kms_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .deletion_protection = "DeletionProtection",
                .kms_key = "KmsKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ledger) } {
            return .{ .service_metadata = service_metadata, .action = update_ledger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        deletion_protection: ?bool = null,
        encryption_description: ?LedgerEncryptionDescription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .state = "State",
                .creation_date_time = "CreationDateTime",
                .deletion_protection = "DeletionProtection",
                .encryption_description = "EncryptionDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const update_ledger_permissions_mode: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/ledgers/{Name}/permissions-mode",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLedgerPermissionsMode",
    Request: type = struct {
        name: []const u8,
        permissions_mode: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .permissions_mode = "PermissionsMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ledger_permissions_mode) } {
            return .{ .service_metadata = service_metadata, .action = update_ledger_permissions_mode };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        permissions_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .arn = "Arn",
                .permissions_mode = "PermissionsMode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};

pub const LedgerEncryptionDescription = struct {
    kms_key_arn: []const u8,
    encryption_status: []const u8,
    inaccessible_kms_key_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_arn = "KmsKeyArn",
            .encryption_status = "EncryptionStatus",
            .inaccessible_kms_key_date_time = "InaccessibleKmsKeyDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisConfiguration = struct {
    stream_arn: []const u8,
    aggregation_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_arn = "StreamArn",
            .aggregation_enabled = "AggregationEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const JournalS3ExportDescription = struct {
    ledger_name: []const u8,
    export_id: []const u8,
    export_creation_time: i64,
    status: []const u8,
    inclusive_start_time: i64,
    exclusive_end_time: i64,
    s3_export_configuration: S3ExportConfiguration,
    role_arn: []const u8,
    output_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ledger_name = "LedgerName",
            .export_id = "ExportId",
            .export_creation_time = "ExportCreationTime",
            .status = "Status",
            .inclusive_start_time = "InclusiveStartTime",
            .exclusive_end_time = "ExclusiveEndTime",
            .s3_export_configuration = "S3ExportConfiguration",
            .role_arn = "RoleArn",
            .output_format = "OutputFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ExportConfiguration = struct {
    bucket: []const u8,
    prefix: []const u8,
    encryption_configuration: S3EncryptionConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
            .encryption_configuration = "EncryptionConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const S3EncryptionConfiguration = struct {
    object_encryption_type: []const u8,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_encryption_type = "ObjectEncryptionType",
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const JournalKinesisStreamDescription = struct {
    ledger_name: []const u8,
    creation_time: ?i64 = null,
    inclusive_start_time: ?i64 = null,
    exclusive_end_time: ?i64 = null,
    role_arn: []const u8,
    stream_id: []const u8,
    arn: ?[]const u8 = null,
    status: []const u8,
    kinesis_configuration: KinesisConfiguration,
    error_cause: ?[]const u8 = null,
    stream_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ledger_name = "LedgerName",
            .creation_time = "CreationTime",
            .inclusive_start_time = "InclusiveStartTime",
            .exclusive_end_time = "ExclusiveEndTime",
            .role_arn = "RoleArn",
            .stream_id = "StreamId",
            .arn = "Arn",
            .status = "Status",
            .kinesis_configuration = "KinesisConfiguration",
            .error_cause = "ErrorCause",
            .stream_name = "StreamName",
        };
        return @field(mappings, field_name);
    }
};

pub const ValueHolder = struct {
    ion_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ion_text = "IonText",
        };
        return @field(mappings, field_name);
    }
};
