const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-07-11";
pub const sdk_id: []const u8 = "QLDB Session";
pub const arn_namespace: ?[]const u8 = "qldb";
pub const endpoint_prefix: []const u8 = "session.qldb";
pub const sigv4_name: []const u8 = "qldb";
pub const name: []const u8 = "QLDBSession";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2019-07-11",
    sdk_id: []const u8 = "QLDB Session",
    arn_namespace: ?[]const u8 = "qldb",
    endpoint_prefix: []const u8 = "session.qldb",
    sigv4_name: []const u8 = "qldb",
    name: []const u8 = "QLDBSession",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const send_command: struct {
    action_name: []const u8 = "SendCommand",
    Request: type = struct {
        session_token: ?[]const u8 = null,
        start_session: ?struct {
            ledger_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ledger_name = "LedgerName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        start_transaction: ?struct {

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{};
                return @field(mappings, field_name);
            }
        } = null,
        end_session: ?struct {

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{};
                return @field(mappings, field_name);
            }
        } = null,
        commit_transaction: ?struct {
            transaction_id: []const u8,
            commit_digest: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transaction_id = "TransactionId",
                    .commit_digest = "CommitDigest",
                };
                return @field(mappings, field_name);
            }
        } = null,
        abort_transaction: ?struct {

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{};
                return @field(mappings, field_name);
            }
        } = null,
        execute_statement: ?struct {
            transaction_id: []const u8,
            statement: []const u8,
            parameters: ?[]ValueHolder = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transaction_id = "TransactionId",
                    .statement = "Statement",
                    .parameters = "Parameters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        fetch_page: ?struct {
            transaction_id: []const u8,
            next_page_token: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transaction_id = "TransactionId",
                    .next_page_token = "NextPageToken",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_token = "SessionToken",
                .start_session = "StartSession",
                .start_transaction = "StartTransaction",
                .end_session = "EndSession",
                .commit_transaction = "CommitTransaction",
                .abort_transaction = "AbortTransaction",
                .execute_statement = "ExecuteStatement",
                .fetch_page = "FetchPage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_command) } {
            return .{ .service_metadata = service_metadata, .action = send_command };
        }
    },
    Response: type = struct {
        start_session: ?struct {
            session_token: ?[]const u8 = null,
            timing_information: ?TimingInformation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .session_token = "SessionToken",
                    .timing_information = "TimingInformation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        start_transaction: ?struct {
            transaction_id: ?[]const u8 = null,
            timing_information: ?TimingInformation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transaction_id = "TransactionId",
                    .timing_information = "TimingInformation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        end_session: ?struct {
            timing_information: ?TimingInformation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timing_information = "TimingInformation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        commit_transaction: ?struct {
            transaction_id: ?[]const u8 = null,
            commit_digest: ?[]const u8 = null,
            timing_information: ?TimingInformation = null,
            consumed_i_os: ?IOUsage = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transaction_id = "TransactionId",
                    .commit_digest = "CommitDigest",
                    .timing_information = "TimingInformation",
                    .consumed_i_os = "ConsumedIOs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        abort_transaction: ?struct {
            timing_information: ?TimingInformation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timing_information = "TimingInformation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        execute_statement: ?struct {
            first_page: ?Page = null,
            timing_information: ?TimingInformation = null,
            consumed_i_os: ?IOUsage = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .first_page = "FirstPage",
                    .timing_information = "TimingInformation",
                    .consumed_i_os = "ConsumedIOs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        fetch_page: ?struct {
            page: ?Page = null,
            timing_information: ?TimingInformation = null,
            consumed_i_os: ?IOUsage = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .page = "Page",
                    .timing_information = "TimingInformation",
                    .consumed_i_os = "ConsumedIOs",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_session = "StartSession",
                .start_transaction = "StartTransaction",
                .end_session = "EndSession",
                .commit_transaction = "CommitTransaction",
                .abort_transaction = "AbortTransaction",
                .execute_statement = "ExecuteStatement",
                .fetch_page = "FetchPage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        CapacityExceeded,
        InvalidSession,
        LimitExceeded,
        OccConflict,
        RateExceeded,
    },
} = .{};

pub const IOUsage = struct {
    read_i_os: ?i64 = null,
    write_i_os: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .read_i_os = "ReadIOs",
            .write_i_os = "WriteIOs",
        };
        return @field(mappings, field_name);
    }
};

pub const TimingInformation = struct {
    processing_time_milliseconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .processing_time_milliseconds = "ProcessingTimeMilliseconds",
        };
        return @field(mappings, field_name);
    }
};

pub const Page = struct {
    values: ?[]ValueHolder = null,
    next_page_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
            .next_page_token = "NextPageToken",
        };
        return @field(mappings, field_name);
    }
};

pub const ValueHolder = struct {
    ion_binary: ?[]const u8 = null,
    ion_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ion_binary = "IonBinary",
            .ion_text = "IonText",
        };
        return @field(mappings, field_name);
    }
};
