const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-01-04";
pub const sdk_id: []const u8 = "RAM";
pub const arn_namespace: ?[]const u8 = "ram";
pub const endpoint_prefix: []const u8 = "ram";
pub const sigv4_name: []const u8 = "ram";
pub const name: []const u8 = "AmazonResourceSharing";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-01-04",
    sdk_id: []const u8 = "RAM",
    arn_namespace: ?[]const u8 = "ram",
    endpoint_prefix: []const u8 = "ram",
    sigv4_name: []const u8 = "ram",
    name: []const u8 = "AmazonResourceSharing",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_resource_share_invitation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/acceptresourceshareinvitation",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptResourceShareInvitation",
    Request: type = struct {
        resource_share_invitation_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_invitation_arn = "resourceShareInvitationArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_resource_share_invitation) } {
            return .{ .service_metadata = service_metadata, .action = accept_resource_share_invitation };
        }
    },
    Response: type = struct {
        resource_share_invitation: ?ResourceShareInvitation = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_invitation = "resourceShareInvitation",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        MalformedArn,
        OperationNotPermitted,
        ResourceShareInvitationAlreadyAccepted,
        ResourceShareInvitationAlreadyRejected,
        ResourceShareInvitationArnNotFound,
        ResourceShareInvitationExpired,
        ServerInternal,
        ServiceUnavailable,
    },
} = .{};
pub const associate_resource_share: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/associateresourceshare",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateResourceShare",
    Request: type = struct {
        resource_share_arn: []const u8,
        resource_arns: ?[][]const u8 = null,
        principals: ?[][]const u8 = null,
        client_token: ?[]const u8 = null,
        sources: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arn = "resourceShareArn",
                .resource_arns = "resourceArns",
                .principals = "principals",
                .client_token = "clientToken",
                .sources = "sources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_resource_share) } {
            return .{ .service_metadata = service_metadata, .action = associate_resource_share };
        }
    },
    Response: type = struct {
        resource_share_associations: ?[]ResourceShareAssociation = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_associations = "resourceShareAssociations",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        InvalidParameter,
        InvalidStateTransition,
        MalformedArn,
        OperationNotPermitted,
        ResourceShareLimitExceeded,
        ServerInternal,
        ServiceUnavailable,
        Throttling,
        UnknownResource,
    },
} = .{};
pub const associate_resource_share_permission: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/associateresourcesharepermission",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateResourceSharePermission",
    Request: type = struct {
        resource_share_arn: []const u8,
        permission_arn: []const u8,
        replace: ?bool = null,
        client_token: ?[]const u8 = null,
        permission_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arn = "resourceShareArn",
                .permission_arn = "permissionArn",
                .replace = "replace",
                .client_token = "clientToken",
                .permission_version = "permissionVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_resource_share_permission) } {
            return .{ .service_metadata = service_metadata, .action = associate_resource_share_permission };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "returnValue",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidClientToken,
        InvalidParameter,
        MalformedArn,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const create_permission: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createpermission",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePermission",
    Request: type = struct {
        name: []const u8,
        resource_type: []const u8,
        policy_template: []const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .resource_type = "resourceType",
                .policy_template = "policyTemplate",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_permission) } {
            return .{ .service_metadata = service_metadata, .action = create_permission };
        }
    },
    Response: type = struct {
        permission: ?ResourceSharePermissionSummary = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission = "permission",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        InvalidParameter,
        InvalidPolicy,
        MalformedPolicyTemplate,
        OperationNotPermitted,
        PermissionAlreadyExists,
        PermissionLimitExceeded,
        ServerInternal,
        ServiceUnavailable,
    },
} = .{};
pub const create_permission_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createpermissionversion",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePermissionVersion",
    Request: type = struct {
        permission_arn: []const u8,
        policy_template: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_arn = "permissionArn",
                .policy_template = "policyTemplate",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_permission_version) } {
            return .{ .service_metadata = service_metadata, .action = create_permission_version };
        }
    },
    Response: type = struct {
        permission: ?ResourceSharePermissionDetail = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission = "permission",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        InvalidParameter,
        InvalidPolicy,
        MalformedArn,
        MalformedPolicyTemplate,
        PermissionVersionsLimitExceeded,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const create_resource_share: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createresourceshare",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateResourceShare",
    Request: type = struct {
        name: []const u8,
        resource_arns: ?[][]const u8 = null,
        principals: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        allow_external_principals: ?bool = null,
        client_token: ?[]const u8 = null,
        permission_arns: ?[][]const u8 = null,
        sources: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .resource_arns = "resourceArns",
                .principals = "principals",
                .tags = "tags",
                .allow_external_principals = "allowExternalPrincipals",
                .client_token = "clientToken",
                .permission_arns = "permissionArns",
                .sources = "sources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_share) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_share };
        }
    },
    Response: type = struct {
        resource_share: ?ResourceShare = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share = "resourceShare",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        InvalidParameter,
        InvalidStateTransition,
        MalformedArn,
        OperationNotPermitted,
        ResourceShareLimitExceeded,
        ServerInternal,
        ServiceUnavailable,
        TagLimitExceeded,
        TagPolicyViolation,
        UnknownResource,
    },
} = .{};
pub const delete_permission: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/deletepermission",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePermission",
    Request: type = struct {
        permission_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .permission_arn = "permissionArn",
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_arn = "permissionArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_permission) } {
            return .{ .service_metadata = service_metadata, .action = delete_permission };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,
        client_token: ?[]const u8 = null,
        permission_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "return",
                .client_token = "clientToken",
                .permission_status = "permissionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        MalformedArn,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const delete_permission_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/deletepermissionversion",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePermissionVersion",
    Request: type = struct {
        permission_arn: []const u8,
        permission_version: i64,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .permission_arn = "permissionArn",
            .permission_version = "permissionVersion",
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_arn = "permissionArn",
                .permission_version = "permissionVersion",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_permission_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_permission_version };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,
        client_token: ?[]const u8 = null,
        permission_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "return",
                .client_token = "clientToken",
                .permission_status = "permissionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        InvalidParameter,
        MalformedArn,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const delete_resource_share: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/deleteresourceshare",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteResourceShare",
    Request: type = struct {
        resource_share_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .resource_share_arn = "resourceShareArn",
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arn = "resourceShareArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_share) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_share };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "return",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        InvalidParameter,
        InvalidStateTransition,
        MalformedArn,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const disassociate_resource_share: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/disassociateresourceshare",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateResourceShare",
    Request: type = struct {
        resource_share_arn: []const u8,
        resource_arns: ?[][]const u8 = null,
        principals: ?[][]const u8 = null,
        client_token: ?[]const u8 = null,
        sources: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arn = "resourceShareArn",
                .resource_arns = "resourceArns",
                .principals = "principals",
                .client_token = "clientToken",
                .sources = "sources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_resource_share) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_resource_share };
        }
    },
    Response: type = struct {
        resource_share_associations: ?[]ResourceShareAssociation = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_associations = "resourceShareAssociations",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        InvalidParameter,
        InvalidStateTransition,
        MalformedArn,
        OperationNotPermitted,
        ResourceShareLimitExceeded,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const disassociate_resource_share_permission: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/disassociateresourcesharepermission",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateResourceSharePermission",
    Request: type = struct {
        resource_share_arn: []const u8,
        permission_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arn = "resourceShareArn",
                .permission_arn = "permissionArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_resource_share_permission) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_resource_share_permission };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "returnValue",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidClientToken,
        InvalidParameter,
        InvalidStateTransition,
        MalformedArn,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const enable_sharing_with_aws_organization: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/enablesharingwithawsorganization",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableSharingWithAwsOrganization",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_sharing_with_aws_organization) } {
            return .{ .service_metadata = service_metadata, .action = enable_sharing_with_aws_organization };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "return",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
    },
} = .{};
pub const get_permission: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getpermission",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPermission",
    Request: type = struct {
        permission_arn: []const u8,
        permission_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_arn = "permissionArn",
                .permission_version = "permissionVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_permission) } {
            return .{ .service_metadata = service_metadata, .action = get_permission };
        }
    },
    Response: type = struct {
        permission: ?ResourceSharePermissionDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission = "permission",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MalformedArn,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const get_resource_policies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getresourcepolicies",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourcePolicies",
    Request: type = struct {
        resource_arns: [][]const u8,
        principal: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arns = "resourceArns",
                .principal = "principal",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policies) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policies };
        }
    },
    Response: type = struct {
        policies: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policies = "policies",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        MalformedArn,
        ResourceArnNotFound,
        ServerInternal,
        ServiceUnavailable,
    },
} = .{};
pub const get_resource_share_associations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getresourceshareassociations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceShareAssociations",
    Request: type = struct {
        association_type: []const u8,
        resource_share_arns: ?[][]const u8 = null,
        resource_arn: ?[]const u8 = null,
        principal: ?[]const u8 = null,
        association_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_type = "associationType",
                .resource_share_arns = "resourceShareArns",
                .resource_arn = "resourceArn",
                .principal = "principal",
                .association_status = "associationStatus",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_share_associations) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_share_associations };
        }
    },
    Response: type = struct {
        resource_share_associations: ?[]ResourceShareAssociation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_associations = "resourceShareAssociations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        MalformedArn,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const get_resource_share_invitations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getresourceshareinvitations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceShareInvitations",
    Request: type = struct {
        resource_share_invitation_arns: ?[][]const u8 = null,
        resource_share_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_invitation_arns = "resourceShareInvitationArns",
                .resource_share_arns = "resourceShareArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_share_invitations) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_share_invitations };
        }
    },
    Response: type = struct {
        resource_share_invitations: ?[]ResourceShareInvitation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_invitations = "resourceShareInvitations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidMaxResults,
        InvalidNextToken,
        InvalidParameter,
        MalformedArn,
        ResourceShareInvitationArnNotFound,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const get_resource_shares: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getresourceshares",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceShares",
    Request: type = struct {
        resource_share_arns: ?[][]const u8 = null,
        resource_share_status: ?[]const u8 = null,
        resource_owner: []const u8,
        name: ?[]const u8 = null,
        tag_filters: ?[]struct {
            tag_key: ?[]const u8 = null,
            tag_values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_key = "tagKey",
                    .tag_values = "tagValues",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        permission_arn: ?[]const u8 = null,
        permission_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arns = "resourceShareArns",
                .resource_share_status = "resourceShareStatus",
                .resource_owner = "resourceOwner",
                .name = "name",
                .tag_filters = "tagFilters",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .permission_arn = "permissionArn",
                .permission_version = "permissionVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_shares) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_shares };
        }
    },
    Response: type = struct {
        resource_shares: ?[]ResourceShare = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_shares = "resourceShares",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        MalformedArn,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const list_pending_invitation_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listpendinginvitationresources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPendingInvitationResources",
    Request: type = struct {
        resource_share_invitation_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        resource_region_scope: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_invitation_arn = "resourceShareInvitationArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .resource_region_scope = "resourceRegionScope",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pending_invitation_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_pending_invitation_resources };
        }
    },
    Response: type = struct {
        resources: ?[]Resource = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "resources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        MalformedArn,
        MissingRequiredParameter,
        ResourceShareInvitationAlreadyRejected,
        ResourceShareInvitationArnNotFound,
        ResourceShareInvitationExpired,
        ServerInternal,
        ServiceUnavailable,
    },
} = .{};
pub const list_permission_associations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listpermissionassociations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPermissionAssociations",
    Request: type = struct {
        permission_arn: ?[]const u8 = null,
        permission_version: ?i64 = null,
        association_status: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        feature_set: ?[]const u8 = null,
        default_version: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_arn = "permissionArn",
                .permission_version = "permissionVersion",
                .association_status = "associationStatus",
                .resource_type = "resourceType",
                .feature_set = "featureSet",
                .default_version = "defaultVersion",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permission_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_permission_associations };
        }
    },
    Response: type = struct {
        permissions: ?[]struct {
            arn: ?[]const u8 = null,
            permission_version: ?[]const u8 = null,
            default_version: ?bool = null,
            resource_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            feature_set: ?[]const u8 = null,
            last_updated_time: ?i64 = null,
            resource_share_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .permission_version = "permissionVersion",
                    .default_version = "defaultVersion",
                    .resource_type = "resourceType",
                    .status = "status",
                    .feature_set = "featureSet",
                    .last_updated_time = "lastUpdatedTime",
                    .resource_share_arn = "resourceShareArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "permissions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        MalformedArn,
        ServerInternal,
        ServiceUnavailable,
    },
} = .{};
pub const list_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listpermissions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPermissions",
    Request: type = struct {
        resource_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        permission_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "resourceType",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .permission_type = "permissionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permissions) } {
            return .{ .service_metadata = service_metadata, .action = list_permissions };
        }
    },
    Response: type = struct {
        permissions: ?[]ResourceSharePermissionSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "permissions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
    },
} = .{};
pub const list_permission_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listpermissionversions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPermissionVersions",
    Request: type = struct {
        permission_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_arn = "permissionArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permission_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_permission_versions };
        }
    },
    Response: type = struct {
        permissions: ?[]ResourceSharePermissionSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "permissions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        MalformedArn,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const list_principals: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listprincipals",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPrincipals",
    Request: type = struct {
        resource_owner: []const u8,
        resource_arn: ?[]const u8 = null,
        principals: ?[][]const u8 = null,
        resource_type: ?[]const u8 = null,
        resource_share_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_owner = "resourceOwner",
                .resource_arn = "resourceArn",
                .principals = "principals",
                .resource_type = "resourceType",
                .resource_share_arns = "resourceShareArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_principals) } {
            return .{ .service_metadata = service_metadata, .action = list_principals };
        }
    },
    Response: type = struct {
        principals: ?[]struct {
            id: ?[]const u8 = null,
            resource_share_arn: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            external: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .resource_share_arn = "resourceShareArn",
                    .creation_time = "creationTime",
                    .last_updated_time = "lastUpdatedTime",
                    .external = "external",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principals = "principals",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        MalformedArn,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const list_replace_permission_associations_work: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listreplacepermissionassociationswork",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReplacePermissionAssociationsWork",
    Request: type = struct {
        work_ids: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_ids = "workIds",
                .status = "status",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_replace_permission_associations_work) } {
            return .{ .service_metadata = service_metadata, .action = list_replace_permission_associations_work };
        }
    },
    Response: type = struct {
        replace_permission_associations_works: ?[]ReplacePermissionAssociationsWork = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replace_permission_associations_works = "replacePermissionAssociationsWorks",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        ServerInternal,
        ServiceUnavailable,
    },
} = .{};
pub const list_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listresources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResources",
    Request: type = struct {
        resource_owner: []const u8,
        principal: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        resource_arns: ?[][]const u8 = null,
        resource_share_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        resource_region_scope: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_owner = "resourceOwner",
                .principal = "principal",
                .resource_type = "resourceType",
                .resource_arns = "resourceArns",
                .resource_share_arns = "resourceShareArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .resource_region_scope = "resourceRegionScope",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_resources };
        }
    },
    Response: type = struct {
        resources: ?[]Resource = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "resources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        InvalidResourceType,
        MalformedArn,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const list_resource_share_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listresourcesharepermissions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResourceSharePermissions",
    Request: type = struct {
        resource_share_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arn = "resourceShareArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_share_permissions) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_share_permissions };
        }
    },
    Response: type = struct {
        permissions: ?[]ResourceSharePermissionSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "permissions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        MalformedArn,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const list_resource_types: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listresourcetypes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResourceTypes",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        resource_region_scope: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .resource_region_scope = "resourceRegionScope",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_types) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_types };
        }
    },
    Response: type = struct {
        resource_types: ?[]struct {
            resource_type: ?[]const u8 = null,
            service_name: ?[]const u8 = null,
            resource_region_scope: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "resourceType",
                    .service_name = "serviceName",
                    .resource_region_scope = "resourceRegionScope",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_types = "resourceTypes",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidParameter,
        ServerInternal,
        ServiceUnavailable,
    },
} = .{};
pub const promote_permission_created_from_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/promotepermissioncreatedfrompolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PromotePermissionCreatedFromPolicy",
    Request: type = struct {
        permission_arn: []const u8,
        name: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_arn = "permissionArn",
                .name = "name",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(promote_permission_created_from_policy) } {
            return .{ .service_metadata = service_metadata, .action = promote_permission_created_from_policy };
        }
    },
    Response: type = struct {
        permission: ?ResourceSharePermissionSummary = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission = "permission",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MalformedArn,
        MissingRequiredParameter,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const promote_resource_share_created_from_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/promoteresourcesharecreatedfrompolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PromoteResourceShareCreatedFromPolicy",
    Request: type = struct {
        resource_share_arn: []const u8,

        pub const http_query = .{
            .resource_share_arn = "resourceShareArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arn = "resourceShareArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(promote_resource_share_created_from_policy) } {
            return .{ .service_metadata = service_metadata, .action = promote_resource_share_created_from_policy };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "return",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidStateTransition,
        MalformedArn,
        MissingRequiredParameter,
        OperationNotPermitted,
        ResourceShareLimitExceeded,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
        UnmatchedPolicyPermission,
    },
} = .{};
pub const reject_resource_share_invitation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/rejectresourceshareinvitation",
        .success_code = 200,
    };

    action_name: []const u8 = "RejectResourceShareInvitation",
    Request: type = struct {
        resource_share_invitation_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_invitation_arn = "resourceShareInvitationArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_resource_share_invitation) } {
            return .{ .service_metadata = service_metadata, .action = reject_resource_share_invitation };
        }
    },
    Response: type = struct {
        resource_share_invitation: ?ResourceShareInvitation = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_invitation = "resourceShareInvitation",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        MalformedArn,
        OperationNotPermitted,
        ResourceShareInvitationAlreadyAccepted,
        ResourceShareInvitationAlreadyRejected,
        ResourceShareInvitationArnNotFound,
        ResourceShareInvitationExpired,
        ServerInternal,
        ServiceUnavailable,
    },
} = .{};
pub const replace_permission_associations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/replacepermissionassociations",
        .success_code = 200,
    };

    action_name: []const u8 = "ReplacePermissionAssociations",
    Request: type = struct {
        from_permission_arn: []const u8,
        from_permission_version: ?i64 = null,
        to_permission_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .from_permission_arn = "fromPermissionArn",
                .from_permission_version = "fromPermissionVersion",
                .to_permission_arn = "toPermissionArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replace_permission_associations) } {
            return .{ .service_metadata = service_metadata, .action = replace_permission_associations };
        }
    },
    Response: type = struct {
        replace_permission_associations_work: ?ReplacePermissionAssociationsWork = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replace_permission_associations_work = "replacePermissionAssociationsWork",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        InvalidParameter,
        MalformedArn,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const set_default_permission_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/setdefaultpermissionversion",
        .success_code = 200,
    };

    action_name: []const u8 = "SetDefaultPermissionVersion",
    Request: type = struct {
        permission_arn: []const u8,
        permission_version: i64,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_arn = "permissionArn",
                .permission_version = "permissionVersion",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_default_permission_version) } {
            return .{ .service_metadata = service_metadata, .action = set_default_permission_version };
        }
    },
    Response: type = struct {
        return_value: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .return_value = "return",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        InvalidParameter,
        MalformedArn,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tagresource",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_share_arn: ?[]const u8 = null,
        tags: []Tag,
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arn = "resourceShareArn",
                .tags = "tags",
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MalformedArn,
        ResourceArnNotFound,
        ServerInternal,
        ServiceUnavailable,
        TagLimitExceeded,
        TagPolicyViolation,
        UnknownResource,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/untagresource",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_share_arn: ?[]const u8 = null,
        tag_keys: [][]const u8,
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arn = "resourceShareArn",
                .tag_keys = "tagKeys",
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MalformedArn,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};
pub const update_resource_share: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateresourceshare",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResourceShare",
    Request: type = struct {
        resource_share_arn: []const u8,
        name: ?[]const u8 = null,
        allow_external_principals: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share_arn = "resourceShareArn",
                .name = "name",
                .allow_external_principals = "allowExternalPrincipals",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_share) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_share };
        }
    },
    Response: type = struct {
        resource_share: ?ResourceShare = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_share = "resourceShare",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InvalidClientToken,
        InvalidParameter,
        MalformedArn,
        MissingRequiredParameter,
        OperationNotPermitted,
        ServerInternal,
        ServiceUnavailable,
        UnknownResource,
    },
} = .{};

pub const ResourceShare = struct {
    resource_share_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    owning_account_id: ?[]const u8 = null,
    allow_external_principals: ?bool = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    tags: ?[]Tag = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    feature_set: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_share_arn = "resourceShareArn",
            .name = "name",
            .owning_account_id = "owningAccountId",
            .allow_external_principals = "allowExternalPrincipals",
            .status = "status",
            .status_message = "statusMessage",
            .tags = "tags",
            .creation_time = "creationTime",
            .last_updated_time = "lastUpdatedTime",
            .feature_set = "featureSet",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplacePermissionAssociationsWork = struct {
    id: ?[]const u8 = null,
    from_permission_arn: ?[]const u8 = null,
    from_permission_version: ?[]const u8 = null,
    to_permission_arn: ?[]const u8 = null,
    to_permission_version: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .from_permission_arn = "fromPermissionArn",
            .from_permission_version = "fromPermissionVersion",
            .to_permission_arn = "toPermissionArn",
            .to_permission_version = "toPermissionVersion",
            .status = "status",
            .status_message = "statusMessage",
            .creation_time = "creationTime",
            .last_updated_time = "lastUpdatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceShareInvitation = struct {
    resource_share_invitation_arn: ?[]const u8 = null,
    resource_share_name: ?[]const u8 = null,
    resource_share_arn: ?[]const u8 = null,
    sender_account_id: ?[]const u8 = null,
    receiver_account_id: ?[]const u8 = null,
    invitation_timestamp: ?i64 = null,
    status: ?[]const u8 = null,
    resource_share_associations: ?[]ResourceShareAssociation = null,
    receiver_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_share_invitation_arn = "resourceShareInvitationArn",
            .resource_share_name = "resourceShareName",
            .resource_share_arn = "resourceShareArn",
            .sender_account_id = "senderAccountId",
            .receiver_account_id = "receiverAccountId",
            .invitation_timestamp = "invitationTimestamp",
            .status = "status",
            .resource_share_associations = "resourceShareAssociations",
            .receiver_arn = "receiverArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceShareAssociation = struct {
    resource_share_arn: ?[]const u8 = null,
    resource_share_name: ?[]const u8 = null,
    associated_entity: ?[]const u8 = null,
    association_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    external: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_share_arn = "resourceShareArn",
            .resource_share_name = "resourceShareName",
            .associated_entity = "associatedEntity",
            .association_type = "associationType",
            .status = "status",
            .status_message = "statusMessage",
            .creation_time = "creationTime",
            .last_updated_time = "lastUpdatedTime",
            .external = "external",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceSharePermissionSummary = struct {
    arn: ?[]const u8 = null,
    version: ?[]const u8 = null,
    default_version: ?bool = null,
    name: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    is_resource_type_default: ?bool = null,
    permission_type: ?[]const u8 = null,
    feature_set: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .version = "version",
            .default_version = "defaultVersion",
            .name = "name",
            .resource_type = "resourceType",
            .status = "status",
            .creation_time = "creationTime",
            .last_updated_time = "lastUpdatedTime",
            .is_resource_type_default = "isResourceTypeDefault",
            .permission_type = "permissionType",
            .feature_set = "featureSet",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Resource = struct {
    arn: ?[]const u8 = null,
    type: ?[]const u8 = null,
    resource_share_arn: ?[]const u8 = null,
    resource_group_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    resource_region_scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .type = "type",
            .resource_share_arn = "resourceShareArn",
            .resource_group_arn = "resourceGroupArn",
            .status = "status",
            .status_message = "statusMessage",
            .creation_time = "creationTime",
            .last_updated_time = "lastUpdatedTime",
            .resource_region_scope = "resourceRegionScope",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceSharePermissionDetail = struct {
    arn: ?[]const u8 = null,
    version: ?[]const u8 = null,
    default_version: ?bool = null,
    name: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    permission: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    is_resource_type_default: ?bool = null,
    permission_type: ?[]const u8 = null,
    feature_set: ?[]const u8 = null,
    status: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .version = "version",
            .default_version = "defaultVersion",
            .name = "name",
            .resource_type = "resourceType",
            .permission = "permission",
            .creation_time = "creationTime",
            .last_updated_time = "lastUpdatedTime",
            .is_resource_type_default = "isResourceTypeDefault",
            .permission_type = "permissionType",
            .feature_set = "featureSet",
            .status = "status",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }
};
