const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-06-15";
pub const sdk_id: []const u8 = "rbin";
pub const arn_namespace: ?[]const u8 = "rbin";
pub const endpoint_prefix: []const u8 = "rbin";
pub const sigv4_name: []const u8 = "rbin";
pub const name: []const u8 = "AmazonRecycleBin";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-06-15",
    sdk_id: []const u8 = "rbin",
    arn_namespace: ?[]const u8 = "rbin",
    endpoint_prefix: []const u8 = "rbin",
    sigv4_name: []const u8 = "rbin",
    name: []const u8 = "AmazonRecycleBin",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/rules",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRule",
    Request: type = struct {
        retention_period: RetentionPeriod,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        resource_type: []const u8,
        resource_tags: ?[]ResourceTag = null,
        lock_configuration: ?LockConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retention_period = "RetentionPeriod",
                .description = "Description",
                .tags = "Tags",
                .resource_type = "ResourceType",
                .resource_tags = "ResourceTags",
                .lock_configuration = "LockConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_rule };
        }
    },
    Response: type = struct {
        identifier: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        resource_type: ?[]const u8 = null,
        resource_tags: ?[]ResourceTag = null,
        status: ?[]const u8 = null,
        lock_configuration: ?LockConfiguration = null,
        lock_state: ?[]const u8 = null,
        rule_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .retention_period = "RetentionPeriod",
                .description = "Description",
                .tags = "Tags",
                .resource_type = "ResourceType",
                .resource_tags = "ResourceTags",
                .status = "Status",
                .lock_configuration = "LockConfiguration",
                .lock_state = "LockState",
                .rule_arn = "RuleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_rule: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/rules/{Identifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRule",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_rule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rules/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRule",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rule) } {
            return .{ .service_metadata = service_metadata, .action = get_rule };
        }
    },
    Response: type = struct {
        identifier: ?[]const u8 = null,
        description: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,
        resource_tags: ?[]ResourceTag = null,
        status: ?[]const u8 = null,
        lock_configuration: ?LockConfiguration = null,
        lock_state: ?[]const u8 = null,
        lock_end_time: ?i64 = null,
        rule_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .description = "Description",
                .resource_type = "ResourceType",
                .retention_period = "RetentionPeriod",
                .resource_tags = "ResourceTags",
                .status = "Status",
                .lock_configuration = "LockConfiguration",
                .lock_state = "LockState",
                .lock_end_time = "LockEndTime",
                .rule_arn = "RuleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_rules: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-rules",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRules",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        resource_type: []const u8,
        resource_tags: ?[]ResourceTag = null,
        lock_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .resource_type = "ResourceType",
                .resource_tags = "ResourceTags",
                .lock_state = "LockState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_rules };
        }
    },
    Response: type = struct {
        rules: ?[]struct {
            identifier: ?[]const u8 = null,
            description: ?[]const u8 = null,
            retention_period: ?RetentionPeriod = null,
            lock_state: ?[]const u8 = null,
            rule_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identifier = "Identifier",
                    .description = "Description",
                    .retention_period = "RetentionPeriod",
                    .lock_state = "LockState",
                    .rule_arn = "RuleArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const lock_rule: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/rules/{Identifier}/lock",
        .success_code = 200,
    };

    action_name: []const u8 = "LockRule",
    Request: type = struct {
        identifier: []const u8,
        lock_configuration: LockConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .lock_configuration = "LockConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(lock_rule) } {
            return .{ .service_metadata = service_metadata, .action = lock_rule };
        }
    },
    Response: type = struct {
        identifier: ?[]const u8 = null,
        description: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,
        resource_tags: ?[]ResourceTag = null,
        status: ?[]const u8 = null,
        lock_configuration: ?LockConfiguration = null,
        lock_state: ?[]const u8 = null,
        rule_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .description = "Description",
                .resource_type = "ResourceType",
                .retention_period = "RetentionPeriod",
                .resource_tags = "ResourceTags",
                .status = "Status",
                .lock_configuration = "LockConfiguration",
                .lock_state = "LockState",
                .rule_arn = "RuleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 201,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const unlock_rule: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/rules/{Identifier}/unlock",
        .success_code = 200,
    };

    action_name: []const u8 = "UnlockRule",
    Request: type = struct {
        identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unlock_rule) } {
            return .{ .service_metadata = service_metadata, .action = unlock_rule };
        }
    },
    Response: type = struct {
        identifier: ?[]const u8 = null,
        description: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,
        resource_tags: ?[]ResourceTag = null,
        status: ?[]const u8 = null,
        lock_configuration: ?LockConfiguration = null,
        lock_state: ?[]const u8 = null,
        lock_end_time: ?i64 = null,
        rule_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .description = "Description",
                .resource_type = "ResourceType",
                .retention_period = "RetentionPeriod",
                .resource_tags = "ResourceTags",
                .status = "Status",
                .lock_configuration = "LockConfiguration",
                .lock_state = "LockState",
                .lock_end_time = "LockEndTime",
                .rule_arn = "RuleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_rule: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/rules/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRule",
    Request: type = struct {
        identifier: []const u8,
        retention_period: ?RetentionPeriod = null,
        description: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        resource_tags: ?[]ResourceTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .retention_period = "RetentionPeriod",
                .description = "Description",
                .resource_type = "ResourceType",
                .resource_tags = "ResourceTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_rule };
        }
    },
    Response: type = struct {
        identifier: ?[]const u8 = null,
        retention_period: ?RetentionPeriod = null,
        description: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        resource_tags: ?[]ResourceTag = null,
        status: ?[]const u8 = null,
        lock_state: ?[]const u8 = null,
        lock_end_time: ?i64 = null,
        rule_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .retention_period = "RetentionPeriod",
                .description = "Description",
                .resource_type = "ResourceType",
                .resource_tags = "ResourceTags",
                .status = "Status",
                .lock_state = "LockState",
                .lock_end_time = "LockEndTime",
                .rule_arn = "RuleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};

pub const ResourceTag = struct {
    resource_tag_key: []const u8,
    resource_tag_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_tag_key = "ResourceTagKey",
            .resource_tag_value = "ResourceTagValue",
        };
        return @field(mappings, field_name);
    }
};

pub const RetentionPeriod = struct {
    retention_period_value: i64,
    retention_period_unit: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .retention_period_value = "RetentionPeriodValue",
            .retention_period_unit = "RetentionPeriodUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const LockConfiguration = struct {
    unlock_delay: UnlockDelay,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unlock_delay = "UnlockDelay",
        };
        return @field(mappings, field_name);
    }
};

pub const UnlockDelay = struct {
    unlock_delay_value: i64,
    unlock_delay_unit: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unlock_delay_value = "UnlockDelayValue",
            .unlock_delay_unit = "UnlockDelayUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
