const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-08-01";
pub const sdk_id: []const u8 = "RDS Data";
pub const arn_namespace: ?[]const u8 = "rds-data";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "rds-data";
pub const name: []const u8 = "RdsDataService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-08-01",
    sdk_id: []const u8 = "RDS Data",
    arn_namespace: ?[]const u8 = "rds-data",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "rds-data",
    name: []const u8 = "RdsDataService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_execute_statement: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/BatchExecute",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchExecuteStatement",
    Request: type = struct {
        resource_arn: []const u8,
        secret_arn: []const u8,
        sql: []const u8,
        database: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        parameter_sets: ?[][]SqlParameter = null,
        transaction_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .secret_arn = "secretArn",
                .sql = "sql",
                .database = "database",
                .schema = "schema",
                .parameter_sets = "parameterSets",
                .transaction_id = "transactionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_execute_statement) } {
            return .{ .service_metadata = service_metadata, .action = batch_execute_statement };
        }
    },
    Response: type = struct {
        update_results: ?[]struct {
            generated_fields: ?[]Field = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .generated_fields = "generatedFields",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_results = "updateResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        DatabaseError,
        DatabaseNotFound,
        DatabaseUnavailable,
        Forbidden,
        HttpEndpointNotEnabled,
        InternalServerError,
        InvalidSecret,
        SecretsError,
        ServiceUnavailableError,
        StatementTimeout,
        TransactionNotFound,
    },
} = .{};
pub const begin_transaction: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/BeginTransaction",
        .success_code = 200,
    };

    action_name: []const u8 = "BeginTransaction",
    Request: type = struct {
        resource_arn: []const u8,
        secret_arn: []const u8,
        database: ?[]const u8 = null,
        schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .secret_arn = "secretArn",
                .database = "database",
                .schema = "schema",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(begin_transaction) } {
            return .{ .service_metadata = service_metadata, .action = begin_transaction };
        }
    },
    Response: type = struct {
        transaction_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_id = "transactionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        DatabaseError,
        DatabaseNotFound,
        DatabaseUnavailable,
        Forbidden,
        HttpEndpointNotEnabled,
        InternalServerError,
        InvalidSecret,
        SecretsError,
        ServiceUnavailableError,
        StatementTimeout,
        TransactionNotFound,
    },
} = .{};
pub const commit_transaction: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CommitTransaction",
        .success_code = 200,
    };

    action_name: []const u8 = "CommitTransaction",
    Request: type = struct {
        resource_arn: []const u8,
        secret_arn: []const u8,
        transaction_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .secret_arn = "secretArn",
                .transaction_id = "transactionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(commit_transaction) } {
            return .{ .service_metadata = service_metadata, .action = commit_transaction };
        }
    },
    Response: type = struct {
        transaction_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_status = "transactionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        DatabaseError,
        DatabaseNotFound,
        DatabaseUnavailable,
        Forbidden,
        HttpEndpointNotEnabled,
        InternalServerError,
        InvalidSecret,
        NotFound,
        SecretsError,
        ServiceUnavailableError,
        StatementTimeout,
        TransactionNotFound,
    },
} = .{};
pub const execute_sql: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ExecuteSql",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteSql",
    Request: type = struct {
        db_cluster_or_instance_arn: []const u8,
        aws_secret_store_arn: []const u8,
        sql_statements: []const u8,
        database: ?[]const u8 = null,
        schema: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_cluster_or_instance_arn = "dbClusterOrInstanceArn",
                .aws_secret_store_arn = "awsSecretStoreArn",
                .sql_statements = "sqlStatements",
                .database = "database",
                .schema = "schema",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_sql) } {
            return .{ .service_metadata = service_metadata, .action = execute_sql };
        }
    },
    Response: type = struct {
        sql_statement_results: ?[]struct {
            result_frame: ?struct {
                result_set_metadata: ?struct {
                    column_count: ?i64 = null,
                    column_metadata: ?[]ColumnMetadata = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .column_count = "columnCount",
                            .column_metadata = "columnMetadata",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                records: ?[]struct {
                    values: ?[]Value = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .values = "values",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .result_set_metadata = "resultSetMetadata",
                        .records = "records",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            number_of_records_updated: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .result_frame = "resultFrame",
                    .number_of_records_updated = "numberOfRecordsUpdated",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sql_statement_results = "sqlStatementResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailableError,
    },
} = .{};
pub const execute_statement: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/Execute",
        .success_code = 200,
    };

    action_name: []const u8 = "ExecuteStatement",
    Request: type = struct {
        resource_arn: []const u8,
        secret_arn: []const u8,
        sql: []const u8,
        database: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        parameters: ?[]SqlParameter = null,
        transaction_id: ?[]const u8 = null,
        include_result_metadata: ?bool = null,
        continue_after_timeout: ?bool = null,
        result_set_options: ?struct {
            decimal_return_type: ?[]const u8 = null,
            long_return_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .decimal_return_type = "decimalReturnType",
                    .long_return_type = "longReturnType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        format_records_as: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .secret_arn = "secretArn",
                .sql = "sql",
                .database = "database",
                .schema = "schema",
                .parameters = "parameters",
                .transaction_id = "transactionId",
                .include_result_metadata = "includeResultMetadata",
                .continue_after_timeout = "continueAfterTimeout",
                .result_set_options = "resultSetOptions",
                .format_records_as = "formatRecordsAs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_statement) } {
            return .{ .service_metadata = service_metadata, .action = execute_statement };
        }
    },
    Response: type = struct {
        records: ?[][]Field = null,
        column_metadata: ?[]ColumnMetadata = null,
        number_of_records_updated: ?i64 = null,
        generated_fields: ?[]Field = null,
        formatted_records: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records = "records",
                .column_metadata = "columnMetadata",
                .number_of_records_updated = "numberOfRecordsUpdated",
                .generated_fields = "generatedFields",
                .formatted_records = "formattedRecords",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        DatabaseError,
        DatabaseNotFound,
        DatabaseUnavailable,
        Forbidden,
        HttpEndpointNotEnabled,
        InternalServerError,
        InvalidSecret,
        SecretsError,
        ServiceUnavailableError,
        StatementTimeout,
        TransactionNotFound,
        UnsupportedResult,
    },
} = .{};
pub const rollback_transaction: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/RollbackTransaction",
        .success_code = 200,
    };

    action_name: []const u8 = "RollbackTransaction",
    Request: type = struct {
        resource_arn: []const u8,
        secret_arn: []const u8,
        transaction_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .secret_arn = "secretArn",
                .transaction_id = "transactionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rollback_transaction) } {
            return .{ .service_metadata = service_metadata, .action = rollback_transaction };
        }
    },
    Response: type = struct {
        transaction_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_status = "transactionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        DatabaseError,
        DatabaseNotFound,
        DatabaseUnavailable,
        Forbidden,
        HttpEndpointNotEnabled,
        InternalServerError,
        InvalidSecret,
        NotFound,
        SecretsError,
        ServiceUnavailableError,
        StatementTimeout,
        TransactionNotFound,
    },
} = .{};

pub const Field = union {
    is_null: ?bool,
    boolean_value: ?bool,
    long_value: ?i64,
    double_value: ?f64,
    string_value: ?[]const u8,
    blob_value: ?[]const u8,
    array_value: ?ArrayValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_null = "isNull",
            .boolean_value = "booleanValue",
            .long_value = "longValue",
            .double_value = "doubleValue",
            .string_value = "stringValue",
            .blob_value = "blobValue",
            .array_value = "arrayValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ArrayValue = union {
    boolean_values: ?[]bool,
    long_values: ?[]i64,
    double_values: ?[]f64,
    string_values: ?[][]const u8,
    array_values: ?[]ArrayValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .boolean_values = "booleanValues",
            .long_values = "longValues",
            .double_values = "doubleValues",
            .string_values = "stringValues",
            .array_values = "arrayValues",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnMetadata = struct {
    name: ?[]const u8 = null,
    type: ?i64 = null,
    type_name: ?[]const u8 = null,
    label: ?[]const u8 = null,
    schema_name: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    is_auto_increment: ?bool = null,
    is_signed: ?bool = null,
    is_currency: ?bool = null,
    is_case_sensitive: ?bool = null,
    nullable: ?i64 = null,
    precision: ?i64 = null,
    scale: ?i64 = null,
    array_base_column_type: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .type = "type",
            .type_name = "typeName",
            .label = "label",
            .schema_name = "schemaName",
            .table_name = "tableName",
            .is_auto_increment = "isAutoIncrement",
            .is_signed = "isSigned",
            .is_currency = "isCurrency",
            .is_case_sensitive = "isCaseSensitive",
            .nullable = "nullable",
            .precision = "precision",
            .scale = "scale",
            .array_base_column_type = "arrayBaseColumnType",
        };
        return @field(mappings, field_name);
    }
};

pub const SqlParameter = struct {
    name: ?[]const u8 = null,
    value: ?Field = null,
    type_hint: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
            .type_hint = "typeHint",
        };
        return @field(mappings, field_name);
    }
};

pub const Value = union {
    is_null: ?bool,
    bit_value: ?bool,
    big_int_value: ?i64,
    int_value: ?i64,
    double_value: ?f64,
    real_value: ?f32,
    string_value: ?[]const u8,
    blob_value: ?[]const u8,
    array_values: ?[]Value,
    struct_value: ?struct {
        attributes: ?[]Value = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }
    },

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_null = "isNull",
            .bit_value = "bitValue",
            .big_int_value = "bigIntValue",
            .int_value = "intValue",
            .double_value = "doubleValue",
            .real_value = "realValue",
            .string_value = "stringValue",
            .blob_value = "blobValue",
            .array_values = "arrayValues",
            .struct_value = "structValue",
        };
        return @field(mappings, field_name);
    }
};
