const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-20";
pub const sdk_id: []const u8 = "Redshift Data";
pub const arn_namespace: ?[]const u8 = "redshift-data";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "redshift-data";
pub const name: []const u8 = "RedshiftData";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-20",
    sdk_id: []const u8 = "Redshift Data",
    arn_namespace: ?[]const u8 = "redshift-data",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "redshift-data",
    name: []const u8 = "RedshiftData",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_execute_statement: struct {
    action_name: []const u8 = "BatchExecuteStatement",
    Request: type = struct {
        sqls: [][]const u8,
        cluster_identifier: ?[]const u8 = null,
        secret_arn: ?[]const u8 = null,
        db_user: ?[]const u8 = null,
        database: []const u8,
        with_event: ?bool = null,
        statement_name: ?[]const u8 = null,
        workgroup_name: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sqls = "Sqls",
                .cluster_identifier = "ClusterIdentifier",
                .secret_arn = "SecretArn",
                .db_user = "DbUser",
                .database = "Database",
                .with_event = "WithEvent",
                .statement_name = "StatementName",
                .workgroup_name = "WorkgroupName",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_execute_statement) } {
            return .{ .service_metadata = service_metadata, .action = batch_execute_statement };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        created_at: ?i64 = null,
        cluster_identifier: ?[]const u8 = null,
        db_user: ?[]const u8 = null,
        database: ?[]const u8 = null,
        secret_arn: ?[]const u8 = null,
        workgroup_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .created_at = "CreatedAt",
                .cluster_identifier = "ClusterIdentifier",
                .db_user = "DbUser",
                .database = "Database",
                .secret_arn = "SecretArn",
                .workgroup_name = "WorkgroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActiveStatementsExceeded,
        BatchExecuteStatement,
        Validation,
    },
} = .{};
pub const cancel_statement: struct {
    action_name: []const u8 = "CancelStatement",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_statement) } {
            return .{ .service_metadata = service_metadata, .action = cancel_statement };
        }
    },
    Response: type = struct {
        status: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DatabaseConnection,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_statement: struct {
    action_name: []const u8 = "DescribeStatement",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_statement) } {
            return .{ .service_metadata = service_metadata, .action = describe_statement };
        }
    },
    Response: type = struct {
        id: []const u8,
        secret_arn: ?[]const u8 = null,
        db_user: ?[]const u8 = null,
        database: ?[]const u8 = null,
        cluster_identifier: ?[]const u8 = null,
        duration: ?i64 = null,
        @"error": ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        redshift_pid: ?i64 = null,
        has_result_set: ?bool = null,
        query_string: ?[]const u8 = null,
        result_rows: ?i64 = null,
        result_size: ?i64 = null,
        redshift_query_id: ?i64 = null,
        query_parameters: ?[]SqlParameter = null,
        sub_statements: ?[]struct {
            id: []const u8,
            duration: ?i64 = null,
            @"error": ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            query_string: ?[]const u8 = null,
            result_rows: ?i64 = null,
            result_size: ?i64 = null,
            redshift_query_id: ?i64 = null,
            has_result_set: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .duration = "Duration",
                    .@"error" = "Error",
                    .status = "Status",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .query_string = "QueryString",
                    .result_rows = "ResultRows",
                    .result_size = "ResultSize",
                    .redshift_query_id = "RedshiftQueryId",
                    .has_result_set = "HasResultSet",
                };
                return @field(mappings, field_name);
            }
        } = null,
        workgroup_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .secret_arn = "SecretArn",
                .db_user = "DbUser",
                .database = "Database",
                .cluster_identifier = "ClusterIdentifier",
                .duration = "Duration",
                .@"error" = "Error",
                .status = "Status",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .redshift_pid = "RedshiftPid",
                .has_result_set = "HasResultSet",
                .query_string = "QueryString",
                .result_rows = "ResultRows",
                .result_size = "ResultSize",
                .redshift_query_id = "RedshiftQueryId",
                .query_parameters = "QueryParameters",
                .sub_statements = "SubStatements",
                .workgroup_name = "WorkgroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_table: struct {
    action_name: []const u8 = "DescribeTable",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        secret_arn: ?[]const u8 = null,
        db_user: ?[]const u8 = null,
        database: []const u8,
        connected_database: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        table: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        workgroup_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .secret_arn = "SecretArn",
                .db_user = "DbUser",
                .database = "Database",
                .connected_database = "ConnectedDatabase",
                .schema = "Schema",
                .table = "Table",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .workgroup_name = "WorkgroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_table) } {
            return .{ .service_metadata = service_metadata, .action = describe_table };
        }
    },
    Response: type = struct {
        table_name: ?[]const u8 = null,
        column_list: ?[]ColumnMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_name = "TableName",
                .column_list = "ColumnList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DatabaseConnection,
        InternalServer,
        Validation,
    },
} = .{};
pub const execute_statement: struct {
    action_name: []const u8 = "ExecuteStatement",
    Request: type = struct {
        sql: []const u8,
        cluster_identifier: ?[]const u8 = null,
        secret_arn: ?[]const u8 = null,
        db_user: ?[]const u8 = null,
        database: []const u8,
        with_event: ?bool = null,
        statement_name: ?[]const u8 = null,
        parameters: ?[]SqlParameter = null,
        workgroup_name: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sql = "Sql",
                .cluster_identifier = "ClusterIdentifier",
                .secret_arn = "SecretArn",
                .db_user = "DbUser",
                .database = "Database",
                .with_event = "WithEvent",
                .statement_name = "StatementName",
                .parameters = "Parameters",
                .workgroup_name = "WorkgroupName",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_statement) } {
            return .{ .service_metadata = service_metadata, .action = execute_statement };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        created_at: ?i64 = null,
        cluster_identifier: ?[]const u8 = null,
        db_user: ?[]const u8 = null,
        database: ?[]const u8 = null,
        secret_arn: ?[]const u8 = null,
        workgroup_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .created_at = "CreatedAt",
                .cluster_identifier = "ClusterIdentifier",
                .db_user = "DbUser",
                .database = "Database",
                .secret_arn = "SecretArn",
                .workgroup_name = "WorkgroupName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActiveStatementsExceeded,
        ExecuteStatement,
        Validation,
    },
} = .{};
pub const get_statement_result: struct {
    action_name: []const u8 = "GetStatementResult",
    Request: type = struct {
        id: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_statement_result) } {
            return .{ .service_metadata = service_metadata, .action = get_statement_result };
        }
    },
    Response: type = struct {
        records: [][]union {
            is_null: ?bool,
            boolean_value: ?bool,
            long_value: ?i64,
            double_value: ?f64,
            string_value: ?[]const u8,
            blob_value: ?[]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .is_null = "isNull",
                    .boolean_value = "booleanValue",
                    .long_value = "longValue",
                    .double_value = "doubleValue",
                    .string_value = "stringValue",
                    .blob_value = "blobValue",
                };
                return @field(mappings, field_name);
            }
        },
        column_metadata: ?[]ColumnMetadata = null,
        total_num_rows: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records = "Records",
                .column_metadata = "ColumnMetadata",
                .total_num_rows = "TotalNumRows",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_databases: struct {
    action_name: []const u8 = "ListDatabases",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        database: []const u8,
        secret_arn: ?[]const u8 = null,
        db_user: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        workgroup_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .database = "Database",
                .secret_arn = "SecretArn",
                .db_user = "DbUser",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .workgroup_name = "WorkgroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_databases) } {
            return .{ .service_metadata = service_metadata, .action = list_databases };
        }
    },
    Response: type = struct {
        databases: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .databases = "Databases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DatabaseConnection,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_schemas: struct {
    action_name: []const u8 = "ListSchemas",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        secret_arn: ?[]const u8 = null,
        db_user: ?[]const u8 = null,
        database: []const u8,
        connected_database: ?[]const u8 = null,
        schema_pattern: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        workgroup_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .secret_arn = "SecretArn",
                .db_user = "DbUser",
                .database = "Database",
                .connected_database = "ConnectedDatabase",
                .schema_pattern = "SchemaPattern",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .workgroup_name = "WorkgroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schemas) } {
            return .{ .service_metadata = service_metadata, .action = list_schemas };
        }
    },
    Response: type = struct {
        schemas: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schemas = "Schemas",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DatabaseConnection,
        InternalServer,
        Validation,
    },
} = .{};
pub const list_statements: struct {
    action_name: []const u8 = "ListStatements",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        statement_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        role_level: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .statement_name = "StatementName",
                .status = "Status",
                .role_level = "RoleLevel",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_statements) } {
            return .{ .service_metadata = service_metadata, .action = list_statements };
        }
    },
    Response: type = struct {
        statements: []struct {
            id: []const u8,
            query_string: ?[]const u8 = null,
            query_strings: ?[][]const u8 = null,
            secret_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            statement_name: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            query_parameters: ?[]SqlParameter = null,
            is_batch_statement: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .query_string = "QueryString",
                    .query_strings = "QueryStrings",
                    .secret_arn = "SecretArn",
                    .status = "Status",
                    .statement_name = "StatementName",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .query_parameters = "QueryParameters",
                    .is_batch_statement = "IsBatchStatement",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statements = "Statements",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tables: struct {
    action_name: []const u8 = "ListTables",
    Request: type = struct {
        cluster_identifier: ?[]const u8 = null,
        secret_arn: ?[]const u8 = null,
        db_user: ?[]const u8 = null,
        database: []const u8,
        connected_database: ?[]const u8 = null,
        schema_pattern: ?[]const u8 = null,
        table_pattern: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        workgroup_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_identifier = "ClusterIdentifier",
                .secret_arn = "SecretArn",
                .db_user = "DbUser",
                .database = "Database",
                .connected_database = "ConnectedDatabase",
                .schema_pattern = "SchemaPattern",
                .table_pattern = "TablePattern",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .workgroup_name = "WorkgroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tables) } {
            return .{ .service_metadata = service_metadata, .action = list_tables };
        }
    },
    Response: type = struct {
        tables: ?[]struct {
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            schema: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .type = "type",
                    .schema = "schema",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tables = "Tables",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DatabaseConnection,
        InternalServer,
        Validation,
    },
} = .{};

pub const SqlParameter = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnMetadata = struct {
    is_case_sensitive: ?bool = null,
    is_currency: ?bool = null,
    is_signed: ?bool = null,
    label: ?[]const u8 = null,
    name: ?[]const u8 = null,
    nullable: ?i64 = null,
    precision: ?i64 = null,
    scale: ?i64 = null,
    schema_name: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    type_name: ?[]const u8 = null,
    length: ?i64 = null,
    column_default: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_case_sensitive = "isCaseSensitive",
            .is_currency = "isCurrency",
            .is_signed = "isSigned",
            .label = "label",
            .name = "name",
            .nullable = "nullable",
            .precision = "precision",
            .scale = "scale",
            .schema_name = "schemaName",
            .table_name = "tableName",
            .type_name = "typeName",
            .length = "length",
            .column_default = "columnDefault",
        };
        return @field(mappings, field_name);
    }
};
