const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-04-21";
pub const sdk_id: []const u8 = "Redshift Serverless";
pub const arn_namespace: ?[]const u8 = "redshift-serverless";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "redshift-serverless";
pub const name: []const u8 = "RedshiftServerless";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-04-21",
    sdk_id: []const u8 = "Redshift Serverless",
    arn_namespace: ?[]const u8 = "redshift-serverless",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "redshift-serverless",
    name: []const u8 = "RedshiftServerless",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_custom_domain_association: struct {
    action_name: []const u8 = "CreateCustomDomainAssociation",
    Request: type = struct {
        workgroup_name: []const u8,
        custom_domain_name: []const u8,
        custom_domain_certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workgroup_name = "workgroupName",
                .custom_domain_name = "customDomainName",
                .custom_domain_certificate_arn = "customDomainCertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_domain_association };
        }
    },
    Response: type = struct {
        custom_domain_name: ?[]const u8 = null,
        workgroup_name: ?[]const u8 = null,
        custom_domain_certificate_arn: ?[]const u8 = null,
        custom_domain_certificate_expiry_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_domain_name = "customDomainName",
                .workgroup_name = "workgroupName",
                .custom_domain_certificate_arn = "customDomainCertificateArn",
                .custom_domain_certificate_expiry_time = "customDomainCertificateExpiryTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_custom_domain_association: struct {
    action_name: []const u8 = "DeleteCustomDomainAssociation",
    Request: type = struct {
        workgroup_name: []const u8,
        custom_domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workgroup_name = "workgroupName",
                .custom_domain_name = "customDomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_domain_association };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_credentials: struct {
    action_name: []const u8 = "GetCredentials",
    Request: type = struct {
        db_name: ?[]const u8 = null,
        duration_seconds: ?i64 = null,
        workgroup_name: ?[]const u8 = null,
        custom_domain_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_name = "dbName",
                .duration_seconds = "durationSeconds",
                .workgroup_name = "workgroupName",
                .custom_domain_name = "customDomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_credentials) } {
            return .{ .service_metadata = service_metadata, .action = get_credentials };
        }
    },
    Response: type = struct {
        db_user: ?[]const u8 = null,
        db_password: ?[]const u8 = null,
        expiration: ?i64 = null,
        next_refresh_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .db_user = "dbUser",
                .db_password = "dbPassword",
                .expiration = "expiration",
                .next_refresh_time = "nextRefreshTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_custom_domain_association: struct {
    action_name: []const u8 = "GetCustomDomainAssociation",
    Request: type = struct {
        custom_domain_name: []const u8,
        workgroup_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_domain_name = "customDomainName",
                .workgroup_name = "workgroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_custom_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = get_custom_domain_association };
        }
    },
    Response: type = struct {
        custom_domain_name: ?[]const u8 = null,
        workgroup_name: ?[]const u8 = null,
        custom_domain_certificate_arn: ?[]const u8 = null,
        custom_domain_certificate_expiry_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_domain_name = "customDomainName",
                .workgroup_name = "workgroupName",
                .custom_domain_certificate_arn = "customDomainCertificateArn",
                .custom_domain_certificate_expiry_time = "customDomainCertificateExpiryTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_policy: struct {
    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        resource_policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_policy = "resourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_custom_domain_associations: struct {
    action_name: []const u8 = "ListCustomDomainAssociations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        custom_domain_name: ?[]const u8 = null,
        custom_domain_certificate_arn: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .custom_domain_name = "customDomainName",
                .custom_domain_certificate_arn = "customDomainCertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_domain_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_domain_associations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        associations: ?[]struct {
            custom_domain_certificate_arn: ?[]const u8 = null,
            custom_domain_certificate_expiry_time: ?i64 = null,
            custom_domain_name: ?[]const u8 = null,
            workgroup_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .custom_domain_certificate_arn = "customDomainCertificateArn",
                    .custom_domain_certificate_expiry_time = "customDomainCertificateExpiryTime",
                    .custom_domain_name = "customDomainName",
                    .workgroup_name = "workgroupName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .associations = "associations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidPagination,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        resource_policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_policy = "resourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        TooManyTags,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_custom_domain_association: struct {
    action_name: []const u8 = "UpdateCustomDomainAssociation",
    Request: type = struct {
        workgroup_name: []const u8,
        custom_domain_name: []const u8,
        custom_domain_certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workgroup_name = "workgroupName",
                .custom_domain_name = "customDomainName",
                .custom_domain_certificate_arn = "customDomainCertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_custom_domain_association) } {
            return .{ .service_metadata = service_metadata, .action = update_custom_domain_association };
        }
    },
    Response: type = struct {
        custom_domain_name: ?[]const u8 = null,
        workgroup_name: ?[]const u8 = null,
        custom_domain_certificate_arn: ?[]const u8 = null,
        custom_domain_certificate_expiry_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_domain_name = "customDomainName",
                .workgroup_name = "workgroupName",
                .custom_domain_certificate_arn = "customDomainCertificateArn",
                .custom_domain_certificate_expiry_time = "customDomainCertificateExpiryTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePolicy = struct {
    resource_arn: ?[]const u8 = null,
    policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "resourceArn",
            .policy = "policy",
        };
        return @field(mappings, field_name);
    }
};
