const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-06-27";
pub const sdk_id: []const u8 = "Rekognition";
pub const arn_namespace: ?[]const u8 = "rekognition";
pub const endpoint_prefix: []const u8 = "rekognition";
pub const sigv4_name: []const u8 = "rekognition";
pub const name: []const u8 = "RekognitionService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-06-27",
    sdk_id: []const u8 = "Rekognition",
    arn_namespace: ?[]const u8 = "rekognition",
    endpoint_prefix: []const u8 = "rekognition",
    sigv4_name: []const u8 = "rekognition",
    name: []const u8 = "RekognitionService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_faces: struct {
    action_name: []const u8 = "AssociateFaces",
    Request: type = struct {
        collection_id: []const u8,
        user_id: []const u8,
        face_ids: [][]const u8,
        user_match_threshold: ?f32 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .user_id = "UserId",
                .face_ids = "FaceIds",
                .user_match_threshold = "UserMatchThreshold",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_faces) } {
            return .{ .service_metadata = service_metadata, .action = associate_faces };
        }
    },
    Response: type = struct {
        associated_faces: ?[]struct {
            face_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .face_id = "FaceId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unsuccessful_face_associations: ?[]struct {
            face_id: ?[]const u8 = null,
            user_id: ?[]const u8 = null,
            confidence: ?f32 = null,
            reasons: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .face_id = "FaceId",
                    .user_id = "UserId",
                    .confidence = "Confidence",
                    .reasons = "Reasons",
                };
                return @field(mappings, field_name);
            }
        } = null,
        user_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associated_faces = "AssociatedFaces",
                .unsuccessful_face_associations = "UnsuccessfulFaceAssociations",
                .user_status = "UserStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const compare_faces: struct {
    action_name: []const u8 = "CompareFaces",
    Request: type = struct {
        source_image: Image,
        target_image: Image,
        similarity_threshold: ?f32 = null,
        quality_filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_image = "SourceImage",
                .target_image = "TargetImage",
                .similarity_threshold = "SimilarityThreshold",
                .quality_filter = "QualityFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(compare_faces) } {
            return .{ .service_metadata = service_metadata, .action = compare_faces };
        }
    },
    Response: type = struct {
        source_image_face: ?struct {
            bounding_box: ?BoundingBox = null,
            confidence: ?f32 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bounding_box = "BoundingBox",
                    .confidence = "Confidence",
                };
                return @field(mappings, field_name);
            }
        } = null,
        face_matches: ?[]struct {
            similarity: ?f32 = null,
            face: ?ComparedFace = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .similarity = "Similarity",
                    .face = "Face",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unmatched_faces: ?[]ComparedFace = null,
        source_image_orientation_correction: ?[]const u8 = null,
        target_image_orientation_correction: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_image_face = "SourceImageFace",
                .face_matches = "FaceMatches",
                .unmatched_faces = "UnmatchedFaces",
                .source_image_orientation_correction = "SourceImageOrientationCorrection",
                .target_image_orientation_correction = "TargetImageOrientationCorrection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const copy_project_version: struct {
    action_name: []const u8 = "CopyProjectVersion",
    Request: type = struct {
        source_project_arn: []const u8,
        source_project_version_arn: []const u8,
        destination_project_arn: []const u8,
        version_name: []const u8,
        output_config: OutputConfig,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_project_arn = "SourceProjectArn",
                .source_project_version_arn = "SourceProjectVersionArn",
                .destination_project_arn = "DestinationProjectArn",
                .version_name = "VersionName",
                .output_config = "OutputConfig",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_project_version) } {
            return .{ .service_metadata = service_metadata, .action = copy_project_version };
        }
    },
    Response: type = struct {
        project_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_collection: struct {
    action_name: []const u8 = "CreateCollection",
    Request: type = struct {
        collection_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_collection) } {
            return .{ .service_metadata = service_metadata, .action = create_collection };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,
        collection_arn: ?[]const u8 = null,
        face_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "StatusCode",
                .collection_arn = "CollectionArn",
                .face_model_version = "FaceModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceAlreadyExists,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_dataset: struct {
    action_name: []const u8 = "CreateDataset",
    Request: type = struct {
        dataset_source: ?struct {
            ground_truth_manifest: ?GroundTruthManifest = null,
            dataset_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ground_truth_manifest = "GroundTruthManifest",
                    .dataset_arn = "DatasetArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        dataset_type: []const u8,
        project_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_source = "DatasetSource",
                .dataset_type = "DatasetType",
                .project_arn = "ProjectArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset };
        }
    },
    Response: type = struct {
        dataset_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "DatasetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_face_liveness_session: struct {
    action_name: []const u8 = "CreateFaceLivenessSession",
    Request: type = struct {
        kms_key_id: ?[]const u8 = null,
        settings: ?struct {
            output_config: ?struct {
                s3_bucket: []const u8,
                s3_key_prefix: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3_bucket = "S3Bucket",
                        .s3_key_prefix = "S3KeyPrefix",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            audit_images_limit: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .output_config = "OutputConfig",
                    .audit_images_limit = "AuditImagesLimit",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kms_key_id = "KmsKeyId",
                .settings = "Settings",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_face_liveness_session) } {
            return .{ .service_metadata = service_metadata, .action = create_face_liveness_session };
        }
    },
    Response: type = struct {
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const create_project: struct {
    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        project_name: []const u8,
        feature: ?[]const u8 = null,
        auto_update: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .feature = "Feature",
                .auto_update = "AutoUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {
        project_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        Throttling,
    },
} = .{};
pub const create_project_version: struct {
    action_name: []const u8 = "CreateProjectVersion",
    Request: type = struct {
        project_arn: []const u8,
        version_name: []const u8,
        output_config: OutputConfig,
        training_data: ?TrainingData = null,
        testing_data: ?TestingData = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        kms_key_id: ?[]const u8 = null,
        version_description: ?[]const u8 = null,
        feature_config: ?CustomizationFeatureConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
                .version_name = "VersionName",
                .output_config = "OutputConfig",
                .training_data = "TrainingData",
                .testing_data = "TestingData",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .version_description = "VersionDescription",
                .feature_config = "FeatureConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project_version) } {
            return .{ .service_metadata = service_metadata, .action = create_project_version };
        }
    },
    Response: type = struct {
        project_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_stream_processor: struct {
    action_name: []const u8 = "CreateStreamProcessor",
    Request: type = struct {
        input: StreamProcessorInput,
        output: StreamProcessorOutput,
        name: []const u8,
        settings: StreamProcessorSettings,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        notification_channel: ?StreamProcessorNotificationChannel = null,
        kms_key_id: ?[]const u8 = null,
        regions_of_interest: ?[]RegionOfInterest = null,
        data_sharing_preference: ?StreamProcessorDataSharingPreference = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input = "Input",
                .output = "Output",
                .name = "Name",
                .settings = "Settings",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .notification_channel = "NotificationChannel",
                .kms_key_id = "KmsKeyId",
                .regions_of_interest = "RegionsOfInterest",
                .data_sharing_preference = "DataSharingPreference",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = create_stream_processor };
        }
    },
    Response: type = struct {
        stream_processor_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_processor_arn = "StreamProcessorArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_user: struct {
    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        collection_id: []const u8,
        user_id: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .user_id = "UserId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const delete_collection: struct {
    action_name: []const u8 = "DeleteCollection",
    Request: type = struct {
        collection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_collection) } {
            return .{ .service_metadata = service_metadata, .action = delete_collection };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "StatusCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_dataset: struct {
    action_name: []const u8 = "DeleteDataset",
    Request: type = struct {
        dataset_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "DatasetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_faces: struct {
    action_name: []const u8 = "DeleteFaces",
    Request: type = struct {
        collection_id: []const u8,
        face_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .face_ids = "FaceIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_faces) } {
            return .{ .service_metadata = service_metadata, .action = delete_faces };
        }
    },
    Response: type = struct {
        deleted_faces: ?[][]const u8 = null,
        unsuccessful_face_deletions: ?[]struct {
            face_id: ?[]const u8 = null,
            user_id: ?[]const u8 = null,
            reasons: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .face_id = "FaceId",
                    .user_id = "UserId",
                    .reasons = "Reasons",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deleted_faces = "DeletedFaces",
                .unsuccessful_face_deletions = "UnsuccessfulFaceDeletions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_project: struct {
    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        project_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_project_policy: struct {
    action_name: []const u8 = "DeleteProjectPolicy",
    Request: type = struct {
        project_arn: []const u8,
        policy_name: []const u8,
        policy_revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
                .policy_name = "PolicyName",
                .policy_revision_id = "PolicyRevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_project_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        InvalidPolicyRevisionId,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_project_version: struct {
    action_name: []const u8 = "DeleteProjectVersion",
    Request: type = struct {
        project_version_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_project_version };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_stream_processor: struct {
    action_name: []const u8 = "DeleteStreamProcessor",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = delete_stream_processor };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_user: struct {
    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        collection_id: []const u8,
        user_id: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .user_id = "UserId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_collection: struct {
    action_name: []const u8 = "DescribeCollection",
    Request: type = struct {
        collection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_collection) } {
            return .{ .service_metadata = service_metadata, .action = describe_collection };
        }
    },
    Response: type = struct {
        face_count: ?i64 = null,
        face_model_version: ?[]const u8 = null,
        collection_arn: ?[]const u8 = null,
        creation_timestamp: ?i64 = null,
        user_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .face_count = "FaceCount",
                .face_model_version = "FaceModelVersion",
                .collection_arn = "CollectionARN",
                .creation_timestamp = "CreationTimestamp",
                .user_count = "UserCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_dataset: struct {
    action_name: []const u8 = "DescribeDataset",
    Request: type = struct {
        dataset_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "DatasetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset };
        }
    },
    Response: type = struct {
        dataset_description: ?struct {
            creation_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            status_message_code: ?[]const u8 = null,
            dataset_stats: ?struct {
                labeled_entries: ?i64 = null,
                total_entries: ?i64 = null,
                total_labels: ?i64 = null,
                error_entries: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .labeled_entries = "LabeledEntries",
                        .total_entries = "TotalEntries",
                        .total_labels = "TotalLabels",
                        .error_entries = "ErrorEntries",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_timestamp = "CreationTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .status_message_code = "StatusMessageCode",
                    .dataset_stats = "DatasetStats",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_description = "DatasetDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_projects: struct {
    action_name: []const u8 = "DescribeProjects",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        project_names: ?[][]const u8 = null,
        features: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .project_names = "ProjectNames",
                .features = "Features",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_projects) } {
            return .{ .service_metadata = service_metadata, .action = describe_projects };
        }
    },
    Response: type = struct {
        project_descriptions: ?[]struct {
            project_arn: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            status: ?[]const u8 = null,
            datasets: ?[]struct {
                creation_timestamp: ?i64 = null,
                dataset_type: ?[]const u8 = null,
                dataset_arn: ?[]const u8 = null,
                status: ?[]const u8 = null,
                status_message: ?[]const u8 = null,
                status_message_code: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .creation_timestamp = "CreationTimestamp",
                        .dataset_type = "DatasetType",
                        .dataset_arn = "DatasetArn",
                        .status = "Status",
                        .status_message = "StatusMessage",
                        .status_message_code = "StatusMessageCode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            feature: ?[]const u8 = null,
            auto_update: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_arn = "ProjectArn",
                    .creation_timestamp = "CreationTimestamp",
                    .status = "Status",
                    .datasets = "Datasets",
                    .feature = "Feature",
                    .auto_update = "AutoUpdate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_descriptions = "ProjectDescriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const describe_project_versions: struct {
    action_name: []const u8 = "DescribeProjectVersions",
    Request: type = struct {
        project_arn: []const u8,
        version_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
                .version_names = "VersionNames",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_project_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_project_versions };
        }
    },
    Response: type = struct {
        project_version_descriptions: ?[]struct {
            project_version_arn: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            min_inference_units: ?i64 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            billable_training_time_in_seconds: ?i64 = null,
            training_end_timestamp: ?i64 = null,
            output_config: ?OutputConfig = null,
            training_data_result: ?struct {
                input: ?TrainingData = null,
                output: ?TrainingData = null,
                validation: ?ValidationData = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input = "Input",
                        .output = "Output",
                        .validation = "Validation",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            testing_data_result: ?struct {
                input: ?TestingData = null,
                output: ?TestingData = null,
                validation: ?ValidationData = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input = "Input",
                        .output = "Output",
                        .validation = "Validation",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            evaluation_result: ?struct {
                f1_score: ?f32 = null,
                summary: ?struct {
                    s3_object: ?S3Object = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .s3_object = "S3Object",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .f1_score = "F1Score",
                        .summary = "Summary",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            manifest_summary: ?GroundTruthManifest = null,
            kms_key_id: ?[]const u8 = null,
            max_inference_units: ?i64 = null,
            source_project_version_arn: ?[]const u8 = null,
            version_description: ?[]const u8 = null,
            feature: ?[]const u8 = null,
            base_model_version: ?[]const u8 = null,
            feature_config: ?CustomizationFeatureConfig = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_version_arn = "ProjectVersionArn",
                    .creation_timestamp = "CreationTimestamp",
                    .min_inference_units = "MinInferenceUnits",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .billable_training_time_in_seconds = "BillableTrainingTimeInSeconds",
                    .training_end_timestamp = "TrainingEndTimestamp",
                    .output_config = "OutputConfig",
                    .training_data_result = "TrainingDataResult",
                    .testing_data_result = "TestingDataResult",
                    .evaluation_result = "EvaluationResult",
                    .manifest_summary = "ManifestSummary",
                    .kms_key_id = "KmsKeyId",
                    .max_inference_units = "MaxInferenceUnits",
                    .source_project_version_arn = "SourceProjectVersionArn",
                    .version_description = "VersionDescription",
                    .feature = "Feature",
                    .base_model_version = "BaseModelVersion",
                    .feature_config = "FeatureConfig",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_descriptions = "ProjectVersionDescriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_stream_processor: struct {
    action_name: []const u8 = "DescribeStreamProcessor",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = describe_stream_processor };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        stream_processor_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        creation_timestamp: ?i64 = null,
        last_update_timestamp: ?i64 = null,
        input: ?StreamProcessorInput = null,
        output: ?StreamProcessorOutput = null,
        role_arn: ?[]const u8 = null,
        settings: ?StreamProcessorSettings = null,
        notification_channel: ?StreamProcessorNotificationChannel = null,
        kms_key_id: ?[]const u8 = null,
        regions_of_interest: ?[]RegionOfInterest = null,
        data_sharing_preference: ?StreamProcessorDataSharingPreference = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .stream_processor_arn = "StreamProcessorArn",
                .status = "Status",
                .status_message = "StatusMessage",
                .creation_timestamp = "CreationTimestamp",
                .last_update_timestamp = "LastUpdateTimestamp",
                .input = "Input",
                .output = "Output",
                .role_arn = "RoleArn",
                .settings = "Settings",
                .notification_channel = "NotificationChannel",
                .kms_key_id = "KmsKeyId",
                .regions_of_interest = "RegionsOfInterest",
                .data_sharing_preference = "DataSharingPreference",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const detect_custom_labels: struct {
    action_name: []const u8 = "DetectCustomLabels",
    Request: type = struct {
        project_version_arn: []const u8,
        image: Image,
        max_results: ?i64 = null,
        min_confidence: ?f32 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
                .image = "Image",
                .max_results = "MaxResults",
                .min_confidence = "MinConfidence",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_custom_labels) } {
            return .{ .service_metadata = service_metadata, .action = detect_custom_labels };
        }
    },
    Response: type = struct {
        custom_labels: ?[]struct {
            name: ?[]const u8 = null,
            confidence: ?f32 = null,
            geometry: ?Geometry = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .confidence = "Confidence",
                    .geometry = "Geometry",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_labels = "CustomLabels",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
    },
} = .{};
pub const detect_faces: struct {
    action_name: []const u8 = "DetectFaces",
    Request: type = struct {
        image: Image,
        attributes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_faces) } {
            return .{ .service_metadata = service_metadata, .action = detect_faces };
        }
    },
    Response: type = struct {
        face_details: ?[]FaceDetail = null,
        orientation_correction: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .face_details = "FaceDetails",
                .orientation_correction = "OrientationCorrection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const detect_labels: struct {
    action_name: []const u8 = "DetectLabels",
    Request: type = struct {
        image: Image,
        max_labels: ?i64 = null,
        min_confidence: ?f32 = null,
        features: ?[][]const u8 = null,
        settings: ?struct {
            general_labels: ?GeneralLabelsSettings = null,
            image_properties: ?struct {
                max_dominant_colors: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .max_dominant_colors = "MaxDominantColors",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .general_labels = "GeneralLabels",
                    .image_properties = "ImageProperties",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
                .max_labels = "MaxLabels",
                .min_confidence = "MinConfidence",
                .features = "Features",
                .settings = "Settings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_labels) } {
            return .{ .service_metadata = service_metadata, .action = detect_labels };
        }
    },
    Response: type = struct {
        labels: ?[]Label = null,
        orientation_correction: ?[]const u8 = null,
        label_model_version: ?[]const u8 = null,
        image_properties: ?struct {
            quality: ?DetectLabelsImageQuality = null,
            dominant_colors: ?[]DominantColor = null,
            foreground: ?struct {
                quality: ?DetectLabelsImageQuality = null,
                dominant_colors: ?[]DominantColor = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .quality = "Quality",
                        .dominant_colors = "DominantColors",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            background: ?struct {
                quality: ?DetectLabelsImageQuality = null,
                dominant_colors: ?[]DominantColor = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .quality = "Quality",
                        .dominant_colors = "DominantColors",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .quality = "Quality",
                    .dominant_colors = "DominantColors",
                    .foreground = "Foreground",
                    .background = "Background",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .labels = "Labels",
                .orientation_correction = "OrientationCorrection",
                .label_model_version = "LabelModelVersion",
                .image_properties = "ImageProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const detect_moderation_labels: struct {
    action_name: []const u8 = "DetectModerationLabels",
    Request: type = struct {
        image: Image,
        min_confidence: ?f32 = null,
        human_loop_config: ?struct {
            human_loop_name: []const u8,
            flow_definition_arn: []const u8,
            data_attributes: ?struct {
                content_classifiers: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .content_classifiers = "ContentClassifiers",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .human_loop_name = "HumanLoopName",
                    .flow_definition_arn = "FlowDefinitionArn",
                    .data_attributes = "DataAttributes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        project_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
                .min_confidence = "MinConfidence",
                .human_loop_config = "HumanLoopConfig",
                .project_version = "ProjectVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_moderation_labels) } {
            return .{ .service_metadata = service_metadata, .action = detect_moderation_labels };
        }
    },
    Response: type = struct {
        moderation_labels: ?[]ModerationLabel = null,
        moderation_model_version: ?[]const u8 = null,
        human_loop_activation_output: ?struct {
            human_loop_arn: ?[]const u8 = null,
            human_loop_activation_reasons: ?[][]const u8 = null,
            human_loop_activation_conditions_evaluation_results: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .human_loop_arn = "HumanLoopArn",
                    .human_loop_activation_reasons = "HumanLoopActivationReasons",
                    .human_loop_activation_conditions_evaluation_results = "HumanLoopActivationConditionsEvaluationResults",
                };
                return @field(mappings, field_name);
            }
        } = null,
        project_version: ?[]const u8 = null,
        content_types: ?[]struct {
            confidence: ?f32 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .confidence = "Confidence",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .moderation_labels = "ModerationLabels",
                .moderation_model_version = "ModerationModelVersion",
                .human_loop_activation_output = "HumanLoopActivationOutput",
                .project_version = "ProjectVersion",
                .content_types = "ContentTypes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        HumanLoopQuotaExceeded,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
    },
} = .{};
pub const detect_protective_equipment: struct {
    action_name: []const u8 = "DetectProtectiveEquipment",
    Request: type = struct {
        image: Image,
        summarization_attributes: ?struct {
            min_confidence: f32,
            required_equipment_types: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .min_confidence = "MinConfidence",
                    .required_equipment_types = "RequiredEquipmentTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
                .summarization_attributes = "SummarizationAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_protective_equipment) } {
            return .{ .service_metadata = service_metadata, .action = detect_protective_equipment };
        }
    },
    Response: type = struct {
        protective_equipment_model_version: ?[]const u8 = null,
        persons: ?[]struct {
            body_parts: ?[]struct {
                name: ?[]const u8 = null,
                confidence: ?f32 = null,
                equipment_detections: ?[]struct {
                    bounding_box: ?BoundingBox = null,
                    confidence: ?f32 = null,
                    type: ?[]const u8 = null,
                    covers_body_part: ?struct {
                        confidence: ?f32 = null,
                        value: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .confidence = "Confidence",
                                .value = "Value",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bounding_box = "BoundingBox",
                            .confidence = "Confidence",
                            .type = "Type",
                            .covers_body_part = "CoversBodyPart",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .confidence = "Confidence",
                        .equipment_detections = "EquipmentDetections",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            bounding_box: ?BoundingBox = null,
            confidence: ?f32 = null,
            id: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .body_parts = "BodyParts",
                    .bounding_box = "BoundingBox",
                    .confidence = "Confidence",
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        } = null,
        summary: ?struct {
            persons_with_required_equipment: ?[]i64 = null,
            persons_without_required_equipment: ?[]i64 = null,
            persons_indeterminate: ?[]i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .persons_with_required_equipment = "PersonsWithRequiredEquipment",
                    .persons_without_required_equipment = "PersonsWithoutRequiredEquipment",
                    .persons_indeterminate = "PersonsIndeterminate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .protective_equipment_model_version = "ProtectiveEquipmentModelVersion",
                .persons = "Persons",
                .summary = "Summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const detect_text: struct {
    action_name: []const u8 = "DetectText",
    Request: type = struct {
        image: Image,
        filters: ?struct {
            word_filter: ?DetectionFilter = null,
            regions_of_interest: ?[]RegionOfInterest = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .word_filter = "WordFilter",
                    .regions_of_interest = "RegionsOfInterest",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_text) } {
            return .{ .service_metadata = service_metadata, .action = detect_text };
        }
    },
    Response: type = struct {
        text_detections: ?[]TextDetection = null,
        text_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .text_detections = "TextDetections",
                .text_model_version = "TextModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const disassociate_faces: struct {
    action_name: []const u8 = "DisassociateFaces",
    Request: type = struct {
        collection_id: []const u8,
        user_id: []const u8,
        client_request_token: ?[]const u8 = null,
        face_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .user_id = "UserId",
                .client_request_token = "ClientRequestToken",
                .face_ids = "FaceIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_faces) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_faces };
        }
    },
    Response: type = struct {
        disassociated_faces: ?[]struct {
            face_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .face_id = "FaceId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unsuccessful_face_disassociations: ?[]struct {
            face_id: ?[]const u8 = null,
            user_id: ?[]const u8 = null,
            reasons: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .face_id = "FaceId",
                    .user_id = "UserId",
                    .reasons = "Reasons",
                };
                return @field(mappings, field_name);
            }
        } = null,
        user_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .disassociated_faces = "DisassociatedFaces",
                .unsuccessful_face_disassociations = "UnsuccessfulFaceDisassociations",
                .user_status = "UserStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const distribute_dataset_entries: struct {
    action_name: []const u8 = "DistributeDatasetEntries",
    Request: type = struct {
        datasets: []struct {
            arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datasets = "Datasets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(distribute_dataset_entries) } {
            return .{ .service_metadata = service_metadata, .action = distribute_dataset_entries };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
    },
} = .{};
pub const get_celebrity_info: struct {
    action_name: []const u8 = "GetCelebrityInfo",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_celebrity_info) } {
            return .{ .service_metadata = service_metadata, .action = get_celebrity_info };
        }
    },
    Response: type = struct {
        urls: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        known_gender: ?KnownGender = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .urls = "Urls",
                .name = "Name",
                .known_gender = "KnownGender",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_celebrity_recognition: struct {
    action_name: []const u8 = "GetCelebrityRecognition",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_celebrity_recognition) } {
            return .{ .service_metadata = service_metadata, .action = get_celebrity_recognition };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        next_token: ?[]const u8 = null,
        celebrities: ?[]struct {
            timestamp: ?i64 = null,
            celebrity: ?struct {
                urls: ?[][]const u8 = null,
                name: ?[]const u8 = null,
                id: ?[]const u8 = null,
                confidence: ?f32 = null,
                bounding_box: ?BoundingBox = null,
                face: ?FaceDetail = null,
                known_gender: ?KnownGender = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .urls = "Urls",
                        .name = "Name",
                        .id = "Id",
                        .confidence = "Confidence",
                        .bounding_box = "BoundingBox",
                        .face = "Face",
                        .known_gender = "KnownGender",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .celebrity = "Celebrity",
                };
                return @field(mappings, field_name);
            }
        } = null,
        job_id: ?[]const u8 = null,
        video: ?Video = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .next_token = "NextToken",
                .celebrities = "Celebrities",
                .job_id = "JobId",
                .video = "Video",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_content_moderation: struct {
    action_name: []const u8 = "GetContentModeration",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        aggregate_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
                .aggregate_by = "AggregateBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_content_moderation) } {
            return .{ .service_metadata = service_metadata, .action = get_content_moderation };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        moderation_labels: ?[]struct {
            timestamp: ?i64 = null,
            moderation_label: ?ModerationLabel = null,
            start_timestamp_millis: ?i64 = null,
            end_timestamp_millis: ?i64 = null,
            duration_millis: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .moderation_label = "ModerationLabel",
                    .start_timestamp_millis = "StartTimestampMillis",
                    .end_timestamp_millis = "EndTimestampMillis",
                    .duration_millis = "DurationMillis",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        moderation_model_version: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        video: ?Video = null,
        job_tag: ?[]const u8 = null,
        get_request_metadata: ?struct {
            sort_by: ?[]const u8 = null,
            aggregate_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sort_by = "SortBy",
                    .aggregate_by = "AggregateBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .moderation_labels = "ModerationLabels",
                .next_token = "NextToken",
                .moderation_model_version = "ModerationModelVersion",
                .job_id = "JobId",
                .video = "Video",
                .job_tag = "JobTag",
                .get_request_metadata = "GetRequestMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_face_detection: struct {
    action_name: []const u8 = "GetFaceDetection",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_face_detection) } {
            return .{ .service_metadata = service_metadata, .action = get_face_detection };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        next_token: ?[]const u8 = null,
        faces: ?[]struct {
            timestamp: ?i64 = null,
            face: ?FaceDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .face = "Face",
                };
                return @field(mappings, field_name);
            }
        } = null,
        job_id: ?[]const u8 = null,
        video: ?Video = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .next_token = "NextToken",
                .faces = "Faces",
                .job_id = "JobId",
                .video = "Video",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_face_liveness_session_results: struct {
    action_name: []const u8 = "GetFaceLivenessSessionResults",
    Request: type = struct {
        session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_face_liveness_session_results) } {
            return .{ .service_metadata = service_metadata, .action = get_face_liveness_session_results };
        }
    },
    Response: type = struct {
        session_id: []const u8,
        status: []const u8,
        confidence: ?f32 = null,
        reference_image: ?AuditImage = null,
        audit_images: ?[]AuditImage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
                .status = "Status",
                .confidence = "Confidence",
                .reference_image = "ReferenceImage",
                .audit_images = "AuditImages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        SessionNotFound,
        Throttling,
    },
} = .{};
pub const get_face_search: struct {
    action_name: []const u8 = "GetFaceSearch",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_face_search) } {
            return .{ .service_metadata = service_metadata, .action = get_face_search };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        persons: ?[]struct {
            timestamp: ?i64 = null,
            person: ?PersonDetail = null,
            face_matches: ?[]FaceMatch = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .person = "Person",
                    .face_matches = "FaceMatches",
                };
                return @field(mappings, field_name);
            }
        } = null,
        job_id: ?[]const u8 = null,
        video: ?Video = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .next_token = "NextToken",
                .video_metadata = "VideoMetadata",
                .persons = "Persons",
                .job_id = "JobId",
                .video = "Video",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_label_detection: struct {
    action_name: []const u8 = "GetLabelDetection",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        aggregate_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
                .aggregate_by = "AggregateBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_label_detection) } {
            return .{ .service_metadata = service_metadata, .action = get_label_detection };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        next_token: ?[]const u8 = null,
        labels: ?[]struct {
            timestamp: ?i64 = null,
            label: ?Label = null,
            start_timestamp_millis: ?i64 = null,
            end_timestamp_millis: ?i64 = null,
            duration_millis: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .label = "Label",
                    .start_timestamp_millis = "StartTimestampMillis",
                    .end_timestamp_millis = "EndTimestampMillis",
                    .duration_millis = "DurationMillis",
                };
                return @field(mappings, field_name);
            }
        } = null,
        label_model_version: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        video: ?Video = null,
        job_tag: ?[]const u8 = null,
        get_request_metadata: ?struct {
            sort_by: ?[]const u8 = null,
            aggregate_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sort_by = "SortBy",
                    .aggregate_by = "AggregateBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .next_token = "NextToken",
                .labels = "Labels",
                .label_model_version = "LabelModelVersion",
                .job_id = "JobId",
                .video = "Video",
                .job_tag = "JobTag",
                .get_request_metadata = "GetRequestMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_media_analysis_job: struct {
    action_name: []const u8 = "GetMediaAnalysisJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_media_analysis_job) } {
            return .{ .service_metadata = service_metadata, .action = get_media_analysis_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        job_name: ?[]const u8 = null,
        operations_config: MediaAnalysisOperationsConfig,
        status: []const u8,
        failure_details: ?MediaAnalysisJobFailureDetails = null,
        creation_timestamp: i64,
        completion_timestamp: ?i64 = null,
        input: MediaAnalysisInput,
        output_config: MediaAnalysisOutputConfig,
        kms_key_id: ?[]const u8 = null,
        results: ?MediaAnalysisResults = null,
        manifest_summary: ?MediaAnalysisManifestSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .job_name = "JobName",
                .operations_config = "OperationsConfig",
                .status = "Status",
                .failure_details = "FailureDetails",
                .creation_timestamp = "CreationTimestamp",
                .completion_timestamp = "CompletionTimestamp",
                .input = "Input",
                .output_config = "OutputConfig",
                .kms_key_id = "KmsKeyId",
                .results = "Results",
                .manifest_summary = "ManifestSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_person_tracking: struct {
    action_name: []const u8 = "GetPersonTracking",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_person_tracking) } {
            return .{ .service_metadata = service_metadata, .action = get_person_tracking };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        next_token: ?[]const u8 = null,
        persons: ?[]struct {
            timestamp: ?i64 = null,
            person: ?PersonDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .person = "Person",
                };
                return @field(mappings, field_name);
            }
        } = null,
        job_id: ?[]const u8 = null,
        video: ?Video = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .next_token = "NextToken",
                .persons = "Persons",
                .job_id = "JobId",
                .video = "Video",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_segment_detection: struct {
    action_name: []const u8 = "GetSegmentDetection",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_segment_detection) } {
            return .{ .service_metadata = service_metadata, .action = get_segment_detection };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?[]VideoMetadata = null,
        audio_metadata: ?[]struct {
            codec: ?[]const u8 = null,
            duration_millis: ?i64 = null,
            sample_rate: ?i64 = null,
            number_of_channels: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .codec = "Codec",
                    .duration_millis = "DurationMillis",
                    .sample_rate = "SampleRate",
                    .number_of_channels = "NumberOfChannels",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        segments: ?[]struct {
            type: ?[]const u8 = null,
            start_timestamp_millis: ?i64 = null,
            end_timestamp_millis: ?i64 = null,
            duration_millis: ?i64 = null,
            start_timecode_smpte: ?[]const u8 = null,
            end_timecode_smpte: ?[]const u8 = null,
            duration_smpte: ?[]const u8 = null,
            technical_cue_segment: ?struct {
                type: ?[]const u8 = null,
                confidence: ?f32 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .confidence = "Confidence",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            shot_segment: ?struct {
                index: ?i64 = null,
                confidence: ?f32 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .index = "Index",
                        .confidence = "Confidence",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            start_frame_number: ?i64 = null,
            end_frame_number: ?i64 = null,
            duration_frames: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .start_timestamp_millis = "StartTimestampMillis",
                    .end_timestamp_millis = "EndTimestampMillis",
                    .duration_millis = "DurationMillis",
                    .start_timecode_smpte = "StartTimecodeSMPTE",
                    .end_timecode_smpte = "EndTimecodeSMPTE",
                    .duration_smpte = "DurationSMPTE",
                    .technical_cue_segment = "TechnicalCueSegment",
                    .shot_segment = "ShotSegment",
                    .start_frame_number = "StartFrameNumber",
                    .end_frame_number = "EndFrameNumber",
                    .duration_frames = "DurationFrames",
                };
                return @field(mappings, field_name);
            }
        } = null,
        selected_segment_types: ?[]struct {
            type: ?[]const u8 = null,
            model_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .model_version = "ModelVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        job_id: ?[]const u8 = null,
        video: ?Video = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .audio_metadata = "AudioMetadata",
                .next_token = "NextToken",
                .segments = "Segments",
                .selected_segment_types = "SelectedSegmentTypes",
                .job_id = "JobId",
                .video = "Video",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_text_detection: struct {
    action_name: []const u8 = "GetTextDetection",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_text_detection) } {
            return .{ .service_metadata = service_metadata, .action = get_text_detection };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        text_detections: ?[]struct {
            timestamp: ?i64 = null,
            text_detection: ?TextDetection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .text_detection = "TextDetection",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        text_model_version: ?[]const u8 = null,
        job_id: ?[]const u8 = null,
        video: ?Video = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .text_detections = "TextDetections",
                .next_token = "NextToken",
                .text_model_version = "TextModelVersion",
                .job_id = "JobId",
                .video = "Video",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const index_faces: struct {
    action_name: []const u8 = "IndexFaces",
    Request: type = struct {
        collection_id: []const u8,
        image: Image,
        external_image_id: ?[]const u8 = null,
        detection_attributes: ?[][]const u8 = null,
        max_faces: ?i64 = null,
        quality_filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .image = "Image",
                .external_image_id = "ExternalImageId",
                .detection_attributes = "DetectionAttributes",
                .max_faces = "MaxFaces",
                .quality_filter = "QualityFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(index_faces) } {
            return .{ .service_metadata = service_metadata, .action = index_faces };
        }
    },
    Response: type = struct {
        face_records: ?[]struct {
            face: ?Face = null,
            face_detail: ?FaceDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .face = "Face",
                    .face_detail = "FaceDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,
        orientation_correction: ?[]const u8 = null,
        face_model_version: ?[]const u8 = null,
        unindexed_faces: ?[]struct {
            reasons: ?[][]const u8 = null,
            face_detail: ?FaceDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reasons = "Reasons",
                    .face_detail = "FaceDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .face_records = "FaceRecords",
                .orientation_correction = "OrientationCorrection",
                .face_model_version = "FaceModelVersion",
                .unindexed_faces = "UnindexedFaces",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const list_collections: struct {
    action_name: []const u8 = "ListCollections",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_collections) } {
            return .{ .service_metadata = service_metadata, .action = list_collections };
        }
    },
    Response: type = struct {
        collection_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        face_model_versions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_ids = "CollectionIds",
                .next_token = "NextToken",
                .face_model_versions = "FaceModelVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_dataset_entries: struct {
    action_name: []const u8 = "ListDatasetEntries",
    Request: type = struct {
        dataset_arn: []const u8,
        contains_labels: ?[][]const u8 = null,
        labeled: ?bool = null,
        source_ref_contains: ?[]const u8 = null,
        has_errors: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "DatasetArn",
                .contains_labels = "ContainsLabels",
                .labeled = "Labeled",
                .source_ref_contains = "SourceRefContains",
                .has_errors = "HasErrors",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dataset_entries) } {
            return .{ .service_metadata = service_metadata, .action = list_dataset_entries };
        }
    },
    Response: type = struct {
        dataset_entries: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_entries = "DatasetEntries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
    },
} = .{};
pub const list_dataset_labels: struct {
    action_name: []const u8 = "ListDatasetLabels",
    Request: type = struct {
        dataset_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "DatasetArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dataset_labels) } {
            return .{ .service_metadata = service_metadata, .action = list_dataset_labels };
        }
    },
    Response: type = struct {
        dataset_label_descriptions: ?[]struct {
            label_name: ?[]const u8 = null,
            label_stats: ?struct {
                entry_count: ?i64 = null,
                bounding_box_count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .entry_count = "EntryCount",
                        .bounding_box_count = "BoundingBoxCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .label_name = "LabelName",
                    .label_stats = "LabelStats",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_label_descriptions = "DatasetLabelDescriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
    },
} = .{};
pub const list_faces: struct {
    action_name: []const u8 = "ListFaces",
    Request: type = struct {
        collection_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        user_id: ?[]const u8 = null,
        face_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .user_id = "UserId",
                .face_ids = "FaceIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_faces) } {
            return .{ .service_metadata = service_metadata, .action = list_faces };
        }
    },
    Response: type = struct {
        faces: ?[]Face = null,
        next_token: ?[]const u8 = null,
        face_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .faces = "Faces",
                .next_token = "NextToken",
                .face_model_version = "FaceModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_media_analysis_jobs: struct {
    action_name: []const u8 = "ListMediaAnalysisJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_media_analysis_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_media_analysis_jobs };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        media_analysis_jobs: []struct {
            job_id: []const u8,
            job_name: ?[]const u8 = null,
            operations_config: MediaAnalysisOperationsConfig,
            status: []const u8,
            failure_details: ?MediaAnalysisJobFailureDetails = null,
            creation_timestamp: i64,
            completion_timestamp: ?i64 = null,
            input: MediaAnalysisInput,
            output_config: MediaAnalysisOutputConfig,
            kms_key_id: ?[]const u8 = null,
            results: ?MediaAnalysisResults = null,
            manifest_summary: ?MediaAnalysisManifestSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .job_name = "JobName",
                    .operations_config = "OperationsConfig",
                    .status = "Status",
                    .failure_details = "FailureDetails",
                    .creation_timestamp = "CreationTimestamp",
                    .completion_timestamp = "CompletionTimestamp",
                    .input = "Input",
                    .output_config = "OutputConfig",
                    .kms_key_id = "KmsKeyId",
                    .results = "Results",
                    .manifest_summary = "ManifestSummary",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .media_analysis_jobs = "MediaAnalysisJobs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const list_project_policies: struct {
    action_name: []const u8 = "ListProjectPolicies",
    Request: type = struct {
        project_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_project_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_project_policies };
        }
    },
    Response: type = struct {
        project_policies: ?[]struct {
            project_arn: ?[]const u8 = null,
            policy_name: ?[]const u8 = null,
            policy_revision_id: ?[]const u8 = null,
            policy_document: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_arn = "ProjectArn",
                    .policy_name = "PolicyName",
                    .policy_revision_id = "PolicyRevisionId",
                    .policy_document = "PolicyDocument",
                    .creation_timestamp = "CreationTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_policies = "ProjectPolicies",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_stream_processors: struct {
    action_name: []const u8 = "ListStreamProcessors",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_stream_processors) } {
            return .{ .service_metadata = service_metadata, .action = list_stream_processors };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        stream_processors: ?[]struct {
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .stream_processors = "StreamProcessors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_users: struct {
    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        collection_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        users: ?[]struct {
            user_id: ?[]const u8 = null,
            user_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_id = "UserId",
                    .user_status = "UserStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_project_policy: struct {
    action_name: []const u8 = "PutProjectPolicy",
    Request: type = struct {
        project_arn: []const u8,
        policy_name: []const u8,
        policy_revision_id: ?[]const u8 = null,
        policy_document: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
                .policy_name = "PolicyName",
                .policy_revision_id = "PolicyRevisionId",
                .policy_document = "PolicyDocument",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_project_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_project_policy };
        }
    },
    Response: type = struct {
        policy_revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_revision_id = "PolicyRevisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        InvalidPolicyRevisionId,
        LimitExceeded,
        MalformedPolicyDocument,
        ProvisionedThroughputExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const recognize_celebrities: struct {
    action_name: []const u8 = "RecognizeCelebrities",
    Request: type = struct {
        image: Image,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(recognize_celebrities) } {
            return .{ .service_metadata = service_metadata, .action = recognize_celebrities };
        }
    },
    Response: type = struct {
        celebrity_faces: ?[]struct {
            urls: ?[][]const u8 = null,
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            face: ?ComparedFace = null,
            match_confidence: ?f32 = null,
            known_gender: ?KnownGender = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .urls = "Urls",
                    .name = "Name",
                    .id = "Id",
                    .face = "Face",
                    .match_confidence = "MatchConfidence",
                    .known_gender = "KnownGender",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unrecognized_faces: ?[]ComparedFace = null,
        orientation_correction: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .celebrity_faces = "CelebrityFaces",
                .unrecognized_faces = "UnrecognizedFaces",
                .orientation_correction = "OrientationCorrection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const search_faces: struct {
    action_name: []const u8 = "SearchFaces",
    Request: type = struct {
        collection_id: []const u8,
        face_id: []const u8,
        max_faces: ?i64 = null,
        face_match_threshold: ?f32 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .face_id = "FaceId",
                .max_faces = "MaxFaces",
                .face_match_threshold = "FaceMatchThreshold",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_faces) } {
            return .{ .service_metadata = service_metadata, .action = search_faces };
        }
    },
    Response: type = struct {
        searched_face_id: ?[]const u8 = null,
        face_matches: ?[]FaceMatch = null,
        face_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .searched_face_id = "SearchedFaceId",
                .face_matches = "FaceMatches",
                .face_model_version = "FaceModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_faces_by_image: struct {
    action_name: []const u8 = "SearchFacesByImage",
    Request: type = struct {
        collection_id: []const u8,
        image: Image,
        max_faces: ?i64 = null,
        face_match_threshold: ?f32 = null,
        quality_filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .image = "Image",
                .max_faces = "MaxFaces",
                .face_match_threshold = "FaceMatchThreshold",
                .quality_filter = "QualityFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_faces_by_image) } {
            return .{ .service_metadata = service_metadata, .action = search_faces_by_image };
        }
    },
    Response: type = struct {
        searched_face_bounding_box: ?BoundingBox = null,
        searched_face_confidence: ?f32 = null,
        face_matches: ?[]FaceMatch = null,
        face_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .searched_face_bounding_box = "SearchedFaceBoundingBox",
                .searched_face_confidence = "SearchedFaceConfidence",
                .face_matches = "FaceMatches",
                .face_model_version = "FaceModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_users: struct {
    action_name: []const u8 = "SearchUsers",
    Request: type = struct {
        collection_id: []const u8,
        user_id: ?[]const u8 = null,
        face_id: ?[]const u8 = null,
        user_match_threshold: ?f32 = null,
        max_users: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .user_id = "UserId",
                .face_id = "FaceId",
                .user_match_threshold = "UserMatchThreshold",
                .max_users = "MaxUsers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_users) } {
            return .{ .service_metadata = service_metadata, .action = search_users };
        }
    },
    Response: type = struct {
        user_matches: ?[]UserMatch = null,
        face_model_version: ?[]const u8 = null,
        searched_face: ?struct {
            face_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .face_id = "FaceId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        searched_user: ?struct {
            user_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_id = "UserId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_matches = "UserMatches",
                .face_model_version = "FaceModelVersion",
                .searched_face = "SearchedFace",
                .searched_user = "SearchedUser",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_users_by_image: struct {
    action_name: []const u8 = "SearchUsersByImage",
    Request: type = struct {
        collection_id: []const u8,
        image: Image,
        user_match_threshold: ?f32 = null,
        max_users: ?i64 = null,
        quality_filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .image = "Image",
                .user_match_threshold = "UserMatchThreshold",
                .max_users = "MaxUsers",
                .quality_filter = "QualityFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_users_by_image) } {
            return .{ .service_metadata = service_metadata, .action = search_users_by_image };
        }
    },
    Response: type = struct {
        user_matches: ?[]UserMatch = null,
        face_model_version: ?[]const u8 = null,
        searched_face: ?struct {
            face_detail: ?FaceDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .face_detail = "FaceDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unsearched_faces: ?[]struct {
            face_details: ?FaceDetail = null,
            reasons: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .face_details = "FaceDetails",
                    .reasons = "Reasons",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_matches = "UserMatches",
                .face_model_version = "FaceModelVersion",
                .searched_face = "SearchedFace",
                .unsearched_faces = "UnsearchedFaces",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const start_celebrity_recognition: struct {
    action_name: []const u8 = "StartCelebrityRecognition",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_celebrity_recognition) } {
            return .{ .service_metadata = service_metadata, .action = start_celebrity_recognition };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_content_moderation: struct {
    action_name: []const u8 = "StartContentModeration",
    Request: type = struct {
        video: Video,
        min_confidence: ?f32 = null,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .min_confidence = "MinConfidence",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_content_moderation) } {
            return .{ .service_metadata = service_metadata, .action = start_content_moderation };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_face_detection: struct {
    action_name: []const u8 = "StartFaceDetection",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        face_attributes: ?[]const u8 = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .face_attributes = "FaceAttributes",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_face_detection) } {
            return .{ .service_metadata = service_metadata, .action = start_face_detection };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_face_search: struct {
    action_name: []const u8 = "StartFaceSearch",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        face_match_threshold: ?f32 = null,
        collection_id: []const u8,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .face_match_threshold = "FaceMatchThreshold",
                .collection_id = "CollectionId",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_face_search) } {
            return .{ .service_metadata = service_metadata, .action = start_face_search };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_label_detection: struct {
    action_name: []const u8 = "StartLabelDetection",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        min_confidence: ?f32 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,
        features: ?[][]const u8 = null,
        settings: ?struct {
            general_labels: ?GeneralLabelsSettings = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .general_labels = "GeneralLabels",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .min_confidence = "MinConfidence",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
                .features = "Features",
                .settings = "Settings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_label_detection) } {
            return .{ .service_metadata = service_metadata, .action = start_label_detection };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_media_analysis_job: struct {
    action_name: []const u8 = "StartMediaAnalysisJob",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        job_name: ?[]const u8 = null,
        operations_config: MediaAnalysisOperationsConfig,
        input: MediaAnalysisInput,
        output_config: MediaAnalysisOutputConfig,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .job_name = "JobName",
                .operations_config = "OperationsConfig",
                .input = "Input",
                .output_config = "OutputConfig",
                .kms_key_id = "KmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_media_analysis_job) } {
            return .{ .service_metadata = service_metadata, .action = start_media_analysis_job };
        }
    },
    Response: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidManifest,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
    },
} = .{};
pub const start_person_tracking: struct {
    action_name: []const u8 = "StartPersonTracking",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_person_tracking) } {
            return .{ .service_metadata = service_metadata, .action = start_person_tracking };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_project_version: struct {
    action_name: []const u8 = "StartProjectVersion",
    Request: type = struct {
        project_version_arn: []const u8,
        min_inference_units: i64,
        max_inference_units: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
                .min_inference_units = "MinInferenceUnits",
                .max_inference_units = "MaxInferenceUnits",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_project_version) } {
            return .{ .service_metadata = service_metadata, .action = start_project_version };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const start_segment_detection: struct {
    action_name: []const u8 = "StartSegmentDetection",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,
        filters: ?struct {
            technical_cue_filter: ?struct {
                min_segment_confidence: ?f32 = null,
                black_frame: ?struct {
                    max_pixel_threshold: ?f32 = null,
                    min_coverage_percentage: ?f32 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .max_pixel_threshold = "MaxPixelThreshold",
                            .min_coverage_percentage = "MinCoveragePercentage",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .min_segment_confidence = "MinSegmentConfidence",
                        .black_frame = "BlackFrame",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            shot_filter: ?struct {
                min_segment_confidence: ?f32 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .min_segment_confidence = "MinSegmentConfidence",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .technical_cue_filter = "TechnicalCueFilter",
                    .shot_filter = "ShotFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        segment_types: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
                .filters = "Filters",
                .segment_types = "SegmentTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_segment_detection) } {
            return .{ .service_metadata = service_metadata, .action = start_segment_detection };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_stream_processor: struct {
    action_name: []const u8 = "StartStreamProcessor",
    Request: type = struct {
        name: []const u8,
        start_selector: ?struct {
            kvs_stream_start_selector: ?struct {
                producer_timestamp: ?i64 = null,
                fragment_number: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .producer_timestamp = "ProducerTimestamp",
                        .fragment_number = "FragmentNumber",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .kvs_stream_start_selector = "KVSStreamStartSelector",
                };
                return @field(mappings, field_name);
            }
        } = null,
        stop_selector: ?struct {
            max_duration_in_seconds: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .max_duration_in_seconds = "MaxDurationInSeconds",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .start_selector = "StartSelector",
                .stop_selector = "StopSelector",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = start_stream_processor };
        }
    },
    Response: type = struct {
        session_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "SessionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const start_text_detection: struct {
    action_name: []const u8 = "StartTextDetection",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,
        filters: ?struct {
            word_filter: ?DetectionFilter = null,
            regions_of_interest: ?[]RegionOfInterest = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .word_filter = "WordFilter",
                    .regions_of_interest = "RegionsOfInterest",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_text_detection) } {
            return .{ .service_metadata = service_metadata, .action = start_text_detection };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const stop_project_version: struct {
    action_name: []const u8 = "StopProjectVersion",
    Request: type = struct {
        project_version_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_project_version) } {
            return .{ .service_metadata = service_metadata, .action = stop_project_version };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const stop_stream_processor: struct {
    action_name: []const u8 = "StopStreamProcessor",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = stop_stream_processor };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_dataset_entries: struct {
    action_name: []const u8 = "UpdateDatasetEntries",
    Request: type = struct {
        dataset_arn: []const u8,
        changes: struct {
            ground_truth: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ground_truth = "GroundTruth",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "DatasetArn",
                .changes = "Changes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dataset_entries) } {
            return .{ .service_metadata = service_metadata, .action = update_dataset_entries };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_stream_processor: struct {
    action_name: []const u8 = "UpdateStreamProcessor",
    Request: type = struct {
        name: []const u8,
        settings_for_update: ?struct {
            connected_home_for_update: ?struct {
                labels: ?[][]const u8 = null,
                min_confidence: ?f32 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .labels = "Labels",
                        .min_confidence = "MinConfidence",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connected_home_for_update = "ConnectedHomeForUpdate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        regions_of_interest_for_update: ?[]RegionOfInterest = null,
        data_sharing_preference_for_update: ?StreamProcessorDataSharingPreference = null,
        parameters_to_delete: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .settings_for_update = "SettingsForUpdate",
                .regions_of_interest_for_update = "RegionsOfInterestForUpdate",
                .data_sharing_preference_for_update = "DataSharingPreferenceForUpdate",
                .parameters_to_delete = "ParametersToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = update_stream_processor };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const StreamProcessorDataSharingPreference = struct {
    opt_in: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .opt_in = "OptIn",
        };
        return @field(mappings, field_name);
    }
};

pub const RegionOfInterest = struct {
    bounding_box: ?BoundingBox = null,
    polygon: ?[]Point = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .polygon = "Polygon",
        };
        return @field(mappings, field_name);
    }
};

pub const Point = struct {
    x: ?f32 = null,
    y: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .x = "X",
            .y = "Y",
        };
        return @field(mappings, field_name);
    }
};

pub const BoundingBox = struct {
    width: ?f32 = null,
    height: ?f32 = null,
    left: ?f32 = null,
    top: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .width = "Width",
            .height = "Height",
            .left = "Left",
            .top = "Top",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectionFilter = struct {
    min_confidence: ?f32 = null,
    min_bounding_box_height: ?f32 = null,
    min_bounding_box_width: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_confidence = "MinConfidence",
            .min_bounding_box_height = "MinBoundingBoxHeight",
            .min_bounding_box_width = "MinBoundingBoxWidth",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationChannel = struct {
    sns_topic_arn: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_topic_arn = "SNSTopicArn",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Video = struct {
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Object = struct {
    bucket: ?[]const u8 = null,
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .name = "Name",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaAnalysisOutputConfig = struct {
    s3_bucket: []const u8,
    s3_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_key_prefix = "S3KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaAnalysisInput = struct {
    s3_object: S3Object,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaAnalysisOperationsConfig = struct {
    detect_moderation_labels: ?MediaAnalysisDetectModerationLabelsConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detect_moderation_labels = "DetectModerationLabels",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaAnalysisDetectModerationLabelsConfig = struct {
    min_confidence: ?f32 = null,
    project_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_confidence = "MinConfidence",
            .project_version = "ProjectVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const GeneralLabelsSettings = struct {
    label_inclusion_filters: ?[][]const u8 = null,
    label_exclusion_filters: ?[][]const u8 = null,
    label_category_inclusion_filters: ?[][]const u8 = null,
    label_category_exclusion_filters: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .label_inclusion_filters = "LabelInclusionFilters",
            .label_exclusion_filters = "LabelExclusionFilters",
            .label_category_inclusion_filters = "LabelCategoryInclusionFilters",
            .label_category_exclusion_filters = "LabelCategoryExclusionFilters",
        };
        return @field(mappings, field_name);
    }
};

pub const FaceDetail = struct {
    bounding_box: ?BoundingBox = null,
    age_range: ?AgeRange = null,
    smile: ?Smile = null,
    eyeglasses: ?Eyeglasses = null,
    sunglasses: ?Sunglasses = null,
    gender: ?Gender = null,
    beard: ?Beard = null,
    mustache: ?Mustache = null,
    eyes_open: ?EyeOpen = null,
    mouth_open: ?MouthOpen = null,
    emotions: ?[]Emotion = null,
    landmarks: ?[]Landmark = null,
    pose: ?Pose = null,
    quality: ?ImageQuality = null,
    confidence: ?f32 = null,
    face_occluded: ?FaceOccluded = null,
    eye_direction: ?EyeDirection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .age_range = "AgeRange",
            .smile = "Smile",
            .eyeglasses = "Eyeglasses",
            .sunglasses = "Sunglasses",
            .gender = "Gender",
            .beard = "Beard",
            .mustache = "Mustache",
            .eyes_open = "EyesOpen",
            .mouth_open = "MouthOpen",
            .emotions = "Emotions",
            .landmarks = "Landmarks",
            .pose = "Pose",
            .quality = "Quality",
            .confidence = "Confidence",
            .face_occluded = "FaceOccluded",
            .eye_direction = "EyeDirection",
        };
        return @field(mappings, field_name);
    }
};

pub const EyeDirection = struct {
    yaw: ?f32 = null,
    pitch: ?f32 = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .yaw = "Yaw",
            .pitch = "Pitch",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const FaceOccluded = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageQuality = struct {
    brightness: ?f32 = null,
    sharpness: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .brightness = "Brightness",
            .sharpness = "Sharpness",
        };
        return @field(mappings, field_name);
    }
};

pub const Pose = struct {
    roll: ?f32 = null,
    yaw: ?f32 = null,
    pitch: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .roll = "Roll",
            .yaw = "Yaw",
            .pitch = "Pitch",
        };
        return @field(mappings, field_name);
    }
};

pub const Landmark = struct {
    type: ?[]const u8 = null,
    x: ?f32 = null,
    y: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .x = "X",
            .y = "Y",
        };
        return @field(mappings, field_name);
    }
};

pub const Emotion = struct {
    type: ?[]const u8 = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const MouthOpen = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const EyeOpen = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Mustache = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Beard = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Gender = struct {
    value: ?[]const u8 = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Sunglasses = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Eyeglasses = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Smile = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const AgeRange = struct {
    low: ?i64 = null,
    high: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .low = "Low",
            .high = "High",
        };
        return @field(mappings, field_name);
    }
};

pub const UserMatch = struct {
    similarity: ?f32 = null,
    user: ?MatchedUser = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .similarity = "Similarity",
            .user = "User",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchedUser = struct {
    user_id: ?[]const u8 = null,
    user_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_id = "UserId",
            .user_status = "UserStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Image = struct {
    bytes: ?[]const u8 = null,
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bytes = "Bytes",
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const FaceMatch = struct {
    similarity: ?f32 = null,
    face: ?Face = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .similarity = "Similarity",
            .face = "Face",
        };
        return @field(mappings, field_name);
    }
};

pub const Face = struct {
    face_id: ?[]const u8 = null,
    bounding_box: ?BoundingBox = null,
    image_id: ?[]const u8 = null,
    external_image_id: ?[]const u8 = null,
    confidence: ?f32 = null,
    index_faces_model_version: ?[]const u8 = null,
    user_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .face_id = "FaceId",
            .bounding_box = "BoundingBox",
            .image_id = "ImageId",
            .external_image_id = "ExternalImageId",
            .confidence = "Confidence",
            .index_faces_model_version = "IndexFacesModelVersion",
            .user_id = "UserId",
        };
        return @field(mappings, field_name);
    }
};

pub const ComparedFace = struct {
    bounding_box: ?BoundingBox = null,
    confidence: ?f32 = null,
    landmarks: ?[]Landmark = null,
    pose: ?Pose = null,
    quality: ?ImageQuality = null,
    emotions: ?[]Emotion = null,
    smile: ?Smile = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .confidence = "Confidence",
            .landmarks = "Landmarks",
            .pose = "Pose",
            .quality = "Quality",
            .emotions = "Emotions",
            .smile = "Smile",
        };
        return @field(mappings, field_name);
    }
};

pub const KnownGender = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaAnalysisManifestSummary = struct {
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaAnalysisResults = struct {
    s3_object: ?S3Object = null,
    model_versions: ?MediaAnalysisModelVersions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object = "S3Object",
            .model_versions = "ModelVersions",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaAnalysisModelVersions = struct {
    moderation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .moderation = "Moderation",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaAnalysisJobFailureDetails = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const TextDetection = struct {
    detected_text: ?[]const u8 = null,
    type: ?[]const u8 = null,
    id: ?i64 = null,
    parent_id: ?i64 = null,
    confidence: ?f32 = null,
    geometry: ?Geometry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detected_text = "DetectedText",
            .type = "Type",
            .id = "Id",
            .parent_id = "ParentId",
            .confidence = "Confidence",
            .geometry = "Geometry",
        };
        return @field(mappings, field_name);
    }
};

pub const Geometry = struct {
    bounding_box: ?BoundingBox = null,
    polygon: ?[]Point = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .polygon = "Polygon",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoMetadata = struct {
    codec: ?[]const u8 = null,
    duration_millis: ?i64 = null,
    format: ?[]const u8 = null,
    frame_rate: ?f32 = null,
    frame_height: ?i64 = null,
    frame_width: ?i64 = null,
    color_range: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .codec = "Codec",
            .duration_millis = "DurationMillis",
            .format = "Format",
            .frame_rate = "FrameRate",
            .frame_height = "FrameHeight",
            .frame_width = "FrameWidth",
            .color_range = "ColorRange",
        };
        return @field(mappings, field_name);
    }
};

pub const PersonDetail = struct {
    index: ?i64 = null,
    bounding_box: ?BoundingBox = null,
    face: ?FaceDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index = "Index",
            .bounding_box = "BoundingBox",
            .face = "Face",
        };
        return @field(mappings, field_name);
    }
};

pub const Label = struct {
    name: ?[]const u8 = null,
    confidence: ?f32 = null,
    instances: ?[]Instance = null,
    parents: ?[]Parent = null,
    aliases: ?[]LabelAlias = null,
    categories: ?[]LabelCategory = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .confidence = "Confidence",
            .instances = "Instances",
            .parents = "Parents",
            .aliases = "Aliases",
            .categories = "Categories",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelCategory = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelAlias = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Parent = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Instance = struct {
    bounding_box: ?BoundingBox = null,
    confidence: ?f32 = null,
    dominant_colors: ?[]DominantColor = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .confidence = "Confidence",
            .dominant_colors = "DominantColors",
        };
        return @field(mappings, field_name);
    }
};

pub const DominantColor = struct {
    red: ?i64 = null,
    blue: ?i64 = null,
    green: ?i64 = null,
    hex_code: ?[]const u8 = null,
    css_color: ?[]const u8 = null,
    simplified_color: ?[]const u8 = null,
    pixel_percent: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .red = "Red",
            .blue = "Blue",
            .green = "Green",
            .hex_code = "HexCode",
            .css_color = "CSSColor",
            .simplified_color = "SimplifiedColor",
            .pixel_percent = "PixelPercent",
        };
        return @field(mappings, field_name);
    }
};

pub const AuditImage = struct {
    bytes: ?[]const u8 = null,
    s3_object: ?S3Object = null,
    bounding_box: ?BoundingBox = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bytes = "Bytes",
            .s3_object = "S3Object",
            .bounding_box = "BoundingBox",
        };
        return @field(mappings, field_name);
    }
};

pub const ModerationLabel = struct {
    confidence: ?f32 = null,
    name: ?[]const u8 = null,
    parent_name: ?[]const u8 = null,
    taxonomy_level: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .confidence = "Confidence",
            .name = "Name",
            .parent_name = "ParentName",
            .taxonomy_level = "TaxonomyLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectLabelsImageQuality = struct {
    brightness: ?f32 = null,
    sharpness: ?f32 = null,
    contrast: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .brightness = "Brightness",
            .sharpness = "Sharpness",
            .contrast = "Contrast",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamProcessorNotificationChannel = struct {
    sns_topic_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_topic_arn = "SNSTopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamProcessorSettings = struct {
    face_search: ?FaceSearchSettings = null,
    connected_home: ?ConnectedHomeSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .face_search = "FaceSearch",
            .connected_home = "ConnectedHome",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectedHomeSettings = struct {
    labels: [][]const u8,
    min_confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .labels = "Labels",
            .min_confidence = "MinConfidence",
        };
        return @field(mappings, field_name);
    }
};

pub const FaceSearchSettings = struct {
    collection_id: ?[]const u8 = null,
    face_match_threshold: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .collection_id = "CollectionId",
            .face_match_threshold = "FaceMatchThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamProcessorOutput = struct {
    kinesis_data_stream: ?KinesisDataStream = null,
    s3_destination: ?S3Destination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kinesis_data_stream = "KinesisDataStream",
            .s3_destination = "S3Destination",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Destination = struct {
    bucket: ?[]const u8 = null,
    key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key_prefix = "KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisDataStream = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamProcessorInput = struct {
    kinesis_video_stream: ?KinesisVideoStream = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kinesis_video_stream = "KinesisVideoStream",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisVideoStream = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomizationFeatureConfig = struct {
    content_moderation: ?CustomizationFeatureContentModerationConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_moderation = "ContentModeration",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomizationFeatureContentModerationConfig = struct {
    confidence_threshold: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .confidence_threshold = "ConfidenceThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const GroundTruthManifest = struct {
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const ValidationData = struct {
    assets: ?[]Asset = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assets = "Assets",
        };
        return @field(mappings, field_name);
    }
};

pub const Asset = struct {
    ground_truth_manifest: ?GroundTruthManifest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ground_truth_manifest = "GroundTruthManifest",
        };
        return @field(mappings, field_name);
    }
};

pub const TestingData = struct {
    assets: ?[]Asset = null,
    auto_create: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assets = "Assets",
            .auto_create = "AutoCreate",
        };
        return @field(mappings, field_name);
    }
};

pub const TrainingData = struct {
    assets: ?[]Asset = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assets = "Assets",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputConfig = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_key_prefix = "S3KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};
