const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-05-13";
pub const sdk_id: []const u8 = "repostspace";
pub const arn_namespace: ?[]const u8 = "repostspace";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "repostspace";
pub const name: []const u8 = "RepostSpace";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2022-05-13",
    sdk_id: []const u8 = "repostspace",
    arn_namespace: ?[]const u8 = "repostspace",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "repostspace",
    name: []const u8 = "RepostSpace",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_space: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/spaces",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSpace",
    Request: type = struct {
        name: []const u8,
        subdomain: []const u8,
        tier: []const u8,
        description: ?[]const u8 = null,
        user_kms_key: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .subdomain = "subdomain",
                .tier = "tier",
                .description = "description",
                .user_kms_key = "userKMSKey",
                .tags = "tags",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_space) } {
            return .{ .service_metadata = service_metadata, .action = create_space };
        }
    },
    Response: type = struct {
        space_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .space_id = "spaceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_space: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/spaces/{spaceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSpace",
    Request: type = struct {
        space_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .space_id = "spaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_space) } {
            return .{ .service_metadata = service_metadata, .action = delete_space };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const deregister_admin: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/spaces/{spaceId}/admins/{adminId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterAdmin",
    Request: type = struct {
        space_id: []const u8,
        admin_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .space_id = "spaceId",
                .admin_id = "adminId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_admin) } {
            return .{ .service_metadata = service_metadata, .action = deregister_admin };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_space: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/spaces/{spaceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSpace",
    Request: type = struct {
        space_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .space_id = "spaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_space) } {
            return .{ .service_metadata = service_metadata, .action = get_space };
        }
    },
    Response: type = struct {
        space_id: []const u8,
        arn: []const u8,
        name: []const u8,
        status: []const u8,
        configuration_status: []const u8,
        client_id: []const u8,
        description: ?[]const u8 = null,
        vanity_domain_status: []const u8,
        vanity_domain: []const u8,
        random_domain: []const u8,
        customer_role_arn: ?[]const u8 = null,
        create_date_time: i64,
        delete_date_time: ?i64 = null,
        tier: []const u8,
        storage_limit: i64,
        user_admins: ?[][]const u8 = null,
        group_admins: ?[][]const u8 = null,
        user_kms_key: ?[]const u8 = null,
        user_count: ?i64 = null,
        content_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .space_id = "spaceId",
                .arn = "arn",
                .name = "name",
                .status = "status",
                .configuration_status = "configurationStatus",
                .client_id = "clientId",
                .description = "description",
                .vanity_domain_status = "vanityDomainStatus",
                .vanity_domain = "vanityDomain",
                .random_domain = "randomDomain",
                .customer_role_arn = "customerRoleArn",
                .create_date_time = "createDateTime",
                .delete_date_time = "deleteDateTime",
                .tier = "tier",
                .storage_limit = "storageLimit",
                .user_admins = "userAdmins",
                .group_admins = "groupAdmins",
                .user_kms_key = "userKMSKey",
                .user_count = "userCount",
                .content_size = "contentSize",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_spaces: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/spaces",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSpaces",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_spaces) } {
            return .{ .service_metadata = service_metadata, .action = list_spaces };
        }
    },
    Response: type = struct {
        spaces: []struct {
            space_id: []const u8,
            arn: []const u8,
            name: []const u8,
            description: ?[]const u8 = null,
            status: []const u8,
            configuration_status: []const u8,
            vanity_domain_status: []const u8,
            vanity_domain: []const u8,
            random_domain: []const u8,
            tier: []const u8,
            storage_limit: i64,
            create_date_time: i64,
            delete_date_time: ?i64 = null,
            user_kms_key: ?[]const u8 = null,
            user_count: ?i64 = null,
            content_size: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .space_id = "spaceId",
                    .arn = "arn",
                    .name = "name",
                    .description = "description",
                    .status = "status",
                    .configuration_status = "configurationStatus",
                    .vanity_domain_status = "vanityDomainStatus",
                    .vanity_domain = "vanityDomain",
                    .random_domain = "randomDomain",
                    .tier = "tier",
                    .storage_limit = "storageLimit",
                    .create_date_time = "createDateTime",
                    .delete_date_time = "deleteDateTime",
                    .user_kms_key = "userKMSKey",
                    .user_count = "userCount",
                    .content_size = "contentSize",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .spaces = "spaces",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const register_admin: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/spaces/{spaceId}/admins/{adminId}",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterAdmin",
    Request: type = struct {
        space_id: []const u8,
        admin_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .space_id = "spaceId",
                .admin_id = "adminId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_admin) } {
            return .{ .service_metadata = service_metadata, .action = register_admin };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const send_invites: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/spaces/{spaceId}/invite",
        .success_code = 200,
    };

    action_name: []const u8 = "SendInvites",
    Request: type = struct {
        space_id: []const u8,
        accessor_ids: [][]const u8,
        title: []const u8,
        body: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .space_id = "spaceId",
                .accessor_ids = "accessorIds",
                .title = "title",
                .body = "body",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_invites) } {
            return .{ .service_metadata = service_metadata, .action = send_invites };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_space: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/spaces/{spaceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSpace",
    Request: type = struct {
        space_id: []const u8,
        description: ?[]const u8 = null,
        tier: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .space_id = "spaceId",
                .description = "description",
                .tier = "tier",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_space) } {
            return .{ .service_metadata = service_metadata, .action = update_space };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
