const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-04-30";
pub const sdk_id: []const u8 = "resiliencehub";
pub const arn_namespace: ?[]const u8 = "resiliencehub";
pub const endpoint_prefix: []const u8 = "resiliencehub";
pub const sigv4_name: []const u8 = "resiliencehub";
pub const name: []const u8 = "AwsResilienceHub";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-04-30",
    sdk_id: []const u8 = "resiliencehub",
    arn_namespace: ?[]const u8 = "resiliencehub",
    endpoint_prefix: []const u8 = "resiliencehub",
    sigv4_name: []const u8 = "resiliencehub",
    name: []const u8 = "AwsResilienceHub",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const add_draft_app_version_resource_mappings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/add-draft-app-version-resource-mappings",
        .success_code = 200,
    };

    action_name: []const u8 = "AddDraftAppVersionResourceMappings",
    Request: type = struct {
        app_arn: []const u8,
        resource_mappings: []ResourceMapping,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .resource_mappings = "resourceMappings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_draft_app_version_resource_mappings) } {
            return .{ .service_metadata = service_metadata, .action = add_draft_app_version_resource_mappings };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        resource_mappings: []ResourceMapping,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .resource_mappings = "resourceMappings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const batch_update_recommendation_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/batch-update-recommendation-status",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateRecommendationStatus",
    Request: type = struct {
        app_arn: []const u8,
        request_entries: []struct {
            entry_id: []const u8,
            reference_id: []const u8,
            item: UpdateRecommendationStatusItem,
            excluded: bool,
            exclude_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .reference_id = "referenceId",
                    .item = "item",
                    .excluded = "excluded",
                    .exclude_reason = "excludeReason",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .request_entries = "requestEntries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_recommendation_status) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_recommendation_status };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        successful_entries: []struct {
            entry_id: []const u8,
            reference_id: []const u8,
            item: UpdateRecommendationStatusItem,
            excluded: bool,
            exclude_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .reference_id = "referenceId",
                    .item = "item",
                    .excluded = "excluded",
                    .exclude_reason = "excludeReason",
                };
                return @field(mappings, field_name);
            }
        },
        failed_entries: []struct {
            entry_id: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entry_id = "entryId",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .successful_entries = "successfulEntries",
                .failed_entries = "failedEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_app: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/create-app",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateApp",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        policy_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,
        assessment_schedule: ?[]const u8 = null,
        permission_model: ?PermissionModel = null,
        event_subscriptions: ?[]EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .policy_arn = "policyArn",
                .tags = "tags",
                .client_token = "clientToken",
                .assessment_schedule = "assessmentSchedule",
                .permission_model = "permissionModel",
                .event_subscriptions = "eventSubscriptions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app) } {
            return .{ .service_metadata = service_metadata, .action = create_app };
        }
    },
    Response: type = struct {
        app: App,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app = "app",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_app_version_app_component: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/create-app-version-app-component",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAppVersionAppComponent",
    Request: type = struct {
        app_arn: []const u8,
        id: ?[]const u8 = null,
        name: []const u8,
        type: []const u8,
        additional_info: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .id = "id",
                .name = "name",
                .type = "type",
                .additional_info = "additionalInfo",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_info", field_name))
                return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_version_app_component) } {
            return .{ .service_metadata = service_metadata, .action = create_app_version_app_component };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        app_component: ?AppComponent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .app_component = "appComponent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_app_version_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/create-app-version-resource",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAppVersionResource",
    Request: type = struct {
        app_arn: []const u8,
        resource_name: ?[]const u8 = null,
        logical_resource_id: LogicalResourceId,
        physical_resource_id: []const u8,
        aws_region: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        resource_type: []const u8,
        app_components: [][]const u8,
        additional_info: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .resource_name = "resourceName",
                .logical_resource_id = "logicalResourceId",
                .physical_resource_id = "physicalResourceId",
                .aws_region = "awsRegion",
                .aws_account_id = "awsAccountId",
                .resource_type = "resourceType",
                .app_components = "appComponents",
                .additional_info = "additionalInfo",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_info", field_name))
                return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_version_resource) } {
            return .{ .service_metadata = service_metadata, .action = create_app_version_resource };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        physical_resource: ?PhysicalResource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .physical_resource = "physicalResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_recommendation_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/create-recommendation-template",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRecommendationTemplate",
    Request: type = struct {
        recommendation_ids: ?[][]const u8 = null,
        format: ?[]const u8 = null,
        recommendation_types: ?[][]const u8 = null,
        assessment_arn: []const u8,
        name: []const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        bucket_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_ids = "recommendationIds",
                .format = "format",
                .recommendation_types = "recommendationTypes",
                .assessment_arn = "assessmentArn",
                .name = "name",
                .client_token = "clientToken",
                .tags = "tags",
                .bucket_name = "bucketName",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_recommendation_template) } {
            return .{ .service_metadata = service_metadata, .action = create_recommendation_template };
        }
    },
    Response: type = struct {
        recommendation_template: ?RecommendationTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_template = "recommendationTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_resiliency_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/create-resiliency-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateResiliencyPolicy",
    Request: type = struct {
        policy_name: []const u8,
        policy_description: ?[]const u8 = null,
        data_location_constraint: ?[]const u8 = null,
        tier: []const u8,
        policy: []struct {
            key: ?[]const u8 = null,
            value: ?FailurePolicy = null,
        },
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .policy_description = "policyDescription",
                .data_location_constraint = "dataLocationConstraint",
                .tier = "tier",
                .policy = "policy",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "policy", field_name))
                return try serializeMap(self.policy, self.fieldNameFor("policy"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resiliency_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_resiliency_policy };
        }
    },
    Response: type = struct {
        policy: ResiliencyPolicy,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_app: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-app",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApp",
    Request: type = struct {
        app_arn: []const u8,
        force_delete: ?bool = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .force_delete = "forceDelete",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app) } {
            return .{ .service_metadata = service_metadata, .action = delete_app };
        }
    },
    Response: type = struct {
        app_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_app_assessment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-app-assessment",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAppAssessment",
    Request: type = struct {
        assessment_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_arn = "assessmentArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_assessment) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_assessment };
        }
    },
    Response: type = struct {
        assessment_arn: []const u8,
        assessment_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_arn = "assessmentArn",
                .assessment_status = "assessmentStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_app_input_source: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-app-input-source",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAppInputSource",
    Request: type = struct {
        app_arn: []const u8,
        source_arn: ?[]const u8 = null,
        terraform_source: ?TerraformSource = null,
        client_token: ?[]const u8 = null,
        eks_source_cluster_namespace: ?EksSourceClusterNamespace = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .source_arn = "sourceArn",
                .terraform_source = "terraformSource",
                .client_token = "clientToken",
                .eks_source_cluster_namespace = "eksSourceClusterNamespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_input_source) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_input_source };
        }
    },
    Response: type = struct {
        app_arn: ?[]const u8 = null,
        app_input_source: ?AppInputSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_input_source = "appInputSource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_app_version_app_component: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-app-version-app-component",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAppVersionAppComponent",
    Request: type = struct {
        app_arn: []const u8,
        id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .id = "id",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_version_app_component) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_version_app_component };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        app_component: ?AppComponent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .app_component = "appComponent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_app_version_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-app-version-resource",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAppVersionResource",
    Request: type = struct {
        app_arn: []const u8,
        resource_name: ?[]const u8 = null,
        logical_resource_id: ?LogicalResourceId = null,
        physical_resource_id: ?[]const u8 = null,
        aws_region: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .resource_name = "resourceName",
                .logical_resource_id = "logicalResourceId",
                .physical_resource_id = "physicalResourceId",
                .aws_region = "awsRegion",
                .aws_account_id = "awsAccountId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_version_resource) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_version_resource };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        physical_resource: ?PhysicalResource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .physical_resource = "physicalResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_recommendation_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-recommendation-template",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRecommendationTemplate",
    Request: type = struct {
        recommendation_template_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_template_arn = "recommendationTemplateArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_recommendation_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_recommendation_template };
        }
    },
    Response: type = struct {
        recommendation_template_arn: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_template_arn = "recommendationTemplateArn",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resiliency_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-resiliency-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteResiliencyPolicy",
    Request: type = struct {
        policy_arn: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_arn = "policyArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resiliency_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resiliency_policy };
        }
    },
    Response: type = struct {
        policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_arn = "policyArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_app: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-app",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeApp",
    Request: type = struct {
        app_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app) } {
            return .{ .service_metadata = service_metadata, .action = describe_app };
        }
    },
    Response: type = struct {
        app: App,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app = "app",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_app_assessment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-app-assessment",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppAssessment",
    Request: type = struct {
        assessment_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_arn = "assessmentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_assessment) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_assessment };
        }
    },
    Response: type = struct {
        assessment: AppAssessment,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment = "assessment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_app_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-app-version",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppVersion",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_version) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_version };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        additional_info: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .additional_info = "additionalInfo",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_info", field_name))
                return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_app_version_app_component: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-app-version-app-component",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppVersionAppComponent",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_version_app_component) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_version_app_component };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        app_component: ?AppComponent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .app_component = "appComponent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_app_version_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-app-version-resource",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppVersionResource",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        resource_name: ?[]const u8 = null,
        logical_resource_id: ?LogicalResourceId = null,
        physical_resource_id: ?[]const u8 = null,
        aws_region: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .resource_name = "resourceName",
                .logical_resource_id = "logicalResourceId",
                .physical_resource_id = "physicalResourceId",
                .aws_region = "awsRegion",
                .aws_account_id = "awsAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_version_resource) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_version_resource };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        physical_resource: ?PhysicalResource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .physical_resource = "physicalResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_app_version_resources_resolution_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-app-version-resources-resolution-status",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppVersionResourcesResolutionStatus",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        resolution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .resolution_id = "resolutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_version_resources_resolution_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_version_resources_resolution_status };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        resolution_id: []const u8,
        status: []const u8,
        error_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .resolution_id = "resolutionId",
                .status = "status",
                .error_message = "errorMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_app_version_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-app-version-template",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppVersionTemplate",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_version_template) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_version_template };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        app_template_body: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .app_template_body = "appTemplateBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_draft_app_version_resources_import_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-draft-app-version-resources-import-status",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDraftAppVersionResourcesImportStatus",
    Request: type = struct {
        app_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_draft_app_version_resources_import_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_draft_app_version_resources_import_status };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        status: []const u8,
        status_change_time: i64,
        error_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .status = "status",
                .status_change_time = "statusChangeTime",
                .error_message = "errorMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_resiliency_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describe-resiliency-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeResiliencyPolicy",
    Request: type = struct {
        policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_arn = "policyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resiliency_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_resiliency_policy };
        }
    },
    Response: type = struct {
        policy: ResiliencyPolicy,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const import_resources_to_draft_app_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/import-resources-to-draft-app-version",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportResourcesToDraftAppVersion",
    Request: type = struct {
        app_arn: []const u8,
        source_arns: ?[][]const u8 = null,
        terraform_sources: ?[]TerraformSource = null,
        import_strategy: ?[]const u8 = null,
        eks_sources: ?[]EksSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .source_arns = "sourceArns",
                .terraform_sources = "terraformSources",
                .import_strategy = "importStrategy",
                .eks_sources = "eksSources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_resources_to_draft_app_version) } {
            return .{ .service_metadata = service_metadata, .action = import_resources_to_draft_app_version };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        source_arns: ?[][]const u8 = null,
        status: []const u8,
        terraform_sources: ?[]TerraformSource = null,
        eks_sources: ?[]EksSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .source_arns = "sourceArns",
                .status = "status",
                .terraform_sources = "terraformSources",
                .eks_sources = "eksSources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_alarm_recommendations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-alarm-recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAlarmRecommendations",
    Request: type = struct {
        assessment_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_arn = "assessmentArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_alarm_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_alarm_recommendations };
        }
    },
    Response: type = struct {
        alarm_recommendations: []struct {
            recommendation_id: []const u8,
            reference_id: []const u8,
            name: []const u8,
            description: ?[]const u8 = null,
            type: []const u8,
            app_component_name: ?[]const u8 = null,
            items: ?[]RecommendationItem = null,
            prerequisite: ?[]const u8 = null,
            app_component_names: ?[][]const u8 = null,
            recommendation_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation_id = "recommendationId",
                    .reference_id = "referenceId",
                    .name = "name",
                    .description = "description",
                    .type = "type",
                    .app_component_name = "appComponentName",
                    .items = "items",
                    .prerequisite = "prerequisite",
                    .app_component_names = "appComponentNames",
                    .recommendation_status = "recommendationStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alarm_recommendations = "alarmRecommendations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_assessment_compliance_drifts: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-app-assessment-compliance-drifts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppAssessmentComplianceDrifts",
    Request: type = struct {
        assessment_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_arn = "assessmentArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_assessment_compliance_drifts) } {
            return .{ .service_metadata = service_metadata, .action = list_app_assessment_compliance_drifts };
        }
    },
    Response: type = struct {
        compliance_drifts: []struct {
            entity_id: ?[]const u8 = null,
            entity_type: ?[]const u8 = null,
            drift_type: ?[]const u8 = null,
            app_id: ?[]const u8 = null,
            app_version: ?[]const u8 = null,
            expected_reference_id: ?[]const u8 = null,
            expected_value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?DisruptionCompliance = null,
            } = null,
            actual_reference_id: ?[]const u8 = null,
            actual_value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?DisruptionCompliance = null,
            } = null,
            diff_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .entity_id = "entityId",
                    .entity_type = "entityType",
                    .drift_type = "driftType",
                    .app_id = "appId",
                    .app_version = "appVersion",
                    .expected_reference_id = "expectedReferenceId",
                    .expected_value = "expectedValue",
                    .actual_reference_id = "actualReferenceId",
                    .actual_value = "actualValue",
                    .diff_type = "diffType",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "expected_value", field_name))
                    return try serializeMap(self.expected_value, self.fieldNameFor("expected_value"), options, out_stream);
                if (std.mem.eql(u8, "actual_value", field_name))
                    return try serializeMap(self.actual_value, self.fieldNameFor("actual_value"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compliance_drifts = "complianceDrifts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_assessments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/list-app-assessments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppAssessments",
    Request: type = struct {
        app_arn: ?[]const u8 = null,
        assessment_name: ?[]const u8 = null,
        assessment_status: ?[][]const u8 = null,
        compliance_status: ?[]const u8 = null,
        invoker: ?[]const u8 = null,
        reverse_order: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .app_arn = "appArn",
            .assessment_name = "assessmentName",
            .assessment_status = "assessmentStatus",
            .compliance_status = "complianceStatus",
            .invoker = "invoker",
            .reverse_order = "reverseOrder",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .assessment_name = "assessmentName",
                .assessment_status = "assessmentStatus",
                .compliance_status = "complianceStatus",
                .invoker = "invoker",
                .reverse_order = "reverseOrder",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_assessments) } {
            return .{ .service_metadata = service_metadata, .action = list_app_assessments };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        assessment_summaries: []struct {
            app_arn: ?[]const u8 = null,
            app_version: ?[]const u8 = null,
            assessment_status: []const u8,
            invoker: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            message: ?[]const u8 = null,
            assessment_name: ?[]const u8 = null,
            assessment_arn: []const u8,
            compliance_status: ?[]const u8 = null,
            cost: ?Cost = null,
            resiliency_score: ?f64 = null,
            version_name: ?[]const u8 = null,
            drift_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_arn = "appArn",
                    .app_version = "appVersion",
                    .assessment_status = "assessmentStatus",
                    .invoker = "invoker",
                    .start_time = "startTime",
                    .end_time = "endTime",
                    .message = "message",
                    .assessment_name = "assessmentName",
                    .assessment_arn = "assessmentArn",
                    .compliance_status = "complianceStatus",
                    .cost = "cost",
                    .resiliency_score = "resiliencyScore",
                    .version_name = "versionName",
                    .drift_status = "driftStatus",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .assessment_summaries = "assessmentSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_component_compliances: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-app-component-compliances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppComponentCompliances",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        assessment_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .assessment_arn = "assessmentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_component_compliances) } {
            return .{ .service_metadata = service_metadata, .action = list_app_component_compliances };
        }
    },
    Response: type = struct {
        component_compliances: []struct {
            cost: ?Cost = null,
            app_component_name: ?[]const u8 = null,
            compliance: ?[]struct {
                key: ?[]const u8 = null,
                value: ?DisruptionCompliance = null,
            } = null,
            message: ?[]const u8 = null,
            status: ?[]const u8 = null,
            resiliency_score: ?ResiliencyScore = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cost = "cost",
                    .app_component_name = "appComponentName",
                    .compliance = "compliance",
                    .message = "message",
                    .status = "status",
                    .resiliency_score = "resiliencyScore",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "compliance", field_name))
                    return try serializeMap(self.compliance, self.fieldNameFor("compliance"), options, out_stream);
                return false;
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_compliances = "componentCompliances",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_component_recommendations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-app-component-recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppComponentRecommendations",
    Request: type = struct {
        assessment_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_arn = "assessmentArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_component_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_app_component_recommendations };
        }
    },
    Response: type = struct {
        component_recommendations: []struct {
            app_component_name: []const u8,
            recommendation_status: []const u8,
            config_recommendations: []struct {
                cost: ?Cost = null,
                app_component_name: ?[]const u8 = null,
                compliance: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?DisruptionCompliance = null,
                } = null,
                recommendation_compliance: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?struct {
                        expected_compliance_status: []const u8,
                        expected_rto_in_secs: ?i64 = null,
                        expected_rto_description: ?[]const u8 = null,
                        expected_rpo_in_secs: ?i64 = null,
                        expected_rpo_description: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .expected_compliance_status = "expectedComplianceStatus",
                                .expected_rto_in_secs = "expectedRtoInSecs",
                                .expected_rto_description = "expectedRtoDescription",
                                .expected_rpo_in_secs = "expectedRpoInSecs",
                                .expected_rpo_description = "expectedRpoDescription",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                } = null,
                optimization_type: []const u8,
                name: []const u8,
                description: ?[]const u8 = null,
                suggested_changes: ?[][]const u8 = null,
                ha_architecture: ?[]const u8 = null,
                reference_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cost = "cost",
                        .app_component_name = "appComponentName",
                        .compliance = "compliance",
                        .recommendation_compliance = "recommendationCompliance",
                        .optimization_type = "optimizationType",
                        .name = "name",
                        .description = "description",
                        .suggested_changes = "suggestedChanges",
                        .ha_architecture = "haArchitecture",
                        .reference_id = "referenceId",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "compliance", field_name))
                        return try serializeMap(self.compliance, self.fieldNameFor("compliance"), options, out_stream);
                    if (std.mem.eql(u8, "recommendation_compliance", field_name))
                        return try serializeMap(self.recommendation_compliance, self.fieldNameFor("recommendation_compliance"), options, out_stream);
                    return false;
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_component_name = "appComponentName",
                    .recommendation_status = "recommendationStatus",
                    .config_recommendations = "configRecommendations",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_recommendations = "componentRecommendations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_input_sources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-app-input-sources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppInputSources",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_input_sources) } {
            return .{ .service_metadata = service_metadata, .action = list_app_input_sources };
        }
    },
    Response: type = struct {
        app_input_sources: []AppInputSource,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_input_sources = "appInputSources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_apps: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/list-apps",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApps",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name: ?[]const u8 = null,
        app_arn: ?[]const u8 = null,
        from_last_assessment_time: ?i64 = null,
        to_last_assessment_time: ?i64 = null,
        reverse_order: ?bool = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .name = "name",
            .app_arn = "appArn",
            .from_last_assessment_time = "fromLastAssessmentTime",
            .to_last_assessment_time = "toLastAssessmentTime",
            .reverse_order = "reverseOrder",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .name = "name",
                .app_arn = "appArn",
                .from_last_assessment_time = "fromLastAssessmentTime",
                .to_last_assessment_time = "toLastAssessmentTime",
                .reverse_order = "reverseOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_apps) } {
            return .{ .service_metadata = service_metadata, .action = list_apps };
        }
    },
    Response: type = struct {
        app_summaries: []struct {
            app_arn: []const u8,
            name: []const u8,
            description: ?[]const u8 = null,
            creation_time: i64,
            compliance_status: ?[]const u8 = null,
            resiliency_score: ?f64 = null,
            assessment_schedule: ?[]const u8 = null,
            status: ?[]const u8 = null,
            drift_status: ?[]const u8 = null,
            last_app_compliance_evaluation_time: ?i64 = null,
            rto_in_secs: ?i64 = null,
            rpo_in_secs: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_arn = "appArn",
                    .name = "name",
                    .description = "description",
                    .creation_time = "creationTime",
                    .compliance_status = "complianceStatus",
                    .resiliency_score = "resiliencyScore",
                    .assessment_schedule = "assessmentSchedule",
                    .status = "status",
                    .drift_status = "driftStatus",
                    .last_app_compliance_evaluation_time = "lastAppComplianceEvaluationTime",
                    .rto_in_secs = "rtoInSecs",
                    .rpo_in_secs = "rpoInSecs",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_summaries = "appSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_version_app_components: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-app-version-app-components",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppVersionAppComponents",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_version_app_components) } {
            return .{ .service_metadata = service_metadata, .action = list_app_version_app_components };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        app_components: ?[]AppComponent = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .app_components = "appComponents",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_version_resource_mappings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-app-version-resource-mappings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppVersionResourceMappings",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_version_resource_mappings) } {
            return .{ .service_metadata = service_metadata, .action = list_app_version_resource_mappings };
        }
    },
    Response: type = struct {
        resource_mappings: []ResourceMapping,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_mappings = "resourceMappings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_version_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-app-version-resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppVersionResources",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        resolution_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .resolution_id = "resolutionId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_version_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_app_version_resources };
        }
    },
    Response: type = struct {
        physical_resources: []PhysicalResource,
        resolution_id: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .physical_resources = "physicalResources",
                .resolution_id = "resolutionId",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_app_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-app-versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppVersions",
    Request: type = struct {
        app_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .start_time = "startTime",
                .end_time = "endTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_app_versions };
        }
    },
    Response: type = struct {
        app_versions: []struct {
            app_version: []const u8,
            identifier: ?i64 = null,
            creation_time: ?i64 = null,
            version_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_version = "appVersion",
                    .identifier = "identifier",
                    .creation_time = "creationTime",
                    .version_name = "versionName",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_versions = "appVersions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_recommendation_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/list-recommendation-templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecommendationTemplates",
    Request: type = struct {
        assessment_arn: []const u8,
        reverse_order: ?bool = null,
        status: ?[][]const u8 = null,
        recommendation_template_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .assessment_arn = "assessmentArn",
            .reverse_order = "reverseOrder",
            .status = "status",
            .recommendation_template_arn = "recommendationTemplateArn",
            .name = "name",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment_arn = "assessmentArn",
                .reverse_order = "reverseOrder",
                .status = "status",
                .recommendation_template_arn = "recommendationTemplateArn",
                .name = "name",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendation_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendation_templates };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recommendation_templates: ?[]RecommendationTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .recommendation_templates = "recommendationTemplates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_resiliency_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/list-resiliency-policies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResiliencyPolicies",
    Request: type = struct {
        policy_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .policy_name = "policyName",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "policyName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resiliency_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_resiliency_policies };
        }
    },
    Response: type = struct {
        resiliency_policies: []ResiliencyPolicy,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resiliency_policies = "resiliencyPolicies",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_sop_recommendations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-sop-recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSopRecommendations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        assessment_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .assessment_arn = "assessmentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sop_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_sop_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        sop_recommendations: []struct {
            service_type: []const u8,
            app_component_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            recommendation_id: []const u8,
            name: ?[]const u8 = null,
            items: ?[]RecommendationItem = null,
            reference_id: []const u8,
            prerequisite: ?[]const u8 = null,
            recommendation_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_type = "serviceType",
                    .app_component_name = "appComponentName",
                    .description = "description",
                    .recommendation_id = "recommendationId",
                    .name = "name",
                    .items = "items",
                    .reference_id = "referenceId",
                    .prerequisite = "prerequisite",
                    .recommendation_status = "recommendationStatus",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .sop_recommendations = "sopRecommendations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_suggested_resiliency_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/list-suggested-resiliency-policies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSuggestedResiliencyPolicies",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_suggested_resiliency_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_suggested_resiliency_policies };
        }
    },
    Response: type = struct {
        resiliency_policies: []ResiliencyPolicy,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resiliency_policies = "resiliencyPolicies",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_test_recommendations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-test-recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTestRecommendations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        assessment_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .assessment_arn = "assessmentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_test_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_test_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        test_recommendations: []struct {
            recommendation_id: ?[]const u8 = null,
            reference_id: []const u8,
            app_component_name: ?[]const u8 = null,
            name: ?[]const u8 = null,
            intent: ?[]const u8 = null,
            risk: ?[]const u8 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            items: ?[]RecommendationItem = null,
            prerequisite: ?[]const u8 = null,
            depends_on_alarms: ?[][]const u8 = null,
            recommendation_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation_id = "recommendationId",
                    .reference_id = "referenceId",
                    .app_component_name = "appComponentName",
                    .name = "name",
                    .intent = "intent",
                    .risk = "risk",
                    .type = "type",
                    .description = "description",
                    .items = "items",
                    .prerequisite = "prerequisite",
                    .depends_on_alarms = "dependsOnAlarms",
                    .recommendation_status = "recommendationStatus",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .test_recommendations = "testRecommendations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_unsupported_app_version_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-unsupported-app-version-resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUnsupportedAppVersionResources",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        resolution_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .resolution_id = "resolutionId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_unsupported_app_version_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_unsupported_app_version_resources };
        }
    },
    Response: type = struct {
        unsupported_resources: []struct {
            logical_resource_id: LogicalResourceId,
            physical_resource_id: PhysicalResourceId,
            resource_type: []const u8,
            unsupported_resource_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .logical_resource_id = "logicalResourceId",
                    .physical_resource_id = "physicalResourceId",
                    .resource_type = "resourceType",
                    .unsupported_resource_status = "unsupportedResourceStatus",
                };
                return @field(mappings, field_name);
            }
        },
        resolution_id: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unsupported_resources = "unsupportedResources",
                .resolution_id = "resolutionId",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const publish_app_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/publish-app-version",
        .success_code = 200,
    };

    action_name: []const u8 = "PublishAppVersion",
    Request: type = struct {
        app_arn: []const u8,
        version_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .version_name = "versionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish_app_version) } {
            return .{ .service_metadata = service_metadata, .action = publish_app_version };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: ?[]const u8 = null,
        identifier: ?i64 = null,
        version_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .identifier = "identifier",
                .version_name = "versionName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_draft_app_version_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/put-draft-app-version-template",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDraftAppVersionTemplate",
    Request: type = struct {
        app_arn: []const u8,
        app_template_body: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_template_body = "appTemplateBody",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_draft_app_version_template) } {
            return .{ .service_metadata = service_metadata, .action = put_draft_app_version_template };
        }
    },
    Response: type = struct {
        app_arn: ?[]const u8 = null,
        app_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const remove_draft_app_version_resource_mappings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/remove-draft-app-version-resource-mappings",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveDraftAppVersionResourceMappings",
    Request: type = struct {
        app_arn: []const u8,
        resource_names: ?[][]const u8 = null,
        logical_stack_names: ?[][]const u8 = null,
        app_registry_app_names: ?[][]const u8 = null,
        resource_group_names: ?[][]const u8 = null,
        terraform_source_names: ?[][]const u8 = null,
        eks_source_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .resource_names = "resourceNames",
                .logical_stack_names = "logicalStackNames",
                .app_registry_app_names = "appRegistryAppNames",
                .resource_group_names = "resourceGroupNames",
                .terraform_source_names = "terraformSourceNames",
                .eks_source_names = "eksSourceNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_draft_app_version_resource_mappings) } {
            return .{ .service_metadata = service_metadata, .action = remove_draft_app_version_resource_mappings };
        }
    },
    Response: type = struct {
        app_arn: ?[]const u8 = null,
        app_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const resolve_app_version_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/resolve-app-version-resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ResolveAppVersionResources",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resolve_app_version_resources) } {
            return .{ .service_metadata = service_metadata, .action = resolve_app_version_resources };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        resolution_id: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .resolution_id = "resolutionId",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_app_assessment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/start-app-assessment",
        .success_code = 200,
    };

    action_name: []const u8 = "StartAppAssessment",
    Request: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        assessment_name: []const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .assessment_name = "assessmentName",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_app_assessment) } {
            return .{ .service_metadata = service_metadata, .action = start_app_assessment };
        }
    },
    Response: type = struct {
        assessment: AppAssessment,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assessment = "assessment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_app: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-app",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApp",
    Request: type = struct {
        app_arn: []const u8,
        description: ?[]const u8 = null,
        policy_arn: ?[]const u8 = null,
        clear_resiliency_policy_arn: ?bool = null,
        assessment_schedule: ?[]const u8 = null,
        permission_model: ?PermissionModel = null,
        event_subscriptions: ?[]EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .description = "description",
                .policy_arn = "policyArn",
                .clear_resiliency_policy_arn = "clearResiliencyPolicyArn",
                .assessment_schedule = "assessmentSchedule",
                .permission_model = "permissionModel",
                .event_subscriptions = "eventSubscriptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app) } {
            return .{ .service_metadata = service_metadata, .action = update_app };
        }
    },
    Response: type = struct {
        app: App,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app = "app",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_app_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-app-version",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAppVersion",
    Request: type = struct {
        app_arn: []const u8,
        additional_info: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .additional_info = "additionalInfo",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_info", field_name))
                return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_version) } {
            return .{ .service_metadata = service_metadata, .action = update_app_version };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        additional_info: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .additional_info = "additionalInfo",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_info", field_name))
                return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_app_version_app_component: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-app-version-app-component",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAppVersionAppComponent",
    Request: type = struct {
        app_arn: []const u8,
        id: []const u8,
        name: ?[]const u8 = null,
        type: ?[]const u8 = null,
        additional_info: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .id = "id",
                .name = "name",
                .type = "type",
                .additional_info = "additionalInfo",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_info", field_name))
                return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_version_app_component) } {
            return .{ .service_metadata = service_metadata, .action = update_app_version_app_component };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        app_component: ?AppComponent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .app_component = "appComponent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_app_version_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-app-version-resource",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAppVersionResource",
    Request: type = struct {
        app_arn: []const u8,
        resource_name: ?[]const u8 = null,
        logical_resource_id: ?LogicalResourceId = null,
        physical_resource_id: ?[]const u8 = null,
        aws_region: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        app_components: ?[][]const u8 = null,
        additional_info: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        excluded: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .resource_name = "resourceName",
                .logical_resource_id = "logicalResourceId",
                .physical_resource_id = "physicalResourceId",
                .aws_region = "awsRegion",
                .aws_account_id = "awsAccountId",
                .resource_type = "resourceType",
                .app_components = "appComponents",
                .additional_info = "additionalInfo",
                .excluded = "excluded",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_info", field_name))
                return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_version_resource) } {
            return .{ .service_metadata = service_metadata, .action = update_app_version_resource };
        }
    },
    Response: type = struct {
        app_arn: []const u8,
        app_version: []const u8,
        physical_resource: ?PhysicalResource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "appArn",
                .app_version = "appVersion",
                .physical_resource = "physicalResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_resiliency_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-resiliency-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResiliencyPolicy",
    Request: type = struct {
        policy_arn: []const u8,
        policy_name: ?[]const u8 = null,
        policy_description: ?[]const u8 = null,
        data_location_constraint: ?[]const u8 = null,
        tier: ?[]const u8 = null,
        policy: ?[]struct {
            key: ?[]const u8 = null,
            value: ?FailurePolicy = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_arn = "policyArn",
                .policy_name = "policyName",
                .policy_description = "policyDescription",
                .data_location_constraint = "dataLocationConstraint",
                .tier = "tier",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "policy", field_name))
                return try serializeMap(self.policy, self.fieldNameFor("policy"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resiliency_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_resiliency_policy };
        }
    },
    Response: type = struct {
        policy: ResiliencyPolicy,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const ResiliencyPolicy = struct {
    policy_arn: ?[]const u8 = null,
    policy_name: ?[]const u8 = null,
    policy_description: ?[]const u8 = null,
    data_location_constraint: ?[]const u8 = null,
    tier: ?[]const u8 = null,
    estimated_cost_tier: ?[]const u8 = null,
    policy: ?[]struct {
        key: ?[]const u8 = null,
        value: ?FailurePolicy = null,
    } = null,
    creation_time: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_arn = "policyArn",
            .policy_name = "policyName",
            .policy_description = "policyDescription",
            .data_location_constraint = "dataLocationConstraint",
            .tier = "tier",
            .estimated_cost_tier = "estimatedCostTier",
            .policy = "policy",
            .creation_time = "creationTime",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "policy", field_name))
            return try serializeMap(self.policy, self.fieldNameFor("policy"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const FailurePolicy = struct {
    rto_in_secs: i64,
    rpo_in_secs: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rto_in_secs = "rtoInSecs",
            .rpo_in_secs = "rpoInSecs",
        };
        return @field(mappings, field_name);
    }
};

pub const PhysicalResource = struct {
    resource_name: ?[]const u8 = null,
    logical_resource_id: LogicalResourceId,
    physical_resource_id: PhysicalResourceId,
    resource_type: []const u8,
    app_components: ?[]AppComponent = null,
    additional_info: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    excluded: ?bool = null,
    source_type: ?[]const u8 = null,
    parent_resource_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_name = "resourceName",
            .logical_resource_id = "logicalResourceId",
            .physical_resource_id = "physicalResourceId",
            .resource_type = "resourceType",
            .app_components = "appComponents",
            .additional_info = "additionalInfo",
            .excluded = "excluded",
            .source_type = "sourceType",
            .parent_resource_name = "parentResourceName",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_info", field_name))
            return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
        return false;
    }
};

pub const AppComponent = struct {
    name: []const u8,
    type: []const u8,
    id: ?[]const u8 = null,
    additional_info: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .type = "type",
            .id = "id",
            .additional_info = "additionalInfo",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "additional_info", field_name))
            return try serializeMap(self.additional_info, self.fieldNameFor("additional_info"), options, out_stream);
        return false;
    }
};

pub const PhysicalResourceId = struct {
    identifier: []const u8,
    type: []const u8,
    aws_region: ?[]const u8 = null,
    aws_account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "identifier",
            .type = "type",
            .aws_region = "awsRegion",
            .aws_account_id = "awsAccountId",
        };
        return @field(mappings, field_name);
    }
};

pub const LogicalResourceId = struct {
    identifier: []const u8,
    logical_stack_name: ?[]const u8 = null,
    resource_group_name: ?[]const u8 = null,
    terraform_source_name: ?[]const u8 = null,
    eks_source_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "identifier",
            .logical_stack_name = "logicalStackName",
            .resource_group_name = "resourceGroupName",
            .terraform_source_name = "terraformSourceName",
            .eks_source_name = "eksSourceName",
        };
        return @field(mappings, field_name);
    }
};

pub const App = struct {
    app_arn: []const u8,
    name: []const u8,
    description: ?[]const u8 = null,
    policy_arn: ?[]const u8 = null,
    creation_time: i64,
    status: ?[]const u8 = null,
    compliance_status: ?[]const u8 = null,
    last_app_compliance_evaluation_time: ?i64 = null,
    resiliency_score: ?f64 = null,
    last_resiliency_score_evaluation_time: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    assessment_schedule: ?[]const u8 = null,
    permission_model: ?PermissionModel = null,
    event_subscriptions: ?[]EventSubscription = null,
    drift_status: ?[]const u8 = null,
    last_drift_evaluation_time: ?i64 = null,
    rto_in_secs: ?i64 = null,
    rpo_in_secs: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_arn = "appArn",
            .name = "name",
            .description = "description",
            .policy_arn = "policyArn",
            .creation_time = "creationTime",
            .status = "status",
            .compliance_status = "complianceStatus",
            .last_app_compliance_evaluation_time = "lastAppComplianceEvaluationTime",
            .resiliency_score = "resiliencyScore",
            .last_resiliency_score_evaluation_time = "lastResiliencyScoreEvaluationTime",
            .tags = "tags",
            .assessment_schedule = "assessmentSchedule",
            .permission_model = "permissionModel",
            .event_subscriptions = "eventSubscriptions",
            .drift_status = "driftStatus",
            .last_drift_evaluation_time = "lastDriftEvaluationTime",
            .rto_in_secs = "rtoInSecs",
            .rpo_in_secs = "rpoInSecs",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const EventSubscription = struct {
    name: []const u8,
    event_type: []const u8,
    sns_topic_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .event_type = "eventType",
            .sns_topic_arn = "snsTopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PermissionModel = struct {
    type: []const u8,
    invoker_role_name: ?[]const u8 = null,
    cross_account_role_arns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .invoker_role_name = "invokerRoleName",
            .cross_account_role_arns = "crossAccountRoleArns",
        };
        return @field(mappings, field_name);
    }
};

pub const AppAssessment = struct {
    app_arn: ?[]const u8 = null,
    app_version: ?[]const u8 = null,
    invoker: []const u8,
    cost: ?Cost = null,
    resiliency_score: ?ResiliencyScore = null,
    compliance: ?[]struct {
        key: ?[]const u8 = null,
        value: ?DisruptionCompliance = null,
    } = null,
    compliance_status: ?[]const u8 = null,
    assessment_status: []const u8,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    message: ?[]const u8 = null,
    assessment_name: ?[]const u8 = null,
    assessment_arn: []const u8,
    policy: ?ResiliencyPolicy = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    resource_errors_details: ?ResourceErrorsDetails = null,
    version_name: ?[]const u8 = null,
    drift_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_arn = "appArn",
            .app_version = "appVersion",
            .invoker = "invoker",
            .cost = "cost",
            .resiliency_score = "resiliencyScore",
            .compliance = "compliance",
            .compliance_status = "complianceStatus",
            .assessment_status = "assessmentStatus",
            .start_time = "startTime",
            .end_time = "endTime",
            .message = "message",
            .assessment_name = "assessmentName",
            .assessment_arn = "assessmentArn",
            .policy = "policy",
            .tags = "tags",
            .resource_errors_details = "resourceErrorsDetails",
            .version_name = "versionName",
            .drift_status = "driftStatus",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "compliance", field_name))
            return try serializeMap(self.compliance, self.fieldNameFor("compliance"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ResourceErrorsDetails = struct {
    resource_errors: ?[]ResourceError = null,
    has_more_errors: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_errors = "resourceErrors",
            .has_more_errors = "hasMoreErrors",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceError = struct {
    logical_resource_id: ?[]const u8 = null,
    physical_resource_id: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .logical_resource_id = "logicalResourceId",
            .physical_resource_id = "physicalResourceId",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const DisruptionCompliance = struct {
    achievable_rto_in_secs: ?i64 = null,
    current_rto_in_secs: ?i64 = null,
    rto_reference_id: ?[]const u8 = null,
    rto_description: ?[]const u8 = null,
    current_rpo_in_secs: ?i64 = null,
    rpo_reference_id: ?[]const u8 = null,
    rpo_description: ?[]const u8 = null,
    compliance_status: []const u8,
    achievable_rpo_in_secs: ?i64 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .achievable_rto_in_secs = "achievableRtoInSecs",
            .current_rto_in_secs = "currentRtoInSecs",
            .rto_reference_id = "rtoReferenceId",
            .rto_description = "rtoDescription",
            .current_rpo_in_secs = "currentRpoInSecs",
            .rpo_reference_id = "rpoReferenceId",
            .rpo_description = "rpoDescription",
            .compliance_status = "complianceStatus",
            .achievable_rpo_in_secs = "achievableRpoInSecs",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ResiliencyScore = struct {
    score: f64,
    disruption_score: []struct {
        key: ?[]const u8 = null,
        value: ?f64 = null,
    },
    component_score: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ScoringComponentResiliencyScore = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .score = "score",
            .disruption_score = "disruptionScore",
            .component_score = "componentScore",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "disruption_score", field_name))
            return try serializeMap(self.disruption_score, self.fieldNameFor("disruption_score"), options, out_stream);
        if (std.mem.eql(u8, "component_score", field_name))
            return try serializeMap(self.component_score, self.fieldNameFor("component_score"), options, out_stream);
        return false;
    }
};

pub const ScoringComponentResiliencyScore = struct {
    score: ?f64 = null,
    possible_score: ?f64 = null,
    outstanding_count: ?i64 = null,
    excluded_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .score = "score",
            .possible_score = "possibleScore",
            .outstanding_count = "outstandingCount",
            .excluded_count = "excludedCount",
        };
        return @field(mappings, field_name);
    }
};

pub const Cost = struct {
    amount: f64,
    currency: []const u8,
    frequency: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amount = "amount",
            .currency = "currency",
            .frequency = "frequency",
        };
        return @field(mappings, field_name);
    }
};

pub const RecommendationItem = struct {
    resource_id: ?[]const u8 = null,
    target_account_id: ?[]const u8 = null,
    target_region: ?[]const u8 = null,
    already_implemented: ?bool = null,
    excluded: ?bool = null,
    exclude_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_id = "resourceId",
            .target_account_id = "targetAccountId",
            .target_region = "targetRegion",
            .already_implemented = "alreadyImplemented",
            .excluded = "excluded",
            .exclude_reason = "excludeReason",
        };
        return @field(mappings, field_name);
    }
};

pub const RecommendationTemplate = struct {
    templates_location: ?S3Location = null,
    assessment_arn: []const u8,
    app_arn: ?[]const u8 = null,
    recommendation_ids: ?[][]const u8 = null,
    recommendation_types: [][]const u8,
    format: []const u8,
    recommendation_template_arn: []const u8,
    message: ?[]const u8 = null,
    status: []const u8,
    name: []const u8,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    needs_replacements: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .templates_location = "templatesLocation",
            .assessment_arn = "assessmentArn",
            .app_arn = "appArn",
            .recommendation_ids = "recommendationIds",
            .recommendation_types = "recommendationTypes",
            .format = "format",
            .recommendation_template_arn = "recommendationTemplateArn",
            .message = "message",
            .status = "status",
            .name = "name",
            .start_time = "startTime",
            .end_time = "endTime",
            .tags = "tags",
            .needs_replacements = "needsReplacements",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const S3Location = struct {
    bucket: ?[]const u8 = null,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceMapping = struct {
    resource_name: ?[]const u8 = null,
    logical_stack_name: ?[]const u8 = null,
    app_registry_app_name: ?[]const u8 = null,
    resource_group_name: ?[]const u8 = null,
    mapping_type: []const u8,
    physical_resource_id: PhysicalResourceId,
    terraform_source_name: ?[]const u8 = null,
    eks_source_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_name = "resourceName",
            .logical_stack_name = "logicalStackName",
            .app_registry_app_name = "appRegistryAppName",
            .resource_group_name = "resourceGroupName",
            .mapping_type = "mappingType",
            .physical_resource_id = "physicalResourceId",
            .terraform_source_name = "terraformSourceName",
            .eks_source_name = "eksSourceName",
        };
        return @field(mappings, field_name);
    }
};

pub const AppInputSource = struct {
    source_name: ?[]const u8 = null,
    import_type: []const u8,
    source_arn: ?[]const u8 = null,
    terraform_source: ?TerraformSource = null,
    resource_count: ?i64 = null,
    eks_source_cluster_namespace: ?EksSourceClusterNamespace = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_name = "sourceName",
            .import_type = "importType",
            .source_arn = "sourceArn",
            .terraform_source = "terraformSource",
            .resource_count = "resourceCount",
            .eks_source_cluster_namespace = "eksSourceClusterNamespace",
        };
        return @field(mappings, field_name);
    }
};

pub const EksSourceClusterNamespace = struct {
    eks_cluster_arn: []const u8,
    namespace: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .eks_cluster_arn = "eksClusterArn",
            .namespace = "namespace",
        };
        return @field(mappings, field_name);
    }
};

pub const TerraformSource = struct {
    s3_state_file_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_state_file_url = "s3StateFileUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const EksSource = struct {
    eks_cluster_arn: []const u8,
    namespaces: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .eks_cluster_arn = "eksClusterArn",
            .namespaces = "namespaces",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateRecommendationStatusItem = struct {
    resource_id: ?[]const u8 = null,
    target_account_id: ?[]const u8 = null,
    target_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_id = "resourceId",
            .target_account_id = "targetAccountId",
            .target_region = "targetRegion",
        };
        return @field(mappings, field_name);
    }
};
