const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-07-28";
pub const sdk_id: []const u8 = "Resource Explorer 2";
pub const arn_namespace: ?[]const u8 = "resource-explorer-2";
pub const endpoint_prefix: []const u8 = "resource-explorer-2";
pub const sigv4_name: []const u8 = "resource-explorer-2";
pub const name: []const u8 = "ResourceExplorer";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2022-07-28",
    sdk_id: []const u8 = "Resource Explorer 2",
    arn_namespace: ?[]const u8 = "resource-explorer-2",
    endpoint_prefix: []const u8 = "resource-explorer-2",
    sigv4_name: []const u8 = "resource-explorer-2",
    name: []const u8 = "ResourceExplorer",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_get_view: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/BatchGetView",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetView",
    Request: type = struct {
        view_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .view_arns = "ViewArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_view) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_view };
        }
    },
    Response: type = struct {
        views: ?[]struct {
            view_arn: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            last_updated_at: ?i64 = null,
            scope: ?[]const u8 = null,
            included_properties: ?[]struct {
                name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            filters: ?struct {
                filter_string: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .filter_string = "FilterString",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .view_arn = "ViewArn",
                    .owner = "Owner",
                    .last_updated_at = "LastUpdatedAt",
                    .scope = "Scope",
                    .included_properties = "IncludedProperties",
                    .filters = "Filters",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]struct {
            view_arn: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .view_arn = "ViewArn",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .views = "Views",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Unauthorized,
        Validation,
    },
} = .{};
pub const disassociate_default_view: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DisassociateDefaultView",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateDefaultView",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_default_view) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_default_view };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_account_level_service_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetAccountLevelServiceConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccountLevelServiceConfiguration",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_level_service_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_account_level_service_configuration };
        }
    },
    Response: type = struct {
        org_configuration: ?struct {
            aws_service_access_status: []const u8,
            service_linked_role: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aws_service_access_status = "AWSServiceAccessStatus",
                    .service_linked_role = "ServiceLinkedRole",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .org_configuration = "OrgConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_default_view: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetDefaultView",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDefaultView",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_default_view) } {
            return .{ .service_metadata = service_metadata, .action = get_default_view };
        }
    },
    Response: type = struct {
        view_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .view_arn = "ViewArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_index: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetIndex",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIndex",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_index) } {
            return .{ .service_metadata = service_metadata, .action = get_index };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        type: ?[]const u8 = null,
        state: ?[]const u8 = null,
        replicating_from: ?[][]const u8 = null,
        replicating_to: ?[][]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .type = "Type",
                .state = "State",
                .replicating_from = "ReplicatingFrom",
                .replicating_to = "ReplicatingTo",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_indexes_for_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListIndexesForMembers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIndexesForMembers",
    Request: type = struct {
        account_id_list: [][]const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id_list = "AccountIdList",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_indexes_for_members) } {
            return .{ .service_metadata = service_metadata, .action = list_indexes_for_members };
        }
    },
    Response: type = struct {
        indexes: ?[]struct {
            account_id: ?[]const u8 = null,
            region: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .region = "Region",
                    .arn = "Arn",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .indexes = "Indexes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_supported_resource_types: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListSupportedResourceTypes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSupportedResourceTypes",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_supported_resource_types) } {
            return .{ .service_metadata = service_metadata, .action = list_supported_resource_types };
        }
    },
    Response: type = struct {
        resource_types: ?[]struct {
            service: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service = "Service",
                    .resource_type = "ResourceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_types = "ResourceTypes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Unauthorized,
        Validation,
    },
} = .{};
pub const search: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/Search",
        .success_code = 200,
    };

    action_name: []const u8 = "Search",
    Request: type = struct {
        query_string: []const u8,
        max_results: ?i64 = null,
        view_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_string = "QueryString",
                .max_results = "MaxResults",
                .view_arn = "ViewArn",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search) } {
            return .{ .service_metadata = service_metadata, .action = search };
        }
    },
    Response: type = struct {
        resources: ?[]struct {
            arn: ?[]const u8 = null,
            owning_account_id: ?[]const u8 = null,
            region: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            service: ?[]const u8 = null,
            last_reported_at: ?i64 = null,
            properties: ?[]struct {
                name: ?[]const u8 = null,
                last_reported_at: ?i64 = null,
                data: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .last_reported_at = "LastReportedAt",
                        .data = "Data",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .owning_account_id = "OwningAccountId",
                    .region = "Region",
                    .resource_type = "ResourceType",
                    .service = "Service",
                    .last_reported_at = "LastReportedAt",
                    .properties = "Properties",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        view_arn: ?[]const u8 = null,
        count: ?struct {
            total_resources: ?i64 = null,
            complete: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .total_resources = "TotalResources",
                    .complete = "Complete",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "Resources",
                .next_token = "NextToken",
                .view_arn = "ViewArn",
                .count = "Count",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Unauthorized,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Unauthorized,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Unauthorized,
        Validation,
    },
} = .{};
