const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-11-27";
pub const sdk_id: []const u8 = "Resource Groups";
pub const arn_namespace: ?[]const u8 = "resource-groups";
pub const endpoint_prefix: []const u8 = "resource-groups";
pub const sigv4_name: []const u8 = "resource-groups";
pub const name: []const u8 = "Ardi";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-11-27",
    sdk_id: []const u8 = "Resource Groups",
    arn_namespace: ?[]const u8 = "resource-groups",
    endpoint_prefix: []const u8 = "resource-groups",
    sigv4_name: []const u8 = "resource-groups",
    name: []const u8 = "Ardi",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGroup",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        resource_query: ?ResourceQuery = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        configuration: ?[]GroupConfigurationItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .resource_query = "ResourceQuery",
                .tags = "Tags",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group) } {
            return .{ .service_metadata = service_metadata, .action = create_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,
        resource_query: ?ResourceQuery = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        group_configuration: ?GroupConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
                .resource_query = "ResourceQuery",
                .tags = "Tags",
                .group_configuration = "GroupConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
    },
} = .{};
pub const delete_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-group",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGroup",
    Request: type = struct {
        group_name: ?[]const u8 = null,
        group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group = "Group",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_account_settings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-account-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccountSettings",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_account_settings };
        }
    },
    Response: type = struct {
        account_settings: ?AccountSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_settings = "AccountSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
    },
} = .{};
pub const get_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-group",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroup",
    Request: type = struct {
        group_name: ?[]const u8 = null,
        group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group = "Group",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group) } {
            return .{ .service_metadata = service_metadata, .action = get_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_group_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-group-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroupConfiguration",
    Request: type = struct {
        group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_group_configuration };
        }
    },
    Response: type = struct {
        group_configuration: ?GroupConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_configuration = "GroupConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_group_query: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-group-query",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroupQuery",
    Request: type = struct {
        group_name: ?[]const u8 = null,
        group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group = "Group",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group_query) } {
            return .{ .service_metadata = service_metadata, .action = get_group_query };
        }
    },
    Response: type = struct {
        group_query: ?GroupQuery = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_query = "GroupQuery",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resources/{Arn}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTags",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_tags) } {
            return .{ .service_metadata = service_metadata, .action = get_tags };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const group_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/group-resources",
        .success_code = 200,
    };

    action_name: []const u8 = "GroupResources",
    Request: type = struct {
        group: []const u8,
        resource_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
                .resource_arns = "ResourceArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(group_resources) } {
            return .{ .service_metadata = service_metadata, .action = group_resources };
        }
    },
    Response: type = struct {
        succeeded: ?[][]const u8 = null,
        failed: ?[]FailedResource = null,
        pending: ?[]PendingResource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .succeeded = "Succeeded",
                .failed = "Failed",
                .pending = "Pending",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_group_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-group-resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGroupResources",
    Request: type = struct {
        group_name: ?[]const u8 = null,
        group: ?[]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group = "Group",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_group_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_group_resources };
        }
    },
    Response: type = struct {
        resources: ?[]struct {
            identifier: ?ResourceIdentifier = null,
            status: ?struct {
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identifier = "Identifier",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        resource_identifiers: ?[]ResourceIdentifier = null,
        next_token: ?[]const u8 = null,
        query_errors: ?[]QueryError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "Resources",
                .resource_identifiers = "ResourceIdentifiers",
                .next_token = "NextToken",
                .query_errors = "QueryErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_groups: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/groups-list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGroups",
    Request: type = struct {
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_groups };
        }
    },
    Response: type = struct {
        group_identifiers: ?[]struct {
            group_name: ?[]const u8 = null,
            group_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_name = "GroupName",
                    .group_arn = "GroupArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        groups: ?[]Group = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_identifiers = "GroupIdentifiers",
                .groups = "Groups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
    },
} = .{};
pub const put_group_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/put-group-configuration",
        .success_code = 202,
    };

    action_name: []const u8 = "PutGroupConfiguration",
    Request: type = struct {
        group: ?[]const u8 = null,
        configuration: ?[]GroupConfigurationItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_group_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_group_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const search_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/resources/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchResources",
    Request: type = struct {
        resource_query: ResourceQuery,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_query = "ResourceQuery",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_resources) } {
            return .{ .service_metadata = service_metadata, .action = search_resources };
        }
    },
    Response: type = struct {
        resource_identifiers: ?[]ResourceIdentifier = null,
        next_token: ?[]const u8 = null,
        query_errors: ?[]QueryError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifiers = "ResourceIdentifiers",
                .next_token = "NextToken",
                .query_errors = "QueryErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const tag: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/resources/{Arn}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "Tag",
    Request: type = struct {
        arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag) } {
            return .{ .service_metadata = service_metadata, .action = tag };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const ungroup_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ungroup-resources",
        .success_code = 200,
    };

    action_name: []const u8 = "UngroupResources",
    Request: type = struct {
        group: []const u8,
        resource_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
                .resource_arns = "ResourceArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(ungroup_resources) } {
            return .{ .service_metadata = service_metadata, .action = ungroup_resources };
        }
    },
    Response: type = struct {
        succeeded: ?[][]const u8 = null,
        failed: ?[]FailedResource = null,
        pending: ?[]PendingResource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .succeeded = "Succeeded",
                .failed = "Failed",
                .pending = "Pending",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const untag: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/resources/{Arn}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "Untag",
    Request: type = struct {
        arn: []const u8,
        keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .keys = "Keys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag) } {
            return .{ .service_metadata = service_metadata, .action = untag };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        keys: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .keys = "Keys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_account_settings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-account-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccountSettings",
    Request: type = struct {
        group_lifecycle_events_desired_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_lifecycle_events_desired_status = "GroupLifecycleEventsDesiredStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_account_settings };
        }
    },
    Response: type = struct {
        account_settings: ?AccountSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_settings = "AccountSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        TooManyRequests,
    },
} = .{};
pub const update_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-group",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGroup",
    Request: type = struct {
        group_name: ?[]const u8 = null,
        group: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group = "Group",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_group) } {
            return .{ .service_metadata = service_metadata, .action = update_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_group_query: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-group-query",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGroupQuery",
    Request: type = struct {
        group_name: ?[]const u8 = null,
        group: ?[]const u8 = null,
        resource_query: ResourceQuery,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group = "Group",
                .resource_query = "ResourceQuery",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_group_query) } {
            return .{ .service_metadata = service_metadata, .action = update_group_query };
        }
    },
    Response: type = struct {
        group_query: ?GroupQuery = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_query = "GroupQuery",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        MethodNotAllowed,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const GroupQuery = struct {
    group_name: []const u8,
    resource_query: ResourceQuery,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
            .resource_query = "ResourceQuery",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceQuery = struct {
    type: []const u8,
    query: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .query = "Query",
        };
        return @field(mappings, field_name);
    }
};

pub const Group = struct {
    group_arn: []const u8,
    name: []const u8,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_arn = "GroupArn",
            .name = "Name",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountSettings = struct {
    group_lifecycle_events_desired_status: ?[]const u8 = null,
    group_lifecycle_events_status: ?[]const u8 = null,
    group_lifecycle_events_status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_lifecycle_events_desired_status = "GroupLifecycleEventsDesiredStatus",
            .group_lifecycle_events_status = "GroupLifecycleEventsStatus",
            .group_lifecycle_events_status_message = "GroupLifecycleEventsStatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingResource = struct {
    resource_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedResource = struct {
    resource_arn: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    error_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .error_message = "ErrorMessage",
            .error_code = "ErrorCode",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryError = struct {
    error_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceIdentifier = struct {
    resource_arn: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .resource_type = "ResourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupConfigurationItem = struct {
    type: []const u8,
    parameters: ?[]GroupConfigurationParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupConfigurationParameter = struct {
    name: []const u8,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupConfiguration = struct {
    configuration: ?[]GroupConfigurationItem = null,
    proposed_configuration: ?[]GroupConfigurationItem = null,
    status: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration = "Configuration",
            .proposed_configuration = "ProposedConfiguration",
            .status = "Status",
            .failure_reason = "FailureReason",
        };
        return @field(mappings, field_name);
    }
};
