const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-06-29";
pub const sdk_id: []const u8 = "RoboMaker";
pub const arn_namespace: ?[]const u8 = "robomaker";
pub const endpoint_prefix: []const u8 = "robomaker";
pub const sigv4_name: []const u8 = "robomaker";
pub const name: []const u8 = "robomaker";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-06-29",
    sdk_id: []const u8 = "RoboMaker",
    arn_namespace: ?[]const u8 = "robomaker",
    endpoint_prefix: []const u8 = "robomaker",
    sigv4_name: []const u8 = "robomaker",
    name: []const u8 = "robomaker",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_delete_worlds: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/batchDeleteWorlds",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDeleteWorlds",
    Request: type = struct {
        worlds: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .worlds = "worlds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_worlds) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_worlds };
        }
    },
    Response: type = struct {
        unprocessed_worlds: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_worlds = "unprocessedWorlds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const batch_describe_simulation_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/batchDescribeSimulationJob",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDescribeSimulationJob",
    Request: type = struct {
        jobs: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_describe_simulation_job) } {
            return .{ .service_metadata = service_metadata, .action = batch_describe_simulation_job };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            last_started_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            failure_behavior: ?[]const u8 = null,
            failure_code: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            client_request_token: ?[]const u8 = null,
            output_location: ?OutputLocation = null,
            logging_config: ?LoggingConfig = null,
            max_job_duration_in_seconds: ?i64 = null,
            simulation_time_millis: ?i64 = null,
            iam_role: ?[]const u8 = null,
            robot_applications: ?[]RobotApplicationConfig = null,
            simulation_applications: ?[]SimulationApplicationConfig = null,
            data_sources: ?[]DataSource = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            vpc_config: ?VPCConfigResponse = null,
            network_interface: ?NetworkInterface = null,
            compute: ?ComputeResponse = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .status = "status",
                    .last_started_at = "lastStartedAt",
                    .last_updated_at = "lastUpdatedAt",
                    .failure_behavior = "failureBehavior",
                    .failure_code = "failureCode",
                    .failure_reason = "failureReason",
                    .client_request_token = "clientRequestToken",
                    .output_location = "outputLocation",
                    .logging_config = "loggingConfig",
                    .max_job_duration_in_seconds = "maxJobDurationInSeconds",
                    .simulation_time_millis = "simulationTimeMillis",
                    .iam_role = "iamRole",
                    .robot_applications = "robotApplications",
                    .simulation_applications = "simulationApplications",
                    .data_sources = "dataSources",
                    .tags = "tags",
                    .vpc_config = "vpcConfig",
                    .network_interface = "networkInterface",
                    .compute = "compute",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        unprocessed_jobs: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
                .unprocessed_jobs = "unprocessedJobs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const cancel_deployment_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cancelDeploymentJob",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelDeploymentJob",
    Request: type = struct {
        job: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_deployment_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_deployment_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const cancel_simulation_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cancelSimulationJob",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelSimulationJob",
    Request: type = struct {
        job: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_simulation_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_simulation_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const cancel_simulation_job_batch: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cancelSimulationJobBatch",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelSimulationJobBatch",
    Request: type = struct {
        batch: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch = "batch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_simulation_job_batch) } {
            return .{ .service_metadata = service_metadata, .action = cancel_simulation_job_batch };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const cancel_world_export_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cancelWorldExportJob",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelWorldExportJob",
    Request: type = struct {
        job: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_world_export_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_world_export_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const cancel_world_generation_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cancelWorldGenerationJob",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelWorldGenerationJob",
    Request: type = struct {
        job: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_world_generation_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_world_generation_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_deployment_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createDeploymentJob",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDeploymentJob",
    Request: type = struct {
        deployment_config: ?DeploymentConfig = null,
        client_request_token: []const u8,
        fleet: []const u8,
        deployment_application_configs: []DeploymentApplicationConfig,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_config = "deploymentConfig",
                .client_request_token = "clientRequestToken",
                .fleet = "fleet",
                .deployment_application_configs = "deploymentApplicationConfigs",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_deployment_job) } {
            return .{ .service_metadata = service_metadata, .action = create_deployment_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        fleet: ?[]const u8 = null,
        status: ?[]const u8 = null,
        deployment_application_configs: ?[]DeploymentApplicationConfig = null,
        failure_reason: ?[]const u8 = null,
        failure_code: ?[]const u8 = null,
        created_at: ?i64 = null,
        deployment_config: ?DeploymentConfig = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .fleet = "fleet",
                .status = "status",
                .deployment_application_configs = "deploymentApplicationConfigs",
                .failure_reason = "failureReason",
                .failure_code = "failureCode",
                .created_at = "createdAt",
                .deployment_config = "deploymentConfig",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ConcurrentDeployment,
        IdempotentParameterMismatch,
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_fleet: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createFleet",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFleet",
    Request: type = struct {
        name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fleet) } {
            return .{ .service_metadata = service_metadata, .action = create_fleet };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        created_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .created_at = "createdAt",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const create_robot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createRobot",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRobot",
    Request: type = struct {
        name: []const u8,
        architecture: []const u8,
        greengrass_group_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .architecture = "architecture",
                .greengrass_group_id = "greengrassGroupId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_robot) } {
            return .{ .service_metadata = service_metadata, .action = create_robot };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        created_at: ?i64 = null,
        greengrass_group_id: ?[]const u8 = null,
        architecture: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .created_at = "createdAt",
                .greengrass_group_id = "greengrassGroupId",
                .architecture = "architecture",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_robot_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createRobotApplication",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRobotApplication",
    Request: type = struct {
        name: []const u8,
        sources: ?[]SourceConfig = null,
        robot_software_suite: RobotSoftwareSuite,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .sources = "sources",
                .robot_software_suite = "robotSoftwareSuite",
                .tags = "tags",
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_robot_application) } {
            return .{ .service_metadata = service_metadata, .action = create_robot_application };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        sources: ?[]Source = null,
        robot_software_suite: ?RobotSoftwareSuite = null,
        last_updated_at: ?i64 = null,
        revision_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .version = "version",
                .sources = "sources",
                .robot_software_suite = "robotSoftwareSuite",
                .last_updated_at = "lastUpdatedAt",
                .revision_id = "revisionId",
                .tags = "tags",
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_robot_application_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createRobotApplicationVersion",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRobotApplicationVersion",
    Request: type = struct {
        application: []const u8,
        current_revision_id: ?[]const u8 = null,
        s3_etags: ?[][]const u8 = null,
        image_digest: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .current_revision_id = "currentRevisionId",
                .s3_etags = "s3Etags",
                .image_digest = "imageDigest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_robot_application_version) } {
            return .{ .service_metadata = service_metadata, .action = create_robot_application_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        sources: ?[]Source = null,
        robot_software_suite: ?RobotSoftwareSuite = null,
        last_updated_at: ?i64 = null,
        revision_id: ?[]const u8 = null,
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .version = "version",
                .sources = "sources",
                .robot_software_suite = "robotSoftwareSuite",
                .last_updated_at = "lastUpdatedAt",
                .revision_id = "revisionId",
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const create_simulation_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createSimulationApplication",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSimulationApplication",
    Request: type = struct {
        name: []const u8,
        sources: ?[]SourceConfig = null,
        simulation_software_suite: SimulationSoftwareSuite,
        robot_software_suite: RobotSoftwareSuite,
        rendering_engine: ?RenderingEngine = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .sources = "sources",
                .simulation_software_suite = "simulationSoftwareSuite",
                .robot_software_suite = "robotSoftwareSuite",
                .rendering_engine = "renderingEngine",
                .tags = "tags",
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_simulation_application) } {
            return .{ .service_metadata = service_metadata, .action = create_simulation_application };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        sources: ?[]Source = null,
        simulation_software_suite: ?SimulationSoftwareSuite = null,
        robot_software_suite: ?RobotSoftwareSuite = null,
        rendering_engine: ?RenderingEngine = null,
        last_updated_at: ?i64 = null,
        revision_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .version = "version",
                .sources = "sources",
                .simulation_software_suite = "simulationSoftwareSuite",
                .robot_software_suite = "robotSoftwareSuite",
                .rendering_engine = "renderingEngine",
                .last_updated_at = "lastUpdatedAt",
                .revision_id = "revisionId",
                .tags = "tags",
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceAlreadyExists,
        Throttling,
    },
} = .{};
pub const create_simulation_application_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createSimulationApplicationVersion",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSimulationApplicationVersion",
    Request: type = struct {
        application: []const u8,
        current_revision_id: ?[]const u8 = null,
        s3_etags: ?[][]const u8 = null,
        image_digest: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .current_revision_id = "currentRevisionId",
                .s3_etags = "s3Etags",
                .image_digest = "imageDigest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_simulation_application_version) } {
            return .{ .service_metadata = service_metadata, .action = create_simulation_application_version };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        sources: ?[]Source = null,
        simulation_software_suite: ?SimulationSoftwareSuite = null,
        robot_software_suite: ?RobotSoftwareSuite = null,
        rendering_engine: ?RenderingEngine = null,
        last_updated_at: ?i64 = null,
        revision_id: ?[]const u8 = null,
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .version = "version",
                .sources = "sources",
                .simulation_software_suite = "simulationSoftwareSuite",
                .robot_software_suite = "robotSoftwareSuite",
                .rendering_engine = "renderingEngine",
                .last_updated_at = "lastUpdatedAt",
                .revision_id = "revisionId",
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const create_simulation_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createSimulationJob",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSimulationJob",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        output_location: ?OutputLocation = null,
        logging_config: ?LoggingConfig = null,
        max_job_duration_in_seconds: i64,
        iam_role: []const u8,
        failure_behavior: ?[]const u8 = null,
        robot_applications: ?[]RobotApplicationConfig = null,
        simulation_applications: ?[]SimulationApplicationConfig = null,
        data_sources: ?[]DataSourceConfig = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc_config: ?VPCConfig = null,
        compute: ?Compute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "clientRequestToken",
                .output_location = "outputLocation",
                .logging_config = "loggingConfig",
                .max_job_duration_in_seconds = "maxJobDurationInSeconds",
                .iam_role = "iamRole",
                .failure_behavior = "failureBehavior",
                .robot_applications = "robotApplications",
                .simulation_applications = "simulationApplications",
                .data_sources = "dataSources",
                .tags = "tags",
                .vpc_config = "vpcConfig",
                .compute = "compute",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_simulation_job) } {
            return .{ .service_metadata = service_metadata, .action = create_simulation_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        last_started_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        failure_behavior: ?[]const u8 = null,
        failure_code: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        output_location: ?OutputLocation = null,
        logging_config: ?LoggingConfig = null,
        max_job_duration_in_seconds: ?i64 = null,
        simulation_time_millis: ?i64 = null,
        iam_role: ?[]const u8 = null,
        robot_applications: ?[]RobotApplicationConfig = null,
        simulation_applications: ?[]SimulationApplicationConfig = null,
        data_sources: ?[]DataSource = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc_config: ?VPCConfigResponse = null,
        compute: ?ComputeResponse = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .status = "status",
                .last_started_at = "lastStartedAt",
                .last_updated_at = "lastUpdatedAt",
                .failure_behavior = "failureBehavior",
                .failure_code = "failureCode",
                .client_request_token = "clientRequestToken",
                .output_location = "outputLocation",
                .logging_config = "loggingConfig",
                .max_job_duration_in_seconds = "maxJobDurationInSeconds",
                .simulation_time_millis = "simulationTimeMillis",
                .iam_role = "iamRole",
                .robot_applications = "robotApplications",
                .simulation_applications = "simulationApplications",
                .data_sources = "dataSources",
                .tags = "tags",
                .vpc_config = "vpcConfig",
                .compute = "compute",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_world_export_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createWorldExportJob",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorldExportJob",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        worlds: [][]const u8,
        output_location: OutputLocation,
        iam_role: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "clientRequestToken",
                .worlds = "worlds",
                .output_location = "outputLocation",
                .iam_role = "iamRole",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_world_export_job) } {
            return .{ .service_metadata = service_metadata, .action = create_world_export_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_at: ?i64 = null,
        failure_code: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        output_location: ?OutputLocation = null,
        iam_role: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .status = "status",
                .created_at = "createdAt",
                .failure_code = "failureCode",
                .client_request_token = "clientRequestToken",
                .output_location = "outputLocation",
                .iam_role = "iamRole",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_world_generation_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createWorldGenerationJob",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorldGenerationJob",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        template: []const u8,
        world_count: WorldCount,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        world_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "clientRequestToken",
                .template = "template",
                .world_count = "worldCount",
                .tags = "tags",
                .world_tags = "worldTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "world_tags", field_name))
                return try serializeMap(self.world_tags, self.fieldNameFor("world_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_world_generation_job) } {
            return .{ .service_metadata = service_metadata, .action = create_world_generation_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_at: ?i64 = null,
        failure_code: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        template: ?[]const u8 = null,
        world_count: ?WorldCount = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        world_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .status = "status",
                .created_at = "createdAt",
                .failure_code = "failureCode",
                .client_request_token = "clientRequestToken",
                .template = "template",
                .world_count = "worldCount",
                .tags = "tags",
                .world_tags = "worldTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "world_tags", field_name))
                return try serializeMap(self.world_tags, self.fieldNameFor("world_tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_world_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createWorldTemplate",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorldTemplate",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        name: ?[]const u8 = null,
        template_body: ?[]const u8 = null,
        template_location: ?TemplateLocation = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "clientRequestToken",
                .name = "name",
                .template_body = "templateBody",
                .template_location = "templateLocation",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_world_template) } {
            return .{ .service_metadata = service_metadata, .action = create_world_template };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        created_at: ?i64 = null,
        name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .client_request_token = "clientRequestToken",
                .created_at = "createdAt",
                .name = "name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_fleet: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteFleet",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFleet",
    Request: type = struct {
        fleet: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet = "fleet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fleet) } {
            return .{ .service_metadata = service_metadata, .action = delete_fleet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const delete_robot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteRobot",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRobot",
    Request: type = struct {
        robot: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .robot = "robot",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_robot) } {
            return .{ .service_metadata = service_metadata, .action = delete_robot };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const delete_robot_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteRobotApplication",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRobotApplication",
    Request: type = struct {
        application: []const u8,
        application_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .application_version = "applicationVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_robot_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_robot_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const delete_simulation_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteSimulationApplication",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSimulationApplication",
    Request: type = struct {
        application: []const u8,
        application_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .application_version = "applicationVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_simulation_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_simulation_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const delete_world_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteWorldTemplate",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorldTemplate",
    Request: type = struct {
        template: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template = "template",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_world_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_world_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const deregister_robot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deregisterRobot",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterRobot",
    Request: type = struct {
        fleet: []const u8,
        robot: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet = "fleet",
                .robot = "robot",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_robot) } {
            return .{ .service_metadata = service_metadata, .action = deregister_robot };
        }
    },
    Response: type = struct {
        fleet: ?[]const u8 = null,
        robot: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet = "fleet",
                .robot = "robot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_deployment_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeDeploymentJob",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDeploymentJob",
    Request: type = struct {
        job: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_deployment_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_deployment_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        fleet: ?[]const u8 = null,
        status: ?[]const u8 = null,
        deployment_config: ?DeploymentConfig = null,
        deployment_application_configs: ?[]DeploymentApplicationConfig = null,
        failure_reason: ?[]const u8 = null,
        failure_code: ?[]const u8 = null,
        created_at: ?i64 = null,
        robot_deployment_summary: ?[]struct {
            arn: ?[]const u8 = null,
            deployment_start_time: ?i64 = null,
            deployment_finish_time: ?i64 = null,
            status: ?[]const u8 = null,
            progress_detail: ?struct {
                current_progress: ?[]const u8 = null,
                percent_done: ?f32 = null,
                estimated_time_remaining_seconds: ?i64 = null,
                target_resource: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .current_progress = "currentProgress",
                        .percent_done = "percentDone",
                        .estimated_time_remaining_seconds = "estimatedTimeRemainingSeconds",
                        .target_resource = "targetResource",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            failure_reason: ?[]const u8 = null,
            failure_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .deployment_start_time = "deploymentStartTime",
                    .deployment_finish_time = "deploymentFinishTime",
                    .status = "status",
                    .progress_detail = "progressDetail",
                    .failure_reason = "failureReason",
                    .failure_code = "failureCode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .fleet = "fleet",
                .status = "status",
                .deployment_config = "deploymentConfig",
                .deployment_application_configs = "deploymentApplicationConfigs",
                .failure_reason = "failureReason",
                .failure_code = "failureCode",
                .created_at = "createdAt",
                .robot_deployment_summary = "robotDeploymentSummary",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_fleet: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeFleet",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFleet",
    Request: type = struct {
        fleet: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet = "fleet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        robots: ?[]Robot = null,
        created_at: ?i64 = null,
        last_deployment_status: ?[]const u8 = null,
        last_deployment_job: ?[]const u8 = null,
        last_deployment_time: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .arn = "arn",
                .robots = "robots",
                .created_at = "createdAt",
                .last_deployment_status = "lastDeploymentStatus",
                .last_deployment_job = "lastDeploymentJob",
                .last_deployment_time = "lastDeploymentTime",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_robot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeRobot",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRobot",
    Request: type = struct {
        robot: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .robot = "robot",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_robot) } {
            return .{ .service_metadata = service_metadata, .action = describe_robot };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        fleet_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        greengrass_group_id: ?[]const u8 = null,
        created_at: ?i64 = null,
        architecture: ?[]const u8 = null,
        last_deployment_job: ?[]const u8 = null,
        last_deployment_time: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .fleet_arn = "fleetArn",
                .status = "status",
                .greengrass_group_id = "greengrassGroupId",
                .created_at = "createdAt",
                .architecture = "architecture",
                .last_deployment_job = "lastDeploymentJob",
                .last_deployment_time = "lastDeploymentTime",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_robot_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeRobotApplication",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRobotApplication",
    Request: type = struct {
        application: []const u8,
        application_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .application_version = "applicationVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_robot_application) } {
            return .{ .service_metadata = service_metadata, .action = describe_robot_application };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        sources: ?[]Source = null,
        robot_software_suite: ?RobotSoftwareSuite = null,
        revision_id: ?[]const u8 = null,
        last_updated_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        environment: ?Environment = null,
        image_digest: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .version = "version",
                .sources = "sources",
                .robot_software_suite = "robotSoftwareSuite",
                .revision_id = "revisionId",
                .last_updated_at = "lastUpdatedAt",
                .tags = "tags",
                .environment = "environment",
                .image_digest = "imageDigest",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_simulation_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeSimulationApplication",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSimulationApplication",
    Request: type = struct {
        application: []const u8,
        application_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .application_version = "applicationVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_simulation_application) } {
            return .{ .service_metadata = service_metadata, .action = describe_simulation_application };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        sources: ?[]Source = null,
        simulation_software_suite: ?SimulationSoftwareSuite = null,
        robot_software_suite: ?RobotSoftwareSuite = null,
        rendering_engine: ?RenderingEngine = null,
        revision_id: ?[]const u8 = null,
        last_updated_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        environment: ?Environment = null,
        image_digest: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .version = "version",
                .sources = "sources",
                .simulation_software_suite = "simulationSoftwareSuite",
                .robot_software_suite = "robotSoftwareSuite",
                .rendering_engine = "renderingEngine",
                .revision_id = "revisionId",
                .last_updated_at = "lastUpdatedAt",
                .tags = "tags",
                .environment = "environment",
                .image_digest = "imageDigest",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_simulation_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeSimulationJob",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSimulationJob",
    Request: type = struct {
        job: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_simulation_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_simulation_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        last_started_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        failure_behavior: ?[]const u8 = null,
        failure_code: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        output_location: ?OutputLocation = null,
        logging_config: ?LoggingConfig = null,
        max_job_duration_in_seconds: ?i64 = null,
        simulation_time_millis: ?i64 = null,
        iam_role: ?[]const u8 = null,
        robot_applications: ?[]RobotApplicationConfig = null,
        simulation_applications: ?[]SimulationApplicationConfig = null,
        data_sources: ?[]DataSource = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vpc_config: ?VPCConfigResponse = null,
        network_interface: ?NetworkInterface = null,
        compute: ?ComputeResponse = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .status = "status",
                .last_started_at = "lastStartedAt",
                .last_updated_at = "lastUpdatedAt",
                .failure_behavior = "failureBehavior",
                .failure_code = "failureCode",
                .failure_reason = "failureReason",
                .client_request_token = "clientRequestToken",
                .output_location = "outputLocation",
                .logging_config = "loggingConfig",
                .max_job_duration_in_seconds = "maxJobDurationInSeconds",
                .simulation_time_millis = "simulationTimeMillis",
                .iam_role = "iamRole",
                .robot_applications = "robotApplications",
                .simulation_applications = "simulationApplications",
                .data_sources = "dataSources",
                .tags = "tags",
                .vpc_config = "vpcConfig",
                .network_interface = "networkInterface",
                .compute = "compute",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_simulation_job_batch: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeSimulationJobBatch",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSimulationJobBatch",
    Request: type = struct {
        batch: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch = "batch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_simulation_job_batch) } {
            return .{ .service_metadata = service_metadata, .action = describe_simulation_job_batch };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        last_updated_at: ?i64 = null,
        created_at: ?i64 = null,
        client_request_token: ?[]const u8 = null,
        batch_policy: ?BatchPolicy = null,
        failure_code: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        failed_requests: ?[]FailedCreateSimulationJobRequest = null,
        pending_requests: ?[]SimulationJobRequest = null,
        created_requests: ?[]SimulationJobSummary = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .status = "status",
                .last_updated_at = "lastUpdatedAt",
                .created_at = "createdAt",
                .client_request_token = "clientRequestToken",
                .batch_policy = "batchPolicy",
                .failure_code = "failureCode",
                .failure_reason = "failureReason",
                .failed_requests = "failedRequests",
                .pending_requests = "pendingRequests",
                .created_requests = "createdRequests",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const describe_world: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeWorld",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeWorld",
    Request: type = struct {
        world: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .world = "world",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_world) } {
            return .{ .service_metadata = service_metadata, .action = describe_world };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        generation_job: ?[]const u8 = null,
        template: ?[]const u8 = null,
        created_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        world_description_body: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .generation_job = "generationJob",
                .template = "template",
                .created_at = "createdAt",
                .tags = "tags",
                .world_description_body = "worldDescriptionBody",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_world_export_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeWorldExportJob",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeWorldExportJob",
    Request: type = struct {
        job: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_world_export_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_world_export_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_at: ?i64 = null,
        failure_code: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        worlds: ?[][]const u8 = null,
        output_location: ?OutputLocation = null,
        iam_role: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .status = "status",
                .created_at = "createdAt",
                .failure_code = "failureCode",
                .failure_reason = "failureReason",
                .client_request_token = "clientRequestToken",
                .worlds = "worlds",
                .output_location = "outputLocation",
                .iam_role = "iamRole",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_world_generation_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeWorldGenerationJob",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeWorldGenerationJob",
    Request: type = struct {
        job: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_world_generation_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_world_generation_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_at: ?i64 = null,
        failure_code: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        template: ?[]const u8 = null,
        world_count: ?WorldCount = null,
        finished_worlds_summary: ?struct {
            finished_count: ?i64 = null,
            succeeded_worlds: ?[][]const u8 = null,
            failure_summary: ?struct {
                total_failure_count: ?i64 = null,
                failures: ?[]struct {
                    failure_code: ?[]const u8 = null,
                    sample_failure_reason: ?[]const u8 = null,
                    failure_count: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .failure_code = "failureCode",
                            .sample_failure_reason = "sampleFailureReason",
                            .failure_count = "failureCount",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .total_failure_count = "totalFailureCount",
                        .failures = "failures",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finished_count = "finishedCount",
                    .succeeded_worlds = "succeededWorlds",
                    .failure_summary = "failureSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        world_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .status = "status",
                .created_at = "createdAt",
                .failure_code = "failureCode",
                .failure_reason = "failureReason",
                .client_request_token = "clientRequestToken",
                .template = "template",
                .world_count = "worldCount",
                .finished_worlds_summary = "finishedWorldsSummary",
                .tags = "tags",
                .world_tags = "worldTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "world_tags", field_name))
                return try serializeMap(self.world_tags, self.fieldNameFor("world_tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_world_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeWorldTemplate",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeWorldTemplate",
    Request: type = struct {
        template: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template = "template",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_world_template) } {
            return .{ .service_metadata = service_metadata, .action = describe_world_template };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,
        name: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .client_request_token = "clientRequestToken",
                .name = "name",
                .created_at = "createdAt",
                .last_updated_at = "lastUpdatedAt",
                .tags = "tags",
                .version = "version",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_world_template_body: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getWorldTemplateBody",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorldTemplateBody",
    Request: type = struct {
        template: ?[]const u8 = null,
        generation_job: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template = "template",
                .generation_job = "generationJob",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_world_template_body) } {
            return .{ .service_metadata = service_metadata, .action = get_world_template_body };
        }
    },
    Response: type = struct {
        template_body: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_body = "templateBody",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_deployment_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listDeploymentJobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeploymentJobs",
    Request: type = struct {
        filters: ?[]Filter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_deployment_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_deployment_jobs };
        }
    },
    Response: type = struct {
        deployment_jobs: ?[]struct {
            arn: ?[]const u8 = null,
            fleet: ?[]const u8 = null,
            status: ?[]const u8 = null,
            deployment_application_configs: ?[]DeploymentApplicationConfig = null,
            deployment_config: ?DeploymentConfig = null,
            failure_reason: ?[]const u8 = null,
            failure_code: ?[]const u8 = null,
            created_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .fleet = "fleet",
                    .status = "status",
                    .deployment_application_configs = "deploymentApplicationConfigs",
                    .deployment_config = "deploymentConfig",
                    .failure_reason = "failureReason",
                    .failure_code = "failureCode",
                    .created_at = "createdAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_jobs = "deploymentJobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_fleets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listFleets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFleets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fleets) } {
            return .{ .service_metadata = service_metadata, .action = list_fleets };
        }
    },
    Response: type = struct {
        fleet_details: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_deployment_status: ?[]const u8 = null,
            last_deployment_job: ?[]const u8 = null,
            last_deployment_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                    .created_at = "createdAt",
                    .last_deployment_status = "lastDeploymentStatus",
                    .last_deployment_job = "lastDeploymentJob",
                    .last_deployment_time = "lastDeploymentTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_details = "fleetDetails",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_robot_applications: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listRobotApplications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRobotApplications",
    Request: type = struct {
        version_qualifier: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version_qualifier = "versionQualifier",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_robot_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_robot_applications };
        }
    },
    Response: type = struct {
        robot_application_summaries: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            version: ?[]const u8 = null,
            last_updated_at: ?i64 = null,
            robot_software_suite: ?RobotSoftwareSuite = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                    .version = "version",
                    .last_updated_at = "lastUpdatedAt",
                    .robot_software_suite = "robotSoftwareSuite",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .robot_application_summaries = "robotApplicationSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const list_robots: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listRobots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRobots",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_robots) } {
            return .{ .service_metadata = service_metadata, .action = list_robots };
        }
    },
    Response: type = struct {
        robots: ?[]Robot = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .robots = "robots",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_simulation_applications: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listSimulationApplications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSimulationApplications",
    Request: type = struct {
        version_qualifier: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version_qualifier = "versionQualifier",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_simulation_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_simulation_applications };
        }
    },
    Response: type = struct {
        simulation_application_summaries: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            version: ?[]const u8 = null,
            last_updated_at: ?i64 = null,
            robot_software_suite: ?RobotSoftwareSuite = null,
            simulation_software_suite: ?SimulationSoftwareSuite = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                    .version = "version",
                    .last_updated_at = "lastUpdatedAt",
                    .robot_software_suite = "robotSoftwareSuite",
                    .simulation_software_suite = "simulationSoftwareSuite",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .simulation_application_summaries = "simulationApplicationSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const list_simulation_job_batches: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listSimulationJobBatches",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSimulationJobBatches",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_simulation_job_batches) } {
            return .{ .service_metadata = service_metadata, .action = list_simulation_job_batches };
        }
    },
    Response: type = struct {
        simulation_job_batch_summaries: ?[]struct {
            arn: ?[]const u8 = null,
            last_updated_at: ?i64 = null,
            created_at: ?i64 = null,
            status: ?[]const u8 = null,
            failed_request_count: ?i64 = null,
            pending_request_count: ?i64 = null,
            created_request_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .last_updated_at = "lastUpdatedAt",
                    .created_at = "createdAt",
                    .status = "status",
                    .failed_request_count = "failedRequestCount",
                    .pending_request_count = "pendingRequestCount",
                    .created_request_count = "createdRequestCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .simulation_job_batch_summaries = "simulationJobBatchSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
    },
} = .{};
pub const list_simulation_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listSimulationJobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSimulationJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_simulation_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_simulation_jobs };
        }
    },
    Response: type = struct {
        simulation_job_summaries: []SimulationJobSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .simulation_job_summaries = "simulationJobSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_world_export_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listWorldExportJobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorldExportJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_world_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_world_export_jobs };
        }
    },
    Response: type = struct {
        world_export_job_summaries: []struct {
            arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            worlds: ?[][]const u8 = null,
            output_location: ?OutputLocation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .status = "status",
                    .created_at = "createdAt",
                    .worlds = "worlds",
                    .output_location = "outputLocation",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .world_export_job_summaries = "worldExportJobSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const list_world_generation_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listWorldGenerationJobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorldGenerationJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_world_generation_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_world_generation_jobs };
        }
    },
    Response: type = struct {
        world_generation_job_summaries: []struct {
            arn: ?[]const u8 = null,
            template: ?[]const u8 = null,
            created_at: ?i64 = null,
            status: ?[]const u8 = null,
            world_count: ?WorldCount = null,
            succeeded_world_count: ?i64 = null,
            failed_world_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .template = "template",
                    .created_at = "createdAt",
                    .status = "status",
                    .world_count = "worldCount",
                    .succeeded_world_count = "succeededWorldCount",
                    .failed_world_count = "failedWorldCount",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .world_generation_job_summaries = "worldGenerationJobSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const list_worlds: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listWorlds",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorlds",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_worlds) } {
            return .{ .service_metadata = service_metadata, .action = list_worlds };
        }
    },
    Response: type = struct {
        world_summaries: ?[]struct {
            arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            generation_job: ?[]const u8 = null,
            template: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .created_at = "createdAt",
                    .generation_job = "generationJob",
                    .template = "template",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .world_summaries = "worldSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const list_world_templates: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listWorldTemplates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorldTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_world_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_world_templates };
        }
    },
    Response: type = struct {
        template_summaries: ?[]struct {
            arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .name = "name",
                    .version = "version",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_summaries = "templateSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const register_robot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/registerRobot",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterRobot",
    Request: type = struct {
        fleet: []const u8,
        robot: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet = "fleet",
                .robot = "robot",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_robot) } {
            return .{ .service_metadata = service_metadata, .action = register_robot };
        }
    },
    Response: type = struct {
        fleet: ?[]const u8 = null,
        robot: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet = "fleet",
                .robot = "robot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const restart_simulation_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restartSimulationJob",
        .success_code = 200,
    };

    action_name: []const u8 = "RestartSimulationJob",
    Request: type = struct {
        job: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "job",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restart_simulation_job) } {
            return .{ .service_metadata = service_metadata, .action = restart_simulation_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const start_simulation_job_batch: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/startSimulationJobBatch",
        .success_code = 200,
    };

    action_name: []const u8 = "StartSimulationJobBatch",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        batch_policy: ?BatchPolicy = null,
        create_simulation_job_requests: []SimulationJobRequest,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "clientRequestToken",
                .batch_policy = "batchPolicy",
                .create_simulation_job_requests = "createSimulationJobRequests",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_simulation_job_batch) } {
            return .{ .service_metadata = service_metadata, .action = start_simulation_job_batch };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_at: ?i64 = null,
        client_request_token: ?[]const u8 = null,
        batch_policy: ?BatchPolicy = null,
        failure_code: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        failed_requests: ?[]FailedCreateSimulationJobRequest = null,
        pending_requests: ?[]SimulationJobRequest = null,
        created_requests: ?[]SimulationJobSummary = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .status = "status",
                .created_at = "createdAt",
                .client_request_token = "clientRequestToken",
                .batch_policy = "batchPolicy",
                .failure_code = "failureCode",
                .failure_reason = "failureReason",
                .failed_requests = "failedRequests",
                .pending_requests = "pendingRequests",
                .created_requests = "createdRequests",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        IdempotentParameterMismatch,
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const sync_deployment_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/syncDeploymentJob",
        .success_code = 200,
    };

    action_name: []const u8 = "SyncDeploymentJob",
    Request: type = struct {
        client_request_token: []const u8,
        fleet: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "clientRequestToken",
                .fleet = "fleet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(sync_deployment_job) } {
            return .{ .service_metadata = service_metadata, .action = sync_deployment_job };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        fleet: ?[]const u8 = null,
        status: ?[]const u8 = null,
        deployment_config: ?DeploymentConfig = null,
        deployment_application_configs: ?[]DeploymentApplicationConfig = null,
        failure_reason: ?[]const u8 = null,
        failure_code: ?[]const u8 = null,
        created_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .fleet = "fleet",
                .status = "status",
                .deployment_config = "deploymentConfig",
                .deployment_application_configs = "deploymentApplicationConfigs",
                .failure_reason = "failureReason",
                .failure_code = "failureCode",
                .created_at = "createdAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentDeployment,
        IdempotentParameterMismatch,
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_robot_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateRobotApplication",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRobotApplication",
    Request: type = struct {
        application: []const u8,
        sources: ?[]SourceConfig = null,
        robot_software_suite: RobotSoftwareSuite,
        current_revision_id: ?[]const u8 = null,
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .sources = "sources",
                .robot_software_suite = "robotSoftwareSuite",
                .current_revision_id = "currentRevisionId",
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_robot_application) } {
            return .{ .service_metadata = service_metadata, .action = update_robot_application };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        sources: ?[]Source = null,
        robot_software_suite: ?RobotSoftwareSuite = null,
        last_updated_at: ?i64 = null,
        revision_id: ?[]const u8 = null,
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .version = "version",
                .sources = "sources",
                .robot_software_suite = "robotSoftwareSuite",
                .last_updated_at = "lastUpdatedAt",
                .revision_id = "revisionId",
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_simulation_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateSimulationApplication",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSimulationApplication",
    Request: type = struct {
        application: []const u8,
        sources: ?[]SourceConfig = null,
        simulation_software_suite: SimulationSoftwareSuite,
        robot_software_suite: RobotSoftwareSuite,
        rendering_engine: ?RenderingEngine = null,
        current_revision_id: ?[]const u8 = null,
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .sources = "sources",
                .simulation_software_suite = "simulationSoftwareSuite",
                .robot_software_suite = "robotSoftwareSuite",
                .rendering_engine = "renderingEngine",
                .current_revision_id = "currentRevisionId",
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_simulation_application) } {
            return .{ .service_metadata = service_metadata, .action = update_simulation_application };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version: ?[]const u8 = null,
        sources: ?[]Source = null,
        simulation_software_suite: ?SimulationSoftwareSuite = null,
        robot_software_suite: ?RobotSoftwareSuite = null,
        rendering_engine: ?RenderingEngine = null,
        last_updated_at: ?i64 = null,
        revision_id: ?[]const u8 = null,
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .version = "version",
                .sources = "sources",
                .simulation_software_suite = "simulationSoftwareSuite",
                .robot_software_suite = "robotSoftwareSuite",
                .rendering_engine = "renderingEngine",
                .last_updated_at = "lastUpdatedAt",
                .revision_id = "revisionId",
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_world_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateWorldTemplate",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateWorldTemplate",
    Request: type = struct {
        template: []const u8,
        name: ?[]const u8 = null,
        template_body: ?[]const u8 = null,
        template_location: ?TemplateLocation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template = "template",
                .name = "name",
                .template_body = "templateBody",
                .template_location = "templateLocation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_world_template) } {
            return .{ .service_metadata = service_metadata, .action = update_world_template };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .created_at = "createdAt",
                .last_updated_at = "lastUpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const TemplateLocation = struct {
    s3_bucket: []const u8,
    s3_key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
            .s3_key = "s3Key",
        };
        return @field(mappings, field_name);
    }
};

pub const Environment = struct {
    uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .uri = "uri",
        };
        return @field(mappings, field_name);
    }
};

pub const RenderingEngine = struct {
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const RobotSoftwareSuite = struct {
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const SimulationSoftwareSuite = struct {
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const Source = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,
    etag: ?[]const u8 = null,
    architecture: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
            .s3_key = "s3Key",
            .etag = "etag",
            .architecture = "architecture",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceConfig = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key: ?[]const u8 = null,
    architecture: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
            .s3_key = "s3Key",
            .architecture = "architecture",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentApplicationConfig = struct {
    application: []const u8,
    application_version: []const u8,
    launch_config: DeploymentLaunchConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application = "application",
            .application_version = "applicationVersion",
            .launch_config = "launchConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentLaunchConfig = struct {
    package_name: []const u8,
    pre_launch_file: ?[]const u8 = null,
    launch_file: []const u8,
    post_launch_file: ?[]const u8 = null,
    environment_variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_name = "packageName",
            .pre_launch_file = "preLaunchFile",
            .launch_file = "launchFile",
            .post_launch_file = "postLaunchFile",
            .environment_variables = "environmentVariables",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment_variables", field_name))
            return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
        return false;
    }
};

pub const DeploymentConfig = struct {
    concurrent_deployment_percentage: ?i64 = null,
    failure_threshold_percentage: ?i64 = null,
    robot_deployment_timeout_in_seconds: ?i64 = null,
    download_condition_file: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .concurrent_deployment_percentage = "concurrentDeploymentPercentage",
            .failure_threshold_percentage = "failureThresholdPercentage",
            .robot_deployment_timeout_in_seconds = "robotDeploymentTimeoutInSeconds",
            .download_condition_file = "downloadConditionFile",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Object = struct {
    bucket: []const u8,
    key: []const u8,
    etag: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key = "key",
            .etag = "etag",
        };
        return @field(mappings, field_name);
    }
};

pub const SimulationJobSummary = struct {
    arn: ?[]const u8 = null,
    last_updated_at: ?i64 = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    simulation_application_names: ?[][]const u8 = null,
    robot_application_names: ?[][]const u8 = null,
    data_source_names: ?[][]const u8 = null,
    compute_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .last_updated_at = "lastUpdatedAt",
            .name = "name",
            .status = "status",
            .simulation_application_names = "simulationApplicationNames",
            .robot_application_names = "robotApplicationNames",
            .data_source_names = "dataSourceNames",
            .compute_type = "computeType",
        };
        return @field(mappings, field_name);
    }
};

pub const SimulationJobRequest = struct {
    output_location: ?OutputLocation = null,
    logging_config: ?LoggingConfig = null,
    max_job_duration_in_seconds: i64,
    iam_role: ?[]const u8 = null,
    failure_behavior: ?[]const u8 = null,
    use_default_applications: ?bool = null,
    robot_applications: ?[]RobotApplicationConfig = null,
    simulation_applications: ?[]SimulationApplicationConfig = null,
    data_sources: ?[]DataSourceConfig = null,
    vpc_config: ?VPCConfig = null,
    compute: ?Compute = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_location = "outputLocation",
            .logging_config = "loggingConfig",
            .max_job_duration_in_seconds = "maxJobDurationInSeconds",
            .iam_role = "iamRole",
            .failure_behavior = "failureBehavior",
            .use_default_applications = "useDefaultApplications",
            .robot_applications = "robotApplications",
            .simulation_applications = "simulationApplications",
            .data_sources = "dataSources",
            .vpc_config = "vpcConfig",
            .compute = "compute",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Compute = struct {
    simulation_unit_limit: ?i64 = null,
    compute_type: ?[]const u8 = null,
    gpu_unit_limit: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simulation_unit_limit = "simulationUnitLimit",
            .compute_type = "computeType",
            .gpu_unit_limit = "gpuUnitLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const VPCConfig = struct {
    subnets: [][]const u8,
    security_groups: ?[][]const u8 = null,
    assign_public_ip: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnets = "subnets",
            .security_groups = "securityGroups",
            .assign_public_ip = "assignPublicIp",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceConfig = struct {
    name: []const u8,
    s3_bucket: []const u8,
    s3_keys: [][]const u8,
    type: ?[]const u8 = null,
    destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .s3_bucket = "s3Bucket",
            .s3_keys = "s3Keys",
            .type = "type",
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const SimulationApplicationConfig = struct {
    application: []const u8,
    application_version: ?[]const u8 = null,
    launch_config: LaunchConfig,
    upload_configurations: ?[]UploadConfiguration = null,
    world_configs: ?[]WorldConfig = null,
    use_default_upload_configurations: ?bool = null,
    tools: ?[]Tool = null,
    use_default_tools: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application = "application",
            .application_version = "applicationVersion",
            .launch_config = "launchConfig",
            .upload_configurations = "uploadConfigurations",
            .world_configs = "worldConfigs",
            .use_default_upload_configurations = "useDefaultUploadConfigurations",
            .tools = "tools",
            .use_default_tools = "useDefaultTools",
        };
        return @field(mappings, field_name);
    }
};

pub const Tool = struct {
    stream_ui: ?bool = null,
    name: []const u8,
    command: []const u8,
    stream_output_to_cloud_watch: ?bool = null,
    exit_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_ui = "streamUI",
            .name = "name",
            .command = "command",
            .stream_output_to_cloud_watch = "streamOutputToCloudWatch",
            .exit_behavior = "exitBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const WorldConfig = struct {
    world: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .world = "world",
        };
        return @field(mappings, field_name);
    }
};

pub const UploadConfiguration = struct {
    name: []const u8,
    path: []const u8,
    upload_behavior: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .path = "path",
            .upload_behavior = "uploadBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchConfig = struct {
    package_name: ?[]const u8 = null,
    launch_file: ?[]const u8 = null,
    environment_variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    port_forwarding_config: ?PortForwardingConfig = null,
    stream_ui: ?bool = null,
    command: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_name = "packageName",
            .launch_file = "launchFile",
            .environment_variables = "environmentVariables",
            .port_forwarding_config = "portForwardingConfig",
            .stream_ui = "streamUI",
            .command = "command",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment_variables", field_name))
            return try serializeMap(self.environment_variables, self.fieldNameFor("environment_variables"), options, out_stream);
        return false;
    }
};

pub const PortForwardingConfig = struct {
    port_mappings: ?[]PortMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port_mappings = "portMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const PortMapping = struct {
    job_port: i64,
    application_port: i64,
    enable_on_public_ip: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_port = "jobPort",
            .application_port = "applicationPort",
            .enable_on_public_ip = "enableOnPublicIp",
        };
        return @field(mappings, field_name);
    }
};

pub const RobotApplicationConfig = struct {
    application: []const u8,
    application_version: ?[]const u8 = null,
    launch_config: LaunchConfig,
    upload_configurations: ?[]UploadConfiguration = null,
    use_default_upload_configurations: ?bool = null,
    tools: ?[]Tool = null,
    use_default_tools: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application = "application",
            .application_version = "applicationVersion",
            .launch_config = "launchConfig",
            .upload_configurations = "uploadConfigurations",
            .use_default_upload_configurations = "useDefaultUploadConfigurations",
            .tools = "tools",
            .use_default_tools = "useDefaultTools",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingConfig = struct {
    record_all_ros_topics: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .record_all_ros_topics = "recordAllRosTopics",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputLocation = struct {
    s3_bucket: ?[]const u8 = null,
    s3_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
            .s3_prefix = "s3Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedCreateSimulationJobRequest = struct {
    request: ?SimulationJobRequest = null,
    failure_reason: ?[]const u8 = null,
    failure_code: ?[]const u8 = null,
    failed_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .request = "request",
            .failure_reason = "failureReason",
            .failure_code = "failureCode",
            .failed_at = "failedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchPolicy = struct {
    timeout_in_seconds: ?i64 = null,
    max_concurrency: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_in_seconds = "timeoutInSeconds",
            .max_concurrency = "maxConcurrency",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const WorldCount = struct {
    floorplan_count: ?i64 = null,
    interior_count_per_floorplan: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .floorplan_count = "floorplanCount",
            .interior_count_per_floorplan = "interiorCountPerFloorplan",
        };
        return @field(mappings, field_name);
    }
};

pub const Robot = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    fleet_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    green_grass_group_id: ?[]const u8 = null,
    created_at: ?i64 = null,
    architecture: ?[]const u8 = null,
    last_deployment_job: ?[]const u8 = null,
    last_deployment_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .fleet_arn = "fleetArn",
            .status = "status",
            .green_grass_group_id = "greenGrassGroupId",
            .created_at = "createdAt",
            .architecture = "architecture",
            .last_deployment_job = "lastDeploymentJob",
            .last_deployment_time = "lastDeploymentTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeResponse = struct {
    simulation_unit_limit: ?i64 = null,
    compute_type: ?[]const u8 = null,
    gpu_unit_limit: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simulation_unit_limit = "simulationUnitLimit",
            .compute_type = "computeType",
            .gpu_unit_limit = "gpuUnitLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterface = struct {
    network_interface_id: ?[]const u8 = null,
    private_ip_address: ?[]const u8 = null,
    public_ip_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_interface_id = "networkInterfaceId",
            .private_ip_address = "privateIpAddress",
            .public_ip_address = "publicIpAddress",
        };
        return @field(mappings, field_name);
    }
};

pub const VPCConfigResponse = struct {
    subnets: ?[][]const u8 = null,
    security_groups: ?[][]const u8 = null,
    vpc_id: ?[]const u8 = null,
    assign_public_ip: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnets = "subnets",
            .security_groups = "securityGroups",
            .vpc_id = "vpcId",
            .assign_public_ip = "assignPublicIp",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSource = struct {
    name: ?[]const u8 = null,
    s3_bucket: ?[]const u8 = null,
    s3_keys: ?[]S3KeyOutput = null,
    type: ?[]const u8 = null,
    destination: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .s3_bucket = "s3Bucket",
            .s3_keys = "s3Keys",
            .type = "type",
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const S3KeyOutput = struct {
    s3_key: ?[]const u8 = null,
    etag: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_key = "s3Key",
            .etag = "etag",
        };
        return @field(mappings, field_name);
    }
};
