const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-02";
pub const sdk_id: []const u8 = "Route53 Recovery Cluster";
pub const arn_namespace: ?[]const u8 = "route53-recovery-cluster";
pub const endpoint_prefix: []const u8 = "route53-recovery-cluster";
pub const sigv4_name: []const u8 = "route53-recovery-cluster";
pub const name: []const u8 = "ToggleCustomerAPI";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-02",
    sdk_id: []const u8 = "Route53 Recovery Cluster",
    arn_namespace: ?[]const u8 = "route53-recovery-cluster",
    endpoint_prefix: []const u8 = "route53-recovery-cluster",
    sigv4_name: []const u8 = "route53-recovery-cluster",
    name: []const u8 = "ToggleCustomerAPI",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const get_routing_control_state: struct {
    action_name: []const u8 = "GetRoutingControlState",
    Request: type = struct {
        routing_control_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_control_arn = "RoutingControlArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_routing_control_state) } {
            return .{ .service_metadata = service_metadata, .action = get_routing_control_state };
        }
    },
    Response: type = struct {
        routing_control_arn: []const u8,
        routing_control_state: []const u8,
        routing_control_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_control_arn = "RoutingControlArn",
                .routing_control_state = "RoutingControlState",
                .routing_control_name = "RoutingControlName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EndpointTemporarilyUnavailable,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_routing_controls: struct {
    action_name: []const u8 = "ListRoutingControls",
    Request: type = struct {
        control_panel_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_panel_arn = "ControlPanelArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_routing_controls) } {
            return .{ .service_metadata = service_metadata, .action = list_routing_controls };
        }
    },
    Response: type = struct {
        routing_controls: []struct {
            control_panel_arn: ?[]const u8 = null,
            control_panel_name: ?[]const u8 = null,
            routing_control_arn: ?[]const u8 = null,
            routing_control_name: ?[]const u8 = null,
            routing_control_state: ?[]const u8 = null,
            owner: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .control_panel_arn = "ControlPanelArn",
                    .control_panel_name = "ControlPanelName",
                    .routing_control_arn = "RoutingControlArn",
                    .routing_control_name = "RoutingControlName",
                    .routing_control_state = "RoutingControlState",
                    .owner = "Owner",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_controls = "RoutingControls",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EndpointTemporarilyUnavailable,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_routing_control_state: struct {
    action_name: []const u8 = "UpdateRoutingControlState",
    Request: type = struct {
        routing_control_arn: []const u8,
        routing_control_state: []const u8,
        safety_rules_to_override: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_control_arn = "RoutingControlArn",
                .routing_control_state = "RoutingControlState",
                .safety_rules_to_override = "SafetyRulesToOverride",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_control_state) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_control_state };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        EndpointTemporarilyUnavailable,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_routing_control_states: struct {
    action_name: []const u8 = "UpdateRoutingControlStates",
    Request: type = struct {
        update_routing_control_state_entries: []struct {
            routing_control_arn: []const u8,
            routing_control_state: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .routing_control_arn = "RoutingControlArn",
                    .routing_control_state = "RoutingControlState",
                };
                return @field(mappings, field_name);
            }
        },
        safety_rules_to_override: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_routing_control_state_entries = "UpdateRoutingControlStateEntries",
                .safety_rules_to_override = "SafetyRulesToOverride",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_control_states) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_control_states };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        EndpointTemporarilyUnavailable,
        InternalServer,
        ResourceNotFound,
        ServiceLimitExceeded,
        Throttling,
        Validation,
    },
} = .{};
