const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-11-02";
pub const sdk_id: []const u8 = "Route53 Recovery Control Config";
pub const arn_namespace: ?[]const u8 = "route53-recovery-control-config";
pub const endpoint_prefix: []const u8 = "route53-recovery-control-config";
pub const sigv4_name: []const u8 = "route53-recovery-control-config";
pub const name: []const u8 = "Route53RecoveryControlConfig";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-11-02",
    sdk_id: []const u8 = "Route53 Recovery Control Config",
    arn_namespace: ?[]const u8 = "route53-recovery-control-config",
    endpoint_prefix: []const u8 = "route53-recovery-control-config",
    sigv4_name: []const u8 = "route53-recovery-control-config",
    name: []const u8 = "Route53RecoveryControlConfig",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_cluster: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cluster",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCluster",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        cluster_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .cluster_name = "ClusterName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_control_panel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/controlpanel",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateControlPanel",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        cluster_arn: []const u8,
        control_panel_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .cluster_arn = "ClusterArn",
                .control_panel_name = "ControlPanelName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_control_panel) } {
            return .{ .service_metadata = service_metadata, .action = create_control_panel };
        }
    },
    Response: type = struct {
        control_panel: ?ControlPanel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_panel = "ControlPanel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_routing_control: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routingcontrol",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRoutingControl",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        cluster_arn: []const u8,
        control_panel_arn: ?[]const u8 = null,
        routing_control_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .cluster_arn = "ClusterArn",
                .control_panel_arn = "ControlPanelArn",
                .routing_control_name = "RoutingControlName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_routing_control) } {
            return .{ .service_metadata = service_metadata, .action = create_routing_control };
        }
    },
    Response: type = struct {
        routing_control: ?RoutingControl = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_control = "RoutingControl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_safety_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/safetyrule",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSafetyRule",
    Request: type = struct {
        assertion_rule: ?struct {
            asserted_controls: [][]const u8,
            control_panel_arn: []const u8,
            name: []const u8,
            rule_config: RuleConfig,
            wait_period_ms: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .asserted_controls = "AssertedControls",
                    .control_panel_arn = "ControlPanelArn",
                    .name = "Name",
                    .rule_config = "RuleConfig",
                    .wait_period_ms = "WaitPeriodMs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_token: ?[]const u8 = null,
        gating_rule: ?struct {
            control_panel_arn: []const u8,
            gating_controls: [][]const u8,
            name: []const u8,
            rule_config: RuleConfig,
            target_controls: [][]const u8,
            wait_period_ms: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .control_panel_arn = "ControlPanelArn",
                    .gating_controls = "GatingControls",
                    .name = "Name",
                    .rule_config = "RuleConfig",
                    .target_controls = "TargetControls",
                    .wait_period_ms = "WaitPeriodMs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assertion_rule = "AssertionRule",
                .client_token = "ClientToken",
                .gating_rule = "GatingRule",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_safety_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_safety_rule };
        }
    },
    Response: type = struct {
        assertion_rule: ?AssertionRule = null,
        gating_rule: ?GatingRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assertion_rule = "AssertionRule",
                .gating_rule = "GatingRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const delete_cluster: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/cluster/{ClusterArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCluster",
    Request: type = struct {
        cluster_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_control_panel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/controlpanel/{ControlPanelArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteControlPanel",
    Request: type = struct {
        control_panel_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_panel_arn = "ControlPanelArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_control_panel) } {
            return .{ .service_metadata = service_metadata, .action = delete_control_panel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_routing_control: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/routingcontrol/{RoutingControlArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRoutingControl",
    Request: type = struct {
        routing_control_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_control_arn = "RoutingControlArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_routing_control) } {
            return .{ .service_metadata = service_metadata, .action = delete_routing_control };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_safety_rule: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/safetyrule/{SafetyRuleArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSafetyRule",
    Request: type = struct {
        safety_rule_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .safety_rule_arn = "SafetyRuleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_safety_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_safety_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_cluster: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cluster/{ClusterArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCluster",
    Request: type = struct {
        cluster_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster };
        }
    },
    Response: type = struct {
        cluster: ?Cluster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster = "Cluster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_control_panel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/controlpanel/{ControlPanelArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeControlPanel",
    Request: type = struct {
        control_panel_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_panel_arn = "ControlPanelArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_control_panel) } {
            return .{ .service_metadata = service_metadata, .action = describe_control_panel };
        }
    },
    Response: type = struct {
        control_panel: ?ControlPanel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_panel = "ControlPanel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_routing_control: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/routingcontrol/{RoutingControlArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRoutingControl",
    Request: type = struct {
        routing_control_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_control_arn = "RoutingControlArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_routing_control) } {
            return .{ .service_metadata = service_metadata, .action = describe_routing_control };
        }
    },
    Response: type = struct {
        routing_control: ?RoutingControl = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_control = "RoutingControl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_safety_rule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/safetyrule/{SafetyRuleArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSafetyRule",
    Request: type = struct {
        safety_rule_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .safety_rule_arn = "SafetyRuleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_safety_rule) } {
            return .{ .service_metadata = service_metadata, .action = describe_safety_rule };
        }
    },
    Response: type = struct {
        assertion_rule: ?AssertionRule = null,
        gating_rule: ?GatingRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assertion_rule = "AssertionRule",
                .gating_rule = "GatingRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_resource_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resourcePolicy/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const list_associated_route53_health_checks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/routingcontrol/{RoutingControlArn}/associatedRoute53HealthChecks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssociatedRoute53HealthChecks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        routing_control_arn: []const u8,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .routing_control_arn = "RoutingControlArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associated_route53_health_checks) } {
            return .{ .service_metadata = service_metadata, .action = list_associated_route53_health_checks };
        }
    },
    Response: type = struct {
        health_check_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check_ids = "HealthCheckIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_clusters: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cluster",
        .success_code = 200,
    };

    action_name: []const u8 = "ListClusters",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_clusters) } {
            return .{ .service_metadata = service_metadata, .action = list_clusters };
        }
    },
    Response: type = struct {
        clusters: ?[]Cluster = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .clusters = "Clusters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_control_panels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/controlpanels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListControlPanels",
    Request: type = struct {
        cluster_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .cluster_arn = "ClusterArn",
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_control_panels) } {
            return .{ .service_metadata = service_metadata, .action = list_control_panels };
        }
    },
    Response: type = struct {
        control_panels: ?[]ControlPanel = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_panels = "ControlPanels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_routing_controls: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/controlpanel/{ControlPanelArn}/routingcontrols",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRoutingControls",
    Request: type = struct {
        control_panel_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_panel_arn = "ControlPanelArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_routing_controls) } {
            return .{ .service_metadata = service_metadata, .action = list_routing_controls };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        routing_controls: ?[]RoutingControl = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .routing_controls = "RoutingControls",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_safety_rules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/controlpanel/{ControlPanelArn}/safetyrules",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSafetyRules",
    Request: type = struct {
        control_panel_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_panel_arn = "ControlPanelArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_safety_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_safety_rules };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        safety_rules: ?[]struct {
            assertion: ?AssertionRule = null,
            gating: ?GatingRule = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .assertion = "ASSERTION",
                    .gating = "GATING",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .safety_rules = "SafetyRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "TagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_control_panel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/controlpanel",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateControlPanel",
    Request: type = struct {
        control_panel_arn: []const u8,
        control_panel_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_panel_arn = "ControlPanelArn",
                .control_panel_name = "ControlPanelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_control_panel) } {
            return .{ .service_metadata = service_metadata, .action = update_control_panel };
        }
    },
    Response: type = struct {
        control_panel: ?ControlPanel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .control_panel = "ControlPanel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_routing_control: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/routingcontrol",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoutingControl",
    Request: type = struct {
        routing_control_arn: []const u8,
        routing_control_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_control_arn = "RoutingControlArn",
                .routing_control_name = "RoutingControlName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_control) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_control };
        }
    },
    Response: type = struct {
        routing_control: ?RoutingControl = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_control = "RoutingControl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_safety_rule: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/safetyrule",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSafetyRule",
    Request: type = struct {
        assertion_rule_update: ?struct {
            name: []const u8,
            safety_rule_arn: []const u8,
            wait_period_ms: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .safety_rule_arn = "SafetyRuleArn",
                    .wait_period_ms = "WaitPeriodMs",
                };
                return @field(mappings, field_name);
            }
        } = null,
        gating_rule_update: ?struct {
            name: []const u8,
            safety_rule_arn: []const u8,
            wait_period_ms: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .safety_rule_arn = "SafetyRuleArn",
                    .wait_period_ms = "WaitPeriodMs",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assertion_rule_update = "AssertionRuleUpdate",
                .gating_rule_update = "GatingRuleUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_safety_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_safety_rule };
        }
    },
    Response: type = struct {
        assertion_rule: ?AssertionRule = null,
        gating_rule: ?GatingRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assertion_rule = "AssertionRule",
                .gating_rule = "GatingRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const GatingRule = struct {
    control_panel_arn: []const u8,
    gating_controls: [][]const u8,
    name: []const u8,
    rule_config: RuleConfig,
    safety_rule_arn: []const u8,
    status: []const u8,
    target_controls: [][]const u8,
    wait_period_ms: i64,
    owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .control_panel_arn = "ControlPanelArn",
            .gating_controls = "GatingControls",
            .name = "Name",
            .rule_config = "RuleConfig",
            .safety_rule_arn = "SafetyRuleArn",
            .status = "Status",
            .target_controls = "TargetControls",
            .wait_period_ms = "WaitPeriodMs",
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleConfig = struct {
    inverted: bool,
    threshold: i64,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inverted = "Inverted",
            .threshold = "Threshold",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const AssertionRule = struct {
    asserted_controls: [][]const u8,
    control_panel_arn: []const u8,
    name: []const u8,
    rule_config: RuleConfig,
    safety_rule_arn: []const u8,
    status: []const u8,
    wait_period_ms: i64,
    owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .asserted_controls = "AssertedControls",
            .control_panel_arn = "ControlPanelArn",
            .name = "Name",
            .rule_config = "RuleConfig",
            .safety_rule_arn = "SafetyRuleArn",
            .status = "Status",
            .wait_period_ms = "WaitPeriodMs",
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};

pub const RoutingControl = struct {
    control_panel_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    routing_control_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .control_panel_arn = "ControlPanelArn",
            .name = "Name",
            .routing_control_arn = "RoutingControlArn",
            .status = "Status",
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};

pub const ControlPanel = struct {
    cluster_arn: ?[]const u8 = null,
    control_panel_arn: ?[]const u8 = null,
    default_control_panel: ?bool = null,
    name: ?[]const u8 = null,
    routing_control_count: ?i64 = null,
    status: ?[]const u8 = null,
    owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_arn = "ClusterArn",
            .control_panel_arn = "ControlPanelArn",
            .default_control_panel = "DefaultControlPanel",
            .name = "Name",
            .routing_control_count = "RoutingControlCount",
            .status = "Status",
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};

pub const Cluster = struct {
    cluster_arn: ?[]const u8 = null,
    cluster_endpoints: ?[]ClusterEndpoint = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_arn = "ClusterArn",
            .cluster_endpoints = "ClusterEndpoints",
            .name = "Name",
            .status = "Status",
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterEndpoint = struct {
    endpoint: ?[]const u8 = null,
    region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint = "Endpoint",
            .region = "Region",
        };
        return @field(mappings, field_name);
    }
};
