const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-02";
pub const sdk_id: []const u8 = "Route53 Recovery Readiness";
pub const arn_namespace: ?[]const u8 = "route53-recovery-readiness";
pub const endpoint_prefix: []const u8 = "route53-recovery-readiness";
pub const sigv4_name: []const u8 = "route53-recovery-readiness";
pub const name: []const u8 = "Route53RecoveryReadiness";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-02",
    sdk_id: []const u8 = "Route53 Recovery Readiness",
    arn_namespace: ?[]const u8 = "route53-recovery-readiness",
    endpoint_prefix: []const u8 = "route53-recovery-readiness",
    sigv4_name: []const u8 = "route53-recovery-readiness",
    name: []const u8 = "Route53RecoveryReadiness",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_cell: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/cells",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCell",
    Request: type = struct {
        cell_name: []const u8,
        cells: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cell_name = "cellName",
                .cells = "cells",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cell) } {
            return .{ .service_metadata = service_metadata, .action = create_cell };
        }
    },
    Response: type = struct {
        cell_arn: ?[]const u8 = null,
        cell_name: ?[]const u8 = null,
        cells: ?[][]const u8 = null,
        parent_readiness_scopes: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cell_arn = "cellArn",
                .cell_name = "cellName",
                .cells = "cells",
                .parent_readiness_scopes = "parentReadinessScopes",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_cross_account_authorization: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/crossaccountauthorizations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCrossAccountAuthorization",
    Request: type = struct {
        cross_account_authorization: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_account_authorization = "crossAccountAuthorization",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cross_account_authorization) } {
            return .{ .service_metadata = service_metadata, .action = create_cross_account_authorization };
        }
    },
    Response: type = struct {
        cross_account_authorization: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_account_authorization = "crossAccountAuthorization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_readiness_check: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/readinesschecks",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateReadinessCheck",
    Request: type = struct {
        readiness_check_name: []const u8,
        resource_set_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .readiness_check_name = "readinessCheckName",
                .resource_set_name = "resourceSetName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_readiness_check) } {
            return .{ .service_metadata = service_metadata, .action = create_readiness_check };
        }
    },
    Response: type = struct {
        readiness_check_arn: ?[]const u8 = null,
        readiness_check_name: ?[]const u8 = null,
        resource_set: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .readiness_check_arn = "readinessCheckArn",
                .readiness_check_name = "readinessCheckName",
                .resource_set = "resourceSet",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_recovery_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/recoverygroups",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRecoveryGroup",
    Request: type = struct {
        cells: ?[][]const u8 = null,
        recovery_group_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cells = "cells",
                .recovery_group_name = "recoveryGroupName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_recovery_group) } {
            return .{ .service_metadata = service_metadata, .action = create_recovery_group };
        }
    },
    Response: type = struct {
        cells: ?[][]const u8 = null,
        recovery_group_arn: ?[]const u8 = null,
        recovery_group_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cells = "cells",
                .recovery_group_arn = "recoveryGroupArn",
                .recovery_group_name = "recoveryGroupName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_resource_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/resourcesets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateResourceSet",
    Request: type = struct {
        resource_set_name: []const u8,
        resource_set_type: []const u8,
        resources: []Resource,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_set_name = "resourceSetName",
                .resource_set_type = "resourceSetType",
                .resources = "resources",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_set) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_set };
        }
    },
    Response: type = struct {
        resource_set_arn: ?[]const u8 = null,
        resource_set_name: ?[]const u8 = null,
        resource_set_type: ?[]const u8 = null,
        resources: ?[]Resource = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_set_arn = "resourceSetArn",
                .resource_set_name = "resourceSetName",
                .resource_set_type = "resourceSetType",
                .resources = "resources",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_cell: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/cells/{CellName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteCell",
    Request: type = struct {
        cell_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cell_name = "CellName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cell) } {
            return .{ .service_metadata = service_metadata, .action = delete_cell };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_cross_account_authorization: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/crossaccountauthorizations/{CrossAccountAuthorization}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCrossAccountAuthorization",
    Request: type = struct {
        cross_account_authorization: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_account_authorization = "CrossAccountAuthorization",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cross_account_authorization) } {
            return .{ .service_metadata = service_metadata, .action = delete_cross_account_authorization };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_readiness_check: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/readinesschecks/{ReadinessCheckName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteReadinessCheck",
    Request: type = struct {
        readiness_check_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .readiness_check_name = "ReadinessCheckName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_readiness_check) } {
            return .{ .service_metadata = service_metadata, .action = delete_readiness_check };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_recovery_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/recoverygroups/{RecoveryGroupName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRecoveryGroup",
    Request: type = struct {
        recovery_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recovery_group_name = "RecoveryGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_recovery_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_recovery_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resource_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/resourcesets/{ResourceSetName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteResourceSet",
    Request: type = struct {
        resource_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_set_name = "ResourceSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_set };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_architecture_recommendations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/recoverygroups/{RecoveryGroupName}/architectureRecommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetArchitectureRecommendations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        recovery_group_name: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .recovery_group_name = "RecoveryGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_architecture_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_architecture_recommendations };
        }
    },
    Response: type = struct {
        last_audit_timestamp: ?i64 = null,
        next_token: ?[]const u8 = null,
        recommendations: ?[]struct {
            recommendation_text: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommendation_text = "recommendationText",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .last_audit_timestamp = "lastAuditTimestamp",
                .next_token = "nextToken",
                .recommendations = "recommendations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_cell: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cells/{CellName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCell",
    Request: type = struct {
        cell_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cell_name = "CellName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cell) } {
            return .{ .service_metadata = service_metadata, .action = get_cell };
        }
    },
    Response: type = struct {
        cell_arn: ?[]const u8 = null,
        cell_name: ?[]const u8 = null,
        cells: ?[][]const u8 = null,
        parent_readiness_scopes: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cell_arn = "cellArn",
                .cell_name = "cellName",
                .cells = "cells",
                .parent_readiness_scopes = "parentReadinessScopes",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_cell_readiness_summary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cellreadiness/{CellName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCellReadinessSummary",
    Request: type = struct {
        cell_name: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cell_name = "CellName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cell_readiness_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_cell_readiness_summary };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        readiness: ?[]const u8 = null,
        readiness_checks: ?[]ReadinessCheckSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .readiness = "readiness",
                .readiness_checks = "readinessChecks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_readiness_check: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/readinesschecks/{ReadinessCheckName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetReadinessCheck",
    Request: type = struct {
        readiness_check_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .readiness_check_name = "ReadinessCheckName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_readiness_check) } {
            return .{ .service_metadata = service_metadata, .action = get_readiness_check };
        }
    },
    Response: type = struct {
        readiness_check_arn: ?[]const u8 = null,
        readiness_check_name: ?[]const u8 = null,
        resource_set: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .readiness_check_arn = "readinessCheckArn",
                .readiness_check_name = "readinessCheckName",
                .resource_set = "resourceSet",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_readiness_check_resource_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/readinesschecks/{ReadinessCheckName}/resource/{ResourceIdentifier}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetReadinessCheckResourceStatus",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        readiness_check_name: []const u8,
        resource_identifier: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .readiness_check_name = "ReadinessCheckName",
                .resource_identifier = "ResourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_readiness_check_resource_status) } {
            return .{ .service_metadata = service_metadata, .action = get_readiness_check_resource_status };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        readiness: ?[]const u8 = null,
        rules: ?[]struct {
            last_checked_timestamp: i64,
            messages: []Message,
            readiness: []const u8,
            rule_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .last_checked_timestamp = "lastCheckedTimestamp",
                    .messages = "messages",
                    .readiness = "readiness",
                    .rule_id = "ruleId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .readiness = "readiness",
                .rules = "rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_readiness_check_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/readinesschecks/{ReadinessCheckName}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetReadinessCheckStatus",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        readiness_check_name: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .readiness_check_name = "ReadinessCheckName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_readiness_check_status) } {
            return .{ .service_metadata = service_metadata, .action = get_readiness_check_status };
        }
    },
    Response: type = struct {
        messages: ?[]Message = null,
        next_token: ?[]const u8 = null,
        readiness: ?[]const u8 = null,
        resources: ?[]struct {
            component_id: ?[]const u8 = null,
            last_checked_timestamp: i64,
            readiness: []const u8,
            resource_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .component_id = "componentId",
                    .last_checked_timestamp = "lastCheckedTimestamp",
                    .readiness = "readiness",
                    .resource_arn = "resourceArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .messages = "messages",
                .next_token = "nextToken",
                .readiness = "readiness",
                .resources = "resources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_recovery_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/recoverygroups/{RecoveryGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecoveryGroup",
    Request: type = struct {
        recovery_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recovery_group_name = "RecoveryGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recovery_group) } {
            return .{ .service_metadata = service_metadata, .action = get_recovery_group };
        }
    },
    Response: type = struct {
        cells: ?[][]const u8 = null,
        recovery_group_arn: ?[]const u8 = null,
        recovery_group_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cells = "cells",
                .recovery_group_arn = "recoveryGroupArn",
                .recovery_group_name = "recoveryGroupName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_recovery_group_readiness_summary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/recoverygroupreadiness/{RecoveryGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecoveryGroupReadinessSummary",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        recovery_group_name: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .recovery_group_name = "RecoveryGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recovery_group_readiness_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_recovery_group_readiness_summary };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        readiness: ?[]const u8 = null,
        readiness_checks: ?[]ReadinessCheckSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .readiness = "readiness",
                .readiness_checks = "readinessChecks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resourcesets/{ResourceSetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceSet",
    Request: type = struct {
        resource_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_set_name = "ResourceSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_set) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_set };
        }
    },
    Response: type = struct {
        resource_set_arn: ?[]const u8 = null,
        resource_set_name: ?[]const u8 = null,
        resource_set_type: ?[]const u8 = null,
        resources: ?[]Resource = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_set_arn = "resourceSetArn",
                .resource_set_name = "resourceSetName",
                .resource_set_type = "resourceSetType",
                .resources = "resources",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_cells: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cells",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCells",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cells) } {
            return .{ .service_metadata = service_metadata, .action = list_cells };
        }
    },
    Response: type = struct {
        cells: ?[]struct {
            cell_arn: []const u8,
            cell_name: []const u8,
            cells: [][]const u8,
            parent_readiness_scopes: [][]const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cell_arn = "cellArn",
                    .cell_name = "cellName",
                    .cells = "cells",
                    .parent_readiness_scopes = "parentReadinessScopes",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cells = "cells",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_cross_account_authorizations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/crossaccountauthorizations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCrossAccountAuthorizations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cross_account_authorizations) } {
            return .{ .service_metadata = service_metadata, .action = list_cross_account_authorizations };
        }
    },
    Response: type = struct {
        cross_account_authorizations: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cross_account_authorizations = "crossAccountAuthorizations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_readiness_checks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/readinesschecks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReadinessChecks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_readiness_checks) } {
            return .{ .service_metadata = service_metadata, .action = list_readiness_checks };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        readiness_checks: ?[]struct {
            readiness_check_arn: []const u8,
            readiness_check_name: ?[]const u8 = null,
            resource_set: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .readiness_check_arn = "readinessCheckArn",
                    .readiness_check_name = "readinessCheckName",
                    .resource_set = "resourceSet",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .readiness_checks = "readinessChecks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_recovery_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/recoverygroups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecoveryGroups",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recovery_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_recovery_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recovery_groups: ?[]struct {
            cells: [][]const u8,
            recovery_group_arn: []const u8,
            recovery_group_name: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cells = "cells",
                    .recovery_group_arn = "recoveryGroupArn",
                    .recovery_group_name = "recoveryGroupName",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .recovery_groups = "recoveryGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_resource_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resourcesets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResourceSets",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_sets };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        resource_sets: ?[]struct {
            resource_set_arn: []const u8,
            resource_set_name: []const u8,
            resource_set_type: []const u8,
            resources: []Resource,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_set_arn = "resourceSetArn",
                    .resource_set_name = "resourceSetName",
                    .resource_set_type = "resourceSetType",
                    .resources = "resources",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .resource_sets = "resourceSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_rules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rules",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRules",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_rules };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        rules: ?[]struct {
            resource_type: []const u8,
            rule_description: []const u8,
            rule_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "resourceType",
                    .rule_description = "ruleDescription",
                    .rule_id = "ruleId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .rules = "rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResources",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resources };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_cell: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/cells/{CellName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCell",
    Request: type = struct {
        cell_name: []const u8,
        cells: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cell_name = "CellName",
                .cells = "cells",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cell) } {
            return .{ .service_metadata = service_metadata, .action = update_cell };
        }
    },
    Response: type = struct {
        cell_arn: ?[]const u8 = null,
        cell_name: ?[]const u8 = null,
        cells: ?[][]const u8 = null,
        parent_readiness_scopes: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cell_arn = "cellArn",
                .cell_name = "cellName",
                .cells = "cells",
                .parent_readiness_scopes = "parentReadinessScopes",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_readiness_check: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/readinesschecks/{ReadinessCheckName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateReadinessCheck",
    Request: type = struct {
        readiness_check_name: []const u8,
        resource_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .readiness_check_name = "ReadinessCheckName",
                .resource_set_name = "resourceSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_readiness_check) } {
            return .{ .service_metadata = service_metadata, .action = update_readiness_check };
        }
    },
    Response: type = struct {
        readiness_check_arn: ?[]const u8 = null,
        readiness_check_name: ?[]const u8 = null,
        resource_set: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .readiness_check_arn = "readinessCheckArn",
                .readiness_check_name = "readinessCheckName",
                .resource_set = "resourceSet",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_recovery_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/recoverygroups/{RecoveryGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRecoveryGroup",
    Request: type = struct {
        cells: [][]const u8,
        recovery_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cells = "cells",
                .recovery_group_name = "RecoveryGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_recovery_group) } {
            return .{ .service_metadata = service_metadata, .action = update_recovery_group };
        }
    },
    Response: type = struct {
        cells: ?[][]const u8 = null,
        recovery_group_arn: ?[]const u8 = null,
        recovery_group_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cells = "cells",
                .recovery_group_arn = "recoveryGroupArn",
                .recovery_group_name = "recoveryGroupName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_resource_set: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/resourcesets/{ResourceSetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResourceSet",
    Request: type = struct {
        resource_set_name: []const u8,
        resource_set_type: []const u8,
        resources: []Resource,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_set_name = "ResourceSetName",
                .resource_set_type = "resourceSetType",
                .resources = "resources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_set) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_set };
        }
    },
    Response: type = struct {
        resource_set_arn: ?[]const u8 = null,
        resource_set_name: ?[]const u8 = null,
        resource_set_type: ?[]const u8 = null,
        resources: ?[]Resource = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_set_arn = "resourceSetArn",
                .resource_set_name = "resourceSetName",
                .resource_set_type = "resourceSetType",
                .resources = "resources",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Resource = struct {
    component_id: ?[]const u8 = null,
    dns_target_resource: ?DNSTargetResource = null,
    readiness_scopes: ?[][]const u8 = null,
    resource_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_id = "componentId",
            .dns_target_resource = "dnsTargetResource",
            .readiness_scopes = "readinessScopes",
            .resource_arn = "resourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DNSTargetResource = struct {
    domain_name: ?[]const u8 = null,
    hosted_zone_arn: ?[]const u8 = null,
    record_set_id: ?[]const u8 = null,
    record_type: ?[]const u8 = null,
    target_resource: ?TargetResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "domainName",
            .hosted_zone_arn = "hostedZoneArn",
            .record_set_id = "recordSetId",
            .record_type = "recordType",
            .target_resource = "targetResource",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetResource = struct {
    nlb_resource: ?NLBResource = null,
    r53_resource: ?R53ResourceRecord = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nlb_resource = "nLBResource",
            .r53_resource = "r53Resource",
        };
        return @field(mappings, field_name);
    }
};

pub const R53ResourceRecord = struct {
    domain_name: ?[]const u8 = null,
    record_set_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "domainName",
            .record_set_id = "recordSetId",
        };
        return @field(mappings, field_name);
    }
};

pub const NLBResource = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const ReadinessCheckSummary = struct {
    readiness: ?[]const u8 = null,
    readiness_check_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .readiness = "readiness",
            .readiness_check_name = "readinessCheckName",
        };
        return @field(mappings, field_name);
    }
};

pub const Message = struct {
    message_text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_text = "messageText",
        };
        return @field(mappings, field_name);
    }
};
