const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2013-04-01";
pub const sdk_id: []const u8 = "Route 53";
pub const arn_namespace: ?[]const u8 = "route53";
pub const endpoint_prefix: []const u8 = "route53";
pub const sigv4_name: []const u8 = "route53";
pub const name: []const u8 = "AWSDnsV20130401";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_xml;

pub const service_metadata: struct {
    version: []const u8 = "2013-04-01",
    sdk_id: []const u8 = "Route 53",
    arn_namespace: ?[]const u8 = "route53",
    endpoint_prefix: []const u8 = "route53",
    sigv4_name: []const u8 = "route53",
    name: []const u8 = "AWSDnsV20130401",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_xml,
} = .{};
pub const activate_key_signing_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/keysigningkey/{HostedZoneId}/{Name}/activate",
        .success_code = 200,
    };

    action_name: []const u8 = "ActivateKeySigningKey",
    Request: type = struct {
        hosted_zone_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(activate_key_signing_key) } {
            return .{ .service_metadata = service_metadata, .action = activate_key_signing_key };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidInput,
        InvalidKeySigningKeyStatus,
        InvalidKMSArn,
        InvalidSigningStatus,
        NoSuchKeySigningKey,
    },
} = .{};
pub const associate_vpc_with_hosted_zone: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/hostedzone/{HostedZoneId}/associatevpc",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateVPCWithHostedZone",
    Request: type = struct {
        hosted_zone_id: []const u8,
        vpc: VPC,
        comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .vpc = "VPC",
                .comment = "Comment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_vpc_with_hosted_zone) } {
            return .{ .service_metadata = service_metadata, .action = associate_vpc_with_hosted_zone };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingDomainExists,
        InvalidInput,
        InvalidVPCId,
        LimitsExceeded,
        NoSuchHostedZone,
        NotAuthorized,
        PriorRequestNotComplete,
        PublicZoneVPCAssociation,
    },
} = .{};
pub const change_cidr_collection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/cidrcollection/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "ChangeCidrCollection",
    Request: type = struct {
        id: []const u8,
        collection_version: ?i64 = null,
        changes: []struct {
            location_name: []const u8,
            action: []const u8,
            cidr_list: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .location_name = "LocationName",
                    .action = "Action",
                    .cidr_list = "CidrList",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .collection_version = "CollectionVersion",
                .changes = "Changes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(change_cidr_collection) } {
            return .{ .service_metadata = service_metadata, .action = change_cidr_collection };
        }
    },
    Response: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CidrBlockInUse,
        CidrCollectionVersionMismatch,
        ConcurrentModification,
        InvalidInput,
        LimitsExceeded,
        NoSuchCidrCollection,
    },
} = .{};
pub const change_resource_record_sets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/hostedzone/{HostedZoneId}/rrset",
        .success_code = 200,
    };

    action_name: []const u8 = "ChangeResourceRecordSets",
    Request: type = struct {
        hosted_zone_id: []const u8,
        change_batch: struct {
            comment: ?[]const u8 = null,
            changes: []struct {
                action: []const u8,
                resource_record_set: ResourceRecordSet,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action = "Action",
                        .resource_record_set = "ResourceRecordSet",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .comment = "Comment",
                    .changes = "Changes",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .change_batch = "ChangeBatch",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(change_resource_record_sets) } {
            return .{ .service_metadata = service_metadata, .action = change_resource_record_sets };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidChangeBatch,
        InvalidInput,
        NoSuchHealthCheck,
        NoSuchHostedZone,
        PriorRequestNotComplete,
    },
} = .{};
pub const change_tags_for_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/tags/{ResourceType}/{ResourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ChangeTagsForResource",
    Request: type = struct {
        resource_type: []const u8,
        resource_id: []const u8,
        add_tags: ?[]Tag = null,
        remove_tag_keys: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .resource_id = "ResourceId",
                .add_tags = "AddTags",
                .remove_tag_keys = "RemoveTagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(change_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = change_tags_for_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHealthCheck,
        NoSuchHostedZone,
        PriorRequestNotComplete,
        Throttling,
    },
} = .{};
pub const create_cidr_collection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/cidrcollection",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateCidrCollection",
    Request: type = struct {
        name: []const u8,
        caller_reference: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .caller_reference = "CallerReference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cidr_collection) } {
            return .{ .service_metadata = service_metadata, .action = create_cidr_collection };
        }
    },
    Response: type = struct {
        collection: ?struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .name = "Name",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }
        } = null,
        location: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection = "Collection",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CidrCollectionAlreadyExists,
        ConcurrentModification,
        InvalidInput,
        LimitsExceeded,
    },
} = .{};
pub const create_health_check: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/healthcheck",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateHealthCheck",
    Request: type = struct {
        caller_reference: []const u8,
        health_check_config: HealthCheckConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .caller_reference = "CallerReference",
                .health_check_config = "HealthCheckConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_health_check) } {
            return .{ .service_metadata = service_metadata, .action = create_health_check };
        }
    },
    Response: type = struct {
        health_check: HealthCheck,
        location: []const u8,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check = "HealthCheck",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HealthCheckAlreadyExists,
        InvalidInput,
        TooManyHealthChecks,
    },
} = .{};
pub const create_hosted_zone: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/hostedzone",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateHostedZone",
    Request: type = struct {
        name: []const u8,
        vpc: ?VPC = null,
        caller_reference: []const u8,
        hosted_zone_config: ?HostedZoneConfig = null,
        delegation_set_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .vpc = "VPC",
                .caller_reference = "CallerReference",
                .hosted_zone_config = "HostedZoneConfig",
                .delegation_set_id = "DelegationSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_hosted_zone) } {
            return .{ .service_metadata = service_metadata, .action = create_hosted_zone };
        }
    },
    Response: type = struct {
        hosted_zone: HostedZone,
        change_info: ChangeInfo,
        delegation_set: DelegationSet,
        vpc: ?VPC = null,
        location: []const u8,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone = "HostedZone",
                .change_info = "ChangeInfo",
                .delegation_set = "DelegationSet",
                .vpc = "VPC",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingDomainExists,
        DelegationSetNotAvailable,
        DelegationSetNotReusable,
        HostedZoneAlreadyExists,
        InvalidDomainName,
        InvalidInput,
        InvalidVPCId,
        NoSuchDelegationSet,
        TooManyHostedZones,
    },
} = .{};
pub const create_key_signing_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/keysigningkey",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateKeySigningKey",
    Request: type = struct {
        caller_reference: []const u8,
        hosted_zone_id: []const u8,
        key_management_service_arn: []const u8,
        name: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .caller_reference = "CallerReference",
                .hosted_zone_id = "HostedZoneId",
                .key_management_service_arn = "KeyManagementServiceArn",
                .name = "Name",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_key_signing_key) } {
            return .{ .service_metadata = service_metadata, .action = create_key_signing_key };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,
        key_signing_key: KeySigningKey,
        location: []const u8,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
                .key_signing_key = "KeySigningKey",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidArgument,
        InvalidInput,
        InvalidKeySigningKeyName,
        InvalidKeySigningKeyStatus,
        InvalidKMSArn,
        InvalidSigningStatus,
        KeySigningKeyAlreadyExists,
        NoSuchHostedZone,
        TooManyKeySigningKeys,
    },
} = .{};
pub const create_query_logging_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/queryloggingconfig",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateQueryLoggingConfig",
    Request: type = struct {
        hosted_zone_id: []const u8,
        cloud_watch_logs_log_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_query_logging_config) } {
            return .{ .service_metadata = service_metadata, .action = create_query_logging_config };
        }
    },
    Response: type = struct {
        query_logging_config: QueryLoggingConfig,
        location: []const u8,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_logging_config = "QueryLoggingConfig",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InsufficientCloudWatchLogsResourcePolicy,
        InvalidInput,
        NoSuchCloudWatchLogsLogGroup,
        NoSuchHostedZone,
        QueryLoggingConfigAlreadyExists,
    },
} = .{};
pub const create_reusable_delegation_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/delegationset",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateReusableDelegationSet",
    Request: type = struct {
        caller_reference: []const u8,
        hosted_zone_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .caller_reference = "CallerReference",
                .hosted_zone_id = "HostedZoneId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_reusable_delegation_set) } {
            return .{ .service_metadata = service_metadata, .action = create_reusable_delegation_set };
        }
    },
    Response: type = struct {
        delegation_set: DelegationSet,
        location: []const u8,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegation_set = "DelegationSet",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DelegationSetAlreadyCreated,
        DelegationSetAlreadyReusable,
        DelegationSetNotAvailable,
        HostedZoneNotFound,
        InvalidArgument,
        InvalidInput,
        LimitsExceeded,
    },
} = .{};
pub const create_traffic_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/trafficpolicy",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateTrafficPolicy",
    Request: type = struct {
        name: []const u8,
        document: []const u8,
        comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .document = "Document",
                .comment = "Comment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_traffic_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_traffic_policy };
        }
    },
    Response: type = struct {
        traffic_policy: TrafficPolicy,
        location: []const u8,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy = "TrafficPolicy",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidTrafficPolicyDocument,
        TooManyTrafficPolicies,
        TrafficPolicyAlreadyExists,
    },
} = .{};
pub const create_traffic_policy_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/trafficpolicyinstance",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateTrafficPolicyInstance",
    Request: type = struct {
        hosted_zone_id: []const u8,
        name: []const u8,
        ttl: i64,
        traffic_policy_id: []const u8,
        traffic_policy_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .name = "Name",
                .ttl = "TTL",
                .traffic_policy_id = "TrafficPolicyId",
                .traffic_policy_version = "TrafficPolicyVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_traffic_policy_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_traffic_policy_instance };
        }
    },
    Response: type = struct {
        traffic_policy_instance: TrafficPolicyInstance,
        location: []const u8,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy_instance = "TrafficPolicyInstance",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHostedZone,
        NoSuchTrafficPolicy,
        TooManyTrafficPolicyInstances,
        TrafficPolicyInstanceAlreadyExists,
    },
} = .{};
pub const create_traffic_policy_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/trafficpolicy/{Id}",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateTrafficPolicyVersion",
    Request: type = struct {
        id: []const u8,
        document: []const u8,
        comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .document = "Document",
                .comment = "Comment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_traffic_policy_version) } {
            return .{ .service_metadata = service_metadata, .action = create_traffic_policy_version };
        }
    },
    Response: type = struct {
        traffic_policy: TrafficPolicy,
        location: []const u8,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy = "TrafficPolicy",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidInput,
        InvalidTrafficPolicyDocument,
        NoSuchTrafficPolicy,
        TooManyTrafficPolicyVersionsForCurrentPolicy,
    },
} = .{};
pub const create_vpc_association_authorization: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/hostedzone/{HostedZoneId}/authorizevpcassociation",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateVPCAssociationAuthorization",
    Request: type = struct {
        hosted_zone_id: []const u8,
        vpc: VPC,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .vpc = "VPC",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_association_authorization) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_association_authorization };
        }
    },
    Response: type = struct {
        hosted_zone_id: []const u8,
        vpc: VPC,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .vpc = "VPC",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidInput,
        InvalidVPCId,
        NoSuchHostedZone,
        TooManyVPCAssociationAuthorizations,
    },
} = .{};
pub const deactivate_key_signing_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/keysigningkey/{HostedZoneId}/{Name}/deactivate",
        .success_code = 200,
    };

    action_name: []const u8 = "DeactivateKeySigningKey",
    Request: type = struct {
        hosted_zone_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deactivate_key_signing_key) } {
            return .{ .service_metadata = service_metadata, .action = deactivate_key_signing_key };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidInput,
        InvalidKeySigningKeyStatus,
        InvalidSigningStatus,
        KeySigningKeyInParentDSRecord,
        KeySigningKeyInUse,
        NoSuchKeySigningKey,
    },
} = .{};
pub const delete_cidr_collection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2013-04-01/cidrcollection/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCidrCollection",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cidr_collection) } {
            return .{ .service_metadata = service_metadata, .action = delete_cidr_collection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CidrCollectionInUse,
        ConcurrentModification,
        InvalidInput,
        NoSuchCidrCollection,
    },
} = .{};
pub const delete_health_check: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2013-04-01/healthcheck/{HealthCheckId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteHealthCheck",
    Request: type = struct {
        health_check_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check_id = "HealthCheckId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_health_check) } {
            return .{ .service_metadata = service_metadata, .action = delete_health_check };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HealthCheckInUse,
        InvalidInput,
        NoSuchHealthCheck,
    },
} = .{};
pub const delete_hosted_zone: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2013-04-01/hostedzone/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteHostedZone",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_hosted_zone) } {
            return .{ .service_metadata = service_metadata, .action = delete_hosted_zone };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HostedZoneNotEmpty,
        InvalidDomainName,
        InvalidInput,
        NoSuchHostedZone,
        PriorRequestNotComplete,
    },
} = .{};
pub const delete_key_signing_key: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2013-04-01/keysigningkey/{HostedZoneId}/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteKeySigningKey",
    Request: type = struct {
        hosted_zone_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_key_signing_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_key_signing_key };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidInput,
        InvalidKeySigningKeyStatus,
        InvalidKMSArn,
        InvalidSigningStatus,
        NoSuchKeySigningKey,
    },
} = .{};
pub const delete_query_logging_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2013-04-01/queryloggingconfig/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteQueryLoggingConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_query_logging_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_query_logging_config };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidInput,
        NoSuchQueryLoggingConfig,
    },
} = .{};
pub const delete_reusable_delegation_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2013-04-01/delegationset/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteReusableDelegationSet",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_reusable_delegation_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_reusable_delegation_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DelegationSetInUse,
        DelegationSetNotReusable,
        InvalidInput,
        NoSuchDelegationSet,
    },
} = .{};
pub const delete_traffic_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2013-04-01/trafficpolicy/{Id}/{Version}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTrafficPolicy",
    Request: type = struct {
        id: []const u8,
        version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_traffic_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_traffic_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidInput,
        NoSuchTrafficPolicy,
        TrafficPolicyInUse,
    },
} = .{};
pub const delete_traffic_policy_instance: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2013-04-01/trafficpolicyinstance/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTrafficPolicyInstance",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_traffic_policy_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_traffic_policy_instance };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchTrafficPolicyInstance,
        PriorRequestNotComplete,
    },
} = .{};
pub const delete_vpc_association_authorization: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/hostedzone/{HostedZoneId}/deauthorizevpcassociation",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteVPCAssociationAuthorization",
    Request: type = struct {
        hosted_zone_id: []const u8,
        vpc: VPC,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .vpc = "VPC",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_association_authorization) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_association_authorization };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidInput,
        InvalidVPCId,
        NoSuchHostedZone,
        VPCAssociationAuthorizationNotFound,
    },
} = .{};
pub const disable_hosted_zone_dnssec: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/hostedzone/{HostedZoneId}/disable-dnssec",
        .success_code = 200,
    };

    action_name: []const u8 = "DisableHostedZoneDNSSEC",
    Request: type = struct {
        hosted_zone_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_hosted_zone_dnssec) } {
            return .{ .service_metadata = service_metadata, .action = disable_hosted_zone_dnssec };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        DNSSECNotFound,
        InvalidArgument,
        InvalidInput,
        InvalidKeySigningKeyStatus,
        InvalidKMSArn,
        KeySigningKeyInParentDSRecord,
        NoSuchHostedZone,
    },
} = .{};
pub const disassociate_vpc_from_hosted_zone: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/hostedzone/{HostedZoneId}/disassociatevpc",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateVPCFromHostedZone",
    Request: type = struct {
        hosted_zone_id: []const u8,
        vpc: VPC,
        comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .vpc = "VPC",
                .comment = "Comment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_vpc_from_hosted_zone) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_vpc_from_hosted_zone };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidVPCId,
        LastVPCAssociation,
        NoSuchHostedZone,
        VPCAssociationNotFound,
    },
} = .{};
pub const enable_hosted_zone_dnssec: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/hostedzone/{HostedZoneId}/enable-dnssec",
        .success_code = 200,
    };

    action_name: []const u8 = "EnableHostedZoneDNSSEC",
    Request: type = struct {
        hosted_zone_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_hosted_zone_dnssec) } {
            return .{ .service_metadata = service_metadata, .action = enable_hosted_zone_dnssec };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        DNSSECNotFound,
        HostedZonePartiallyDelegated,
        InvalidArgument,
        InvalidInput,
        InvalidKeySigningKeyStatus,
        InvalidKMSArn,
        KeySigningKeyWithActiveStatusNotFound,
        NoSuchHostedZone,
    },
} = .{};
pub const get_account_limit: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/accountlimit/{Type}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccountLimit",
    Request: type = struct {
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_limit) } {
            return .{ .service_metadata = service_metadata, .action = get_account_limit };
        }
    },
    Response: type = struct {
        limit: struct {
            type: []const u8,
            value: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        count: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .count = "Count",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
    },
} = .{};
pub const get_change: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/change/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChange",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_change) } {
            return .{ .service_metadata = service_metadata, .action = get_change };
        }
    },
    Response: type = struct {
        change_info: ChangeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_info = "ChangeInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchChange,
    },
} = .{};
pub const get_checker_ip_ranges: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/checkeripranges",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCheckerIpRanges",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_checker_ip_ranges) } {
            return .{ .service_metadata = service_metadata, .action = get_checker_ip_ranges };
        }
    },
    Response: type = struct {
        checker_ip_ranges: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .checker_ip_ranges = "CheckerIpRanges",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_dnssec: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/hostedzone/{HostedZoneId}/dnssec",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDNSSEC",
    Request: type = struct {
        hosted_zone_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dnssec) } {
            return .{ .service_metadata = service_metadata, .action = get_dnssec };
        }
    },
    Response: type = struct {
        status: struct {
            serve_signature: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .serve_signature = "ServeSignature",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        },
        key_signing_keys: []KeySigningKey,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .key_signing_keys = "KeySigningKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        InvalidInput,
        NoSuchHostedZone,
    },
} = .{};
pub const get_geo_location: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/geolocation",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGeoLocation",
    Request: type = struct {
        continent_code: ?[]const u8 = null,
        country_code: ?[]const u8 = null,
        subdivision_code: ?[]const u8 = null,

        pub const http_query = .{
            .continent_code = "continentcode",
            .country_code = "countrycode",
            .subdivision_code = "subdivisioncode",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .continent_code = "ContinentCode",
                .country_code = "CountryCode",
                .subdivision_code = "SubdivisionCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_geo_location) } {
            return .{ .service_metadata = service_metadata, .action = get_geo_location };
        }
    },
    Response: type = struct {
        geo_location_details: GeoLocationDetails,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .geo_location_details = "GeoLocationDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchGeoLocation,
    },
} = .{};
pub const get_health_check: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/healthcheck/{HealthCheckId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetHealthCheck",
    Request: type = struct {
        health_check_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check_id = "HealthCheckId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_health_check) } {
            return .{ .service_metadata = service_metadata, .action = get_health_check };
        }
    },
    Response: type = struct {
        health_check: HealthCheck,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check = "HealthCheck",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IncompatibleVersion,
        InvalidInput,
        NoSuchHealthCheck,
    },
} = .{};
pub const get_health_check_count: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/healthcheckcount",
        .success_code = 200,
    };

    action_name: []const u8 = "GetHealthCheckCount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_health_check_count) } {
            return .{ .service_metadata = service_metadata, .action = get_health_check_count };
        }
    },
    Response: type = struct {
        health_check_count: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check_count = "HealthCheckCount",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_health_check_last_failure_reason: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/healthcheck/{HealthCheckId}/lastfailurereason",
        .success_code = 200,
    };

    action_name: []const u8 = "GetHealthCheckLastFailureReason",
    Request: type = struct {
        health_check_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check_id = "HealthCheckId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_health_check_last_failure_reason) } {
            return .{ .service_metadata = service_metadata, .action = get_health_check_last_failure_reason };
        }
    },
    Response: type = struct {
        health_check_observations: []HealthCheckObservation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check_observations = "HealthCheckObservations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHealthCheck,
    },
} = .{};
pub const get_health_check_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/healthcheck/{HealthCheckId}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "GetHealthCheckStatus",
    Request: type = struct {
        health_check_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check_id = "HealthCheckId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_health_check_status) } {
            return .{ .service_metadata = service_metadata, .action = get_health_check_status };
        }
    },
    Response: type = struct {
        health_check_observations: []HealthCheckObservation,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check_observations = "HealthCheckObservations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHealthCheck,
    },
} = .{};
pub const get_hosted_zone: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/hostedzone/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetHostedZone",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_hosted_zone) } {
            return .{ .service_metadata = service_metadata, .action = get_hosted_zone };
        }
    },
    Response: type = struct {
        hosted_zone: HostedZone,
        delegation_set: ?DelegationSet = null,
        vp_cs: ?[]VPC = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone = "HostedZone",
                .delegation_set = "DelegationSet",
                .vp_cs = "VPCs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHostedZone,
    },
} = .{};
pub const get_hosted_zone_count: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/hostedzonecount",
        .success_code = 200,
    };

    action_name: []const u8 = "GetHostedZoneCount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_hosted_zone_count) } {
            return .{ .service_metadata = service_metadata, .action = get_hosted_zone_count };
        }
    },
    Response: type = struct {
        hosted_zone_count: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_count = "HostedZoneCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
    },
} = .{};
pub const get_hosted_zone_limit: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/hostedzonelimit/{HostedZoneId}/{Type}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetHostedZoneLimit",
    Request: type = struct {
        type: []const u8,
        hosted_zone_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .hosted_zone_id = "HostedZoneId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_hosted_zone_limit) } {
            return .{ .service_metadata = service_metadata, .action = get_hosted_zone_limit };
        }
    },
    Response: type = struct {
        limit: struct {
            type: []const u8,
            value: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        count: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .count = "Count",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HostedZoneNotPrivate,
        InvalidInput,
        NoSuchHostedZone,
    },
} = .{};
pub const get_query_logging_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/queryloggingconfig/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetQueryLoggingConfig",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query_logging_config) } {
            return .{ .service_metadata = service_metadata, .action = get_query_logging_config };
        }
    },
    Response: type = struct {
        query_logging_config: QueryLoggingConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_logging_config = "QueryLoggingConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchQueryLoggingConfig,
    },
} = .{};
pub const get_reusable_delegation_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/delegationset/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetReusableDelegationSet",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_reusable_delegation_set) } {
            return .{ .service_metadata = service_metadata, .action = get_reusable_delegation_set };
        }
    },
    Response: type = struct {
        delegation_set: DelegationSet,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegation_set = "DelegationSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DelegationSetNotReusable,
        InvalidInput,
        NoSuchDelegationSet,
    },
} = .{};
pub const get_reusable_delegation_set_limit: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/reusabledelegationsetlimit/{DelegationSetId}/{Type}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetReusableDelegationSetLimit",
    Request: type = struct {
        type: []const u8,
        delegation_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .delegation_set_id = "DelegationSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_reusable_delegation_set_limit) } {
            return .{ .service_metadata = service_metadata, .action = get_reusable_delegation_set_limit };
        }
    },
    Response: type = struct {
        limit: struct {
            type: []const u8,
            value: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        count: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .count = "Count",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchDelegationSet,
    },
} = .{};
pub const get_traffic_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/trafficpolicy/{Id}/{Version}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTrafficPolicy",
    Request: type = struct {
        id: []const u8,
        version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_traffic_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_traffic_policy };
        }
    },
    Response: type = struct {
        traffic_policy: TrafficPolicy,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy = "TrafficPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchTrafficPolicy,
    },
} = .{};
pub const get_traffic_policy_instance: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/trafficpolicyinstance/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTrafficPolicyInstance",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_traffic_policy_instance) } {
            return .{ .service_metadata = service_metadata, .action = get_traffic_policy_instance };
        }
    },
    Response: type = struct {
        traffic_policy_instance: TrafficPolicyInstance,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy_instance = "TrafficPolicyInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchTrafficPolicyInstance,
    },
} = .{};
pub const get_traffic_policy_instance_count: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/trafficpolicyinstancecount",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTrafficPolicyInstanceCount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_traffic_policy_instance_count) } {
            return .{ .service_metadata = service_metadata, .action = get_traffic_policy_instance_count };
        }
    },
    Response: type = struct {
        traffic_policy_instance_count: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy_instance_count = "TrafficPolicyInstanceCount",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_cidr_blocks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/cidrcollection/{CollectionId}/cidrblocks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCidrBlocks",
    Request: type = struct {
        collection_id: []const u8,
        location_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .location_name = "location",
            .next_token = "nexttoken",
            .max_results = "maxresults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .location_name = "LocationName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cidr_blocks) } {
            return .{ .service_metadata = service_metadata, .action = list_cidr_blocks };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        cidr_blocks: ?[]struct {
            cidr_block: ?[]const u8 = null,
            location_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cidr_block = "CidrBlock",
                    .location_name = "LocationName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .cidr_blocks = "CidrBlocks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchCidrCollection,
        NoSuchCidrLocation,
    },
} = .{};
pub const list_cidr_collections: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/cidrcollection",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCidrCollections",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nexttoken",
            .max_results = "maxresults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cidr_collections) } {
            return .{ .service_metadata = service_metadata, .action = list_cidr_collections };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        cidr_collections: ?[]struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .name = "Name",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .cidr_collections = "CidrCollections",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
    },
} = .{};
pub const list_cidr_locations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/cidrcollection/{CollectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCidrLocations",
    Request: type = struct {
        collection_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nexttoken",
            .max_results = "maxresults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cidr_locations) } {
            return .{ .service_metadata = service_metadata, .action = list_cidr_locations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        cidr_locations: ?[]struct {
            location_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .location_name = "LocationName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .cidr_locations = "CidrLocations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchCidrCollection,
    },
} = .{};
pub const list_geo_locations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/geolocations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGeoLocations",
    Request: type = struct {
        start_continent_code: ?[]const u8 = null,
        start_country_code: ?[]const u8 = null,
        start_subdivision_code: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .start_continent_code = "startcontinentcode",
            .start_country_code = "startcountrycode",
            .start_subdivision_code = "startsubdivisioncode",
            .max_items = "maxitems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_continent_code = "StartContinentCode",
                .start_country_code = "StartCountryCode",
                .start_subdivision_code = "StartSubdivisionCode",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_geo_locations) } {
            return .{ .service_metadata = service_metadata, .action = list_geo_locations };
        }
    },
    Response: type = struct {
        geo_location_details_list: []GeoLocationDetails,
        is_truncated: bool,
        next_continent_code: ?[]const u8 = null,
        next_country_code: ?[]const u8 = null,
        next_subdivision_code: ?[]const u8 = null,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .geo_location_details_list = "GeoLocationDetailsList",
                .is_truncated = "IsTruncated",
                .next_continent_code = "NextContinentCode",
                .next_country_code = "NextCountryCode",
                .next_subdivision_code = "NextSubdivisionCode",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
    },
} = .{};
pub const list_health_checks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/healthcheck",
        .success_code = 200,
    };

    action_name: []const u8 = "ListHealthChecks",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "marker",
            .max_items = "maxitems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_health_checks) } {
            return .{ .service_metadata = service_metadata, .action = list_health_checks };
        }
    },
    Response: type = struct {
        health_checks: []HealthCheck,
        marker: []const u8,
        is_truncated: bool,
        next_marker: ?[]const u8 = null,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_checks = "HealthChecks",
                .marker = "Marker",
                .is_truncated = "IsTruncated",
                .next_marker = "NextMarker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        IncompatibleVersion,
        InvalidInput,
    },
} = .{};
pub const list_hosted_zones: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/hostedzone",
        .success_code = 200,
    };

    action_name: []const u8 = "ListHostedZones",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,
        delegation_set_id: ?[]const u8 = null,
        hosted_zone_type: ?[]const u8 = null,

        pub const http_query = .{
            .marker = "marker",
            .max_items = "maxitems",
            .delegation_set_id = "delegationsetid",
            .hosted_zone_type = "hostedzonetype",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
                .delegation_set_id = "DelegationSetId",
                .hosted_zone_type = "HostedZoneType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hosted_zones) } {
            return .{ .service_metadata = service_metadata, .action = list_hosted_zones };
        }
    },
    Response: type = struct {
        hosted_zones: []HostedZone,
        marker: []const u8,
        is_truncated: bool,
        next_marker: ?[]const u8 = null,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zones = "HostedZones",
                .marker = "Marker",
                .is_truncated = "IsTruncated",
                .next_marker = "NextMarker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DelegationSetNotReusable,
        InvalidInput,
        NoSuchDelegationSet,
    },
} = .{};
pub const list_hosted_zones_by_name: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/hostedzonesbyname",
        .success_code = 200,
    };

    action_name: []const u8 = "ListHostedZonesByName",
    Request: type = struct {
        dns_name: ?[]const u8 = null,
        hosted_zone_id: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .dns_name = "dnsname",
            .hosted_zone_id = "hostedzoneid",
            .max_items = "maxitems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dns_name = "DNSName",
                .hosted_zone_id = "HostedZoneId",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hosted_zones_by_name) } {
            return .{ .service_metadata = service_metadata, .action = list_hosted_zones_by_name };
        }
    },
    Response: type = struct {
        hosted_zones: []HostedZone,
        dns_name: ?[]const u8 = null,
        hosted_zone_id: ?[]const u8 = null,
        is_truncated: bool,
        next_dns_name: ?[]const u8 = null,
        next_hosted_zone_id: ?[]const u8 = null,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zones = "HostedZones",
                .dns_name = "DNSName",
                .hosted_zone_id = "HostedZoneId",
                .is_truncated = "IsTruncated",
                .next_dns_name = "NextDNSName",
                .next_hosted_zone_id = "NextHostedZoneId",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidDomainName,
        InvalidInput,
    },
} = .{};
pub const list_hosted_zones_by_vpc: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/hostedzonesbyvpc",
        .success_code = 200,
    };

    action_name: []const u8 = "ListHostedZonesByVPC",
    Request: type = struct {
        vpc_id: []const u8,
        vpc_region: []const u8,
        max_items: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .vpc_id = "vpcid",
            .vpc_region = "vpcregion",
            .max_items = "maxitems",
            .next_token = "nexttoken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "VPCId",
                .vpc_region = "VPCRegion",
                .max_items = "MaxItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hosted_zones_by_vpc) } {
            return .{ .service_metadata = service_metadata, .action = list_hosted_zones_by_vpc };
        }
    },
    Response: type = struct {
        hosted_zone_summaries: []struct {
            hosted_zone_id: []const u8,
            name: []const u8,
            owner: struct {
                owning_account: ?[]const u8 = null,
                owning_service: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .owning_account = "OwningAccount",
                        .owning_service = "OwningService",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .hosted_zone_id = "HostedZoneId",
                    .name = "Name",
                    .owner = "Owner",
                };
                return @field(mappings, field_name);
            }
        },
        max_items: i64,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_summaries = "HostedZoneSummaries",
                .max_items = "MaxItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidPaginationToken,
    },
} = .{};
pub const list_query_logging_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/queryloggingconfig",
        .success_code = 200,
    };

    action_name: []const u8 = "ListQueryLoggingConfigs",
    Request: type = struct {
        hosted_zone_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .hosted_zone_id = "hostedzoneid",
            .next_token = "nexttoken",
            .max_results = "maxresults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_query_logging_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_query_logging_configs };
        }
    },
    Response: type = struct {
        query_logging_configs: []QueryLoggingConfig,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_logging_configs = "QueryLoggingConfigs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidPaginationToken,
        NoSuchHostedZone,
    },
} = .{};
pub const list_resource_record_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/hostedzone/{HostedZoneId}/rrset",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResourceRecordSets",
    Request: type = struct {
        hosted_zone_id: []const u8,
        start_record_name: ?[]const u8 = null,
        start_record_type: ?[]const u8 = null,
        start_record_identifier: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .start_record_name = "name",
            .start_record_type = "type",
            .start_record_identifier = "identifier",
            .max_items = "maxitems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .start_record_name = "StartRecordName",
                .start_record_type = "StartRecordType",
                .start_record_identifier = "StartRecordIdentifier",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_record_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_record_sets };
        }
    },
    Response: type = struct {
        resource_record_sets: []ResourceRecordSet,
        is_truncated: bool,
        next_record_name: ?[]const u8 = null,
        next_record_type: ?[]const u8 = null,
        next_record_identifier: ?[]const u8 = null,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_record_sets = "ResourceRecordSets",
                .is_truncated = "IsTruncated",
                .next_record_name = "NextRecordName",
                .next_record_type = "NextRecordType",
                .next_record_identifier = "NextRecordIdentifier",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHostedZone,
    },
} = .{};
pub const list_reusable_delegation_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/delegationset",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReusableDelegationSets",
    Request: type = struct {
        marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .marker = "marker",
            .max_items = "maxitems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_reusable_delegation_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_reusable_delegation_sets };
        }
    },
    Response: type = struct {
        delegation_sets: []DelegationSet,
        marker: []const u8,
        is_truncated: bool,
        next_marker: ?[]const u8 = null,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegation_sets = "DelegationSets",
                .marker = "Marker",
                .is_truncated = "IsTruncated",
                .next_marker = "NextMarker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/tags/{ResourceType}/{ResourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_type: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        resource_tag_set: ResourceTagSet,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_tag_set = "ResourceTagSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHealthCheck,
        NoSuchHostedZone,
        PriorRequestNotComplete,
        Throttling,
    },
} = .{};
pub const list_tags_for_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/tags/{ResourceType}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResources",
    Request: type = struct {
        resource_type: []const u8,
        resource_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "ResourceType",
                .resource_ids = "ResourceIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resources };
        }
    },
    Response: type = struct {
        resource_tag_sets: []ResourceTagSet,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_tag_sets = "ResourceTagSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHealthCheck,
        NoSuchHostedZone,
        PriorRequestNotComplete,
        Throttling,
    },
} = .{};
pub const list_traffic_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/trafficpolicies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTrafficPolicies",
    Request: type = struct {
        traffic_policy_id_marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .traffic_policy_id_marker = "trafficpolicyid",
            .max_items = "maxitems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy_id_marker = "TrafficPolicyIdMarker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_traffic_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_traffic_policies };
        }
    },
    Response: type = struct {
        traffic_policy_summaries: []struct {
            id: []const u8,
            name: []const u8,
            type: []const u8,
            latest_version: i64,
            traffic_policy_count: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .type = "Type",
                    .latest_version = "LatestVersion",
                    .traffic_policy_count = "TrafficPolicyCount",
                };
                return @field(mappings, field_name);
            }
        },
        is_truncated: bool,
        traffic_policy_id_marker: []const u8,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy_summaries = "TrafficPolicySummaries",
                .is_truncated = "IsTruncated",
                .traffic_policy_id_marker = "TrafficPolicyIdMarker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
    },
} = .{};
pub const list_traffic_policy_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/trafficpolicyinstances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTrafficPolicyInstances",
    Request: type = struct {
        hosted_zone_id_marker: ?[]const u8 = null,
        traffic_policy_instance_name_marker: ?[]const u8 = null,
        traffic_policy_instance_type_marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .hosted_zone_id_marker = "hostedzoneid",
            .traffic_policy_instance_name_marker = "trafficpolicyinstancename",
            .traffic_policy_instance_type_marker = "trafficpolicyinstancetype",
            .max_items = "maxitems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id_marker = "HostedZoneIdMarker",
                .traffic_policy_instance_name_marker = "TrafficPolicyInstanceNameMarker",
                .traffic_policy_instance_type_marker = "TrafficPolicyInstanceTypeMarker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_traffic_policy_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_traffic_policy_instances };
        }
    },
    Response: type = struct {
        traffic_policy_instances: []TrafficPolicyInstance,
        hosted_zone_id_marker: ?[]const u8 = null,
        traffic_policy_instance_name_marker: ?[]const u8 = null,
        traffic_policy_instance_type_marker: ?[]const u8 = null,
        is_truncated: bool,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy_instances = "TrafficPolicyInstances",
                .hosted_zone_id_marker = "HostedZoneIdMarker",
                .traffic_policy_instance_name_marker = "TrafficPolicyInstanceNameMarker",
                .traffic_policy_instance_type_marker = "TrafficPolicyInstanceTypeMarker",
                .is_truncated = "IsTruncated",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchTrafficPolicyInstance,
    },
} = .{};
pub const list_traffic_policy_instances_by_hosted_zone: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/trafficpolicyinstances/hostedzone",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTrafficPolicyInstancesByHostedZone",
    Request: type = struct {
        hosted_zone_id: []const u8,
        traffic_policy_instance_name_marker: ?[]const u8 = null,
        traffic_policy_instance_type_marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .hosted_zone_id = "id",
            .traffic_policy_instance_name_marker = "trafficpolicyinstancename",
            .traffic_policy_instance_type_marker = "trafficpolicyinstancetype",
            .max_items = "maxitems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .traffic_policy_instance_name_marker = "TrafficPolicyInstanceNameMarker",
                .traffic_policy_instance_type_marker = "TrafficPolicyInstanceTypeMarker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_traffic_policy_instances_by_hosted_zone) } {
            return .{ .service_metadata = service_metadata, .action = list_traffic_policy_instances_by_hosted_zone };
        }
    },
    Response: type = struct {
        traffic_policy_instances: []TrafficPolicyInstance,
        traffic_policy_instance_name_marker: ?[]const u8 = null,
        traffic_policy_instance_type_marker: ?[]const u8 = null,
        is_truncated: bool,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy_instances = "TrafficPolicyInstances",
                .traffic_policy_instance_name_marker = "TrafficPolicyInstanceNameMarker",
                .traffic_policy_instance_type_marker = "TrafficPolicyInstanceTypeMarker",
                .is_truncated = "IsTruncated",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHostedZone,
        NoSuchTrafficPolicyInstance,
    },
} = .{};
pub const list_traffic_policy_instances_by_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/trafficpolicyinstances/trafficpolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTrafficPolicyInstancesByPolicy",
    Request: type = struct {
        traffic_policy_id: []const u8,
        traffic_policy_version: i64,
        hosted_zone_id_marker: ?[]const u8 = null,
        traffic_policy_instance_name_marker: ?[]const u8 = null,
        traffic_policy_instance_type_marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .traffic_policy_id = "id",
            .traffic_policy_version = "version",
            .hosted_zone_id_marker = "hostedzoneid",
            .traffic_policy_instance_name_marker = "trafficpolicyinstancename",
            .traffic_policy_instance_type_marker = "trafficpolicyinstancetype",
            .max_items = "maxitems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy_id = "TrafficPolicyId",
                .traffic_policy_version = "TrafficPolicyVersion",
                .hosted_zone_id_marker = "HostedZoneIdMarker",
                .traffic_policy_instance_name_marker = "TrafficPolicyInstanceNameMarker",
                .traffic_policy_instance_type_marker = "TrafficPolicyInstanceTypeMarker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_traffic_policy_instances_by_policy) } {
            return .{ .service_metadata = service_metadata, .action = list_traffic_policy_instances_by_policy };
        }
    },
    Response: type = struct {
        traffic_policy_instances: []TrafficPolicyInstance,
        hosted_zone_id_marker: ?[]const u8 = null,
        traffic_policy_instance_name_marker: ?[]const u8 = null,
        traffic_policy_instance_type_marker: ?[]const u8 = null,
        is_truncated: bool,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy_instances = "TrafficPolicyInstances",
                .hosted_zone_id_marker = "HostedZoneIdMarker",
                .traffic_policy_instance_name_marker = "TrafficPolicyInstanceNameMarker",
                .traffic_policy_instance_type_marker = "TrafficPolicyInstanceTypeMarker",
                .is_truncated = "IsTruncated",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchTrafficPolicy,
        NoSuchTrafficPolicyInstance,
    },
} = .{};
pub const list_traffic_policy_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/trafficpolicies/{Id}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTrafficPolicyVersions",
    Request: type = struct {
        id: []const u8,
        traffic_policy_version_marker: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub const http_query = .{
            .traffic_policy_version_marker = "trafficpolicyversion",
            .max_items = "maxitems",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .traffic_policy_version_marker = "TrafficPolicyVersionMarker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_traffic_policy_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_traffic_policy_versions };
        }
    },
    Response: type = struct {
        traffic_policies: []TrafficPolicy,
        is_truncated: bool,
        traffic_policy_version_marker: []const u8,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policies = "TrafficPolicies",
                .is_truncated = "IsTruncated",
                .traffic_policy_version_marker = "TrafficPolicyVersionMarker",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchTrafficPolicy,
    },
} = .{};
pub const list_vpc_association_authorizations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/hostedzone/{HostedZoneId}/authorizevpcassociation",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVPCAssociationAuthorizations",
    Request: type = struct {
        hosted_zone_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nexttoken",
            .max_results = "maxresults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vpc_association_authorizations) } {
            return .{ .service_metadata = service_metadata, .action = list_vpc_association_authorizations };
        }
    },
    Response: type = struct {
        hosted_zone_id: []const u8,
        next_token: ?[]const u8 = null,
        vp_cs: []VPC,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .next_token = "NextToken",
                .vp_cs = "VPCs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidPaginationToken,
        NoSuchHostedZone,
    },
} = .{};
pub const test_dns_answer: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2013-04-01/testdnsanswer",
        .success_code = 200,
    };

    action_name: []const u8 = "TestDNSAnswer",
    Request: type = struct {
        hosted_zone_id: []const u8,
        record_name: []const u8,
        record_type: []const u8,
        resolver_ip: ?[]const u8 = null,
        edns0_client_subnet_ip: ?[]const u8 = null,
        edns0_client_subnet_mask: ?[]const u8 = null,

        pub const http_query = .{
            .hosted_zone_id = "hostedzoneid",
            .record_name = "recordname",
            .record_type = "recordtype",
            .resolver_ip = "resolverip",
            .edns0_client_subnet_ip = "edns0clientsubnetip",
            .edns0_client_subnet_mask = "edns0clientsubnetmask",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone_id = "HostedZoneId",
                .record_name = "RecordName",
                .record_type = "RecordType",
                .resolver_ip = "ResolverIP",
                .edns0_client_subnet_ip = "EDNS0ClientSubnetIP",
                .edns0_client_subnet_mask = "EDNS0ClientSubnetMask",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_dns_answer) } {
            return .{ .service_metadata = service_metadata, .action = test_dns_answer };
        }
    },
    Response: type = struct {
        nameserver: []const u8,
        record_name: []const u8,
        record_type: []const u8,
        record_data: [][]const u8,
        response_code: []const u8,
        protocol: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nameserver = "Nameserver",
                .record_name = "RecordName",
                .record_type = "RecordType",
                .record_data = "RecordData",
                .response_code = "ResponseCode",
                .protocol = "Protocol",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHostedZone,
    },
} = .{};
pub const update_health_check: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/healthcheck/{HealthCheckId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateHealthCheck",
    Request: type = struct {
        health_check_id: []const u8,
        health_check_version: ?i64 = null,
        ip_address: ?[]const u8 = null,
        port: ?i64 = null,
        resource_path: ?[]const u8 = null,
        fully_qualified_domain_name: ?[]const u8 = null,
        search_string: ?[]const u8 = null,
        failure_threshold: ?i64 = null,
        inverted: ?bool = null,
        disabled: ?bool = null,
        health_threshold: ?i64 = null,
        child_health_checks: ?[][]const u8 = null,
        enable_sni: ?bool = null,
        regions: ?[][]const u8 = null,
        alarm_identifier: ?AlarmIdentifier = null,
        insufficient_data_health_status: ?[]const u8 = null,
        reset_elements: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check_id = "HealthCheckId",
                .health_check_version = "HealthCheckVersion",
                .ip_address = "IPAddress",
                .port = "Port",
                .resource_path = "ResourcePath",
                .fully_qualified_domain_name = "FullyQualifiedDomainName",
                .search_string = "SearchString",
                .failure_threshold = "FailureThreshold",
                .inverted = "Inverted",
                .disabled = "Disabled",
                .health_threshold = "HealthThreshold",
                .child_health_checks = "ChildHealthChecks",
                .enable_sni = "EnableSNI",
                .regions = "Regions",
                .alarm_identifier = "AlarmIdentifier",
                .insufficient_data_health_status = "InsufficientDataHealthStatus",
                .reset_elements = "ResetElements",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_health_check) } {
            return .{ .service_metadata = service_metadata, .action = update_health_check };
        }
    },
    Response: type = struct {
        health_check: HealthCheck,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .health_check = "HealthCheck",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        HealthCheckVersionMismatch,
        InvalidInput,
        NoSuchHealthCheck,
    },
} = .{};
pub const update_hosted_zone_comment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/hostedzone/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateHostedZoneComment",
    Request: type = struct {
        id: []const u8,
        comment: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .comment = "Comment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_hosted_zone_comment) } {
            return .{ .service_metadata = service_metadata, .action = update_hosted_zone_comment };
        }
    },
    Response: type = struct {
        hosted_zone: HostedZone,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosted_zone = "HostedZone",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NoSuchHostedZone,
        PriorRequestNotComplete,
    },
} = .{};
pub const update_traffic_policy_comment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/trafficpolicy/{Id}/{Version}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTrafficPolicyComment",
    Request: type = struct {
        id: []const u8,
        version: i64,
        comment: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .version = "Version",
                .comment = "Comment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_traffic_policy_comment) } {
            return .{ .service_metadata = service_metadata, .action = update_traffic_policy_comment };
        }
    },
    Response: type = struct {
        traffic_policy: TrafficPolicy,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy = "TrafficPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InvalidInput,
        NoSuchTrafficPolicy,
    },
} = .{};
pub const update_traffic_policy_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2013-04-01/trafficpolicyinstance/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTrafficPolicyInstance",
    Request: type = struct {
        id: []const u8,
        ttl: i64,
        traffic_policy_id: []const u8,
        traffic_policy_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .ttl = "TTL",
                .traffic_policy_id = "TrafficPolicyId",
                .traffic_policy_version = "TrafficPolicyVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_traffic_policy_instance) } {
            return .{ .service_metadata = service_metadata, .action = update_traffic_policy_instance };
        }
    },
    Response: type = struct {
        traffic_policy_instance: TrafficPolicyInstance,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_policy_instance = "TrafficPolicyInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConflictingTypes,
        InvalidInput,
        NoSuchTrafficPolicy,
        NoSuchTrafficPolicyInstance,
        PriorRequestNotComplete,
    },
} = .{};

pub const TrafficPolicyInstance = struct {
    id: []const u8,
    hosted_zone_id: []const u8,
    name: []const u8,
    ttl: i64,
    state: []const u8,
    message: []const u8,
    traffic_policy_id: []const u8,
    traffic_policy_version: i64,
    traffic_policy_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .hosted_zone_id = "HostedZoneId",
            .name = "Name",
            .ttl = "TTL",
            .state = "State",
            .message = "Message",
            .traffic_policy_id = "TrafficPolicyId",
            .traffic_policy_version = "TrafficPolicyVersion",
            .traffic_policy_type = "TrafficPolicyType",
        };
        return @field(mappings, field_name);
    }
};

pub const TrafficPolicy = struct {
    id: []const u8,
    version: i64,
    name: []const u8,
    type: []const u8,
    document: []const u8,
    comment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .version = "Version",
            .name = "Name",
            .type = "Type",
            .document = "Document",
            .comment = "Comment",
        };
        return @field(mappings, field_name);
    }
};

pub const HostedZone = struct {
    id: []const u8,
    name: []const u8,
    caller_reference: []const u8,
    config: ?HostedZoneConfig = null,
    resource_record_set_count: ?i64 = null,
    linked_service: ?LinkedService = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .caller_reference = "CallerReference",
            .config = "Config",
            .resource_record_set_count = "ResourceRecordSetCount",
            .linked_service = "LinkedService",
        };
        return @field(mappings, field_name);
    }
};

pub const LinkedService = struct {
    service_principal: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_principal = "ServicePrincipal",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const HostedZoneConfig = struct {
    comment: ?[]const u8 = null,
    private_zone: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment = "Comment",
            .private_zone = "PrivateZone",
        };
        return @field(mappings, field_name);
    }
};

pub const HealthCheck = struct {
    id: []const u8,
    caller_reference: []const u8,
    linked_service: ?LinkedService = null,
    health_check_config: HealthCheckConfig,
    health_check_version: i64,
    cloud_watch_alarm_configuration: ?CloudWatchAlarmConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .caller_reference = "CallerReference",
            .linked_service = "LinkedService",
            .health_check_config = "HealthCheckConfig",
            .health_check_version = "HealthCheckVersion",
            .cloud_watch_alarm_configuration = "CloudWatchAlarmConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchAlarmConfiguration = struct {
    evaluation_periods: i64,
    threshold: f64,
    comparison_operator: []const u8,
    period: i64,
    metric_name: []const u8,
    namespace: []const u8,
    statistic: []const u8,
    dimensions: ?[]Dimension = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .evaluation_periods = "EvaluationPeriods",
            .threshold = "Threshold",
            .comparison_operator = "ComparisonOperator",
            .period = "Period",
            .metric_name = "MetricName",
            .namespace = "Namespace",
            .statistic = "Statistic",
            .dimensions = "Dimensions",
        };
        return @field(mappings, field_name);
    }
};

pub const Dimension = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const HealthCheckConfig = struct {
    ip_address: ?[]const u8 = null,
    port: ?i64 = null,
    type: []const u8,
    resource_path: ?[]const u8 = null,
    fully_qualified_domain_name: ?[]const u8 = null,
    search_string: ?[]const u8 = null,
    request_interval: ?i64 = null,
    failure_threshold: ?i64 = null,
    measure_latency: ?bool = null,
    inverted: ?bool = null,
    disabled: ?bool = null,
    health_threshold: ?i64 = null,
    child_health_checks: ?[][]const u8 = null,
    enable_sni: ?bool = null,
    regions: ?[][]const u8 = null,
    alarm_identifier: ?AlarmIdentifier = null,
    insufficient_data_health_status: ?[]const u8 = null,
    routing_control_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address = "IPAddress",
            .port = "Port",
            .type = "Type",
            .resource_path = "ResourcePath",
            .fully_qualified_domain_name = "FullyQualifiedDomainName",
            .search_string = "SearchString",
            .request_interval = "RequestInterval",
            .failure_threshold = "FailureThreshold",
            .measure_latency = "MeasureLatency",
            .inverted = "Inverted",
            .disabled = "Disabled",
            .health_threshold = "HealthThreshold",
            .child_health_checks = "ChildHealthChecks",
            .enable_sni = "EnableSNI",
            .regions = "Regions",
            .alarm_identifier = "AlarmIdentifier",
            .insufficient_data_health_status = "InsufficientDataHealthStatus",
            .routing_control_arn = "RoutingControlArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AlarmIdentifier = struct {
    region: []const u8,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "Region",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const VPC = struct {
    vpc_region: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_region = "VPCRegion",
            .vpc_id = "VPCId",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceTagSet = struct {
    resource_type: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "ResourceType",
            .resource_id = "ResourceId",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DelegationSet = struct {
    id: ?[]const u8 = null,
    caller_reference: ?[]const u8 = null,
    name_servers: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .caller_reference = "CallerReference",
            .name_servers = "NameServers",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceRecordSet = struct {
    name: []const u8,
    type: []const u8,
    set_identifier: ?[]const u8 = null,
    weight: ?i64 = null,
    region: ?[]const u8 = null,
    geo_location: ?GeoLocation = null,
    failover: ?[]const u8 = null,
    multi_value_answer: ?bool = null,
    ttl: ?i64 = null,
    resource_records: ?[]ResourceRecord = null,
    alias_target: ?AliasTarget = null,
    health_check_id: ?[]const u8 = null,
    traffic_policy_instance_id: ?[]const u8 = null,
    cidr_routing_config: ?CidrRoutingConfig = null,
    geo_proximity_location: ?GeoProximityLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .set_identifier = "SetIdentifier",
            .weight = "Weight",
            .region = "Region",
            .geo_location = "GeoLocation",
            .failover = "Failover",
            .multi_value_answer = "MultiValueAnswer",
            .ttl = "TTL",
            .resource_records = "ResourceRecords",
            .alias_target = "AliasTarget",
            .health_check_id = "HealthCheckId",
            .traffic_policy_instance_id = "TrafficPolicyInstanceId",
            .cidr_routing_config = "CidrRoutingConfig",
            .geo_proximity_location = "GeoProximityLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoProximityLocation = struct {
    aws_region: ?[]const u8 = null,
    local_zone_group: ?[]const u8 = null,
    coordinates: ?Coordinates = null,
    bias: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_region = "AWSRegion",
            .local_zone_group = "LocalZoneGroup",
            .coordinates = "Coordinates",
            .bias = "Bias",
        };
        return @field(mappings, field_name);
    }
};

pub const Coordinates = struct {
    latitude: []const u8,
    longitude: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .latitude = "Latitude",
            .longitude = "Longitude",
        };
        return @field(mappings, field_name);
    }
};

pub const CidrRoutingConfig = struct {
    collection_id: []const u8,
    location_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .collection_id = "CollectionId",
            .location_name = "LocationName",
        };
        return @field(mappings, field_name);
    }
};

pub const AliasTarget = struct {
    hosted_zone_id: []const u8,
    dns_name: []const u8,
    evaluate_target_health: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hosted_zone_id = "HostedZoneId",
            .dns_name = "DNSName",
            .evaluate_target_health = "EvaluateTargetHealth",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceRecord = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoLocation = struct {
    continent_code: ?[]const u8 = null,
    country_code: ?[]const u8 = null,
    subdivision_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .continent_code = "ContinentCode",
            .country_code = "CountryCode",
            .subdivision_code = "SubdivisionCode",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryLoggingConfig = struct {
    id: []const u8,
    hosted_zone_id: []const u8,
    cloud_watch_logs_log_group_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .hosted_zone_id = "HostedZoneId",
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoLocationDetails = struct {
    continent_code: ?[]const u8 = null,
    continent_name: ?[]const u8 = null,
    country_code: ?[]const u8 = null,
    country_name: ?[]const u8 = null,
    subdivision_code: ?[]const u8 = null,
    subdivision_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .continent_code = "ContinentCode",
            .continent_name = "ContinentName",
            .country_code = "CountryCode",
            .country_name = "CountryName",
            .subdivision_code = "SubdivisionCode",
            .subdivision_name = "SubdivisionName",
        };
        return @field(mappings, field_name);
    }
};

pub const HealthCheckObservation = struct {
    region: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,
    status_report: ?StatusReport = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "Region",
            .ip_address = "IPAddress",
            .status_report = "StatusReport",
        };
        return @field(mappings, field_name);
    }
};

pub const StatusReport = struct {
    status: ?[]const u8 = null,
    checked_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .checked_time = "CheckedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const KeySigningKey = struct {
    name: ?[]const u8 = null,
    kms_arn: ?[]const u8 = null,
    flag: ?i64 = null,
    signing_algorithm_mnemonic: ?[]const u8 = null,
    signing_algorithm_type: ?i64 = null,
    digest_algorithm_mnemonic: ?[]const u8 = null,
    digest_algorithm_type: ?i64 = null,
    key_tag: ?i64 = null,
    digest_value: ?[]const u8 = null,
    public_key: ?[]const u8 = null,
    ds_record: ?[]const u8 = null,
    dnskey_record: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    created_date: ?i64 = null,
    last_modified_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .kms_arn = "KmsArn",
            .flag = "Flag",
            .signing_algorithm_mnemonic = "SigningAlgorithmMnemonic",
            .signing_algorithm_type = "SigningAlgorithmType",
            .digest_algorithm_mnemonic = "DigestAlgorithmMnemonic",
            .digest_algorithm_type = "DigestAlgorithmType",
            .key_tag = "KeyTag",
            .digest_value = "DigestValue",
            .public_key = "PublicKey",
            .ds_record = "DSRecord",
            .dnskey_record = "DNSKEYRecord",
            .status = "Status",
            .status_message = "StatusMessage",
            .created_date = "CreatedDate",
            .last_modified_date = "LastModifiedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const ChangeInfo = struct {
    id: []const u8,
    status: []const u8,
    submitted_at: i64,
    comment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .status = "Status",
            .submitted_at = "SubmittedAt",
            .comment = "Comment",
        };
        return @field(mappings, field_name);
    }
};
