const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-08-20";
pub const sdk_id: []const u8 = "S3 Control";
pub const arn_namespace: ?[]const u8 = "s3";
pub const endpoint_prefix: []const u8 = "s3-control";
pub const sigv4_name: []const u8 = "s3";
pub const name: []const u8 = "AWSS3ControlServiceV20180820";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_xml;

pub const service_metadata: struct {
    version: []const u8 = "2018-08-20",
    sdk_id: []const u8 = "S3 Control",
    arn_namespace: ?[]const u8 = "s3",
    endpoint_prefix: []const u8 = "s3-control",
    sigv4_name: []const u8 = "s3",
    name: []const u8 = "AWSS3ControlServiceV20180820",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_xml,
} = .{};
pub const associate_access_grants_identity_center: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/accessgrantsinstance/identitycenter",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateAccessGrantsIdentityCenter",
    Request: type = struct {
        account_id: []const u8,
        identity_center_arn: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .identity_center_arn = "IdentityCenterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_access_grants_identity_center) } {
            return .{ .service_metadata = service_metadata, .action = associate_access_grants_identity_center };
        }
    },
    Response: type = struct {},
} = .{};
pub const create_access_grant: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/accessgrantsinstance/grant",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessGrant",
    Request: type = struct {
        account_id: []const u8,
        access_grants_location_id: []const u8,
        access_grants_location_configuration: ?AccessGrantsLocationConfiguration = null,
        grantee: Grantee,
        permission: []const u8,
        application_arn: ?[]const u8 = null,
        s3_prefix_type: ?[]const u8 = null,
        tags: ?[]Tag = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .access_grants_location_id = "AccessGrantsLocationId",
                .access_grants_location_configuration = "AccessGrantsLocationConfiguration",
                .grantee = "Grantee",
                .permission = "Permission",
                .application_arn = "ApplicationArn",
                .s3_prefix_type = "S3PrefixType",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_grant) } {
            return .{ .service_metadata = service_metadata, .action = create_access_grant };
        }
    },
    Response: type = struct {
        created_at: ?i64 = null,
        access_grant_id: ?[]const u8 = null,
        access_grant_arn: ?[]const u8 = null,
        grantee: ?Grantee = null,
        access_grants_location_id: ?[]const u8 = null,
        access_grants_location_configuration: ?AccessGrantsLocationConfiguration = null,
        permission: ?[]const u8 = null,
        application_arn: ?[]const u8 = null,
        grant_scope: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_at = "CreatedAt",
                .access_grant_id = "AccessGrantId",
                .access_grant_arn = "AccessGrantArn",
                .grantee = "Grantee",
                .access_grants_location_id = "AccessGrantsLocationId",
                .access_grants_location_configuration = "AccessGrantsLocationConfiguration",
                .permission = "Permission",
                .application_arn = "ApplicationArn",
                .grant_scope = "GrantScope",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_access_grants_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/accessgrantsinstance",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessGrantsInstance",
    Request: type = struct {
        account_id: []const u8,
        identity_center_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .identity_center_arn = "IdentityCenterArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_grants_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_access_grants_instance };
        }
    },
    Response: type = struct {
        created_at: ?i64 = null,
        access_grants_instance_id: ?[]const u8 = null,
        access_grants_instance_arn: ?[]const u8 = null,
        identity_center_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_at = "CreatedAt",
                .access_grants_instance_id = "AccessGrantsInstanceId",
                .access_grants_instance_arn = "AccessGrantsInstanceArn",
                .identity_center_arn = "IdentityCenterArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_access_grants_location: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/accessgrantsinstance/location",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessGrantsLocation",
    Request: type = struct {
        account_id: []const u8,
        location_scope: []const u8,
        iam_role_arn: []const u8,
        tags: ?[]Tag = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .location_scope = "LocationScope",
                .iam_role_arn = "IAMRoleArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_grants_location) } {
            return .{ .service_metadata = service_metadata, .action = create_access_grants_location };
        }
    },
    Response: type = struct {
        created_at: ?i64 = null,
        access_grants_location_id: ?[]const u8 = null,
        access_grants_location_arn: ?[]const u8 = null,
        location_scope: ?[]const u8 = null,
        iam_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_at = "CreatedAt",
                .access_grants_location_id = "AccessGrantsLocationId",
                .access_grants_location_arn = "AccessGrantsLocationArn",
                .location_scope = "LocationScope",
                .iam_role_arn = "IAMRoleArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_access_point: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accesspoint/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessPoint",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        bucket: []const u8,
        vpc_configuration: ?VpcConfiguration = null,
        public_access_block_configuration: ?PublicAccessBlockConfiguration = null,
        bucket_account_id: ?[]const u8 = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .bucket = "Bucket",
                .vpc_configuration = "VpcConfiguration",
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
                .bucket_account_id = "BucketAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_point) } {
            return .{ .service_metadata = service_metadata, .action = create_access_point };
        }
    },
    Response: type = struct {
        access_point_arn: ?[]const u8 = null,
        alias: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_point_arn = "AccessPointArn",
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_access_point_for_object_lambda: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessPointForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        configuration: ObjectLambdaConfiguration,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_point_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = create_access_point_for_object_lambda };
        }
    },
    Response: type = struct {
        object_lambda_access_point_arn: ?[]const u8 = null,
        alias: ?ObjectLambdaAccessPointAlias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_lambda_access_point_arn = "ObjectLambdaAccessPointArn",
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_bucket: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/bucket/{Bucket}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBucket",
    Request: type = struct {
        acl: ?[]const u8 = null,
        bucket: []const u8,
        create_bucket_configuration: ?struct {
            location_constraint: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .location_constraint = "LocationConstraint",
                };
                return @field(mappings, field_name);
            }
        } = null,
        grant_full_control: ?[]const u8 = null,
        grant_read: ?[]const u8 = null,
        grant_read_acp: ?[]const u8 = null,
        grant_write: ?[]const u8 = null,
        grant_write_acp: ?[]const u8 = null,
        object_lock_enabled_for_bucket: ?bool = null,
        outpost_id: ?[]const u8 = null,
        pub const http_header = .{
            .acl = "x-amz-acl",
            .grant_full_control = "x-amz-grant-full-control",
            .grant_read = "x-amz-grant-read",
            .grant_read_acp = "x-amz-grant-read-acp",
            .grant_write = "x-amz-grant-write",
            .grant_write_acp = "x-amz-grant-write-acp",
            .object_lock_enabled_for_bucket = "x-amz-bucket-object-lock-enabled",
            .outpost_id = "x-amz-outpost-id",
        };

        pub const http_payload: []const u8 = "create_bucket_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
                .bucket = "Bucket",
                .create_bucket_configuration = "CreateBucketConfiguration",
                .grant_full_control = "GrantFullControl",
                .grant_read = "GrantRead",
                .grant_read_acp = "GrantReadACP",
                .grant_write = "GrantWrite",
                .grant_write_acp = "GrantWriteACP",
                .object_lock_enabled_for_bucket = "ObjectLockEnabledForBucket",
                .outpost_id = "OutpostId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bucket) } {
            return .{ .service_metadata = service_metadata, .action = create_bucket };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,
        bucket_arn: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "Location",
                .bucket_arn = "BucketArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BucketAlreadyExists,
        BucketAlreadyOwnedByYou,
    },
} = .{};
pub const create_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateJob",
    Request: type = struct {
        account_id: []const u8,
        confirmation_required: ?bool = null,
        operation: JobOperation,
        report: JobReport,
        client_request_token: []const u8,
        manifest: ?JobManifest = null,
        description: ?[]const u8 = null,
        priority: i64,
        role_arn: []const u8,
        tags: ?[]S3Tag = null,
        manifest_generator: ?JobManifestGenerator = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .confirmation_required = "ConfirmationRequired",
                .operation = "Operation",
                .report = "Report",
                .client_request_token = "ClientRequestToken",
                .manifest = "Manifest",
                .description = "Description",
                .priority = "Priority",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .manifest_generator = "ManifestGenerator",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job) } {
            return .{ .service_metadata = service_metadata, .action = create_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Idempotency,
        InternalService,
        TooManyRequests,
    },
} = .{};
pub const create_multi_region_access_point: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/async-requests/mrap/create",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMultiRegionAccessPoint",
    Request: type = struct {
        account_id: []const u8,
        client_token: []const u8,
        details: CreateMultiRegionAccessPointInput,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .client_token = "ClientToken",
                .details = "Details",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_multi_region_access_point) } {
            return .{ .service_metadata = service_metadata, .action = create_multi_region_access_point };
        }
    },
    Response: type = struct {
        request_token_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_token_arn = "RequestTokenARN",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_storage_lens_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/storagelensgroup",
        .success_code = 204,
    };

    action_name: []const u8 = "CreateStorageLensGroup",
    Request: type = struct {
        account_id: []const u8,
        storage_lens_group: StorageLensGroup,
        tags: ?[]Tag = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .storage_lens_group = "StorageLensGroup",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_storage_lens_group) } {
            return .{ .service_metadata = service_metadata, .action = create_storage_lens_group };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_grant: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accessgrantsinstance/grant/{AccessGrantId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessGrant",
    Request: type = struct {
        account_id: []const u8,
        access_grant_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .access_grant_id = "AccessGrantId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_grant) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_grant };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_grants_instance: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accessgrantsinstance",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessGrantsInstance",
    Request: type = struct {
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_grants_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_grants_instance };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_grants_instance_resource_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accessgrantsinstance/resourcepolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessGrantsInstanceResourcePolicy",
    Request: type = struct {
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_grants_instance_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_grants_instance_resource_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_grants_location: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accessgrantsinstance/location/{AccessGrantsLocationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessGrantsLocation",
    Request: type = struct {
        account_id: []const u8,
        access_grants_location_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .access_grants_location_id = "AccessGrantsLocationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_grants_location) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_grants_location };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_point: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accesspoint/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessPoint",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_point) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_point };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_point_for_object_lambda: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessPointForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_point_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_point_for_object_lambda };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_point_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accesspoint/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessPointPolicy",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_point_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_point_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_point_policy_for_object_lambda: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessPointPolicyForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_point_policy_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_point_policy_for_object_lambda };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/bucket/{Bucket}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBucket",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_lifecycle_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/bucket/{Bucket}/lifecycleconfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBucketLifecycleConfiguration",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_lifecycle_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_lifecycle_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/bucket/{Bucket}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBucketPolicy",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_replication: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/bucket/{Bucket}/replication",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBucketReplication",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_replication) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_replication };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_tagging: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/bucket/{Bucket}/tagging",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketTagging",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_tagging) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_tagging };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_job_tagging: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/jobs/{JobId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJobTagging",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job_tagging) } {
            return .{ .service_metadata = service_metadata, .action = delete_job_tagging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_multi_region_access_point: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/async-requests/mrap/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteMultiRegionAccessPoint",
    Request: type = struct {
        account_id: []const u8,
        client_token: []const u8,
        details: DeleteMultiRegionAccessPointInput,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .client_token = "ClientToken",
                .details = "Details",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_multi_region_access_point) } {
            return .{ .service_metadata = service_metadata, .action = delete_multi_region_access_point };
        }
    },
    Response: type = struct {
        request_token_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_token_arn = "RequestTokenARN",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_public_access_block: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/configuration/publicAccessBlock",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePublicAccessBlock",
    Request: type = struct {
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_public_access_block) } {
            return .{ .service_metadata = service_metadata, .action = delete_public_access_block };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_storage_lens_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/storagelens/{ConfigId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStorageLensConfiguration",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_storage_lens_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_storage_lens_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_storage_lens_configuration_tagging: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/storagelens/{ConfigId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStorageLensConfigurationTagging",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_storage_lens_configuration_tagging) } {
            return .{ .service_metadata = service_metadata, .action = delete_storage_lens_configuration_tagging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_storage_lens_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/storagelensgroup/{Name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteStorageLensGroup",
    Request: type = struct {
        name: []const u8,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_storage_lens_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_storage_lens_group };
        }
    },
    Response: type = struct {},
} = .{};
pub const describe_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/jobs/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJob",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_job };
        }
    },
    Response: type = struct {
        job: ?struct {
            job_id: ?[]const u8 = null,
            confirmation_required: ?bool = null,
            description: ?[]const u8 = null,
            job_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            manifest: ?JobManifest = null,
            operation: ?JobOperation = null,
            priority: ?i64 = null,
            progress_summary: ?JobProgressSummary = null,
            status_update_reason: ?[]const u8 = null,
            failure_reasons: ?[]struct {
                failure_code: ?[]const u8 = null,
                failure_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .failure_code = "FailureCode",
                        .failure_reason = "FailureReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            report: ?JobReport = null,
            creation_time: ?i64 = null,
            termination_date: ?i64 = null,
            role_arn: ?[]const u8 = null,
            suspended_date: ?i64 = null,
            suspended_cause: ?[]const u8 = null,
            manifest_generator: ?JobManifestGenerator = null,
            generated_manifest_descriptor: ?struct {
                format: ?[]const u8 = null,
                location: ?JobManifestLocation = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .format = "Format",
                        .location = "Location",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .confirmation_required = "ConfirmationRequired",
                    .description = "Description",
                    .job_arn = "JobArn",
                    .status = "Status",
                    .manifest = "Manifest",
                    .operation = "Operation",
                    .priority = "Priority",
                    .progress_summary = "ProgressSummary",
                    .status_update_reason = "StatusUpdateReason",
                    .failure_reasons = "FailureReasons",
                    .report = "Report",
                    .creation_time = "CreationTime",
                    .termination_date = "TerminationDate",
                    .role_arn = "RoleArn",
                    .suspended_date = "SuspendedDate",
                    .suspended_cause = "SuspendedCause",
                    .manifest_generator = "ManifestGenerator",
                    .generated_manifest_descriptor = "GeneratedManifestDescriptor",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "Job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalService,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_multi_region_access_point_operation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/async-requests/mrap/{RequestTokenARN+}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeMultiRegionAccessPointOperation",
    Request: type = struct {
        account_id: []const u8,
        request_token_arn: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .request_token_arn = "RequestTokenARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_multi_region_access_point_operation) } {
            return .{ .service_metadata = service_metadata, .action = describe_multi_region_access_point_operation };
        }
    },
    Response: type = struct {
        async_operation: ?struct {
            creation_time: ?i64 = null,
            operation: ?[]const u8 = null,
            request_token_arn: ?[]const u8 = null,
            request_parameters: ?struct {
                create_multi_region_access_point_request: ?CreateMultiRegionAccessPointInput = null,
                delete_multi_region_access_point_request: ?DeleteMultiRegionAccessPointInput = null,
                put_multi_region_access_point_policy_request: ?PutMultiRegionAccessPointPolicyInput = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .create_multi_region_access_point_request = "CreateMultiRegionAccessPointRequest",
                        .delete_multi_region_access_point_request = "DeleteMultiRegionAccessPointRequest",
                        .put_multi_region_access_point_policy_request = "PutMultiRegionAccessPointPolicyRequest",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            request_status: ?[]const u8 = null,
            response_details: ?struct {
                multi_region_access_point_details: ?struct {
                    regions: ?[]struct {
                        name: ?[]const u8 = null,
                        request_status: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .name = "Name",
                                .request_status = "RequestStatus",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .regions = "Regions",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                error_details: ?struct {
                    code: ?[]const u8 = null,
                    message: ?[]const u8 = null,
                    resource: ?[]const u8 = null,
                    request_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .code = "Code",
                            .message = "Message",
                            .resource = "Resource",
                            .request_id = "RequestId",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .multi_region_access_point_details = "MultiRegionAccessPointDetails",
                        .error_details = "ErrorDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "CreationTime",
                    .operation = "Operation",
                    .request_token_arn = "RequestTokenARN",
                    .request_parameters = "RequestParameters",
                    .request_status = "RequestStatus",
                    .response_details = "ResponseDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .async_operation = "AsyncOperation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const dissociate_access_grants_identity_center: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accessgrantsinstance/identitycenter",
        .success_code = 200,
    };

    action_name: []const u8 = "DissociateAccessGrantsIdentityCenter",
    Request: type = struct {
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(dissociate_access_grants_identity_center) } {
            return .{ .service_metadata = service_metadata, .action = dissociate_access_grants_identity_center };
        }
    },
    Response: type = struct {},
} = .{};
pub const get_access_grant: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accessgrantsinstance/grant/{AccessGrantId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessGrant",
    Request: type = struct {
        account_id: []const u8,
        access_grant_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .access_grant_id = "AccessGrantId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_grant) } {
            return .{ .service_metadata = service_metadata, .action = get_access_grant };
        }
    },
    Response: type = struct {
        created_at: ?i64 = null,
        access_grant_id: ?[]const u8 = null,
        access_grant_arn: ?[]const u8 = null,
        grantee: ?Grantee = null,
        permission: ?[]const u8 = null,
        access_grants_location_id: ?[]const u8 = null,
        access_grants_location_configuration: ?AccessGrantsLocationConfiguration = null,
        grant_scope: ?[]const u8 = null,
        application_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_at = "CreatedAt",
                .access_grant_id = "AccessGrantId",
                .access_grant_arn = "AccessGrantArn",
                .grantee = "Grantee",
                .permission = "Permission",
                .access_grants_location_id = "AccessGrantsLocationId",
                .access_grants_location_configuration = "AccessGrantsLocationConfiguration",
                .grant_scope = "GrantScope",
                .application_arn = "ApplicationArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_grants_instance: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accessgrantsinstance",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessGrantsInstance",
    Request: type = struct {
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_grants_instance) } {
            return .{ .service_metadata = service_metadata, .action = get_access_grants_instance };
        }
    },
    Response: type = struct {
        access_grants_instance_arn: ?[]const u8 = null,
        access_grants_instance_id: ?[]const u8 = null,
        identity_center_arn: ?[]const u8 = null,
        created_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_grants_instance_arn = "AccessGrantsInstanceArn",
                .access_grants_instance_id = "AccessGrantsInstanceId",
                .identity_center_arn = "IdentityCenterArn",
                .created_at = "CreatedAt",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_grants_instance_for_prefix: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accessgrantsinstance/prefix",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessGrantsInstanceForPrefix",
    Request: type = struct {
        account_id: []const u8,
        s3_prefix: []const u8,

        pub const http_query = .{
            .s3_prefix = "s3prefix",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .s3_prefix = "S3Prefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_grants_instance_for_prefix) } {
            return .{ .service_metadata = service_metadata, .action = get_access_grants_instance_for_prefix };
        }
    },
    Response: type = struct {
        access_grants_instance_arn: ?[]const u8 = null,
        access_grants_instance_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_grants_instance_arn = "AccessGrantsInstanceArn",
                .access_grants_instance_id = "AccessGrantsInstanceId",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_grants_instance_resource_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accessgrantsinstance/resourcepolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessGrantsInstanceResourcePolicy",
    Request: type = struct {
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_grants_instance_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_access_grants_instance_resource_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,
        organization: ?[]const u8 = null,
        created_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
                .organization = "Organization",
                .created_at = "CreatedAt",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_grants_location: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accessgrantsinstance/location/{AccessGrantsLocationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessGrantsLocation",
    Request: type = struct {
        account_id: []const u8,
        access_grants_location_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .access_grants_location_id = "AccessGrantsLocationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_grants_location) } {
            return .{ .service_metadata = service_metadata, .action = get_access_grants_location };
        }
    },
    Response: type = struct {
        created_at: ?i64 = null,
        access_grants_location_id: ?[]const u8 = null,
        access_grants_location_arn: ?[]const u8 = null,
        location_scope: ?[]const u8 = null,
        iam_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_at = "CreatedAt",
                .access_grants_location_id = "AccessGrantsLocationId",
                .access_grants_location_arn = "AccessGrantsLocationArn",
                .location_scope = "LocationScope",
                .iam_role_arn = "IAMRoleArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspoint/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPoint",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        bucket: ?[]const u8 = null,
        network_origin: ?[]const u8 = null,
        vpc_configuration: ?VpcConfiguration = null,
        public_access_block_configuration: ?PublicAccessBlockConfiguration = null,
        creation_date: ?i64 = null,
        alias: ?[]const u8 = null,
        access_point_arn: ?[]const u8 = null,
        endpoints: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        bucket_account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .bucket = "Bucket",
                .network_origin = "NetworkOrigin",
                .vpc_configuration = "VpcConfiguration",
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
                .creation_date = "CreationDate",
                .alias = "Alias",
                .access_point_arn = "AccessPointArn",
                .endpoints = "Endpoints",
                .bucket_account_id = "BucketAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "endpoints", field_name))
                return try serializeMap(self.endpoints, self.fieldNameFor("endpoints"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const get_access_point_configuration_for_object_lambda: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointConfigurationForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_configuration_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_configuration_for_object_lambda };
        }
    },
    Response: type = struct {
        configuration: ?ObjectLambdaConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_for_object_lambda: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_for_object_lambda };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        public_access_block_configuration: ?PublicAccessBlockConfiguration = null,
        creation_date: ?i64 = null,
        alias: ?ObjectLambdaAccessPointAlias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
                .creation_date = "CreationDate",
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspoint/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointPolicy",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_policy_for_object_lambda: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointPolicyForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_policy_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_policy_for_object_lambda };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_policy_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspoint/{Name}/policyStatus",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointPolicyStatus",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_policy_status) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_policy_status };
        }
    },
    Response: type = struct {
        policy_status: ?PolicyStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_status = "PolicyStatus",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_policy_status_for_object_lambda: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/policyStatus",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointPolicyStatusForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_policy_status_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_policy_status_for_object_lambda };
        }
    },
    Response: type = struct {
        policy_status: ?PolicyStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_status = "PolicyStatus",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket/{Bucket}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucket",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket };
        }
    },
    Response: type = struct {
        bucket: ?[]const u8 = null,
        public_access_block_enabled: ?bool = null,
        creation_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .public_access_block_enabled = "PublicAccessBlockEnabled",
                .creation_date = "CreationDate",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_lifecycle_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket/{Bucket}/lifecycleconfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketLifecycleConfiguration",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_lifecycle_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_lifecycle_configuration };
        }
    },
    Response: type = struct {
        rules: ?[]LifecycleRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket/{Bucket}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketPolicy",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_replication: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket/{Bucket}/replication",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketReplication",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_replication) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_replication };
        }
    },
    Response: type = struct {
        replication_configuration: ?ReplicationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_configuration = "ReplicationConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_tagging: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket/{Bucket}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketTagging",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_tagging) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_tagging };
        }
    },
    Response: type = struct {
        tag_set: []S3Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_set = "TagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_versioning: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket/{Bucket}/versioning",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketVersioning",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_versioning) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_versioning };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        mfa_delete: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .mfa_delete = "MfaDelete",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_data_access: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accessgrantsinstance/dataaccess",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataAccess",
    Request: type = struct {
        account_id: []const u8,
        target: []const u8,
        permission: []const u8,
        duration_seconds: ?i64 = null,
        privilege: ?[]const u8 = null,
        target_type: ?[]const u8 = null,

        pub const http_query = .{
            .target = "target",
            .permission = "permission",
            .duration_seconds = "durationSeconds",
            .privilege = "privilege",
            .target_type = "targetType",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .target = "Target",
                .permission = "Permission",
                .duration_seconds = "DurationSeconds",
                .privilege = "Privilege",
                .target_type = "TargetType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_access) } {
            return .{ .service_metadata = service_metadata, .action = get_data_access };
        }
    },
    Response: type = struct {
        credentials: ?struct {
            access_key_id: ?[]const u8 = null,
            secret_access_key: ?[]const u8 = null,
            session_token: ?[]const u8 = null,
            expiration: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_key_id = "AccessKeyId",
                    .secret_access_key = "SecretAccessKey",
                    .session_token = "SessionToken",
                    .expiration = "Expiration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        matched_grant_target: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "Credentials",
                .matched_grant_target = "MatchedGrantTarget",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_job_tagging: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/jobs/{JobId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJobTagging",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_tagging) } {
            return .{ .service_metadata = service_metadata, .action = get_job_tagging };
        }
    },
    Response: type = struct {
        tags: ?[]S3Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_multi_region_access_point: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/mrap/instances/{Name+}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMultiRegionAccessPoint",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_multi_region_access_point) } {
            return .{ .service_metadata = service_metadata, .action = get_multi_region_access_point };
        }
    },
    Response: type = struct {
        access_point: ?MultiRegionAccessPointReport = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_point = "AccessPoint",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_multi_region_access_point_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/mrap/instances/{Name+}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMultiRegionAccessPointPolicy",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_multi_region_access_point_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_multi_region_access_point_policy };
        }
    },
    Response: type = struct {
        policy: ?struct {
            established: ?struct {
                policy: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .policy = "Policy",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            proposed: ?struct {
                policy: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .policy = "Policy",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .established = "Established",
                    .proposed = "Proposed",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_multi_region_access_point_policy_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/mrap/instances/{Name+}/policystatus",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMultiRegionAccessPointPolicyStatus",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_multi_region_access_point_policy_status) } {
            return .{ .service_metadata = service_metadata, .action = get_multi_region_access_point_policy_status };
        }
    },
    Response: type = struct {
        established: ?PolicyStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .established = "Established",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_multi_region_access_point_routes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/mrap/instances/{Mrap+}/routes",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMultiRegionAccessPointRoutes",
    Request: type = struct {
        account_id: []const u8,
        mrap: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .mrap = "Mrap",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_multi_region_access_point_routes) } {
            return .{ .service_metadata = service_metadata, .action = get_multi_region_access_point_routes };
        }
    },
    Response: type = struct {
        mrap: ?[]const u8 = null,
        routes: ?[]MultiRegionAccessPointRoute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mrap = "Mrap",
                .routes = "Routes",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_public_access_block: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/configuration/publicAccessBlock",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPublicAccessBlock",
    Request: type = struct {
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_public_access_block) } {
            return .{ .service_metadata = service_metadata, .action = get_public_access_block };
        }
    },
    Response: type = struct {
        public_access_block_configuration: ?PublicAccessBlockConfiguration = null,

        pub const http_payload: []const u8 = "public_access_block_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchPublicAccessBlockConfiguration,
    },
} = .{};
pub const get_storage_lens_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/storagelens/{ConfigId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStorageLensConfiguration",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_storage_lens_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_storage_lens_configuration };
        }
    },
    Response: type = struct {
        storage_lens_configuration: ?StorageLensConfiguration = null,

        pub const http_payload: []const u8 = "storage_lens_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_lens_configuration = "StorageLensConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_storage_lens_configuration_tagging: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/storagelens/{ConfigId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStorageLensConfigurationTagging",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_storage_lens_configuration_tagging) } {
            return .{ .service_metadata = service_metadata, .action = get_storage_lens_configuration_tagging };
        }
    },
    Response: type = struct {
        tags: ?[]StorageLensTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_storage_lens_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/storagelensgroup/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStorageLensGroup",
    Request: type = struct {
        name: []const u8,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_storage_lens_group) } {
            return .{ .service_metadata = service_metadata, .action = get_storage_lens_group };
        }
    },
    Response: type = struct {
        storage_lens_group: ?StorageLensGroup = null,

        pub const http_payload: []const u8 = "storage_lens_group";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_lens_group = "StorageLensGroup",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_access_grants: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accessgrantsinstance/grants",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessGrants",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        grantee_type: ?[]const u8 = null,
        grantee_identifier: ?[]const u8 = null,
        permission: ?[]const u8 = null,
        grant_scope: ?[]const u8 = null,
        application_arn: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .grantee_type = "granteetype",
            .grantee_identifier = "granteeidentifier",
            .permission = "permission",
            .grant_scope = "grantscope",
            .application_arn = "application_arn",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .grantee_type = "GranteeType",
                .grantee_identifier = "GranteeIdentifier",
                .permission = "Permission",
                .grant_scope = "GrantScope",
                .application_arn = "ApplicationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_grants) } {
            return .{ .service_metadata = service_metadata, .action = list_access_grants };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        access_grants_list: ?[]struct {
            created_at: ?i64 = null,
            access_grant_id: ?[]const u8 = null,
            access_grant_arn: ?[]const u8 = null,
            grantee: ?Grantee = null,
            permission: ?[]const u8 = null,
            access_grants_location_id: ?[]const u8 = null,
            access_grants_location_configuration: ?AccessGrantsLocationConfiguration = null,
            grant_scope: ?[]const u8 = null,
            application_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_at = "CreatedAt",
                    .access_grant_id = "AccessGrantId",
                    .access_grant_arn = "AccessGrantArn",
                    .grantee = "Grantee",
                    .permission = "Permission",
                    .access_grants_location_id = "AccessGrantsLocationId",
                    .access_grants_location_configuration = "AccessGrantsLocationConfiguration",
                    .grant_scope = "GrantScope",
                    .application_arn = "ApplicationArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .access_grants_list = "AccessGrantsList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_access_grants_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accessgrantsinstances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessGrantsInstances",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_grants_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_access_grants_instances };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        access_grants_instances_list: ?[]struct {
            access_grants_instance_id: ?[]const u8 = null,
            access_grants_instance_arn: ?[]const u8 = null,
            created_at: ?i64 = null,
            identity_center_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_grants_instance_id = "AccessGrantsInstanceId",
                    .access_grants_instance_arn = "AccessGrantsInstanceArn",
                    .created_at = "CreatedAt",
                    .identity_center_arn = "IdentityCenterArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .access_grants_instances_list = "AccessGrantsInstancesList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_access_grants_locations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accessgrantsinstance/locations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessGrantsLocations",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        location_scope: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .location_scope = "locationscope",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .location_scope = "LocationScope",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_grants_locations) } {
            return .{ .service_metadata = service_metadata, .action = list_access_grants_locations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        access_grants_locations_list: ?[]struct {
            created_at: ?i64 = null,
            access_grants_location_id: ?[]const u8 = null,
            access_grants_location_arn: ?[]const u8 = null,
            location_scope: ?[]const u8 = null,
            iam_role_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_at = "CreatedAt",
                    .access_grants_location_id = "AccessGrantsLocationId",
                    .access_grants_location_arn = "AccessGrantsLocationArn",
                    .location_scope = "LocationScope",
                    .iam_role_arn = "IAMRoleArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .access_grants_locations_list = "AccessGrantsLocationsList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_access_points: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspoint",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessPoints",
    Request: type = struct {
        account_id: []const u8,
        bucket: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .bucket = "bucket",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_points) } {
            return .{ .service_metadata = service_metadata, .action = list_access_points };
        }
    },
    Response: type = struct {
        access_point_list: ?[]struct {
            name: []const u8,
            network_origin: []const u8,
            vpc_configuration: ?VpcConfiguration = null,
            bucket: []const u8,
            access_point_arn: ?[]const u8 = null,
            alias: ?[]const u8 = null,
            bucket_account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .network_origin = "NetworkOrigin",
                    .vpc_configuration = "VpcConfiguration",
                    .bucket = "Bucket",
                    .access_point_arn = "AccessPointArn",
                    .alias = "Alias",
                    .bucket_account_id = "BucketAccountId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_point_list = "AccessPointList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_access_points_for_object_lambda: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspointforobjectlambda",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessPointsForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_points_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = list_access_points_for_object_lambda };
        }
    },
    Response: type = struct {
        object_lambda_access_point_list: ?[]struct {
            name: []const u8,
            object_lambda_access_point_arn: ?[]const u8 = null,
            alias: ?ObjectLambdaAccessPointAlias = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .object_lambda_access_point_arn = "ObjectLambdaAccessPointArn",
                    .alias = "Alias",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_lambda_access_point_list = "ObjectLambdaAccessPointList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        account_id: []const u8,
        job_statuses: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .job_statuses = "jobStatuses",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_statuses = "JobStatuses",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        jobs: ?[]struct {
            job_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            operation: ?[]const u8 = null,
            priority: ?i64 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            termination_date: ?i64 = null,
            progress_summary: ?JobProgressSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .description = "Description",
                    .operation = "Operation",
                    .priority = "Priority",
                    .status = "Status",
                    .creation_time = "CreationTime",
                    .termination_date = "TerminationDate",
                    .progress_summary = "ProgressSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .jobs = "Jobs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidNextToken,
        InvalidRequest,
    },
} = .{};
pub const list_multi_region_access_points: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/mrap/instances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMultiRegionAccessPoints",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_multi_region_access_points) } {
            return .{ .service_metadata = service_metadata, .action = list_multi_region_access_points };
        }
    },
    Response: type = struct {
        access_points: ?[]MultiRegionAccessPointReport = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_points = "AccessPoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_regional_buckets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRegionalBuckets",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        outpost_id: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
            .outpost_id = "x-amz-outpost-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .outpost_id = "OutpostId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_regional_buckets) } {
            return .{ .service_metadata = service_metadata, .action = list_regional_buckets };
        }
    },
    Response: type = struct {
        regional_bucket_list: ?[]struct {
            bucket: []const u8,
            bucket_arn: ?[]const u8 = null,
            public_access_block_enabled: bool,
            creation_date: i64,
            outpost_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bucket = "Bucket",
                    .bucket_arn = "BucketArn",
                    .public_access_block_enabled = "PublicAccessBlockEnabled",
                    .creation_date = "CreationDate",
                    .outpost_id = "OutpostId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regional_bucket_list = "RegionalBucketList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_storage_lens_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/storagelens",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStorageLensConfigurations",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_storage_lens_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_storage_lens_configurations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        storage_lens_configuration_list: ?[]struct {
            id: []const u8,
            storage_lens_arn: []const u8,
            home_region: []const u8,
            is_enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .storage_lens_arn = "StorageLensArn",
                    .home_region = "HomeRegion",
                    .is_enabled = "IsEnabled",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .storage_lens_configuration_list = "StorageLensConfigurationList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_storage_lens_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/storagelensgroup",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStorageLensGroups",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_storage_lens_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_storage_lens_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        storage_lens_group_list: ?[]struct {
            name: []const u8,
            storage_lens_group_arn: []const u8,
            home_region: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .storage_lens_group_arn = "StorageLensGroupArn",
                    .home_region = "HomeRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .storage_lens_group_list = "StorageLensGroupList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/tags/{ResourceArn+}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        account_id: []const u8,
        resource_arn: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_access_grants_instance_resource_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accessgrantsinstance/resourcepolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccessGrantsInstanceResourcePolicy",
    Request: type = struct {
        account_id: []const u8,
        policy: []const u8,
        organization: ?[]const u8 = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .policy = "Policy",
                .organization = "Organization",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_access_grants_instance_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_access_grants_instance_resource_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,
        organization: ?[]const u8 = null,
        created_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
                .organization = "Organization",
                .created_at = "CreatedAt",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_access_point_configuration_for_object_lambda: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccessPointConfigurationForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        configuration: ObjectLambdaConfiguration,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_access_point_configuration_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = put_access_point_configuration_for_object_lambda };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_access_point_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accesspoint/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccessPointPolicy",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        policy: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_access_point_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_access_point_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_access_point_policy_for_object_lambda: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccessPointPolicyForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        policy: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_access_point_policy_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = put_access_point_policy_for_object_lambda };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_lifecycle_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/bucket/{Bucket}/lifecycleconfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketLifecycleConfiguration",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        lifecycle_configuration: ?struct {
            rules: ?[]LifecycleRule = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rules = "Rules",
                };
                return @field(mappings, field_name);
            }
        } = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub const http_payload: []const u8 = "lifecycle_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
                .lifecycle_configuration = "LifecycleConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_lifecycle_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_lifecycle_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/bucket/{Bucket}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketPolicy",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        confirm_remove_self_bucket_access: ?bool = null,
        policy: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
            .confirm_remove_self_bucket_access = "x-amz-confirm-remove-self-bucket-access",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
                .confirm_remove_self_bucket_access = "ConfirmRemoveSelfBucketAccess",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_replication: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/bucket/{Bucket}/replication",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketReplication",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        replication_configuration: ReplicationConfiguration,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub const http_payload: []const u8 = "replication_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
                .replication_configuration = "ReplicationConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_replication) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_replication };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_tagging: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/bucket/{Bucket}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketTagging",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        tagging: struct {
            tag_set: []S3Tag,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_set = "TagSet",
                };
                return @field(mappings, field_name);
            }
        },
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub const http_payload: []const u8 = "tagging";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
                .tagging = "Tagging",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_tagging) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_tagging };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_versioning: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/bucket/{Bucket}/versioning",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketVersioning",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        mfa: ?[]const u8 = null,
        versioning_configuration: struct {
            mfa_delete: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mfa_delete = "MfaDelete",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        },
        pub const http_header = .{
            .account_id = "x-amz-account-id",
            .mfa = "x-amz-mfa",
        };

        pub const http_payload: []const u8 = "versioning_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
                .mfa = "MFA",
                .versioning_configuration = "VersioningConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_versioning) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_versioning };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_job_tagging: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/jobs/{JobId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutJobTagging",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        tags: []S3Tag,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_job_tagging) } {
            return .{ .service_metadata = service_metadata, .action = put_job_tagging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        NotFound,
        TooManyRequests,
        TooManyTags,
    },
} = .{};
pub const put_multi_region_access_point_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/async-requests/mrap/put-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutMultiRegionAccessPointPolicy",
    Request: type = struct {
        account_id: []const u8,
        client_token: []const u8,
        details: PutMultiRegionAccessPointPolicyInput,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .client_token = "ClientToken",
                .details = "Details",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_multi_region_access_point_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_multi_region_access_point_policy };
        }
    },
    Response: type = struct {
        request_token_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_token_arn = "RequestTokenARN",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_public_access_block: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/configuration/publicAccessBlock",
        .success_code = 200,
    };

    action_name: []const u8 = "PutPublicAccessBlock",
    Request: type = struct {
        public_access_block_configuration: PublicAccessBlockConfiguration,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub const http_payload: []const u8 = "public_access_block_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_public_access_block) } {
            return .{ .service_metadata = service_metadata, .action = put_public_access_block };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_storage_lens_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/storagelens/{ConfigId}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutStorageLensConfiguration",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        storage_lens_configuration: StorageLensConfiguration,
        tags: ?[]StorageLensTag = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
                .storage_lens_configuration = "StorageLensConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_storage_lens_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_storage_lens_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_storage_lens_configuration_tagging: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/storagelens/{ConfigId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutStorageLensConfigurationTagging",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        tags: []StorageLensTag,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_storage_lens_configuration_tagging) } {
            return .{ .service_metadata = service_metadata, .action = put_storage_lens_configuration_tagging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const submit_multi_region_access_point_routes: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v20180820/mrap/instances/{Mrap+}/routes",
        .success_code = 200,
    };

    action_name: []const u8 = "SubmitMultiRegionAccessPointRoutes",
    Request: type = struct {
        account_id: []const u8,
        mrap: []const u8,
        route_updates: []MultiRegionAccessPointRoute,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .mrap = "Mrap",
                .route_updates = "RouteUpdates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(submit_multi_region_access_point_routes) } {
            return .{ .service_metadata = service_metadata, .action = submit_multi_region_access_point_routes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/tags/{ResourceArn+}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        account_id: []const u8,
        resource_arn: []const u8,
        tags: []Tag,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/tags/{ResourceArn+}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        account_id: []const u8,
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_access_grants_location: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accessgrantsinstance/location/{AccessGrantsLocationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccessGrantsLocation",
    Request: type = struct {
        account_id: []const u8,
        access_grants_location_id: []const u8,
        iam_role_arn: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .access_grants_location_id = "AccessGrantsLocationId",
                .iam_role_arn = "IAMRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_access_grants_location) } {
            return .{ .service_metadata = service_metadata, .action = update_access_grants_location };
        }
    },
    Response: type = struct {
        created_at: ?i64 = null,
        access_grants_location_id: ?[]const u8 = null,
        access_grants_location_arn: ?[]const u8 = null,
        location_scope: ?[]const u8 = null,
        iam_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_at = "CreatedAt",
                .access_grants_location_id = "AccessGrantsLocationId",
                .access_grants_location_arn = "AccessGrantsLocationArn",
                .location_scope = "LocationScope",
                .iam_role_arn = "IAMRoleArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_job_priority: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/jobs/{JobId}/priority",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJobPriority",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        priority: i64,

        pub const http_query = .{
            .priority = "priority",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
                .priority = "Priority",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job_priority) } {
            return .{ .service_metadata = service_metadata, .action = update_job_priority };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        priority: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .priority = "Priority",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalService,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_job_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/jobs/{JobId}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJobStatus",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        requested_job_status: []const u8,
        status_update_reason: ?[]const u8 = null,

        pub const http_query = .{
            .requested_job_status = "requestedJobStatus",
            .status_update_reason = "statusUpdateReason",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
                .requested_job_status = "RequestedJobStatus",
                .status_update_reason = "StatusUpdateReason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job_status) } {
            return .{ .service_metadata = service_metadata, .action = update_job_status };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_update_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .status = "Status",
                .status_update_reason = "StatusUpdateReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalService,
        JobStatus,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_storage_lens_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/storagelensgroup/{Name}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateStorageLensGroup",
    Request: type = struct {
        name: []const u8,
        account_id: []const u8,
        storage_lens_group: StorageLensGroup,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .account_id = "AccountId",
                .storage_lens_group = "StorageLensGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_storage_lens_group) } {
            return .{ .service_metadata = service_metadata, .action = update_storage_lens_group };
        }
    },
    Response: type = struct {},
} = .{};

pub const StorageLensGroup = struct {
    name: []const u8,
    filter: StorageLensGroupFilter,
    storage_lens_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .filter = "Filter",
            .storage_lens_group_arn = "StorageLensGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensGroupFilter = struct {
    match_any_prefix: ?[][]const u8 = null,
    match_any_suffix: ?[][]const u8 = null,
    match_any_tag: ?[]S3Tag = null,
    match_object_age: ?MatchObjectAge = null,
    match_object_size: ?MatchObjectSize = null,
    @"and": ?StorageLensGroupAndOperator = null,
    @"or": ?StorageLensGroupOrOperator = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_any_prefix = "MatchAnyPrefix",
            .match_any_suffix = "MatchAnySuffix",
            .match_any_tag = "MatchAnyTag",
            .match_object_age = "MatchObjectAge",
            .match_object_size = "MatchObjectSize",
            .@"and" = "And",
            .@"or" = "Or",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensGroupOrOperator = struct {
    match_any_prefix: ?[][]const u8 = null,
    match_any_suffix: ?[][]const u8 = null,
    match_any_tag: ?[]S3Tag = null,
    match_object_age: ?MatchObjectAge = null,
    match_object_size: ?MatchObjectSize = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_any_prefix = "MatchAnyPrefix",
            .match_any_suffix = "MatchAnySuffix",
            .match_any_tag = "MatchAnyTag",
            .match_object_age = "MatchObjectAge",
            .match_object_size = "MatchObjectSize",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchObjectSize = struct {
    bytes_greater_than: ?i64 = null,
    bytes_less_than: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bytes_greater_than = "BytesGreaterThan",
            .bytes_less_than = "BytesLessThan",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchObjectAge = struct {
    days_greater_than: ?i64 = null,
    days_less_than: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .days_greater_than = "DaysGreaterThan",
            .days_less_than = "DaysLessThan",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensGroupAndOperator = struct {
    match_any_prefix: ?[][]const u8 = null,
    match_any_suffix: ?[][]const u8 = null,
    match_any_tag: ?[]S3Tag = null,
    match_object_age: ?MatchObjectAge = null,
    match_object_size: ?MatchObjectSize = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_any_prefix = "MatchAnyPrefix",
            .match_any_suffix = "MatchAnySuffix",
            .match_any_tag = "MatchAnyTag",
            .match_object_age = "MatchObjectAge",
            .match_object_size = "MatchObjectSize",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiRegionAccessPointRoute = struct {
    bucket: ?[]const u8 = null,
    region: ?[]const u8 = null,
    traffic_dial_percentage: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .region = "Region",
            .traffic_dial_percentage = "TrafficDialPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensTag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensConfiguration = struct {
    id: []const u8,
    account_level: AccountLevel,
    include: ?Include = null,
    exclude: ?Exclude = null,
    data_export: ?StorageLensDataExport = null,
    is_enabled: bool,
    aws_org: ?StorageLensAwsOrg = null,
    storage_lens_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .account_level = "AccountLevel",
            .include = "Include",
            .exclude = "Exclude",
            .data_export = "DataExport",
            .is_enabled = "IsEnabled",
            .aws_org = "AwsOrg",
            .storage_lens_arn = "StorageLensArn",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensAwsOrg = struct {
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensDataExport = struct {
    s3_bucket_destination: ?S3BucketDestination = null,
    cloud_watch_metrics: ?CloudWatchMetrics = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_destination = "S3BucketDestination",
            .cloud_watch_metrics = "CloudWatchMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchMetrics = struct {
    is_enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_enabled = "IsEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketDestination = struct {
    format: []const u8,
    output_schema_version: []const u8,
    account_id: []const u8,
    arn: []const u8,
    prefix: ?[]const u8 = null,
    encryption: ?StorageLensDataExportEncryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .output_schema_version = "OutputSchemaVersion",
            .account_id = "AccountId",
            .arn = "Arn",
            .prefix = "Prefix",
            .encryption = "Encryption",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensDataExportEncryption = struct {
    sses3: ?SSES3 = null,
    ssekms: ?SSEKMS = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sses3 = "SSE-S3",
            .ssekms = "SSE-KMS",
        };
        return @field(mappings, field_name);
    }
};

pub const SSEKMS = struct {
    key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_id = "KeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const SSES3 = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Exclude = struct {
    buckets: ?[][]const u8 = null,
    regions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .buckets = "Buckets",
            .regions = "Regions",
        };
        return @field(mappings, field_name);
    }
};

pub const Include = struct {
    buckets: ?[][]const u8 = null,
    regions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .buckets = "Buckets",
            .regions = "Regions",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountLevel = struct {
    activity_metrics: ?ActivityMetrics = null,
    bucket_level: BucketLevel,
    advanced_cost_optimization_metrics: ?AdvancedCostOptimizationMetrics = null,
    advanced_data_protection_metrics: ?AdvancedDataProtectionMetrics = null,
    detailed_status_codes_metrics: ?DetailedStatusCodesMetrics = null,
    storage_lens_group_level: ?StorageLensGroupLevel = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activity_metrics = "ActivityMetrics",
            .bucket_level = "BucketLevel",
            .advanced_cost_optimization_metrics = "AdvancedCostOptimizationMetrics",
            .advanced_data_protection_metrics = "AdvancedDataProtectionMetrics",
            .detailed_status_codes_metrics = "DetailedStatusCodesMetrics",
            .storage_lens_group_level = "StorageLensGroupLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensGroupLevel = struct {
    selection_criteria: ?StorageLensGroupLevelSelectionCriteria = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selection_criteria = "SelectionCriteria",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensGroupLevelSelectionCriteria = struct {
    include: ?[][]const u8 = null,
    exclude: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .include = "Include",
            .exclude = "Exclude",
        };
        return @field(mappings, field_name);
    }
};

pub const DetailedStatusCodesMetrics = struct {
    is_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_enabled = "IsEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedDataProtectionMetrics = struct {
    is_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_enabled = "IsEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedCostOptimizationMetrics = struct {
    is_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_enabled = "IsEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const BucketLevel = struct {
    activity_metrics: ?ActivityMetrics = null,
    prefix_level: ?PrefixLevel = null,
    advanced_cost_optimization_metrics: ?AdvancedCostOptimizationMetrics = null,
    advanced_data_protection_metrics: ?AdvancedDataProtectionMetrics = null,
    detailed_status_codes_metrics: ?DetailedStatusCodesMetrics = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activity_metrics = "ActivityMetrics",
            .prefix_level = "PrefixLevel",
            .advanced_cost_optimization_metrics = "AdvancedCostOptimizationMetrics",
            .advanced_data_protection_metrics = "AdvancedDataProtectionMetrics",
            .detailed_status_codes_metrics = "DetailedStatusCodesMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const PrefixLevel = struct {
    storage_metrics: PrefixLevelStorageMetrics,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_metrics = "StorageMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const PrefixLevelStorageMetrics = struct {
    is_enabled: ?bool = null,
    selection_criteria: ?SelectionCriteria = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_enabled = "IsEnabled",
            .selection_criteria = "SelectionCriteria",
        };
        return @field(mappings, field_name);
    }
};

pub const SelectionCriteria = struct {
    delimiter: ?[]const u8 = null,
    max_depth: ?i64 = null,
    min_storage_bytes_percentage: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delimiter = "Delimiter",
            .max_depth = "MaxDepth",
            .min_storage_bytes_percentage = "MinStorageBytesPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityMetrics = struct {
    is_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_enabled = "IsEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const PublicAccessBlockConfiguration = struct {
    block_public_acls: ?bool = null,
    ignore_public_acls: ?bool = null,
    block_public_policy: ?bool = null,
    restrict_public_buckets: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_public_acls = "BlockPublicAcls",
            .ignore_public_acls = "IgnorePublicAcls",
            .block_public_policy = "BlockPublicPolicy",
            .restrict_public_buckets = "RestrictPublicBuckets",
        };
        return @field(mappings, field_name);
    }
};

pub const PutMultiRegionAccessPointPolicyInput = struct {
    name: []const u8,
    policy: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .policy = "Policy",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationConfiguration = struct {
    role: []const u8,
    rules: []ReplicationRule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role = "Role",
            .rules = "Rules",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationRule = struct {
    id: ?[]const u8 = null,
    priority: ?i64 = null,
    prefix: ?[]const u8 = null,
    filter: ?ReplicationRuleFilter = null,
    status: []const u8,
    source_selection_criteria: ?SourceSelectionCriteria = null,
    existing_object_replication: ?ExistingObjectReplication = null,
    destination: Destination,
    delete_marker_replication: ?DeleteMarkerReplication = null,
    bucket: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "ID",
            .priority = "Priority",
            .prefix = "Prefix",
            .filter = "Filter",
            .status = "Status",
            .source_selection_criteria = "SourceSelectionCriteria",
            .existing_object_replication = "ExistingObjectReplication",
            .destination = "Destination",
            .delete_marker_replication = "DeleteMarkerReplication",
            .bucket = "Bucket",
        };
        return @field(mappings, field_name);
    }
};

pub const DeleteMarkerReplication = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const Destination = struct {
    account: ?[]const u8 = null,
    bucket: []const u8,
    replication_time: ?ReplicationTime = null,
    access_control_translation: ?AccessControlTranslation = null,
    encryption_configuration: ?EncryptionConfiguration = null,
    metrics: ?Metrics = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account = "Account",
            .bucket = "Bucket",
            .replication_time = "ReplicationTime",
            .access_control_translation = "AccessControlTranslation",
            .encryption_configuration = "EncryptionConfiguration",
            .metrics = "Metrics",
            .storage_class = "StorageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const Metrics = struct {
    status: []const u8,
    event_threshold: ?ReplicationTimeValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .event_threshold = "EventThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTimeValue = struct {
    minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minutes = "Minutes",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfiguration = struct {
    replica_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replica_kms_key_id = "ReplicaKmsKeyID",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessControlTranslation = struct {
    owner: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTime = struct {
    status: []const u8,
    time: ReplicationTimeValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .time = "Time",
        };
        return @field(mappings, field_name);
    }
};

pub const ExistingObjectReplication = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceSelectionCriteria = struct {
    sse_kms_encrypted_objects: ?SseKmsEncryptedObjects = null,
    replica_modifications: ?ReplicaModifications = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sse_kms_encrypted_objects = "SseKmsEncryptedObjects",
            .replica_modifications = "ReplicaModifications",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicaModifications = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const SseKmsEncryptedObjects = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationRuleFilter = struct {
    prefix: ?[]const u8 = null,
    tag: ?S3Tag = null,
    @"and": ?ReplicationRuleAndOperator = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tag = "Tag",
            .@"and" = "And",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationRuleAndOperator = struct {
    prefix: ?[]const u8 = null,
    tags: ?[]S3Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleRule = struct {
    expiration: ?LifecycleExpiration = null,
    id: ?[]const u8 = null,
    filter: ?LifecycleRuleFilter = null,
    status: []const u8,
    transitions: ?[]Transition = null,
    noncurrent_version_transitions: ?[]NoncurrentVersionTransition = null,
    noncurrent_version_expiration: ?NoncurrentVersionExpiration = null,
    abort_incomplete_multipart_upload: ?AbortIncompleteMultipartUpload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expiration = "Expiration",
            .id = "ID",
            .filter = "Filter",
            .status = "Status",
            .transitions = "Transitions",
            .noncurrent_version_transitions = "NoncurrentVersionTransitions",
            .noncurrent_version_expiration = "NoncurrentVersionExpiration",
            .abort_incomplete_multipart_upload = "AbortIncompleteMultipartUpload",
        };
        return @field(mappings, field_name);
    }
};

pub const AbortIncompleteMultipartUpload = struct {
    days_after_initiation: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .days_after_initiation = "DaysAfterInitiation",
        };
        return @field(mappings, field_name);
    }
};

pub const NoncurrentVersionExpiration = struct {
    noncurrent_days: ?i64 = null,
    newer_noncurrent_versions: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .noncurrent_days = "NoncurrentDays",
            .newer_noncurrent_versions = "NewerNoncurrentVersions",
        };
        return @field(mappings, field_name);
    }
};

pub const NoncurrentVersionTransition = struct {
    noncurrent_days: ?i64 = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .noncurrent_days = "NoncurrentDays",
            .storage_class = "StorageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const Transition = struct {
    date: ?i64 = null,
    days: ?i64 = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date = "Date",
            .days = "Days",
            .storage_class = "StorageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleRuleFilter = struct {
    prefix: ?[]const u8 = null,
    tag: ?S3Tag = null,
    @"and": ?LifecycleRuleAndOperator = null,
    object_size_greater_than: ?i64 = null,
    object_size_less_than: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tag = "Tag",
            .@"and" = "And",
            .object_size_greater_than = "ObjectSizeGreaterThan",
            .object_size_less_than = "ObjectSizeLessThan",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleRuleAndOperator = struct {
    prefix: ?[]const u8 = null,
    tags: ?[]S3Tag = null,
    object_size_greater_than: ?i64 = null,
    object_size_less_than: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tags = "Tags",
            .object_size_greater_than = "ObjectSizeGreaterThan",
            .object_size_less_than = "ObjectSizeLessThan",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleExpiration = struct {
    date: ?i64 = null,
    days: ?i64 = null,
    expired_object_delete_marker: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date = "Date",
            .days = "Days",
            .expired_object_delete_marker = "ExpiredObjectDeleteMarker",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLambdaConfiguration = struct {
    supporting_access_point: []const u8,
    cloud_watch_metrics_enabled: ?bool = null,
    allowed_features: ?[][]const u8 = null,
    transformation_configurations: []ObjectLambdaTransformationConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .supporting_access_point = "SupportingAccessPoint",
            .cloud_watch_metrics_enabled = "CloudWatchMetricsEnabled",
            .allowed_features = "AllowedFeatures",
            .transformation_configurations = "TransformationConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLambdaTransformationConfiguration = struct {
    actions: [][]const u8,
    content_transformation: ObjectLambdaContentTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .actions = "Actions",
            .content_transformation = "ContentTransformation",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLambdaContentTransformation = union {
    aws_lambda: ?AwsLambdaTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_lambda = "AwsLambda",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaTransformation = struct {
    function_arn: []const u8,
    function_payload: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_arn = "FunctionArn",
            .function_payload = "FunctionPayload",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiRegionAccessPointReport = struct {
    name: ?[]const u8 = null,
    alias: ?[]const u8 = null,
    created_at: ?i64 = null,
    public_access_block: ?PublicAccessBlockConfiguration = null,
    status: ?[]const u8 = null,
    regions: ?[]RegionReport = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .alias = "Alias",
            .created_at = "CreatedAt",
            .public_access_block = "PublicAccessBlock",
            .status = "Status",
            .regions = "Regions",
        };
        return @field(mappings, field_name);
    }
};

pub const RegionReport = struct {
    bucket: ?[]const u8 = null,
    region: ?[]const u8 = null,
    bucket_account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .region = "Region",
            .bucket_account_id = "BucketAccountId",
        };
        return @field(mappings, field_name);
    }
};

pub const JobProgressSummary = struct {
    total_number_of_tasks: ?i64 = null,
    number_of_tasks_succeeded: ?i64 = null,
    number_of_tasks_failed: ?i64 = null,
    timers: ?JobTimers = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_number_of_tasks = "TotalNumberOfTasks",
            .number_of_tasks_succeeded = "NumberOfTasksSucceeded",
            .number_of_tasks_failed = "NumberOfTasksFailed",
            .timers = "Timers",
        };
        return @field(mappings, field_name);
    }
};

pub const JobTimers = struct {
    elapsed_time_in_active_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .elapsed_time_in_active_seconds = "ElapsedTimeInActiveSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLambdaAccessPointAlias = struct {
    value: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfiguration = struct {
    vpc_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessGrantsLocationConfiguration = struct {
    s3_sub_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_sub_prefix = "S3SubPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Grantee = struct {
    grantee_type: ?[]const u8 = null,
    grantee_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grantee_type = "GranteeType",
            .grantee_identifier = "GranteeIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const PolicyStatus = struct {
    is_public: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_public = "IsPublic",
        };
        return @field(mappings, field_name);
    }
};

pub const DeleteMultiRegionAccessPointInput = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateMultiRegionAccessPointInput = struct {
    name: []const u8,
    public_access_block: ?PublicAccessBlockConfiguration = null,
    regions: []Region,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .public_access_block = "PublicAccessBlock",
            .regions = "Regions",
        };
        return @field(mappings, field_name);
    }
};

pub const Region = struct {
    bucket: []const u8,
    bucket_account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .bucket_account_id = "BucketAccountId",
        };
        return @field(mappings, field_name);
    }
};

pub const JobManifestLocation = struct {
    object_arn: []const u8,
    object_version_id: ?[]const u8 = null,
    e_tag: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_arn = "ObjectArn",
            .object_version_id = "ObjectVersionId",
            .e_tag = "ETag",
        };
        return @field(mappings, field_name);
    }
};

pub const JobManifestGenerator = union {
    s3_job_manifest_generator: ?S3JobManifestGenerator,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_job_manifest_generator = "S3JobManifestGenerator",
        };
        return @field(mappings, field_name);
    }
};

pub const S3JobManifestGenerator = struct {
    expected_bucket_owner: ?[]const u8 = null,
    source_bucket: []const u8,
    manifest_output_location: ?S3ManifestOutputLocation = null,
    filter: ?JobManifestGeneratorFilter = null,
    enable_manifest_output: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expected_bucket_owner = "ExpectedBucketOwner",
            .source_bucket = "SourceBucket",
            .manifest_output_location = "ManifestOutputLocation",
            .filter = "Filter",
            .enable_manifest_output = "EnableManifestOutput",
        };
        return @field(mappings, field_name);
    }
};

pub const JobManifestGeneratorFilter = struct {
    eligible_for_replication: ?bool = null,
    created_after: ?i64 = null,
    created_before: ?i64 = null,
    object_replication_statuses: ?[][]const u8 = null,
    key_name_constraint: ?KeyNameConstraint = null,
    object_size_greater_than_bytes: ?i64 = null,
    object_size_less_than_bytes: ?i64 = null,
    match_any_storage_class: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .eligible_for_replication = "EligibleForReplication",
            .created_after = "CreatedAfter",
            .created_before = "CreatedBefore",
            .object_replication_statuses = "ObjectReplicationStatuses",
            .key_name_constraint = "KeyNameConstraint",
            .object_size_greater_than_bytes = "ObjectSizeGreaterThanBytes",
            .object_size_less_than_bytes = "ObjectSizeLessThanBytes",
            .match_any_storage_class = "MatchAnyStorageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyNameConstraint = struct {
    match_any_prefix: ?[][]const u8 = null,
    match_any_suffix: ?[][]const u8 = null,
    match_any_substring: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_any_prefix = "MatchAnyPrefix",
            .match_any_suffix = "MatchAnySuffix",
            .match_any_substring = "MatchAnySubstring",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ManifestOutputLocation = struct {
    expected_manifest_bucket_owner: ?[]const u8 = null,
    bucket: []const u8,
    manifest_prefix: ?[]const u8 = null,
    manifest_encryption: ?GeneratedManifestEncryption = null,
    manifest_format: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expected_manifest_bucket_owner = "ExpectedManifestBucketOwner",
            .bucket = "Bucket",
            .manifest_prefix = "ManifestPrefix",
            .manifest_encryption = "ManifestEncryption",
            .manifest_format = "ManifestFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const GeneratedManifestEncryption = struct {
    sses3: ?SSES3Encryption = null,
    ssekms: ?SSEKMSEncryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sses3 = "SSE-S3",
            .ssekms = "SSE-KMS",
        };
        return @field(mappings, field_name);
    }
};

pub const SSEKMSEncryption = struct {
    key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_id = "KeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const SSES3Encryption = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const JobReport = struct {
    bucket: ?[]const u8 = null,
    format: ?[]const u8 = null,
    enabled: bool,
    prefix: ?[]const u8 = null,
    report_scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .format = "Format",
            .enabled = "Enabled",
            .prefix = "Prefix",
            .report_scope = "ReportScope",
        };
        return @field(mappings, field_name);
    }
};

pub const JobOperation = struct {
    lambda_invoke: ?LambdaInvokeOperation = null,
    s3_put_object_copy: ?S3CopyObjectOperation = null,
    s3_put_object_acl: ?S3SetObjectAclOperation = null,
    s3_put_object_tagging: ?S3SetObjectTaggingOperation = null,
    s3_delete_object_tagging: ?S3DeleteObjectTaggingOperation = null,
    s3_initiate_restore_object: ?S3InitiateRestoreObjectOperation = null,
    s3_put_object_legal_hold: ?S3SetObjectLegalHoldOperation = null,
    s3_put_object_retention: ?S3SetObjectRetentionOperation = null,
    s3_replicate_object: ?S3ReplicateObjectOperation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_invoke = "LambdaInvoke",
            .s3_put_object_copy = "S3PutObjectCopy",
            .s3_put_object_acl = "S3PutObjectAcl",
            .s3_put_object_tagging = "S3PutObjectTagging",
            .s3_delete_object_tagging = "S3DeleteObjectTagging",
            .s3_initiate_restore_object = "S3InitiateRestoreObject",
            .s3_put_object_legal_hold = "S3PutObjectLegalHold",
            .s3_put_object_retention = "S3PutObjectRetention",
            .s3_replicate_object = "S3ReplicateObject",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ReplicateObjectOperation = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const S3SetObjectRetentionOperation = struct {
    bypass_governance_retention: ?bool = null,
    retention: S3Retention,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bypass_governance_retention = "BypassGovernanceRetention",
            .retention = "Retention",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Retention = struct {
    retain_until_date: ?i64 = null,
    mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .retain_until_date = "RetainUntilDate",
            .mode = "Mode",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SetObjectLegalHoldOperation = struct {
    legal_hold: S3ObjectLockLegalHold,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .legal_hold = "LegalHold",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ObjectLockLegalHold = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const S3InitiateRestoreObjectOperation = struct {
    expiration_in_days: ?i64 = null,
    glacier_job_tier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expiration_in_days = "ExpirationInDays",
            .glacier_job_tier = "GlacierJobTier",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DeleteObjectTaggingOperation = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const S3SetObjectTaggingOperation = struct {
    tag_set: ?[]S3Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_set = "TagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SetObjectAclOperation = struct {
    access_control_policy: ?S3AccessControlPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_control_policy = "AccessControlPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const S3AccessControlPolicy = struct {
    access_control_list: ?S3AccessControlList = null,
    canned_access_control_list: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_control_list = "AccessControlList",
            .canned_access_control_list = "CannedAccessControlList",
        };
        return @field(mappings, field_name);
    }
};

pub const S3AccessControlList = struct {
    owner: S3ObjectOwner,
    grants: ?[]S3Grant = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner = "Owner",
            .grants = "Grants",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Grant = struct {
    grantee: ?S3Grantee = null,
    permission: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grantee = "Grantee",
            .permission = "Permission",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Grantee = struct {
    type_identifier: ?[]const u8 = null,
    identifier: ?[]const u8 = null,
    display_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type_identifier = "TypeIdentifier",
            .identifier = "Identifier",
            .display_name = "DisplayName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ObjectOwner = struct {
    id: ?[]const u8 = null,
    display_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "ID",
            .display_name = "DisplayName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3CopyObjectOperation = struct {
    target_resource: ?[]const u8 = null,
    canned_access_control_list: ?[]const u8 = null,
    access_control_grants: ?[]S3Grant = null,
    metadata_directive: ?[]const u8 = null,
    modified_since_constraint: ?i64 = null,
    new_object_metadata: ?S3ObjectMetadata = null,
    new_object_tagging: ?[]S3Tag = null,
    redirect_location: ?[]const u8 = null,
    requester_pays: ?bool = null,
    storage_class: ?[]const u8 = null,
    un_modified_since_constraint: ?i64 = null,
    sse_aws_kms_key_id: ?[]const u8 = null,
    target_key_prefix: ?[]const u8 = null,
    object_lock_legal_hold_status: ?[]const u8 = null,
    object_lock_mode: ?[]const u8 = null,
    object_lock_retain_until_date: ?i64 = null,
    bucket_key_enabled: ?bool = null,
    checksum_algorithm: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_resource = "TargetResource",
            .canned_access_control_list = "CannedAccessControlList",
            .access_control_grants = "AccessControlGrants",
            .metadata_directive = "MetadataDirective",
            .modified_since_constraint = "ModifiedSinceConstraint",
            .new_object_metadata = "NewObjectMetadata",
            .new_object_tagging = "NewObjectTagging",
            .redirect_location = "RedirectLocation",
            .requester_pays = "RequesterPays",
            .storage_class = "StorageClass",
            .un_modified_since_constraint = "UnModifiedSinceConstraint",
            .sse_aws_kms_key_id = "SSEAwsKmsKeyId",
            .target_key_prefix = "TargetKeyPrefix",
            .object_lock_legal_hold_status = "ObjectLockLegalHoldStatus",
            .object_lock_mode = "ObjectLockMode",
            .object_lock_retain_until_date = "ObjectLockRetainUntilDate",
            .bucket_key_enabled = "BucketKeyEnabled",
            .checksum_algorithm = "ChecksumAlgorithm",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ObjectMetadata = struct {
    cache_control: ?[]const u8 = null,
    content_disposition: ?[]const u8 = null,
    content_encoding: ?[]const u8 = null,
    content_language: ?[]const u8 = null,
    user_metadata: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    content_length: ?i64 = null,
    content_md5: ?[]const u8 = null,
    content_type: ?[]const u8 = null,
    http_expires_date: ?i64 = null,
    requester_charged: ?bool = null,
    sse_algorithm: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_control = "CacheControl",
            .content_disposition = "ContentDisposition",
            .content_encoding = "ContentEncoding",
            .content_language = "ContentLanguage",
            .user_metadata = "UserMetadata",
            .content_length = "ContentLength",
            .content_md5 = "ContentMD5",
            .content_type = "ContentType",
            .http_expires_date = "HttpExpiresDate",
            .requester_charged = "RequesterCharged",
            .sse_algorithm = "SSEAlgorithm",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "user_metadata", field_name))
            return try serializeMap(self.user_metadata, self.fieldNameFor("user_metadata"), options, out_stream);
        return false;
    }
};

pub const LambdaInvokeOperation = struct {
    function_arn: ?[]const u8 = null,
    invocation_schema_version: ?[]const u8 = null,
    user_arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_arn = "FunctionArn",
            .invocation_schema_version = "InvocationSchemaVersion",
            .user_arguments = "UserArguments",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "user_arguments", field_name))
            return try serializeMap(self.user_arguments, self.fieldNameFor("user_arguments"), options, out_stream);
        return false;
    }
};

pub const JobManifest = struct {
    spec: JobManifestSpec,
    location: JobManifestLocation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .spec = "Spec",
            .location = "Location",
        };
        return @field(mappings, field_name);
    }
};

pub const JobManifestSpec = struct {
    format: []const u8,
    fields: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .fields = "Fields",
        };
        return @field(mappings, field_name);
    }
};
