const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-25";
pub const sdk_id: []const u8 = "S3Outposts";
pub const arn_namespace: ?[]const u8 = "s3-outposts";
pub const endpoint_prefix: []const u8 = "s3-outposts";
pub const sigv4_name: []const u8 = "s3-outposts";
pub const name: []const u8 = "S3Outposts";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-25",
    sdk_id: []const u8 = "S3Outposts",
    arn_namespace: ?[]const u8 = "s3-outposts",
    endpoint_prefix: []const u8 = "s3-outposts",
    sigv4_name: []const u8 = "s3-outposts",
    name: []const u8 = "S3Outposts",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/S3Outposts/CreateEndpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEndpoint",
    Request: type = struct {
        outpost_id: []const u8,
        subnet_id: []const u8,
        security_group_id: []const u8,
        access_type: ?[]const u8 = null,
        customer_owned_ipv4_pool: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outpost_id = "OutpostId",
                .subnet_id = "SubnetId",
                .security_group_id = "SecurityGroupId",
                .access_type = "AccessType",
                .customer_owned_ipv4_pool = "CustomerOwnedIpv4Pool",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_endpoint };
        }
    },
    Response: type = struct {
        endpoint_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        OutpostOffline,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_endpoint: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/S3Outposts/DeleteEndpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEndpoint",
    Request: type = struct {
        endpoint_id: []const u8,
        outpost_id: []const u8,

        pub const http_query = .{
            .endpoint_id = "endpointId",
            .outpost_id = "outpostId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_id = "EndpointId",
                .outpost_id = "OutpostId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_endpoint };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        OutpostOffline,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_endpoints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/S3Outposts/ListEndpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEndpoints",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_endpoints };
        }
    },
    Response: type = struct {
        endpoints: ?[]Endpoint = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "Endpoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_outposts_with_s3: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/S3Outposts/ListOutpostsWithS3",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOutpostsWithS3",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_outposts_with_s3) } {
            return .{ .service_metadata = service_metadata, .action = list_outposts_with_s3 };
        }
    },
    Response: type = struct {
        outposts: ?[]struct {
            outpost_arn: ?[]const u8 = null,
            s3_outpost_arn: ?[]const u8 = null,
            outpost_id: ?[]const u8 = null,
            owner_id: ?[]const u8 = null,
            capacity_in_bytes: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .outpost_arn = "OutpostArn",
                    .s3_outpost_arn = "S3OutpostArn",
                    .outpost_id = "OutpostId",
                    .owner_id = "OwnerId",
                    .capacity_in_bytes = "CapacityInBytes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outposts = "Outposts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_shared_endpoints: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/S3Outposts/ListSharedEndpoints",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSharedEndpoints",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        outpost_id: []const u8,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .outpost_id = "outpostId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .outpost_id = "OutpostId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_shared_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_shared_endpoints };
        }
    },
    Response: type = struct {
        endpoints: ?[]Endpoint = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "Endpoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Endpoint = struct {
    endpoint_arn: ?[]const u8 = null,
    outposts_id: ?[]const u8 = null,
    cidr_block: ?[]const u8 = null,
    status: ?[]const u8 = null,
    creation_time: ?i64 = null,
    network_interfaces: ?[]NetworkInterface = null,
    vpc_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    security_group_id: ?[]const u8 = null,
    access_type: ?[]const u8 = null,
    customer_owned_ipv4_pool: ?[]const u8 = null,
    failed_reason: ?FailedReason = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_arn = "EndpointArn",
            .outposts_id = "OutpostsId",
            .cidr_block = "CidrBlock",
            .status = "Status",
            .creation_time = "CreationTime",
            .network_interfaces = "NetworkInterfaces",
            .vpc_id = "VpcId",
            .subnet_id = "SubnetId",
            .security_group_id = "SecurityGroupId",
            .access_type = "AccessType",
            .customer_owned_ipv4_pool = "CustomerOwnedIpv4Pool",
            .failed_reason = "FailedReason",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedReason = struct {
    error_code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterface = struct {
    network_interface_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .network_interface_id = "NetworkInterfaceId",
        };
        return @field(mappings, field_name);
    }
};
