const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-11-07";
pub const sdk_id: []const u8 = "SageMaker A2I Runtime";
pub const arn_namespace: ?[]const u8 = "sagemaker";
pub const endpoint_prefix: []const u8 = "a2i-runtime.sagemaker";
pub const sigv4_name: []const u8 = "sagemaker";
pub const name: []const u8 = "AmazonSageMakerA2IRuntime";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-11-07",
    sdk_id: []const u8 = "SageMaker A2I Runtime",
    arn_namespace: ?[]const u8 = "sagemaker",
    endpoint_prefix: []const u8 = "a2i-runtime.sagemaker",
    sigv4_name: []const u8 = "sagemaker",
    name: []const u8 = "AmazonSageMakerA2IRuntime",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_human_loop: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/human-loops/{HumanLoopName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteHumanLoop",
    Request: type = struct {
        human_loop_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_loop_name = "HumanLoopName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_human_loop) } {
            return .{ .service_metadata = service_metadata, .action = delete_human_loop };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_human_loop: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/human-loops/{HumanLoopName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeHumanLoop",
    Request: type = struct {
        human_loop_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_loop_name = "HumanLoopName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_human_loop) } {
            return .{ .service_metadata = service_metadata, .action = describe_human_loop };
        }
    },
    Response: type = struct {
        creation_time: i64,
        failure_reason: ?[]const u8 = null,
        failure_code: ?[]const u8 = null,
        human_loop_status: []const u8,
        human_loop_name: []const u8,
        human_loop_arn: []const u8,
        flow_definition_arn: []const u8,
        human_loop_output: ?struct {
            output_s3_uri: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .output_s3_uri = "OutputS3Uri",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "CreationTime",
                .failure_reason = "FailureReason",
                .failure_code = "FailureCode",
                .human_loop_status = "HumanLoopStatus",
                .human_loop_name = "HumanLoopName",
                .human_loop_arn = "HumanLoopArn",
                .flow_definition_arn = "FlowDefinitionArn",
                .human_loop_output = "HumanLoopOutput",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_human_loops: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/human-loops",
        .success_code = 200,
    };

    action_name: []const u8 = "ListHumanLoops",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        flow_definition_arn: []const u8,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .creation_time_after = "CreationTimeAfter",
            .creation_time_before = "CreationTimeBefore",
            .flow_definition_arn = "FlowDefinitionArn",
            .sort_order = "SortOrder",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .flow_definition_arn = "FlowDefinitionArn",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_human_loops) } {
            return .{ .service_metadata = service_metadata, .action = list_human_loops };
        }
    },
    Response: type = struct {
        human_loop_summaries: []struct {
            human_loop_name: ?[]const u8 = null,
            human_loop_status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            failure_reason: ?[]const u8 = null,
            flow_definition_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .human_loop_name = "HumanLoopName",
                    .human_loop_status = "HumanLoopStatus",
                    .creation_time = "CreationTime",
                    .failure_reason = "FailureReason",
                    .flow_definition_arn = "FlowDefinitionArn",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_loop_summaries = "HumanLoopSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_human_loop: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/human-loops",
        .success_code = 200,
    };

    action_name: []const u8 = "StartHumanLoop",
    Request: type = struct {
        human_loop_name: []const u8,
        flow_definition_arn: []const u8,
        human_loop_input: struct {
            input_content: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .input_content = "InputContent",
                };
                return @field(mappings, field_name);
            }
        },
        data_attributes: ?struct {
            content_classifiers: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .content_classifiers = "ContentClassifiers",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_loop_name = "HumanLoopName",
                .flow_definition_arn = "FlowDefinitionArn",
                .human_loop_input = "HumanLoopInput",
                .data_attributes = "DataAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_human_loop) } {
            return .{ .service_metadata = service_metadata, .action = start_human_loop };
        }
    },
    Response: type = struct {
        human_loop_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_loop_arn = "HumanLoopArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_human_loop: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/human-loops/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopHumanLoop",
    Request: type = struct {
        human_loop_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_loop_name = "HumanLoopName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_human_loop) } {
            return .{ .service_metadata = service_metadata, .action = stop_human_loop };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
