const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-01";
pub const sdk_id: []const u8 = "SageMaker FeatureStore Runtime";
pub const arn_namespace: ?[]const u8 = "sagemaker";
pub const endpoint_prefix: []const u8 = "featurestore-runtime.sagemaker";
pub const sigv4_name: []const u8 = "sagemaker";
pub const name: []const u8 = "AmazonSageMakerFeatureStoreRuntime";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-01",
    sdk_id: []const u8 = "SageMaker FeatureStore Runtime",
    arn_namespace: ?[]const u8 = "sagemaker",
    endpoint_prefix: []const u8 = "featurestore-runtime.sagemaker",
    sigv4_name: []const u8 = "sagemaker",
    name: []const u8 = "AmazonSageMakerFeatureStoreRuntime",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_get_record: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/BatchGetRecord",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetRecord",
    Request: type = struct {
        identifiers: []BatchGetRecordIdentifier,
        expiration_time_response: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifiers = "Identifiers",
                .expiration_time_response = "ExpirationTimeResponse",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_record) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_record };
        }
    },
    Response: type = struct {
        records: []struct {
            feature_group_name: []const u8,
            record_identifier_value_as_string: []const u8,
            record: []FeatureValue,
            expires_at: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .feature_group_name = "FeatureGroupName",
                    .record_identifier_value_as_string = "RecordIdentifierValueAsString",
                    .record = "Record",
                    .expires_at = "ExpiresAt",
                };
                return @field(mappings, field_name);
            }
        },
        errors: []struct {
            feature_group_name: []const u8,
            record_identifier_value_as_string: []const u8,
            error_code: []const u8,
            error_message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .feature_group_name = "FeatureGroupName",
                    .record_identifier_value_as_string = "RecordIdentifierValueAsString",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        },
        unprocessed_identifiers: []BatchGetRecordIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records = "Records",
                .errors = "Errors",
                .unprocessed_identifiers = "UnprocessedIdentifiers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessForbidden,
        InternalFailure,
        ServiceUnavailable,
        ValidationError,
    },
} = .{};
pub const delete_record: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/FeatureGroup/{FeatureGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRecord",
    Request: type = struct {
        feature_group_name: []const u8,
        record_identifier_value_as_string: []const u8,
        event_time: []const u8,
        target_stores: ?[][]const u8 = null,
        deletion_mode: ?[]const u8 = null,

        pub const http_query = .{
            .record_identifier_value_as_string = "RecordIdentifierValueAsString",
            .event_time = "EventTime",
            .target_stores = "TargetStores",
            .deletion_mode = "DeletionMode",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_name = "FeatureGroupName",
                .record_identifier_value_as_string = "RecordIdentifierValueAsString",
                .event_time = "EventTime",
                .target_stores = "TargetStores",
                .deletion_mode = "DeletionMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_record) } {
            return .{ .service_metadata = service_metadata, .action = delete_record };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessForbidden,
        InternalFailure,
        ServiceUnavailable,
        ValidationError,
    },
} = .{};
pub const get_record: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/FeatureGroup/{FeatureGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecord",
    Request: type = struct {
        feature_group_name: []const u8,
        record_identifier_value_as_string: []const u8,
        feature_names: ?[][]const u8 = null,
        expiration_time_response: ?[]const u8 = null,

        pub const http_query = .{
            .record_identifier_value_as_string = "RecordIdentifierValueAsString",
            .feature_names = "FeatureName",
            .expiration_time_response = "ExpirationTimeResponse",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_name = "FeatureGroupName",
                .record_identifier_value_as_string = "RecordIdentifierValueAsString",
                .feature_names = "FeatureNames",
                .expiration_time_response = "ExpirationTimeResponse",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_record) } {
            return .{ .service_metadata = service_metadata, .action = get_record };
        }
    },
    Response: type = struct {
        record: ?[]FeatureValue = null,
        expires_at: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .record = "Record",
                .expires_at = "ExpiresAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessForbidden,
        InternalFailure,
        ResourceNotFound,
        ServiceUnavailable,
        ValidationError,
    },
} = .{};
pub const put_record: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/FeatureGroup/{FeatureGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutRecord",
    Request: type = struct {
        feature_group_name: []const u8,
        record: []FeatureValue,
        target_stores: ?[][]const u8 = null,
        ttl_duration: ?struct {
            unit: []const u8,
            value: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .unit = "Unit",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_name = "FeatureGroupName",
                .record = "Record",
                .target_stores = "TargetStores",
                .ttl_duration = "TtlDuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_record) } {
            return .{ .service_metadata = service_metadata, .action = put_record };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessForbidden,
        InternalFailure,
        ServiceUnavailable,
        ValidationError,
    },
} = .{};

pub const FeatureValue = struct {
    feature_name: []const u8,
    value_as_string: ?[]const u8 = null,
    value_as_string_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .feature_name = "FeatureName",
            .value_as_string = "ValueAsString",
            .value_as_string_list = "ValueAsStringList",
        };
        return @field(mappings, field_name);
    }
};

pub const BatchGetRecordIdentifier = struct {
    feature_group_name: []const u8,
    record_identifiers_value_as_string: [][]const u8,
    feature_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .feature_group_name = "FeatureGroupName",
            .record_identifiers_value_as_string = "RecordIdentifiersValueAsString",
            .feature_names = "FeatureNames",
        };
        return @field(mappings, field_name);
    }
};
