const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-05-13";
pub const sdk_id: []const u8 = "SageMaker Runtime";
pub const arn_namespace: ?[]const u8 = "sagemaker";
pub const endpoint_prefix: []const u8 = "runtime.sagemaker";
pub const sigv4_name: []const u8 = "sagemaker";
pub const name: []const u8 = "AmazonSageMakerRuntime";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-05-13",
    sdk_id: []const u8 = "SageMaker Runtime",
    arn_namespace: ?[]const u8 = "sagemaker",
    endpoint_prefix: []const u8 = "runtime.sagemaker",
    sigv4_name: []const u8 = "sagemaker",
    name: []const u8 = "AmazonSageMakerRuntime",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const invoke_endpoint: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/endpoints/{EndpointName}/invocations",
        .success_code = 200,
    };

    action_name: []const u8 = "InvokeEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,
        body: []const u8,
        content_type: ?[]const u8 = null,
        accept: ?[]const u8 = null,
        custom_attributes: ?[]const u8 = null,
        target_model: ?[]const u8 = null,
        target_variant: ?[]const u8 = null,
        target_container_hostname: ?[]const u8 = null,
        inference_id: ?[]const u8 = null,
        enable_explanations: ?[]const u8 = null,
        inference_component_name: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .accept = "Accept",
            .custom_attributes = "X-Amzn-SageMaker-Custom-Attributes",
            .target_model = "X-Amzn-SageMaker-Target-Model",
            .target_variant = "X-Amzn-SageMaker-Target-Variant",
            .target_container_hostname = "X-Amzn-SageMaker-Target-Container-Hostname",
            .inference_id = "X-Amzn-SageMaker-Inference-Id",
            .enable_explanations = "X-Amzn-SageMaker-Enable-Explanations",
            .inference_component_name = "X-Amzn-SageMaker-Inference-Component",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .body = "Body",
                .content_type = "ContentType",
                .accept = "Accept",
                .custom_attributes = "CustomAttributes",
                .target_model = "TargetModel",
                .target_variant = "TargetVariant",
                .target_container_hostname = "TargetContainerHostname",
                .inference_id = "InferenceId",
                .enable_explanations = "EnableExplanations",
                .inference_component_name = "InferenceComponentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invoke_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = invoke_endpoint };
        }
    },
    Response: type = struct {
        body: []const u8,
        content_type: ?[]const u8 = null,
        invoked_production_variant: ?[]const u8 = null,
        custom_attributes: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .invoked_production_variant = "x-Amzn-Invoked-Production-Variant",
            .custom_attributes = "X-Amzn-SageMaker-Custom-Attributes",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "Body",
                .content_type = "ContentType",
                .invoked_production_variant = "InvokedProductionVariant",
                .custom_attributes = "CustomAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalDependency,
        InternalFailure,
        ModelError,
        ModelNotReady,
        ServiceUnavailable,
        ValidationError,
    },
} = .{};
pub const invoke_endpoint_async: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/endpoints/{EndpointName}/async-invocations",
        .success_code = 202,
    };

    action_name: []const u8 = "InvokeEndpointAsync",
    Request: type = struct {
        endpoint_name: []const u8,
        content_type: ?[]const u8 = null,
        accept: ?[]const u8 = null,
        custom_attributes: ?[]const u8 = null,
        inference_id: ?[]const u8 = null,
        input_location: []const u8,
        request_ttl_seconds: ?i64 = null,
        invocation_timeout_seconds: ?i64 = null,
        pub const http_header = .{
            .content_type = "X-Amzn-SageMaker-Content-Type",
            .accept = "X-Amzn-SageMaker-Accept",
            .custom_attributes = "X-Amzn-SageMaker-Custom-Attributes",
            .inference_id = "X-Amzn-SageMaker-Inference-Id",
            .input_location = "X-Amzn-SageMaker-InputLocation",
            .request_ttl_seconds = "X-Amzn-SageMaker-RequestTTLSeconds",
            .invocation_timeout_seconds = "X-Amzn-SageMaker-InvocationTimeoutSeconds",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .content_type = "ContentType",
                .accept = "Accept",
                .custom_attributes = "CustomAttributes",
                .inference_id = "InferenceId",
                .input_location = "InputLocation",
                .request_ttl_seconds = "RequestTTLSeconds",
                .invocation_timeout_seconds = "InvocationTimeoutSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invoke_endpoint_async) } {
            return .{ .service_metadata = service_metadata, .action = invoke_endpoint_async };
        }
    },
    Response: type = struct {
        inference_id: ?[]const u8 = null,
        output_location: ?[]const u8 = null,
        failure_location: ?[]const u8 = null,
        pub const http_header = .{
            .output_location = "X-Amzn-SageMaker-OutputLocation",
            .failure_location = "X-Amzn-SageMaker-FailureLocation",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_id = "InferenceId",
                .output_location = "OutputLocation",
                .failure_location = "FailureLocation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        ServiceUnavailable,
        ValidationError,
    },
} = .{};
pub const invoke_endpoint_with_response_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/endpoints/{EndpointName}/invocations-response-stream",
        .success_code = 200,
    };

    action_name: []const u8 = "InvokeEndpointWithResponseStream",
    Request: type = struct {
        endpoint_name: []const u8,
        body: []const u8,
        content_type: ?[]const u8 = null,
        accept: ?[]const u8 = null,
        custom_attributes: ?[]const u8 = null,
        target_variant: ?[]const u8 = null,
        target_container_hostname: ?[]const u8 = null,
        inference_id: ?[]const u8 = null,
        inference_component_name: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .accept = "X-Amzn-SageMaker-Accept",
            .custom_attributes = "X-Amzn-SageMaker-Custom-Attributes",
            .target_variant = "X-Amzn-SageMaker-Target-Variant",
            .target_container_hostname = "X-Amzn-SageMaker-Target-Container-Hostname",
            .inference_id = "X-Amzn-SageMaker-Inference-Id",
            .inference_component_name = "X-Amzn-SageMaker-Inference-Component",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .body = "Body",
                .content_type = "ContentType",
                .accept = "Accept",
                .custom_attributes = "CustomAttributes",
                .target_variant = "TargetVariant",
                .target_container_hostname = "TargetContainerHostname",
                .inference_id = "InferenceId",
                .inference_component_name = "InferenceComponentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invoke_endpoint_with_response_stream) } {
            return .{ .service_metadata = service_metadata, .action = invoke_endpoint_with_response_stream };
        }
    },
    Response: type = struct {
        body: union {
            payload_part: ?struct {
                bytes: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bytes = "Bytes",
                    };
                    return @field(mappings, field_name);
                }
            },
            model_stream_error: ?ModelStreamError,
            internal_stream_failure: ?InternalStreamFailure,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .payload_part = "PayloadPart",
                    .model_stream_error = "ModelStreamError",
                    .internal_stream_failure = "InternalStreamFailure",
                };
                return @field(mappings, field_name);
            }
        },
        content_type: ?[]const u8 = null,
        invoked_production_variant: ?[]const u8 = null,
        custom_attributes: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "X-Amzn-SageMaker-Content-Type",
            .invoked_production_variant = "x-Amzn-Invoked-Production-Variant",
            .custom_attributes = "X-Amzn-SageMaker-Custom-Attributes",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "Body",
                .content_type = "ContentType",
                .invoked_production_variant = "InvokedProductionVariant",
                .custom_attributes = "CustomAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InternalStreamFailure,
        ModelError,
        ModelStreamError,
        ServiceUnavailable,
        ValidationError,
    },
} = .{};

pub const InternalStreamFailure = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelStreamError = struct {
    message: ?[]const u8 = null,
    error_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
            .error_code = "ErrorCode",
        };
        return @field(mappings, field_name);
    }
};
