const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-09-23";
pub const sdk_id: []const u8 = "Sagemaker Edge";
pub const arn_namespace: ?[]const u8 = "sagemaker";
pub const endpoint_prefix: []const u8 = "edge.sagemaker";
pub const sigv4_name: []const u8 = "sagemaker";
pub const name: []const u8 = "AmazonSageMakerEdge";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-09-23",
    sdk_id: []const u8 = "Sagemaker Edge",
    arn_namespace: ?[]const u8 = "sagemaker",
    endpoint_prefix: []const u8 = "edge.sagemaker",
    sigv4_name: []const u8 = "sagemaker",
    name: []const u8 = "AmazonSageMakerEdge",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const get_deployments: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetDeployments",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeployments",
    Request: type = struct {
        device_name: []const u8,
        device_fleet_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_name = "DeviceName",
                .device_fleet_name = "DeviceFleetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deployments) } {
            return .{ .service_metadata = service_metadata, .action = get_deployments };
        }
    },
    Response: type = struct {
        deployments: ?[]struct {
            deployment_name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            failure_handling_policy: ?[]const u8 = null,
            definitions: ?[]struct {
                model_handle: ?[]const u8 = null,
                s3_url: ?[]const u8 = null,
                checksum: ?struct {
                    type: ?[]const u8 = null,
                    sum: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .type = "Type",
                            .sum = "Sum",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                state: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .model_handle = "ModelHandle",
                        .s3_url = "S3Url",
                        .checksum = "Checksum",
                        .state = "State",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .deployment_name = "DeploymentName",
                    .type = "Type",
                    .failure_handling_policy = "FailureHandlingPolicy",
                    .definitions = "Definitions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployments = "Deployments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
    },
} = .{};
pub const get_device_registration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetDeviceRegistration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeviceRegistration",
    Request: type = struct {
        device_name: []const u8,
        device_fleet_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_name = "DeviceName",
                .device_fleet_name = "DeviceFleetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_registration) } {
            return .{ .service_metadata = service_metadata, .action = get_device_registration };
        }
    },
    Response: type = struct {
        device_registration: ?[]const u8 = null,
        cache_ttl: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_registration = "DeviceRegistration",
                .cache_ttl = "CacheTTL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
    },
} = .{};
pub const send_heartbeat: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/SendHeartbeat",
        .success_code = 200,
    };

    action_name: []const u8 = "SendHeartbeat",
    Request: type = struct {
        agent_metrics: ?[]EdgeMetric = null,
        models: ?[]struct {
            model_name: ?[]const u8 = null,
            model_version: ?[]const u8 = null,
            latest_sample_time: ?i64 = null,
            latest_inference: ?i64 = null,
            model_metrics: ?[]EdgeMetric = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_version = "ModelVersion",
                    .latest_sample_time = "LatestSampleTime",
                    .latest_inference = "LatestInference",
                    .model_metrics = "ModelMetrics",
                };
                return @field(mappings, field_name);
            }
        } = null,
        agent_version: []const u8,
        device_name: []const u8,
        device_fleet_name: []const u8,
        deployment_result: ?struct {
            deployment_name: ?[]const u8 = null,
            deployment_status: ?[]const u8 = null,
            deployment_status_message: ?[]const u8 = null,
            deployment_start_time: ?i64 = null,
            deployment_end_time: ?i64 = null,
            deployment_models: ?[]struct {
                model_handle: ?[]const u8 = null,
                model_name: ?[]const u8 = null,
                model_version: ?[]const u8 = null,
                desired_state: ?[]const u8 = null,
                state: ?[]const u8 = null,
                status: ?[]const u8 = null,
                status_reason: ?[]const u8 = null,
                rollback_failure_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .model_handle = "ModelHandle",
                        .model_name = "ModelName",
                        .model_version = "ModelVersion",
                        .desired_state = "DesiredState",
                        .state = "State",
                        .status = "Status",
                        .status_reason = "StatusReason",
                        .rollback_failure_reason = "RollbackFailureReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .deployment_name = "DeploymentName",
                    .deployment_status = "DeploymentStatus",
                    .deployment_status_message = "DeploymentStatusMessage",
                    .deployment_start_time = "DeploymentStartTime",
                    .deployment_end_time = "DeploymentEndTime",
                    .deployment_models = "DeploymentModels",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_metrics = "AgentMetrics",
                .models = "Models",
                .agent_version = "AgentVersion",
                .device_name = "DeviceName",
                .device_fleet_name = "DeviceFleetName",
                .deployment_result = "DeploymentResult",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_heartbeat) } {
            return .{ .service_metadata = service_metadata, .action = send_heartbeat };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
    },
} = .{};

pub const EdgeMetric = struct {
    dimension: ?[]const u8 = null,
    metric_name: ?[]const u8 = null,
    value: ?f64 = null,
    timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension = "Dimension",
            .metric_name = "MetricName",
            .value = "Value",
            .timestamp = "Timestamp",
        };
        return @field(mappings, field_name);
    }
};
