const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-06-28";
pub const sdk_id: []const u8 = "savingsplans";
pub const arn_namespace: ?[]const u8 = "savingsplans";
pub const endpoint_prefix: []const u8 = "savingsplans";
pub const sigv4_name: []const u8 = "savingsplans";
pub const name: []const u8 = "AWSSavingsPlan";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-06-28",
    sdk_id: []const u8 = "savingsplans",
    arn_namespace: ?[]const u8 = "savingsplans",
    endpoint_prefix: []const u8 = "savingsplans",
    sigv4_name: []const u8 = "savingsplans",
    name: []const u8 = "AWSSavingsPlan",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_savings_plan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateSavingsPlan",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSavingsPlan",
    Request: type = struct {
        savings_plan_offering_id: []const u8,
        commitment: []const u8,
        upfront_payment_amount: ?[]const u8 = null,
        purchase_time: ?i64 = null,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plan_offering_id = "savingsPlanOfferingId",
                .commitment = "commitment",
                .upfront_payment_amount = "upfrontPaymentAmount",
                .purchase_time = "purchaseTime",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_savings_plan) } {
            return .{ .service_metadata = service_metadata, .action = create_savings_plan };
        }
    },
    Response: type = struct {
        savings_plan_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plan_id = "savingsPlanId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_queued_savings_plan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteQueuedSavingsPlan",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteQueuedSavingsPlan",
    Request: type = struct {
        savings_plan_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plan_id = "savingsPlanId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_queued_savings_plan) } {
            return .{ .service_metadata = service_metadata, .action = delete_queued_savings_plan };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const describe_savings_plan_rates: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeSavingsPlanRates",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSavingsPlanRates",
    Request: type = struct {
        savings_plan_id: []const u8,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plan_id = "savingsPlanId",
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_savings_plan_rates) } {
            return .{ .service_metadata = service_metadata, .action = describe_savings_plan_rates };
        }
    },
    Response: type = struct {
        savings_plan_id: ?[]const u8 = null,
        search_results: ?[]struct {
            rate: ?[]const u8 = null,
            currency: ?[]const u8 = null,
            unit: ?[]const u8 = null,
            product_type: ?[]const u8 = null,
            service_code: ?[]const u8 = null,
            usage_type: ?[]const u8 = null,
            operation: ?[]const u8 = null,
            properties: ?[]struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rate = "rate",
                    .currency = "currency",
                    .unit = "unit",
                    .product_type = "productType",
                    .service_code = "serviceCode",
                    .usage_type = "usageType",
                    .operation = "operation",
                    .properties = "properties",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plan_id = "savingsPlanId",
                .search_results = "searchResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const describe_savings_plans: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeSavingsPlans",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSavingsPlans",
    Request: type = struct {
        savings_plan_arns: ?[][]const u8 = null,
        savings_plan_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        states: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plan_arns = "savingsPlanArns",
                .savings_plan_ids = "savingsPlanIds",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .states = "states",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_savings_plans) } {
            return .{ .service_metadata = service_metadata, .action = describe_savings_plans };
        }
    },
    Response: type = struct {
        savings_plans: ?[]struct {
            offering_id: ?[]const u8 = null,
            savings_plan_id: ?[]const u8 = null,
            savings_plan_arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            start: ?[]const u8 = null,
            end: ?[]const u8 = null,
            state: ?[]const u8 = null,
            region: ?[]const u8 = null,
            ec2_instance_family: ?[]const u8 = null,
            savings_plan_type: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            product_types: ?[][]const u8 = null,
            currency: ?[]const u8 = null,
            commitment: ?[]const u8 = null,
            upfront_payment_amount: ?[]const u8 = null,
            recurring_payment_amount: ?[]const u8 = null,
            term_duration_in_seconds: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .offering_id = "offeringId",
                    .savings_plan_id = "savingsPlanId",
                    .savings_plan_arn = "savingsPlanArn",
                    .description = "description",
                    .start = "start",
                    .end = "end",
                    .state = "state",
                    .region = "region",
                    .ec2_instance_family = "ec2InstanceFamily",
                    .savings_plan_type = "savingsPlanType",
                    .payment_option = "paymentOption",
                    .product_types = "productTypes",
                    .currency = "currency",
                    .commitment = "commitment",
                    .upfront_payment_amount = "upfrontPaymentAmount",
                    .recurring_payment_amount = "recurringPaymentAmount",
                    .term_duration_in_seconds = "termDurationInSeconds",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plans = "savingsPlans",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const describe_savings_plans_offering_rates: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeSavingsPlansOfferingRates",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSavingsPlansOfferingRates",
    Request: type = struct {
        savings_plan_offering_ids: ?[][]const u8 = null,
        savings_plan_payment_options: ?[][]const u8 = null,
        savings_plan_types: ?[][]const u8 = null,
        products: ?[][]const u8 = null,
        service_codes: ?[][]const u8 = null,
        usage_types: ?[][]const u8 = null,
        operations: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .savings_plan_offering_ids = "savingsPlanOfferingIds",
                .savings_plan_payment_options = "savingsPlanPaymentOptions",
                .savings_plan_types = "savingsPlanTypes",
                .products = "products",
                .service_codes = "serviceCodes",
                .usage_types = "usageTypes",
                .operations = "operations",
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_savings_plans_offering_rates) } {
            return .{ .service_metadata = service_metadata, .action = describe_savings_plans_offering_rates };
        }
    },
    Response: type = struct {
        search_results: ?[]struct {
            savings_plan_offering: ?struct {
                offering_id: ?[]const u8 = null,
                payment_option: ?[]const u8 = null,
                plan_type: ?[]const u8 = null,
                duration_seconds: ?i64 = null,
                currency: ?[]const u8 = null,
                plan_description: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .offering_id = "offeringId",
                        .payment_option = "paymentOption",
                        .plan_type = "planType",
                        .duration_seconds = "durationSeconds",
                        .currency = "currency",
                        .plan_description = "planDescription",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            rate: ?[]const u8 = null,
            unit: ?[]const u8 = null,
            product_type: ?[]const u8 = null,
            service_code: ?[]const u8 = null,
            usage_type: ?[]const u8 = null,
            operation: ?[]const u8 = null,
            properties: ?[]struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .savings_plan_offering = "savingsPlanOffering",
                    .rate = "rate",
                    .unit = "unit",
                    .product_type = "productType",
                    .service_code = "serviceCode",
                    .usage_type = "usageType",
                    .operation = "operation",
                    .properties = "properties",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .search_results = "searchResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const describe_savings_plans_offerings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DescribeSavingsPlansOfferings",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSavingsPlansOfferings",
    Request: type = struct {
        offering_ids: ?[][]const u8 = null,
        payment_options: ?[][]const u8 = null,
        product_type: ?[]const u8 = null,
        plan_types: ?[][]const u8 = null,
        durations: ?[]i64 = null,
        currencies: ?[][]const u8 = null,
        descriptions: ?[][]const u8 = null,
        service_codes: ?[][]const u8 = null,
        usage_types: ?[][]const u8 = null,
        operations: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .offering_ids = "offeringIds",
                .payment_options = "paymentOptions",
                .product_type = "productType",
                .plan_types = "planTypes",
                .durations = "durations",
                .currencies = "currencies",
                .descriptions = "descriptions",
                .service_codes = "serviceCodes",
                .usage_types = "usageTypes",
                .operations = "operations",
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_savings_plans_offerings) } {
            return .{ .service_metadata = service_metadata, .action = describe_savings_plans_offerings };
        }
    },
    Response: type = struct {
        search_results: ?[]struct {
            offering_id: ?[]const u8 = null,
            product_types: ?[][]const u8 = null,
            plan_type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            payment_option: ?[]const u8 = null,
            duration_seconds: ?i64 = null,
            currency: ?[]const u8 = null,
            service_code: ?[]const u8 = null,
            usage_type: ?[]const u8 = null,
            operation: ?[]const u8 = null,
            properties: ?[]struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .offering_id = "offeringId",
                    .product_types = "productTypes",
                    .plan_type = "planType",
                    .description = "description",
                    .payment_option = "paymentOption",
                    .duration_seconds = "durationSeconds",
                    .currency = "currency",
                    .service_code = "serviceCode",
                    .usage_type = "usageType",
                    .operation = "operation",
                    .properties = "properties",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .search_results = "searchResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListTagsForResource",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/TagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UntagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
