const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-02";
pub const sdk_id: []const u8 = "schemas";
pub const arn_namespace: ?[]const u8 = "schemas";
pub const endpoint_prefix: []const u8 = "schemas";
pub const sigv4_name: []const u8 = "schemas";
pub const name: []const u8 = "schemas";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-02",
    sdk_id: []const u8 = "schemas",
    arn_namespace: ?[]const u8 = "schemas",
    endpoint_prefix: []const u8 = "schemas",
    sigv4_name: []const u8 = "schemas",
    name: []const u8 = "schemas",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_discoverer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/discoverers",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDiscoverer",
    Request: type = struct {
        description: ?[]const u8 = null,
        source_arn: []const u8,
        cross_account: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .source_arn = "SourceArn",
                .cross_account = "CrossAccount",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_discoverer) } {
            return .{ .service_metadata = service_metadata, .action = create_discoverer };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        discoverer_arn: ?[]const u8 = null,
        discoverer_id: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        cross_account: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .discoverer_arn = "DiscovererArn",
                .discoverer_id = "DiscovererId",
                .source_arn = "SourceArn",
                .state = "State",
                .cross_account = "CrossAccount",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const create_registry: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/registries/name/{RegistryName}",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRegistry",
    Request: type = struct {
        description: ?[]const u8 = null,
        registry_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .registry_name = "RegistryName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_registry) } {
            return .{ .service_metadata = service_metadata, .action = create_registry };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .registry_arn = "RegistryArn",
                .registry_name = "RegistryName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const create_schema: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/registries/name/{RegistryName}/schemas/name/{SchemaName}",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSchema",
    Request: type = struct {
        content: []const u8,
        description: ?[]const u8 = null,
        registry_name: []const u8,
        schema_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .description = "Description",
                .registry_name = "RegistryName",
                .schema_name = "SchemaName",
                .tags = "tags",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_schema) } {
            return .{ .service_metadata = service_metadata, .action = create_schema };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        last_modified: ?i64 = null,
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        schema_version: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        type: ?[]const u8 = null,
        version_created_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .last_modified = "LastModified",
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .schema_version = "SchemaVersion",
                .tags = "tags",
                .type = "Type",
                .version_created_date = "VersionCreatedDate",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
    },
} = .{};
pub const delete_discoverer: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/discoverers/id/{DiscovererId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDiscoverer",
    Request: type = struct {
        discoverer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discoverer_id = "DiscovererId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_discoverer) } {
            return .{ .service_metadata = service_metadata, .action = delete_discoverer };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const delete_registry: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/registries/name/{RegistryName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRegistry",
    Request: type = struct {
        registry_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_registry) } {
            return .{ .service_metadata = service_metadata, .action = delete_registry };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const delete_resource_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/policy",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        registry_name: ?[]const u8 = null,

        pub const http_query = .{
            .registry_name = "registryName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const delete_schema: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/registries/name/{RegistryName}/schemas/name/{SchemaName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSchema",
    Request: type = struct {
        registry_name: []const u8,
        schema_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .schema_name = "SchemaName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schema) } {
            return .{ .service_metadata = service_metadata, .action = delete_schema };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const delete_schema_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/registries/name/{RegistryName}/schemas/name/{SchemaName}/version/{SchemaVersion}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSchemaVersion",
    Request: type = struct {
        registry_name: []const u8,
        schema_name: []const u8,
        schema_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .schema_name = "SchemaName",
                .schema_version = "SchemaVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schema_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_schema_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const describe_code_binding: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/registries/name/{RegistryName}/schemas/name/{SchemaName}/language/{Language}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCodeBinding",
    Request: type = struct {
        language: []const u8,
        registry_name: []const u8,
        schema_name: []const u8,
        schema_version: ?[]const u8 = null,

        pub const http_query = .{
            .schema_version = "schemaVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language = "Language",
                .registry_name = "RegistryName",
                .schema_name = "SchemaName",
                .schema_version = "SchemaVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_code_binding) } {
            return .{ .service_metadata = service_metadata, .action = describe_code_binding };
        }
    },
    Response: type = struct {
        creation_date: ?i64 = null,
        last_modified: ?i64 = null,
        schema_version: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_date = "CreationDate",
                .last_modified = "LastModified",
                .schema_version = "SchemaVersion",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_discoverer: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/discoverers/id/{DiscovererId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDiscoverer",
    Request: type = struct {
        discoverer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discoverer_id = "DiscovererId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_discoverer) } {
            return .{ .service_metadata = service_metadata, .action = describe_discoverer };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        discoverer_arn: ?[]const u8 = null,
        discoverer_id: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        cross_account: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .discoverer_arn = "DiscovererArn",
                .discoverer_id = "DiscovererId",
                .source_arn = "SourceArn",
                .state = "State",
                .cross_account = "CrossAccount",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const describe_registry: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/registries/name/{RegistryName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRegistry",
    Request: type = struct {
        registry_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_registry) } {
            return .{ .service_metadata = service_metadata, .action = describe_registry };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .registry_arn = "RegistryArn",
                .registry_name = "RegistryName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const describe_schema: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/registries/name/{RegistryName}/schemas/name/{SchemaName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSchema",
    Request: type = struct {
        registry_name: []const u8,
        schema_name: []const u8,
        schema_version: ?[]const u8 = null,

        pub const http_query = .{
            .schema_version = "schemaVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .schema_name = "SchemaName",
                .schema_version = "SchemaVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_schema) } {
            return .{ .service_metadata = service_metadata, .action = describe_schema };
        }
    },
    Response: type = struct {
        content: ?[]const u8 = null,
        description: ?[]const u8 = null,
        last_modified: ?i64 = null,
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        schema_version: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        type: ?[]const u8 = null,
        version_created_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .description = "Description",
                .last_modified = "LastModified",
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .schema_version = "SchemaVersion",
                .tags = "tags",
                .type = "Type",
                .version_created_date = "VersionCreatedDate",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const export_schema: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/registries/name/{RegistryName}/schemas/name/{SchemaName}/export",
        .success_code = 200,
    };

    action_name: []const u8 = "ExportSchema",
    Request: type = struct {
        registry_name: []const u8,
        schema_name: []const u8,
        schema_version: ?[]const u8 = null,
        type: []const u8,

        pub const http_query = .{
            .schema_version = "schemaVersion",
            .type = "type",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .schema_name = "SchemaName",
                .schema_version = "SchemaVersion",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_schema) } {
            return .{ .service_metadata = service_metadata, .action = export_schema };
        }
    },
    Response: type = struct {
        content: ?[]const u8 = null,
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        schema_version: ?[]const u8 = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .schema_version = "SchemaVersion",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_code_binding_source: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/registries/name/{RegistryName}/schemas/name/{SchemaName}/language/{Language}/source",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCodeBindingSource",
    Request: type = struct {
        language: []const u8,
        registry_name: []const u8,
        schema_name: []const u8,
        schema_version: ?[]const u8 = null,

        pub const http_query = .{
            .schema_version = "schemaVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language = "Language",
                .registry_name = "RegistryName",
                .schema_name = "SchemaName",
                .schema_version = "SchemaVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_code_binding_source) } {
            return .{ .service_metadata = service_metadata, .action = get_code_binding_source };
        }
    },
    Response: type = struct {
        body: ?[]const u8 = null,

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "Body",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_discovered_schema: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/discover",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDiscoveredSchema",
    Request: type = struct {
        events: [][]const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "Events",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_discovered_schema) } {
            return .{ .service_metadata = service_metadata, .action = get_discovered_schema };
        }
    },
    Response: type = struct {
        content: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content = "Content",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const get_resource_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        registry_name: ?[]const u8 = null,

        pub const http_query = .{
            .registry_name = "registryName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const list_discoverers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/discoverers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDiscoverers",
    Request: type = struct {
        discoverer_id_prefix: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,
        source_arn_prefix: ?[]const u8 = null,

        pub const http_query = .{
            .discoverer_id_prefix = "discovererIdPrefix",
            .limit = "limit",
            .next_token = "nextToken",
            .source_arn_prefix = "sourceArnPrefix",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discoverer_id_prefix = "DiscovererIdPrefix",
                .limit = "Limit",
                .next_token = "NextToken",
                .source_arn_prefix = "SourceArnPrefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_discoverers) } {
            return .{ .service_metadata = service_metadata, .action = list_discoverers };
        }
    },
    Response: type = struct {
        discoverers: ?[]struct {
            discoverer_arn: ?[]const u8 = null,
            discoverer_id: ?[]const u8 = null,
            source_arn: ?[]const u8 = null,
            state: ?[]const u8 = null,
            cross_account: ?bool = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .discoverer_arn = "DiscovererArn",
                    .discoverer_id = "DiscovererId",
                    .source_arn = "SourceArn",
                    .state = "State",
                    .cross_account = "CrossAccount",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discoverers = "Discoverers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const list_registries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/registries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRegistries",
    Request: type = struct {
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,
        registry_name_prefix: ?[]const u8 = null,
        scope: ?[]const u8 = null,

        pub const http_query = .{
            .limit = "limit",
            .next_token = "nextToken",
            .registry_name_prefix = "registryNamePrefix",
            .scope = "scope",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .next_token = "NextToken",
                .registry_name_prefix = "RegistryNamePrefix",
                .scope = "Scope",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_registries) } {
            return .{ .service_metadata = service_metadata, .action = list_registries };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        registries: ?[]struct {
            registry_arn: ?[]const u8 = null,
            registry_name: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registry_arn = "RegistryArn",
                    .registry_name = "RegistryName",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .registries = "Registries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const list_schemas: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/registries/name/{RegistryName}/schemas",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSchemas",
    Request: type = struct {
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,
        registry_name: []const u8,
        schema_name_prefix: ?[]const u8 = null,

        pub const http_query = .{
            .limit = "limit",
            .next_token = "nextToken",
            .schema_name_prefix = "schemaNamePrefix",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .next_token = "NextToken",
                .registry_name = "RegistryName",
                .schema_name_prefix = "SchemaNamePrefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schemas) } {
            return .{ .service_metadata = service_metadata, .action = list_schemas };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        schemas: ?[]struct {
            last_modified: ?i64 = null,
            schema_arn: ?[]const u8 = null,
            schema_name: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            version_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .last_modified = "LastModified",
                    .schema_arn = "SchemaArn",
                    .schema_name = "SchemaName",
                    .tags = "tags",
                    .version_count = "VersionCount",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .schemas = "Schemas",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const list_schema_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/registries/name/{RegistryName}/schemas/name/{SchemaName}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSchemaVersions",
    Request: type = struct {
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,
        registry_name: []const u8,
        schema_name: []const u8,

        pub const http_query = .{
            .limit = "limit",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .limit = "Limit",
                .next_token = "NextToken",
                .registry_name = "RegistryName",
                .schema_name = "SchemaName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schema_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_schema_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        schema_versions: ?[]struct {
            schema_arn: ?[]const u8 = null,
            schema_name: ?[]const u8 = null,
            schema_version: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .schema_arn = "SchemaArn",
                    .schema_name = "SchemaName",
                    .schema_version = "SchemaVersion",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .schema_versions = "SchemaVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const put_code_binding: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/registries/name/{RegistryName}/schemas/name/{SchemaName}/language/{Language}",
        .success_code = 202,
    };

    action_name: []const u8 = "PutCodeBinding",
    Request: type = struct {
        language: []const u8,
        registry_name: []const u8,
        schema_name: []const u8,
        schema_version: ?[]const u8 = null,

        pub const http_query = .{
            .schema_version = "schemaVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language = "Language",
                .registry_name = "RegistryName",
                .schema_name = "SchemaName",
                .schema_version = "SchemaVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_code_binding) } {
            return .{ .service_metadata = service_metadata, .action = put_code_binding };
        }
    },
    Response: type = struct {
        creation_date: ?i64 = null,
        last_modified: ?i64 = null,
        schema_version: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_date = "CreationDate",
                .last_modified = "LastModified",
                .schema_version = "SchemaVersion",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        Gone,
        InternalServerError,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const put_resource_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        policy: []const u8,
        registry_name: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .registry_name = "registryName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
                .registry_name = "RegistryName",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
                .revision_id = "RevisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        PreconditionFailed,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const search_schemas: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/registries/name/{RegistryName}/schemas/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchSchemas",
    Request: type = struct {
        keywords: []const u8,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,
        registry_name: []const u8,

        pub const http_query = .{
            .keywords = "keywords",
            .limit = "limit",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .keywords = "Keywords",
                .limit = "Limit",
                .next_token = "NextToken",
                .registry_name = "RegistryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_schemas) } {
            return .{ .service_metadata = service_metadata, .action = search_schemas };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        schemas: ?[]struct {
            registry_name: ?[]const u8 = null,
            schema_arn: ?[]const u8 = null,
            schema_name: ?[]const u8 = null,
            schema_versions: ?[]struct {
                created_date: ?i64 = null,
                schema_version: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .created_date = "CreatedDate",
                        .schema_version = "SchemaVersion",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registry_name = "RegistryName",
                    .schema_arn = "SchemaArn",
                    .schema_name = "SchemaName",
                    .schema_versions = "SchemaVersions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .schemas = "Schemas",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const start_discoverer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/discoverers/id/{DiscovererId}/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartDiscoverer",
    Request: type = struct {
        discoverer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discoverer_id = "DiscovererId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_discoverer) } {
            return .{ .service_metadata = service_metadata, .action = start_discoverer };
        }
    },
    Response: type = struct {
        discoverer_id: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discoverer_id = "DiscovererId",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const stop_discoverer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/discoverers/id/{DiscovererId}/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopDiscoverer",
    Request: type = struct {
        discoverer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discoverer_id = "DiscovererId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_discoverer) } {
            return .{ .service_metadata = service_metadata, .action = stop_discoverer };
        }
    },
    Response: type = struct {
        discoverer_id: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .discoverer_id = "DiscovererId",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const update_discoverer: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/discoverers/id/{DiscovererId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDiscoverer",
    Request: type = struct {
        description: ?[]const u8 = null,
        discoverer_id: []const u8,
        cross_account: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .discoverer_id = "DiscovererId",
                .cross_account = "CrossAccount",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_discoverer) } {
            return .{ .service_metadata = service_metadata, .action = update_discoverer };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        discoverer_arn: ?[]const u8 = null,
        discoverer_id: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,
        cross_account: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .discoverer_arn = "DiscovererArn",
                .discoverer_id = "DiscovererId",
                .source_arn = "SourceArn",
                .state = "State",
                .cross_account = "CrossAccount",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const update_registry: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/registries/name/{RegistryName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRegistry",
    Request: type = struct {
        description: ?[]const u8 = null,
        registry_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .registry_name = "RegistryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_registry) } {
            return .{ .service_metadata = service_metadata, .action = update_registry };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .registry_arn = "RegistryArn",
                .registry_name = "RegistryName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const update_schema: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/registries/name/{RegistryName}/schemas/name/{SchemaName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSchema",
    Request: type = struct {
        client_token_id: ?[]const u8 = null,
        content: ?[]const u8 = null,
        description: ?[]const u8 = null,
        registry_name: []const u8,
        schema_name: []const u8,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token_id = "ClientTokenId",
                .content = "Content",
                .description = "Description",
                .registry_name = "RegistryName",
                .schema_name = "SchemaName",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_schema) } {
            return .{ .service_metadata = service_metadata, .action = update_schema };
        }
    },
    Response: type = struct {
        description: ?[]const u8 = null,
        last_modified: ?i64 = null,
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        schema_version: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        type: ?[]const u8 = null,
        version_created_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .last_modified = "LastModified",
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .schema_version = "SchemaVersion",
                .tags = "tags",
                .type = "Type",
                .version_created_date = "VersionCreatedDate",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
    },
} = .{};
