const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-10-17";
pub const sdk_id: []const u8 = "Secrets Manager";
pub const arn_namespace: ?[]const u8 = "secretsmanager";
pub const endpoint_prefix: []const u8 = "secretsmanager";
pub const sigv4_name: []const u8 = "secretsmanager";
pub const name: []const u8 = "secretsmanager";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-10-17",
    sdk_id: []const u8 = "Secrets Manager",
    arn_namespace: ?[]const u8 = "secretsmanager",
    endpoint_prefix: []const u8 = "secretsmanager",
    sigv4_name: []const u8 = "secretsmanager",
    name: []const u8 = "secretsmanager",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_get_secret_value: struct {
    action_name: []const u8 = "BatchGetSecretValue",
    Request: type = struct {
        secret_id_list: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id_list = "SecretIdList",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_secret_value) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_secret_value };
        }
    },
    Response: type = struct {
        secret_values: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version_id: ?[]const u8 = null,
            secret_binary: ?[]const u8 = null,
            secret_string: ?[]const u8 = null,
            version_stages: ?[][]const u8 = null,
            created_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "ARN",
                    .name = "Name",
                    .version_id = "VersionId",
                    .secret_binary = "SecretBinary",
                    .secret_string = "SecretString",
                    .version_stages = "VersionStages",
                    .created_date = "CreatedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        errors: ?[]struct {
            secret_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .secret_id = "SecretId",
                    .error_code = "ErrorCode",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_values = "SecretValues",
                .next_token = "NextToken",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DecryptionFailure,
        InternalServiceError,
        InvalidNextToken,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const cancel_rotate_secret: struct {
    action_name: []const u8 = "CancelRotateSecret",
    Request: type = struct {
        secret_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_rotate_secret) } {
            return .{ .service_metadata = service_metadata, .action = cancel_rotate_secret };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const create_secret: struct {
    action_name: []const u8 = "CreateSecret",
    Request: type = struct {
        name: []const u8,
        client_request_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        secret_binary: ?[]const u8 = null,
        secret_string: ?[]const u8 = null,
        tags: ?[]Tag = null,
        add_replica_regions: ?[]ReplicaRegionType = null,
        force_overwrite_replica_secret: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .client_request_token = "ClientRequestToken",
                .description = "Description",
                .kms_key_id = "KmsKeyId",
                .secret_binary = "SecretBinary",
                .secret_string = "SecretString",
                .tags = "Tags",
                .add_replica_regions = "AddReplicaRegions",
                .force_overwrite_replica_secret = "ForceOverwriteReplicaSecret",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_secret) } {
            return .{ .service_metadata = service_metadata, .action = create_secret };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        replication_status: ?[]ReplicationStatusType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
                .version_id = "VersionId",
                .replication_status = "ReplicationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DecryptionFailure,
        EncryptionFailure,
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        MalformedPolicyDocument,
        PreconditionNotMet,
        ResourceExists,
        ResourceNotFound,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        secret_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const delete_secret: struct {
    action_name: []const u8 = "DeleteSecret",
    Request: type = struct {
        secret_id: []const u8,
        recovery_window_in_days: ?i64 = null,
        force_delete_without_recovery: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .recovery_window_in_days = "RecoveryWindowInDays",
                .force_delete_without_recovery = "ForceDeleteWithoutRecovery",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_secret) } {
            return .{ .service_metadata = service_metadata, .action = delete_secret };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        deletion_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
                .deletion_date = "DeletionDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const describe_secret: struct {
    action_name: []const u8 = "DescribeSecret",
    Request: type = struct {
        secret_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_secret) } {
            return .{ .service_metadata = service_metadata, .action = describe_secret };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        rotation_enabled: ?bool = null,
        rotation_lambda_arn: ?[]const u8 = null,
        rotation_rules: ?RotationRulesType = null,
        last_rotated_date: ?i64 = null,
        last_changed_date: ?i64 = null,
        last_accessed_date: ?i64 = null,
        deleted_date: ?i64 = null,
        next_rotation_date: ?i64 = null,
        tags: ?[]Tag = null,
        version_ids_to_stages: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        owning_service: ?[]const u8 = null,
        created_date: ?i64 = null,
        primary_region: ?[]const u8 = null,
        replication_status: ?[]ReplicationStatusType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
                .description = "Description",
                .kms_key_id = "KmsKeyId",
                .rotation_enabled = "RotationEnabled",
                .rotation_lambda_arn = "RotationLambdaARN",
                .rotation_rules = "RotationRules",
                .last_rotated_date = "LastRotatedDate",
                .last_changed_date = "LastChangedDate",
                .last_accessed_date = "LastAccessedDate",
                .deleted_date = "DeletedDate",
                .next_rotation_date = "NextRotationDate",
                .tags = "Tags",
                .version_ids_to_stages = "VersionIdsToStages",
                .owning_service = "OwningService",
                .created_date = "CreatedDate",
                .primary_region = "PrimaryRegion",
                .replication_status = "ReplicationStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "version_ids_to_stages", field_name))
                return try serializeMap(self.version_ids_to_stages, self.fieldNameFor("version_ids_to_stages"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const get_random_password: struct {
    action_name: []const u8 = "GetRandomPassword",
    Request: type = struct {
        password_length: ?i64 = null,
        exclude_characters: ?[]const u8 = null,
        exclude_numbers: ?bool = null,
        exclude_punctuation: ?bool = null,
        exclude_uppercase: ?bool = null,
        exclude_lowercase: ?bool = null,
        include_space: ?bool = null,
        require_each_included_type: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .password_length = "PasswordLength",
                .exclude_characters = "ExcludeCharacters",
                .exclude_numbers = "ExcludeNumbers",
                .exclude_punctuation = "ExcludePunctuation",
                .exclude_uppercase = "ExcludeUppercase",
                .exclude_lowercase = "ExcludeLowercase",
                .include_space = "IncludeSpace",
                .require_each_included_type = "RequireEachIncludedType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_random_password) } {
            return .{ .service_metadata = service_metadata, .action = get_random_password };
        }
    },
    Response: type = struct {
        random_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .random_password = "RandomPassword",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
    },
} = .{};
pub const get_resource_policy: struct {
    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        secret_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        resource_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const get_secret_value: struct {
    action_name: []const u8 = "GetSecretValue",
    Request: type = struct {
        secret_id: []const u8,
        version_id: ?[]const u8 = null,
        version_stage: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .version_id = "VersionId",
                .version_stage = "VersionStage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_secret_value) } {
            return .{ .service_metadata = service_metadata, .action = get_secret_value };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        secret_binary: ?[]const u8 = null,
        secret_string: ?[]const u8 = null,
        version_stages: ?[][]const u8 = null,
        created_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
                .version_id = "VersionId",
                .secret_binary = "SecretBinary",
                .secret_string = "SecretString",
                .version_stages = "VersionStages",
                .created_date = "CreatedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DecryptionFailure,
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_secrets: struct {
    action_name: []const u8 = "ListSecrets",
    Request: type = struct {
        include_planned_deletion: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .include_planned_deletion = "IncludePlannedDeletion",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_secrets) } {
            return .{ .service_metadata = service_metadata, .action = list_secrets };
        }
    },
    Response: type = struct {
        secret_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            kms_key_id: ?[]const u8 = null,
            rotation_enabled: ?bool = null,
            rotation_lambda_arn: ?[]const u8 = null,
            rotation_rules: ?RotationRulesType = null,
            last_rotated_date: ?i64 = null,
            last_changed_date: ?i64 = null,
            last_accessed_date: ?i64 = null,
            deleted_date: ?i64 = null,
            next_rotation_date: ?i64 = null,
            tags: ?[]Tag = null,
            secret_versions_to_stages: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            owning_service: ?[]const u8 = null,
            created_date: ?i64 = null,
            primary_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "ARN",
                    .name = "Name",
                    .description = "Description",
                    .kms_key_id = "KmsKeyId",
                    .rotation_enabled = "RotationEnabled",
                    .rotation_lambda_arn = "RotationLambdaARN",
                    .rotation_rules = "RotationRules",
                    .last_rotated_date = "LastRotatedDate",
                    .last_changed_date = "LastChangedDate",
                    .last_accessed_date = "LastAccessedDate",
                    .deleted_date = "DeletedDate",
                    .next_rotation_date = "NextRotationDate",
                    .tags = "Tags",
                    .secret_versions_to_stages = "SecretVersionsToStages",
                    .owning_service = "OwningService",
                    .created_date = "CreatedDate",
                    .primary_region = "PrimaryRegion",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "secret_versions_to_stages", field_name))
                    return try serializeMap(self.secret_versions_to_stages, self.fieldNameFor("secret_versions_to_stages"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_list = "SecretList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidParameter,
        InvalidRequest,
    },
} = .{};
pub const list_secret_version_ids: struct {
    action_name: []const u8 = "ListSecretVersionIds",
    Request: type = struct {
        secret_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        include_deprecated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .include_deprecated = "IncludeDeprecated",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_secret_version_ids) } {
            return .{ .service_metadata = service_metadata, .action = list_secret_version_ids };
        }
    },
    Response: type = struct {
        versions: ?[]struct {
            version_id: ?[]const u8 = null,
            version_stages: ?[][]const u8 = null,
            last_accessed_date: ?i64 = null,
            created_date: ?i64 = null,
            kms_key_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version_id = "VersionId",
                    .version_stages = "VersionStages",
                    .last_accessed_date = "LastAccessedDate",
                    .created_date = "CreatedDate",
                    .kms_key_ids = "KmsKeyIds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .versions = "Versions",
                .next_token = "NextToken",
                .arn = "ARN",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidParameter,
        ResourceNotFound,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        secret_id: []const u8,
        resource_policy: []const u8,
        block_public_policy: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .resource_policy = "ResourcePolicy",
                .block_public_policy = "BlockPublicPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        MalformedPolicyDocument,
        PublicPolicy,
        ResourceNotFound,
    },
} = .{};
pub const put_secret_value: struct {
    action_name: []const u8 = "PutSecretValue",
    Request: type = struct {
        secret_id: []const u8,
        client_request_token: ?[]const u8 = null,
        secret_binary: ?[]const u8 = null,
        secret_string: ?[]const u8 = null,
        version_stages: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .client_request_token = "ClientRequestToken",
                .secret_binary = "SecretBinary",
                .secret_string = "SecretString",
                .version_stages = "VersionStages",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_secret_value) } {
            return .{ .service_metadata = service_metadata, .action = put_secret_value };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        version_stages: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
                .version_id = "VersionId",
                .version_stages = "VersionStages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DecryptionFailure,
        EncryptionFailure,
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
    },
} = .{};
pub const remove_regions_from_replication: struct {
    action_name: []const u8 = "RemoveRegionsFromReplication",
    Request: type = struct {
        secret_id: []const u8,
        remove_replica_regions: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .remove_replica_regions = "RemoveReplicaRegions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_regions_from_replication) } {
            return .{ .service_metadata = service_metadata, .action = remove_regions_from_replication };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        replication_status: ?[]ReplicationStatusType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .replication_status = "ReplicationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const replicate_secret_to_regions: struct {
    action_name: []const u8 = "ReplicateSecretToRegions",
    Request: type = struct {
        secret_id: []const u8,
        add_replica_regions: []ReplicaRegionType,
        force_overwrite_replica_secret: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .add_replica_regions = "AddReplicaRegions",
                .force_overwrite_replica_secret = "ForceOverwriteReplicaSecret",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replicate_secret_to_regions) } {
            return .{ .service_metadata = service_metadata, .action = replicate_secret_to_regions };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        replication_status: ?[]ReplicationStatusType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .replication_status = "ReplicationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const restore_secret: struct {
    action_name: []const u8 = "RestoreSecret",
    Request: type = struct {
        secret_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_secret) } {
            return .{ .service_metadata = service_metadata, .action = restore_secret };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const rotate_secret: struct {
    action_name: []const u8 = "RotateSecret",
    Request: type = struct {
        secret_id: []const u8,
        client_request_token: ?[]const u8 = null,
        rotation_lambda_arn: ?[]const u8 = null,
        rotation_rules: ?RotationRulesType = null,
        rotate_immediately: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .client_request_token = "ClientRequestToken",
                .rotation_lambda_arn = "RotationLambdaARN",
                .rotation_rules = "RotationRules",
                .rotate_immediately = "RotateImmediately",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rotate_secret) } {
            return .{ .service_metadata = service_metadata, .action = rotate_secret };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const stop_replication_to_replica: struct {
    action_name: []const u8 = "StopReplicationToReplica",
    Request: type = struct {
        secret_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_replication_to_replica) } {
            return .{ .service_metadata = service_metadata, .action = stop_replication_to_replica };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        secret_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        secret_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_secret: struct {
    action_name: []const u8 = "UpdateSecret",
    Request: type = struct {
        secret_id: []const u8,
        client_request_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        secret_binary: ?[]const u8 = null,
        secret_string: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .client_request_token = "ClientRequestToken",
                .description = "Description",
                .kms_key_id = "KmsKeyId",
                .secret_binary = "SecretBinary",
                .secret_string = "SecretString",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_secret) } {
            return .{ .service_metadata = service_metadata, .action = update_secret };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DecryptionFailure,
        EncryptionFailure,
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        MalformedPolicyDocument,
        PreconditionNotMet,
        ResourceExists,
        ResourceNotFound,
    },
} = .{};
pub const update_secret_version_stage: struct {
    action_name: []const u8 = "UpdateSecretVersionStage",
    Request: type = struct {
        secret_id: []const u8,
        version_stage: []const u8,
        remove_from_version_id: ?[]const u8 = null,
        move_to_version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .version_stage = "VersionStage",
                .remove_from_version_id = "RemoveFromVersionId",
                .move_to_version_id = "MoveToVersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_secret_version_stage) } {
            return .{ .service_metadata = service_metadata, .action = update_secret_version_stage };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "ARN",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const validate_resource_policy: struct {
    action_name: []const u8 = "ValidateResourcePolicy",
    Request: type = struct {
        secret_id: ?[]const u8 = null,
        resource_policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .secret_id = "SecretId",
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = validate_resource_policy };
        }
    },
    Response: type = struct {
        policy_validation_passed: ?bool = null,
        validation_errors: ?[]struct {
            check_name: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .check_name = "CheckName",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_validation_passed = "PolicyValidationPassed",
                .validation_errors = "ValidationErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidParameter,
        InvalidRequest,
        MalformedPolicyDocument,
        ResourceNotFound,
    },
} = .{};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RotationRulesType = struct {
    automatically_after_days: ?i64 = null,
    duration: ?[]const u8 = null,
    schedule_expression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .automatically_after_days = "AutomaticallyAfterDays",
            .duration = "Duration",
            .schedule_expression = "ScheduleExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationStatusType = struct {
    region: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    last_accessed_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "Region",
            .kms_key_id = "KmsKeyId",
            .status = "Status",
            .status_message = "StatusMessage",
            .last_accessed_date = "LastAccessedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicaRegionType = struct {
    region: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "Region",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    key: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};
