const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-10";
pub const sdk_id: []const u8 = "SecurityLake";
pub const arn_namespace: ?[]const u8 = "securitylake";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "securitylake";
pub const name: []const u8 = "SecurityLake";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-10",
    sdk_id: []const u8 = "SecurityLake",
    arn_namespace: ?[]const u8 = "securitylake",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "securitylake",
    name: []const u8 = "SecurityLake",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_data_lake_exception_subscription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/datalake/exceptions/subscription",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataLakeExceptionSubscription",
    Request: type = struct {
        subscription_protocol: []const u8,
        notification_endpoint: []const u8,
        exception_time_to_live: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_protocol = "subscriptionProtocol",
                .notification_endpoint = "notificationEndpoint",
                .exception_time_to_live = "exceptionTimeToLive",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_lake_exception_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_data_lake_exception_subscription };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_data_lake_exception_subscription: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/datalake/exceptions/subscription",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataLakeExceptionSubscription",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_lake_exception_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_lake_exception_subscription };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const deregister_data_lake_delegated_administrator: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/datalake/delegate",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterDataLakeDelegatedAdministrator",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_data_lake_delegated_administrator) } {
            return .{ .service_metadata = service_metadata, .action = deregister_data_lake_delegated_administrator };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_data_lake_exception_subscription: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/datalake/exceptions/subscription",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataLakeExceptionSubscription",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_lake_exception_subscription) } {
            return .{ .service_metadata = service_metadata, .action = get_data_lake_exception_subscription };
        }
    },
    Response: type = struct {
        subscription_protocol: ?[]const u8 = null,
        notification_endpoint: ?[]const u8 = null,
        exception_time_to_live: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_protocol = "subscriptionProtocol",
                .notification_endpoint = "notificationEndpoint",
                .exception_time_to_live = "exceptionTimeToLive",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_data_lake_exceptions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/datalake/exceptions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataLakeExceptions",
    Request: type = struct {
        regions: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regions = "regions",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_lake_exceptions) } {
            return .{ .service_metadata = service_metadata, .action = list_data_lake_exceptions };
        }
    },
    Response: type = struct {
        exceptions: ?[]struct {
            region: ?[]const u8 = null,
            exception: ?[]const u8 = null,
            remediation: ?[]const u8 = null,
            timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region = "region",
                    .exception = "exception",
                    .remediation = "remediation",
                    .timestamp = "timestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .exceptions = "exceptions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const register_data_lake_delegated_administrator: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/datalake/delegate",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterDataLakeDelegatedAdministrator",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_data_lake_delegated_administrator) } {
            return .{ .service_metadata = service_metadata, .action = register_data_lake_delegated_administrator };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_data_lake_exception_subscription: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/datalake/exceptions/subscription",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataLakeExceptionSubscription",
    Request: type = struct {
        subscription_protocol: []const u8,
        notification_endpoint: []const u8,
        exception_time_to_live: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_protocol = "subscriptionProtocol",
                .notification_endpoint = "notificationEndpoint",
                .exception_time_to_live = "exceptionTimeToLive",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_lake_exception_subscription) } {
            return .{ .service_metadata = service_metadata, .action = update_data_lake_exception_subscription };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};
