const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-09-08";
pub const sdk_id: []const u8 = "ServerlessApplicationRepository";
pub const arn_namespace: ?[]const u8 = "serverlessrepo";
pub const endpoint_prefix: []const u8 = "serverlessrepo";
pub const sigv4_name: []const u8 = "serverlessrepo";
pub const name: []const u8 = "ServerlessApplicationRepository";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-09-08",
    sdk_id: []const u8 = "ServerlessApplicationRepository",
    arn_namespace: ?[]const u8 = "serverlessrepo",
    endpoint_prefix: []const u8 = "serverlessrepo",
    sigv4_name: []const u8 = "serverlessrepo",
    name: []const u8 = "ServerlessApplicationRepository",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateApplication",
    Request: type = struct {
        author: []const u8,
        description: []const u8,
        home_page_url: ?[]const u8 = null,
        labels: ?[][]const u8 = null,
        license_body: ?[]const u8 = null,
        license_url: ?[]const u8 = null,
        name: []const u8,
        readme_body: ?[]const u8 = null,
        readme_url: ?[]const u8 = null,
        semantic_version: ?[]const u8 = null,
        source_code_archive_url: ?[]const u8 = null,
        source_code_url: ?[]const u8 = null,
        spdx_license_id: ?[]const u8 = null,
        template_body: ?[]const u8 = null,
        template_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .author = "author",
                .description = "description",
                .home_page_url = "homePageUrl",
                .labels = "labels",
                .license_body = "licenseBody",
                .license_url = "licenseUrl",
                .name = "name",
                .readme_body = "readmeBody",
                .readme_url = "readmeUrl",
                .semantic_version = "semanticVersion",
                .source_code_archive_url = "sourceCodeArchiveUrl",
                .source_code_url = "sourceCodeUrl",
                .spdx_license_id = "spdxLicenseId",
                .template_body = "templateBody",
                .template_url = "templateUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application) } {
            return .{ .service_metadata = service_metadata, .action = create_application };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        author: ?[]const u8 = null,
        creation_time: ?[]const u8 = null,
        description: ?[]const u8 = null,
        home_page_url: ?[]const u8 = null,
        is_verified_author: ?bool = null,
        labels: ?[][]const u8 = null,
        license_url: ?[]const u8 = null,
        name: ?[]const u8 = null,
        readme_url: ?[]const u8 = null,
        spdx_license_id: ?[]const u8 = null,
        verified_author_url: ?[]const u8 = null,
        version: ?Version = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .author = "author",
                .creation_time = "creationTime",
                .description = "description",
                .home_page_url = "homePageUrl",
                .is_verified_author = "isVerifiedAuthor",
                .labels = "labels",
                .license_url = "licenseUrl",
                .name = "name",
                .readme_url = "readmeUrl",
                .spdx_license_id = "spdxLicenseId",
                .verified_author_url = "verifiedAuthorUrl",
                .version = "version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const create_application_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/applications/{ApplicationId}/versions/{SemanticVersion}",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateApplicationVersion",
    Request: type = struct {
        application_id: []const u8,
        semantic_version: []const u8,
        source_code_archive_url: ?[]const u8 = null,
        source_code_url: ?[]const u8 = null,
        template_body: ?[]const u8 = null,
        template_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .semantic_version = "SemanticVersion",
                .source_code_archive_url = "sourceCodeArchiveUrl",
                .source_code_url = "sourceCodeUrl",
                .template_body = "templateBody",
                .template_url = "templateUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application_version) } {
            return .{ .service_metadata = service_metadata, .action = create_application_version };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        creation_time: ?[]const u8 = null,
        parameter_definitions: ?[]ParameterDefinition = null,
        required_capabilities: ?[][]const u8 = null,
        resources_supported: ?bool = null,
        semantic_version: ?[]const u8 = null,
        source_code_archive_url: ?[]const u8 = null,
        source_code_url: ?[]const u8 = null,
        template_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .creation_time = "creationTime",
                .parameter_definitions = "parameterDefinitions",
                .required_capabilities = "requiredCapabilities",
                .resources_supported = "resourcesSupported",
                .semantic_version = "semanticVersion",
                .source_code_archive_url = "sourceCodeArchiveUrl",
                .source_code_url = "sourceCodeUrl",
                .template_url = "templateUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const create_cloud_formation_change_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{ApplicationId}/changesets",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateCloudFormationChangeSet",
    Request: type = struct {
        application_id: []const u8,
        capabilities: ?[][]const u8 = null,
        change_set_name: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        notification_arns: ?[][]const u8 = null,
        parameter_overrides: ?[]struct {
            name: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        resource_types: ?[][]const u8 = null,
        rollback_configuration: ?struct {
            monitoring_time_in_minutes: ?i64 = null,
            rollback_triggers: ?[]struct {
                arn: []const u8,
                type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .arn = "arn",
                        .type = "type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .monitoring_time_in_minutes = "monitoringTimeInMinutes",
                    .rollback_triggers = "rollbackTriggers",
                };
                return @field(mappings, field_name);
            }
        } = null,
        semantic_version: ?[]const u8 = null,
        stack_name: []const u8,
        tags: ?[]struct {
            key: []const u8,
            value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        template_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .capabilities = "capabilities",
                .change_set_name = "changeSetName",
                .client_token = "clientToken",
                .description = "description",
                .notification_arns = "notificationArns",
                .parameter_overrides = "parameterOverrides",
                .resource_types = "resourceTypes",
                .rollback_configuration = "rollbackConfiguration",
                .semantic_version = "semanticVersion",
                .stack_name = "stackName",
                .tags = "tags",
                .template_id = "templateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cloud_formation_change_set) } {
            return .{ .service_metadata = service_metadata, .action = create_cloud_formation_change_set };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        change_set_id: ?[]const u8 = null,
        semantic_version: ?[]const u8 = null,
        stack_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .change_set_id = "changeSetId",
                .semantic_version = "semanticVersion",
                .stack_id = "stackId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        TooManyRequests,
    },
} = .{};
pub const create_cloud_formation_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{ApplicationId}/templates",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateCloudFormationTemplate",
    Request: type = struct {
        application_id: []const u8,
        semantic_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .semantic_version = "semanticVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cloud_formation_template) } {
            return .{ .service_metadata = service_metadata, .action = create_cloud_formation_template };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        creation_time: ?[]const u8 = null,
        expiration_time: ?[]const u8 = null,
        semantic_version: ?[]const u8 = null,
        status: ?[]const u8 = null,
        template_id: ?[]const u8 = null,
        template_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .creation_time = "creationTime",
                .expiration_time = "expirationTime",
                .semantic_version = "semanticVersion",
                .status = "status",
                .template_id = "templateId",
                .template_url = "templateUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_application: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{ApplicationId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteApplication",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_application };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_application: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplication",
    Request: type = struct {
        application_id: []const u8,
        semantic_version: ?[]const u8 = null,

        pub const http_query = .{
            .semantic_version = "semanticVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .semantic_version = "SemanticVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application) } {
            return .{ .service_metadata = service_metadata, .action = get_application };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        author: ?[]const u8 = null,
        creation_time: ?[]const u8 = null,
        description: ?[]const u8 = null,
        home_page_url: ?[]const u8 = null,
        is_verified_author: ?bool = null,
        labels: ?[][]const u8 = null,
        license_url: ?[]const u8 = null,
        name: ?[]const u8 = null,
        readme_url: ?[]const u8 = null,
        spdx_license_id: ?[]const u8 = null,
        verified_author_url: ?[]const u8 = null,
        version: ?Version = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .author = "author",
                .creation_time = "creationTime",
                .description = "description",
                .home_page_url = "homePageUrl",
                .is_verified_author = "isVerifiedAuthor",
                .labels = "labels",
                .license_url = "licenseUrl",
                .name = "name",
                .readme_url = "readmeUrl",
                .spdx_license_id = "spdxLicenseId",
                .verified_author_url = "verifiedAuthorUrl",
                .version = "version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_application_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplicationPolicy",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_application_policy };
        }
    },
    Response: type = struct {
        statements: ?[]ApplicationPolicyStatement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statements = "statements",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_cloud_formation_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCloudFormationTemplate",
    Request: type = struct {
        application_id: []const u8,
        template_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .template_id = "TemplateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cloud_formation_template) } {
            return .{ .service_metadata = service_metadata, .action = get_cloud_formation_template };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        creation_time: ?[]const u8 = null,
        expiration_time: ?[]const u8 = null,
        semantic_version: ?[]const u8 = null,
        status: ?[]const u8 = null,
        template_id: ?[]const u8 = null,
        template_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .creation_time = "creationTime",
                .expiration_time = "expirationTime",
                .semantic_version = "semanticVersion",
                .status = "status",
                .template_id = "templateId",
                .template_url = "templateUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_application_dependencies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/dependencies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplicationDependencies",
    Request: type = struct {
        application_id: []const u8,
        max_items: ?i64 = null,
        next_token: ?[]const u8 = null,
        semantic_version: ?[]const u8 = null,

        pub const http_query = .{
            .max_items = "maxItems",
            .next_token = "nextToken",
            .semantic_version = "semanticVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .max_items = "MaxItems",
                .next_token = "NextToken",
                .semantic_version = "SemanticVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_dependencies) } {
            return .{ .service_metadata = service_metadata, .action = list_application_dependencies };
        }
    },
    Response: type = struct {
        dependencies: ?[]struct {
            application_id: []const u8,
            semantic_version: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "applicationId",
                    .semantic_version = "semanticVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dependencies = "dependencies",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_applications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplications",
    Request: type = struct {
        max_items: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_items = "maxItems",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_items = "MaxItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_applications };
        }
    },
    Response: type = struct {
        applications: ?[]struct {
            application_id: []const u8,
            author: []const u8,
            creation_time: ?[]const u8 = null,
            description: []const u8,
            home_page_url: ?[]const u8 = null,
            labels: ?[][]const u8 = null,
            name: []const u8,
            spdx_license_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "applicationId",
                    .author = "author",
                    .creation_time = "creationTime",
                    .description = "description",
                    .home_page_url = "homePageUrl",
                    .labels = "labels",
                    .name = "name",
                    .spdx_license_id = "spdxLicenseId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applications = "applications",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const list_application_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{ApplicationId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplicationVersions",
    Request: type = struct {
        application_id: []const u8,
        max_items: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_items = "maxItems",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .max_items = "MaxItems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_application_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        versions: ?[]struct {
            application_id: []const u8,
            creation_time: []const u8,
            semantic_version: []const u8,
            source_code_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "applicationId",
                    .creation_time = "creationTime",
                    .semantic_version = "semanticVersion",
                    .source_code_url = "sourceCodeUrl",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .versions = "versions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_application_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/applications/{ApplicationId}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutApplicationPolicy",
    Request: type = struct {
        application_id: []const u8,
        statements: []ApplicationPolicyStatement,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .statements = "statements",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_application_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_application_policy };
        }
    },
    Response: type = struct {
        statements: ?[]ApplicationPolicyStatement = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statements = "statements",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const unshare_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications/{ApplicationId}/unshare",
        .success_code = 204,
    };

    action_name: []const u8 = "UnshareApplication",
    Request: type = struct {
        application_id: []const u8,
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .organization_id = "organizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unshare_application) } {
            return .{ .service_metadata = service_metadata, .action = unshare_application };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_application: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/applications/{ApplicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApplication",
    Request: type = struct {
        application_id: []const u8,
        author: ?[]const u8 = null,
        description: ?[]const u8 = null,
        home_page_url: ?[]const u8 = null,
        labels: ?[][]const u8 = null,
        readme_body: ?[]const u8 = null,
        readme_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .author = "author",
                .description = "description",
                .home_page_url = "homePageUrl",
                .labels = "labels",
                .readme_body = "readmeBody",
                .readme_url = "readmeUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application) } {
            return .{ .service_metadata = service_metadata, .action = update_application };
        }
    },
    Response: type = struct {
        application_id: ?[]const u8 = null,
        author: ?[]const u8 = null,
        creation_time: ?[]const u8 = null,
        description: ?[]const u8 = null,
        home_page_url: ?[]const u8 = null,
        is_verified_author: ?bool = null,
        labels: ?[][]const u8 = null,
        license_url: ?[]const u8 = null,
        name: ?[]const u8 = null,
        readme_url: ?[]const u8 = null,
        spdx_license_id: ?[]const u8 = null,
        verified_author_url: ?[]const u8 = null,
        version: ?Version = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "applicationId",
                .author = "author",
                .creation_time = "creationTime",
                .description = "description",
                .home_page_url = "homePageUrl",
                .is_verified_author = "isVerifiedAuthor",
                .labels = "labels",
                .license_url = "licenseUrl",
                .name = "name",
                .readme_url = "readmeUrl",
                .spdx_license_id = "spdxLicenseId",
                .verified_author_url = "verifiedAuthorUrl",
                .version = "version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const Version = struct {
    application_id: []const u8,
    creation_time: []const u8,
    parameter_definitions: []ParameterDefinition,
    required_capabilities: [][]const u8,
    resources_supported: bool,
    semantic_version: []const u8,
    source_code_archive_url: ?[]const u8 = null,
    source_code_url: ?[]const u8 = null,
    template_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_id = "applicationId",
            .creation_time = "creationTime",
            .parameter_definitions = "parameterDefinitions",
            .required_capabilities = "requiredCapabilities",
            .resources_supported = "resourcesSupported",
            .semantic_version = "semanticVersion",
            .source_code_archive_url = "sourceCodeArchiveUrl",
            .source_code_url = "sourceCodeUrl",
            .template_url = "templateUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterDefinition = struct {
    allowed_pattern: ?[]const u8 = null,
    allowed_values: ?[][]const u8 = null,
    constraint_description: ?[]const u8 = null,
    default_value: ?[]const u8 = null,
    description: ?[]const u8 = null,
    max_length: ?i64 = null,
    max_value: ?i64 = null,
    min_length: ?i64 = null,
    min_value: ?i64 = null,
    name: []const u8,
    no_echo: ?bool = null,
    referenced_by_resources: [][]const u8,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allowed_pattern = "allowedPattern",
            .allowed_values = "allowedValues",
            .constraint_description = "constraintDescription",
            .default_value = "defaultValue",
            .description = "description",
            .max_length = "maxLength",
            .max_value = "maxValue",
            .min_length = "minLength",
            .min_value = "minValue",
            .name = "name",
            .no_echo = "noEcho",
            .referenced_by_resources = "referencedByResources",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationPolicyStatement = struct {
    actions: [][]const u8,
    principal_org_i_ds: ?[][]const u8 = null,
    principals: [][]const u8,
    statement_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .actions = "actions",
            .principal_org_i_ds = "principalOrgIDs",
            .principals = "principals",
            .statement_id = "statementId",
        };
        return @field(mappings, field_name);
    }
};
