const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-12-10";
pub const sdk_id: []const u8 = "Service Catalog";
pub const arn_namespace: ?[]const u8 = "servicecatalog";
pub const endpoint_prefix: []const u8 = "servicecatalog";
pub const sigv4_name: []const u8 = "servicecatalog";
pub const name: []const u8 = "AWS242ServiceCatalogService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-12-10",
    sdk_id: []const u8 = "Service Catalog",
    arn_namespace: ?[]const u8 = "servicecatalog",
    endpoint_prefix: []const u8 = "servicecatalog",
    sigv4_name: []const u8 = "servicecatalog",
    name: []const u8 = "AWS242ServiceCatalogService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const accept_portfolio_share: struct {
    action_name: []const u8 = "AcceptPortfolioShare",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        portfolio_share_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .portfolio_share_type = "PortfolioShareType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_portfolio_share) } {
            return .{ .service_metadata = service_metadata, .action = accept_portfolio_share };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const associate_budget_with_resource: struct {
    action_name: []const u8 = "AssociateBudgetWithResource",
    Request: type = struct {
        budget_name: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .budget_name = "BudgetName",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_budget_with_resource) } {
            return .{ .service_metadata = service_metadata, .action = associate_budget_with_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InvalidParameters,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const associate_principal_with_portfolio: struct {
    action_name: []const u8 = "AssociatePrincipalWithPortfolio",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        principal_arn: []const u8,
        principal_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .principal_arn = "PrincipalARN",
                .principal_type = "PrincipalType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_principal_with_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = associate_principal_with_portfolio };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const associate_product_with_portfolio: struct {
    action_name: []const u8 = "AssociateProductWithPortfolio",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: []const u8,
        portfolio_id: []const u8,
        source_portfolio_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
                .portfolio_id = "PortfolioId",
                .source_portfolio_id = "SourcePortfolioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_product_with_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = associate_product_with_portfolio };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const associate_service_action_with_provisioning_artifact: struct {
    action_name: []const u8 = "AssociateServiceActionWithProvisioningArtifact",
    Request: type = struct {
        product_id: []const u8,
        provisioning_artifact_id: []const u8,
        service_action_id: []const u8,
        accept_language: ?[]const u8 = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_id = "ProductId",
                .provisioning_artifact_id = "ProvisioningArtifactId",
                .service_action_id = "ServiceActionId",
                .accept_language = "AcceptLanguage",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_service_action_with_provisioning_artifact) } {
            return .{ .service_metadata = service_metadata, .action = associate_service_action_with_provisioning_artifact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InvalidParameters,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const associate_tag_option_with_resource: struct {
    action_name: []const u8 = "AssociateTagOptionWithResource",
    Request: type = struct {
        resource_id: []const u8,
        tag_option_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tag_option_id = "TagOptionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_tag_option_with_resource) } {
            return .{ .service_metadata = service_metadata, .action = associate_tag_option_with_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InvalidParameters,
        InvalidState,
        LimitExceeded,
        ResourceNotFound,
        TagOptionNotMigrated,
    },
} = .{};
pub const batch_associate_service_action_with_provisioning_artifact: struct {
    action_name: []const u8 = "BatchAssociateServiceActionWithProvisioningArtifact",
    Request: type = struct {
        service_action_associations: []ServiceActionAssociation,
        accept_language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_action_associations = "ServiceActionAssociations",
                .accept_language = "AcceptLanguage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_associate_service_action_with_provisioning_artifact) } {
            return .{ .service_metadata = service_metadata, .action = batch_associate_service_action_with_provisioning_artifact };
        }
    },
    Response: type = struct {
        failed_service_action_associations: ?[]FailedServiceActionAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_service_action_associations = "FailedServiceActionAssociations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
    },
} = .{};
pub const batch_disassociate_service_action_from_provisioning_artifact: struct {
    action_name: []const u8 = "BatchDisassociateServiceActionFromProvisioningArtifact",
    Request: type = struct {
        service_action_associations: []ServiceActionAssociation,
        accept_language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_action_associations = "ServiceActionAssociations",
                .accept_language = "AcceptLanguage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_disassociate_service_action_from_provisioning_artifact) } {
            return .{ .service_metadata = service_metadata, .action = batch_disassociate_service_action_from_provisioning_artifact };
        }
    },
    Response: type = struct {
        failed_service_action_associations: ?[]FailedServiceActionAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_service_action_associations = "FailedServiceActionAssociations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
    },
} = .{};
pub const copy_product: struct {
    action_name: []const u8 = "CopyProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        source_product_arn: []const u8,
        target_product_id: ?[]const u8 = null,
        target_product_name: ?[]const u8 = null,
        source_provisioning_artifact_identifiers: ?[][]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        copy_options: ?[][]const u8 = null,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .source_product_arn = "SourceProductArn",
                .target_product_id = "TargetProductId",
                .target_product_name = "TargetProductName",
                .source_provisioning_artifact_identifiers = "SourceProvisioningArtifactIdentifiers",
                .copy_options = "CopyOptions",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "source_provisioning_artifact_identifiers", field_name))
                return try serializeMap(self.source_provisioning_artifact_identifiers, self.fieldNameFor("source_provisioning_artifact_identifiers"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_product) } {
            return .{ .service_metadata = service_metadata, .action = copy_product };
        }
    },
    Response: type = struct {
        copy_product_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .copy_product_token = "CopyProductToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const create_constraint: struct {
    action_name: []const u8 = "CreateConstraint",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        product_id: []const u8,
        parameters: []const u8,
        type: []const u8,
        description: ?[]const u8 = null,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .product_id = "ProductId",
                .parameters = "Parameters",
                .type = "Type",
                .description = "Description",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_constraint) } {
            return .{ .service_metadata = service_metadata, .action = create_constraint };
        }
    },
    Response: type = struct {
        constraint_detail: ?ConstraintDetail = null,
        constraint_parameters: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .constraint_detail = "ConstraintDetail",
                .constraint_parameters = "ConstraintParameters",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InvalidParameters,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_portfolio: struct {
    action_name: []const u8 = "CreatePortfolio",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        display_name: []const u8,
        description: ?[]const u8 = null,
        provider_name: []const u8,
        tags: ?[]Tag = null,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .display_name = "DisplayName",
                .description = "Description",
                .provider_name = "ProviderName",
                .tags = "Tags",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = create_portfolio };
        }
    },
    Response: type = struct {
        portfolio_detail: ?PortfolioDetail = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_detail = "PortfolioDetail",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        LimitExceeded,
        TagOptionNotMigrated,
    },
} = .{};
pub const create_portfolio_share: struct {
    action_name: []const u8 = "CreatePortfolioShare",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        account_id: ?[]const u8 = null,
        organization_node: ?OrganizationNode = null,
        share_tag_options: ?bool = null,
        share_principals: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .account_id = "AccountId",
                .organization_node = "OrganizationNode",
                .share_tag_options = "ShareTagOptions",
                .share_principals = "SharePrincipals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_portfolio_share) } {
            return .{ .service_metadata = service_metadata, .action = create_portfolio_share };
        }
    },
    Response: type = struct {
        portfolio_share_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_share_token = "PortfolioShareToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        InvalidState,
        LimitExceeded,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const create_product: struct {
    action_name: []const u8 = "CreateProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        name: []const u8,
        owner: []const u8,
        description: ?[]const u8 = null,
        distributor: ?[]const u8 = null,
        support_description: ?[]const u8 = null,
        support_email: ?[]const u8 = null,
        support_url: ?[]const u8 = null,
        product_type: []const u8,
        tags: ?[]Tag = null,
        provisioning_artifact_parameters: ?ProvisioningArtifactProperties = null,
        idempotency_token: []const u8,
        source_connection: ?SourceConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .name = "Name",
                .owner = "Owner",
                .description = "Description",
                .distributor = "Distributor",
                .support_description = "SupportDescription",
                .support_email = "SupportEmail",
                .support_url = "SupportUrl",
                .product_type = "ProductType",
                .tags = "Tags",
                .provisioning_artifact_parameters = "ProvisioningArtifactParameters",
                .idempotency_token = "IdempotencyToken",
                .source_connection = "SourceConnection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_product) } {
            return .{ .service_metadata = service_metadata, .action = create_product };
        }
    },
    Response: type = struct {
        product_view_detail: ?ProductViewDetail = null,
        provisioning_artifact_detail: ?ProvisioningArtifactDetail = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_view_detail = "ProductViewDetail",
                .provisioning_artifact_detail = "ProvisioningArtifactDetail",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        LimitExceeded,
        TagOptionNotMigrated,
    },
} = .{};
pub const create_provisioned_product_plan: struct {
    action_name: []const u8 = "CreateProvisionedProductPlan",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        plan_name: []const u8,
        plan_type: []const u8,
        notification_arns: ?[][]const u8 = null,
        path_id: ?[]const u8 = null,
        product_id: []const u8,
        provisioned_product_name: []const u8,
        provisioning_artifact_id: []const u8,
        provisioning_parameters: ?[]UpdateProvisioningParameter = null,
        idempotency_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .plan_name = "PlanName",
                .plan_type = "PlanType",
                .notification_arns = "NotificationArns",
                .path_id = "PathId",
                .product_id = "ProductId",
                .provisioned_product_name = "ProvisionedProductName",
                .provisioning_artifact_id = "ProvisioningArtifactId",
                .provisioning_parameters = "ProvisioningParameters",
                .idempotency_token = "IdempotencyToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_provisioned_product_plan) } {
            return .{ .service_metadata = service_metadata, .action = create_provisioned_product_plan };
        }
    },
    Response: type = struct {
        plan_name: ?[]const u8 = null,
        plan_id: ?[]const u8 = null,
        provision_product_id: ?[]const u8 = null,
        provisioned_product_name: ?[]const u8 = null,
        provisioning_artifact_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .plan_name = "PlanName",
                .plan_id = "PlanId",
                .provision_product_id = "ProvisionProductId",
                .provisioned_product_name = "ProvisionedProductName",
                .provisioning_artifact_id = "ProvisioningArtifactId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const create_provisioning_artifact: struct {
    action_name: []const u8 = "CreateProvisioningArtifact",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: []const u8,
        parameters: ProvisioningArtifactProperties,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
                .parameters = "Parameters",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_provisioning_artifact) } {
            return .{ .service_metadata = service_metadata, .action = create_provisioning_artifact };
        }
    },
    Response: type = struct {
        provisioning_artifact_detail: ?ProvisioningArtifactDetail = null,
        info: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioning_artifact_detail = "ProvisioningArtifactDetail",
                .info = "Info",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "info", field_name))
                return try serializeMap(self.info, self.fieldNameFor("info"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_service_action: struct {
    action_name: []const u8 = "CreateServiceAction",
    Request: type = struct {
        name: []const u8,
        definition_type: []const u8,
        definition: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        description: ?[]const u8 = null,
        accept_language: ?[]const u8 = null,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .definition_type = "DefinitionType",
                .definition = "Definition",
                .description = "Description",
                .accept_language = "AcceptLanguage",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "definition", field_name))
                return try serializeMap(self.definition, self.fieldNameFor("definition"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_service_action) } {
            return .{ .service_metadata = service_metadata, .action = create_service_action };
        }
    },
    Response: type = struct {
        service_action_detail: ?ServiceActionDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_action_detail = "ServiceActionDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        LimitExceeded,
    },
} = .{};
pub const create_tag_option: struct {
    action_name: []const u8 = "CreateTagOption",
    Request: type = struct {
        key: []const u8,
        value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key = "Key",
                .value = "Value",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tag_option) } {
            return .{ .service_metadata = service_metadata, .action = create_tag_option };
        }
    },
    Response: type = struct {
        tag_option_detail: ?TagOptionDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_option_detail = "TagOptionDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        LimitExceeded,
        TagOptionNotMigrated,
    },
} = .{};
pub const delete_constraint: struct {
    action_name: []const u8 = "DeleteConstraint",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_constraint) } {
            return .{ .service_metadata = service_metadata, .action = delete_constraint };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const delete_portfolio: struct {
    action_name: []const u8 = "DeletePortfolio",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = delete_portfolio };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceInUse,
        ResourceNotFound,
        TagOptionNotMigrated,
    },
} = .{};
pub const delete_portfolio_share: struct {
    action_name: []const u8 = "DeletePortfolioShare",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        account_id: ?[]const u8 = null,
        organization_node: ?OrganizationNode = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .account_id = "AccountId",
                .organization_node = "OrganizationNode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_portfolio_share) } {
            return .{ .service_metadata = service_metadata, .action = delete_portfolio_share };
        }
    },
    Response: type = struct {
        portfolio_share_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_share_token = "PortfolioShareToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        InvalidState,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const delete_product: struct {
    action_name: []const u8 = "DeleteProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_product) } {
            return .{ .service_metadata = service_metadata, .action = delete_product };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceInUse,
        ResourceNotFound,
        TagOptionNotMigrated,
    },
} = .{};
pub const delete_provisioned_product_plan: struct {
    action_name: []const u8 = "DeleteProvisionedProductPlan",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        plan_id: []const u8,
        ignore_errors: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .plan_id = "PlanId",
                .ignore_errors = "IgnoreErrors",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_provisioned_product_plan) } {
            return .{ .service_metadata = service_metadata, .action = delete_provisioned_product_plan };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const delete_provisioning_artifact: struct {
    action_name: []const u8 = "DeleteProvisioningArtifact",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: []const u8,
        provisioning_artifact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
                .provisioning_artifact_id = "ProvisioningArtifactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_provisioning_artifact) } {
            return .{ .service_metadata = service_metadata, .action = delete_provisioning_artifact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_service_action: struct {
    action_name: []const u8 = "DeleteServiceAction",
    Request: type = struct {
        id: []const u8,
        accept_language: ?[]const u8 = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .accept_language = "AcceptLanguage",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_service_action) } {
            return .{ .service_metadata = service_metadata, .action = delete_service_action };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_tag_option: struct {
    action_name: []const u8 = "DeleteTagOption",
    Request: type = struct {
        id: []const u8,

        pub const http_query = .{
            .id = "id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tag_option) } {
            return .{ .service_metadata = service_metadata, .action = delete_tag_option };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceNotFound,
        TagOptionNotMigrated,
    },
} = .{};
pub const describe_constraint: struct {
    action_name: []const u8 = "DescribeConstraint",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_constraint) } {
            return .{ .service_metadata = service_metadata, .action = describe_constraint };
        }
    },
    Response: type = struct {
        constraint_detail: ?ConstraintDetail = null,
        constraint_parameters: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .constraint_detail = "ConstraintDetail",
                .constraint_parameters = "ConstraintParameters",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_copy_product_status: struct {
    action_name: []const u8 = "DescribeCopyProductStatus",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        copy_product_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .copy_product_token = "CopyProductToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_copy_product_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_copy_product_status };
        }
    },
    Response: type = struct {
        copy_product_status: ?[]const u8 = null,
        target_product_id: ?[]const u8 = null,
        status_detail: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .copy_product_status = "CopyProductStatus",
                .target_product_id = "TargetProductId",
                .status_detail = "StatusDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_portfolio: struct {
    action_name: []const u8 = "DescribePortfolio",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = describe_portfolio };
        }
    },
    Response: type = struct {
        portfolio_detail: ?PortfolioDetail = null,
        tags: ?[]Tag = null,
        tag_options: ?[]TagOptionDetail = null,
        budgets: ?[]BudgetDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_detail = "PortfolioDetail",
                .tags = "Tags",
                .tag_options = "TagOptions",
                .budgets = "Budgets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_portfolio_shares: struct {
    action_name: []const u8 = "DescribePortfolioShares",
    Request: type = struct {
        portfolio_id: []const u8,
        type: []const u8,
        page_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_id = "PortfolioId",
                .type = "Type",
                .page_token = "PageToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_portfolio_shares) } {
            return .{ .service_metadata = service_metadata, .action = describe_portfolio_shares };
        }
    },
    Response: type = struct {
        next_page_token: ?[]const u8 = null,
        portfolio_share_details: ?[]struct {
            principal_id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            accepted: ?bool = null,
            share_tag_options: ?bool = null,
            share_principals: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .principal_id = "PrincipalId",
                    .type = "Type",
                    .accepted = "Accepted",
                    .share_tag_options = "ShareTagOptions",
                    .share_principals = "SharePrincipals",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_page_token = "NextPageToken",
                .portfolio_share_details = "PortfolioShareDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const describe_portfolio_share_status: struct {
    action_name: []const u8 = "DescribePortfolioShareStatus",
    Request: type = struct {
        portfolio_share_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_share_token = "PortfolioShareToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_portfolio_share_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_portfolio_share_status };
        }
    },
    Response: type = struct {
        portfolio_share_token: ?[]const u8 = null,
        portfolio_id: ?[]const u8 = null,
        organization_node_value: ?[]const u8 = null,
        status: ?[]const u8 = null,
        share_details: ?struct {
            successful_shares: ?[][]const u8 = null,
            share_errors: ?[]struct {
                accounts: ?[][]const u8 = null,
                message: ?[]const u8 = null,
                @"error": ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .accounts = "Accounts",
                        .message = "Message",
                        .@"error" = "Error",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .successful_shares = "SuccessfulShares",
                    .share_errors = "ShareErrors",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_share_token = "PortfolioShareToken",
                .portfolio_id = "PortfolioId",
                .organization_node_value = "OrganizationNodeValue",
                .status = "Status",
                .share_details = "ShareDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const describe_product: struct {
    action_name: []const u8 = "DescribeProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_product) } {
            return .{ .service_metadata = service_metadata, .action = describe_product };
        }
    },
    Response: type = struct {
        product_view_summary: ?ProductViewSummary = null,
        provisioning_artifacts: ?[]ProvisioningArtifact = null,
        budgets: ?[]BudgetDetail = null,
        launch_paths: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_view_summary = "ProductViewSummary",
                .provisioning_artifacts = "ProvisioningArtifacts",
                .budgets = "Budgets",
                .launch_paths = "LaunchPaths",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const describe_product_as_admin: struct {
    action_name: []const u8 = "DescribeProductAsAdmin",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        source_portfolio_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
                .name = "Name",
                .source_portfolio_id = "SourcePortfolioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_product_as_admin) } {
            return .{ .service_metadata = service_metadata, .action = describe_product_as_admin };
        }
    },
    Response: type = struct {
        product_view_detail: ?ProductViewDetail = null,
        provisioning_artifact_summaries: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_time: ?i64 = null,
            provisioning_artifact_metadata: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .description = "Description",
                    .created_time = "CreatedTime",
                    .provisioning_artifact_metadata = "ProvisioningArtifactMetadata",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "provisioning_artifact_metadata", field_name))
                    return try serializeMap(self.provisioning_artifact_metadata, self.fieldNameFor("provisioning_artifact_metadata"), options, out_stream);
                return false;
            }
        } = null,
        tags: ?[]Tag = null,
        tag_options: ?[]TagOptionDetail = null,
        budgets: ?[]BudgetDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_view_detail = "ProductViewDetail",
                .provisioning_artifact_summaries = "ProvisioningArtifactSummaries",
                .tags = "Tags",
                .tag_options = "TagOptions",
                .budgets = "Budgets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const describe_product_view: struct {
    action_name: []const u8 = "DescribeProductView",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_product_view) } {
            return .{ .service_metadata = service_metadata, .action = describe_product_view };
        }
    },
    Response: type = struct {
        product_view_summary: ?ProductViewSummary = null,
        provisioning_artifacts: ?[]ProvisioningArtifact = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_view_summary = "ProductViewSummary",
                .provisioning_artifacts = "ProvisioningArtifacts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const describe_provisioned_product: struct {
    action_name: []const u8 = "DescribeProvisionedProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_provisioned_product) } {
            return .{ .service_metadata = service_metadata, .action = describe_provisioned_product };
        }
    },
    Response: type = struct {
        provisioned_product_detail: ?ProvisionedProductDetail = null,
        cloud_watch_dashboards: ?[]struct {
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_product_detail = "ProvisionedProductDetail",
                .cloud_watch_dashboards = "CloudWatchDashboards",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const describe_provisioned_product_plan: struct {
    action_name: []const u8 = "DescribeProvisionedProductPlan",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        plan_id: []const u8,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .plan_id = "PlanId",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_provisioned_product_plan) } {
            return .{ .service_metadata = service_metadata, .action = describe_provisioned_product_plan };
        }
    },
    Response: type = struct {
        provisioned_product_plan_details: ?struct {
            created_time: ?i64 = null,
            path_id: ?[]const u8 = null,
            product_id: ?[]const u8 = null,
            plan_name: ?[]const u8 = null,
            plan_id: ?[]const u8 = null,
            provision_product_id: ?[]const u8 = null,
            provision_product_name: ?[]const u8 = null,
            plan_type: ?[]const u8 = null,
            provisioning_artifact_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            updated_time: ?i64 = null,
            notification_arns: ?[][]const u8 = null,
            provisioning_parameters: ?[]UpdateProvisioningParameter = null,
            tags: ?[]Tag = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_time = "CreatedTime",
                    .path_id = "PathId",
                    .product_id = "ProductId",
                    .plan_name = "PlanName",
                    .plan_id = "PlanId",
                    .provision_product_id = "ProvisionProductId",
                    .provision_product_name = "ProvisionProductName",
                    .plan_type = "PlanType",
                    .provisioning_artifact_id = "ProvisioningArtifactId",
                    .status = "Status",
                    .updated_time = "UpdatedTime",
                    .notification_arns = "NotificationArns",
                    .provisioning_parameters = "ProvisioningParameters",
                    .tags = "Tags",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        resource_changes: ?[]struct {
            action: ?[]const u8 = null,
            logical_resource_id: ?[]const u8 = null,
            physical_resource_id: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            replacement: ?[]const u8 = null,
            scope: ?[][]const u8 = null,
            details: ?[]struct {
                target: ?struct {
                    attribute: ?[]const u8 = null,
                    name: ?[]const u8 = null,
                    requires_recreation: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .attribute = "Attribute",
                            .name = "Name",
                            .requires_recreation = "RequiresRecreation",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                evaluation: ?[]const u8 = null,
                causing_entity: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .target = "Target",
                        .evaluation = "Evaluation",
                        .causing_entity = "CausingEntity",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .logical_resource_id = "LogicalResourceId",
                    .physical_resource_id = "PhysicalResourceId",
                    .resource_type = "ResourceType",
                    .replacement = "Replacement",
                    .scope = "Scope",
                    .details = "Details",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_product_plan_details = "ProvisionedProductPlanDetails",
                .resource_changes = "ResourceChanges",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const describe_provisioning_artifact: struct {
    action_name: []const u8 = "DescribeProvisioningArtifact",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        provisioning_artifact_id: ?[]const u8 = null,
        product_id: ?[]const u8 = null,
        provisioning_artifact_name: ?[]const u8 = null,
        product_name: ?[]const u8 = null,
        verbose: ?bool = null,
        include_provisioning_artifact_parameters: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .provisioning_artifact_id = "ProvisioningArtifactId",
                .product_id = "ProductId",
                .provisioning_artifact_name = "ProvisioningArtifactName",
                .product_name = "ProductName",
                .verbose = "Verbose",
                .include_provisioning_artifact_parameters = "IncludeProvisioningArtifactParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_provisioning_artifact) } {
            return .{ .service_metadata = service_metadata, .action = describe_provisioning_artifact };
        }
    },
    Response: type = struct {
        provisioning_artifact_detail: ?ProvisioningArtifactDetail = null,
        info: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        status: ?[]const u8 = null,
        provisioning_artifact_parameters: ?[]ProvisioningArtifactParameter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioning_artifact_detail = "ProvisioningArtifactDetail",
                .info = "Info",
                .status = "Status",
                .provisioning_artifact_parameters = "ProvisioningArtifactParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "info", field_name))
                return try serializeMap(self.info, self.fieldNameFor("info"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const describe_provisioning_parameters: struct {
    action_name: []const u8 = "DescribeProvisioningParameters",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: ?[]const u8 = null,
        product_name: ?[]const u8 = null,
        provisioning_artifact_id: ?[]const u8 = null,
        provisioning_artifact_name: ?[]const u8 = null,
        path_id: ?[]const u8 = null,
        path_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
                .product_name = "ProductName",
                .provisioning_artifact_id = "ProvisioningArtifactId",
                .provisioning_artifact_name = "ProvisioningArtifactName",
                .path_id = "PathId",
                .path_name = "PathName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_provisioning_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_provisioning_parameters };
        }
    },
    Response: type = struct {
        provisioning_artifact_parameters: ?[]ProvisioningArtifactParameter = null,
        constraint_summaries: ?[]ConstraintSummary = null,
        usage_instructions: ?[]struct {
            type: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tag_options: ?[]struct {
            key: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        provisioning_artifact_preferences: ?struct {
            stack_set_accounts: ?[][]const u8 = null,
            stack_set_regions: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stack_set_accounts = "StackSetAccounts",
                    .stack_set_regions = "StackSetRegions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        provisioning_artifact_outputs: ?[]ProvisioningArtifactOutput = null,
        provisioning_artifact_output_keys: ?[]ProvisioningArtifactOutput = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioning_artifact_parameters = "ProvisioningArtifactParameters",
                .constraint_summaries = "ConstraintSummaries",
                .usage_instructions = "UsageInstructions",
                .tag_options = "TagOptions",
                .provisioning_artifact_preferences = "ProvisioningArtifactPreferences",
                .provisioning_artifact_outputs = "ProvisioningArtifactOutputs",
                .provisioning_artifact_output_keys = "ProvisioningArtifactOutputKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const describe_record: struct {
    action_name: []const u8 = "DescribeRecord",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: []const u8,
        page_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
                .page_token = "PageToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_record) } {
            return .{ .service_metadata = service_metadata, .action = describe_record };
        }
    },
    Response: type = struct {
        record_detail: ?RecordDetail = null,
        record_outputs: ?[]RecordOutput = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .record_detail = "RecordDetail",
                .record_outputs = "RecordOutputs",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_service_action: struct {
    action_name: []const u8 = "DescribeServiceAction",
    Request: type = struct {
        id: []const u8,
        accept_language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .accept_language = "AcceptLanguage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_service_action) } {
            return .{ .service_metadata = service_metadata, .action = describe_service_action };
        }
    },
    Response: type = struct {
        service_action_detail: ?ServiceActionDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_action_detail = "ServiceActionDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_service_action_execution_parameters: struct {
    action_name: []const u8 = "DescribeServiceActionExecutionParameters",
    Request: type = struct {
        provisioned_product_id: []const u8,
        service_action_id: []const u8,
        accept_language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_product_id = "ProvisionedProductId",
                .service_action_id = "ServiceActionId",
                .accept_language = "AcceptLanguage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_service_action_execution_parameters) } {
            return .{ .service_metadata = service_metadata, .action = describe_service_action_execution_parameters };
        }
    },
    Response: type = struct {
        service_action_parameters: ?[]struct {
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            default_values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .type = "Type",
                    .default_values = "DefaultValues",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_action_parameters = "ServiceActionParameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const describe_tag_option: struct {
    action_name: []const u8 = "DescribeTagOption",
    Request: type = struct {
        id: []const u8,

        pub const http_query = .{
            .id = "id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tag_option) } {
            return .{ .service_metadata = service_metadata, .action = describe_tag_option };
        }
    },
    Response: type = struct {
        tag_option_detail: ?TagOptionDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_option_detail = "TagOptionDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        TagOptionNotMigrated,
    },
} = .{};
pub const disable_aws_organizations_access: struct {
    action_name: []const u8 = "DisableAWSOrganizationsAccess",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_aws_organizations_access) } {
            return .{ .service_metadata = service_metadata, .action = disable_aws_organizations_access };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_budget_from_resource: struct {
    action_name: []const u8 = "DisassociateBudgetFromResource",
    Request: type = struct {
        budget_name: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .budget_name = "BudgetName",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_budget_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_budget_from_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const disassociate_principal_from_portfolio: struct {
    action_name: []const u8 = "DisassociatePrincipalFromPortfolio",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        principal_arn: []const u8,
        principal_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .principal_arn = "PrincipalARN",
                .principal_type = "PrincipalType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_principal_from_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_principal_from_portfolio };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_product_from_portfolio: struct {
    action_name: []const u8 = "DisassociateProductFromPortfolio",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: []const u8,
        portfolio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
                .portfolio_id = "PortfolioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_product_from_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_product_from_portfolio };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_service_action_from_provisioning_artifact: struct {
    action_name: []const u8 = "DisassociateServiceActionFromProvisioningArtifact",
    Request: type = struct {
        product_id: []const u8,
        provisioning_artifact_id: []const u8,
        service_action_id: []const u8,
        accept_language: ?[]const u8 = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_id = "ProductId",
                .provisioning_artifact_id = "ProvisioningArtifactId",
                .service_action_id = "ServiceActionId",
                .accept_language = "AcceptLanguage",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_service_action_from_provisioning_artifact) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_service_action_from_provisioning_artifact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const disassociate_tag_option_from_resource: struct {
    action_name: []const u8 = "DisassociateTagOptionFromResource",
    Request: type = struct {
        resource_id: []const u8,
        tag_option_id: []const u8,

        pub const http_query = .{
            .resource_id = "resourceId",
            .tag_option_id = "tagOptionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tag_option_id = "TagOptionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_tag_option_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_tag_option_from_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        TagOptionNotMigrated,
    },
} = .{};
pub const enable_aws_organizations_access: struct {
    action_name: []const u8 = "EnableAWSOrganizationsAccess",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_aws_organizations_access) } {
            return .{ .service_metadata = service_metadata, .action = enable_aws_organizations_access };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidState,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const execute_provisioned_product_plan: struct {
    action_name: []const u8 = "ExecuteProvisionedProductPlan",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        plan_id: []const u8,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .plan_id = "PlanId",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_provisioned_product_plan) } {
            return .{ .service_metadata = service_metadata, .action = execute_provisioned_product_plan };
        }
    },
    Response: type = struct {
        record_detail: ?RecordDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .record_detail = "RecordDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const execute_provisioned_product_service_action: struct {
    action_name: []const u8 = "ExecuteProvisionedProductServiceAction",
    Request: type = struct {
        provisioned_product_id: []const u8,
        service_action_id: []const u8,
        execute_token: []const u8,
        accept_language: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_product_id = "ProvisionedProductId",
                .service_action_id = "ServiceActionId",
                .execute_token = "ExecuteToken",
                .accept_language = "AcceptLanguage",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_provisioned_product_service_action) } {
            return .{ .service_metadata = service_metadata, .action = execute_provisioned_product_service_action };
        }
    },
    Response: type = struct {
        record_detail: ?RecordDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .record_detail = "RecordDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const get_aws_organizations_access_status: struct {
    action_name: []const u8 = "GetAWSOrganizationsAccessStatus",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_aws_organizations_access_status) } {
            return .{ .service_metadata = service_metadata, .action = get_aws_organizations_access_status };
        }
    },
    Response: type = struct {
        access_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_status = "AccessStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const get_provisioned_product_outputs: struct {
    action_name: []const u8 = "GetProvisionedProductOutputs",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        provisioned_product_id: ?[]const u8 = null,
        provisioned_product_name: ?[]const u8 = null,
        output_keys: ?[][]const u8 = null,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .provisioned_product_id = "ProvisionedProductId",
                .provisioned_product_name = "ProvisionedProductName",
                .output_keys = "OutputKeys",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_provisioned_product_outputs) } {
            return .{ .service_metadata = service_metadata, .action = get_provisioned_product_outputs };
        }
    },
    Response: type = struct {
        outputs: ?[]RecordOutput = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .outputs = "Outputs",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const import_as_provisioned_product: struct {
    action_name: []const u8 = "ImportAsProvisionedProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: []const u8,
        provisioning_artifact_id: []const u8,
        provisioned_product_name: []const u8,
        physical_id: []const u8,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
                .provisioning_artifact_id = "ProvisioningArtifactId",
                .provisioned_product_name = "ProvisionedProductName",
                .physical_id = "PhysicalId",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_as_provisioned_product) } {
            return .{ .service_metadata = service_metadata, .action = import_as_provisioned_product };
        }
    },
    Response: type = struct {
        record_detail: ?RecordDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .record_detail = "RecordDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InvalidParameters,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const list_accepted_portfolio_shares: struct {
    action_name: []const u8 = "ListAcceptedPortfolioShares",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        page_token: ?[]const u8 = null,
        page_size: ?i64 = null,
        portfolio_share_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .page_token = "PageToken",
                .page_size = "PageSize",
                .portfolio_share_type = "PortfolioShareType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accepted_portfolio_shares) } {
            return .{ .service_metadata = service_metadata, .action = list_accepted_portfolio_shares };
        }
    },
    Response: type = struct {
        portfolio_details: ?[]PortfolioDetail = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_details = "PortfolioDetails",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        OperationNotSupported,
    },
} = .{};
pub const list_budgets_for_resource: struct {
    action_name: []const u8 = "ListBudgetsForResource",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        resource_id: []const u8,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .resource_id = "ResourceId",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_budgets_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_budgets_for_resource };
        }
    },
    Response: type = struct {
        budgets: ?[]BudgetDetail = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .budgets = "Budgets",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_constraints_for_portfolio: struct {
    action_name: []const u8 = "ListConstraintsForPortfolio",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        product_id: ?[]const u8 = null,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .product_id = "ProductId",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_constraints_for_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = list_constraints_for_portfolio };
        }
    },
    Response: type = struct {
        constraint_details: ?[]ConstraintDetail = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .constraint_details = "ConstraintDetails",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_launch_paths: struct {
    action_name: []const u8 = "ListLaunchPaths",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: []const u8,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_launch_paths) } {
            return .{ .service_metadata = service_metadata, .action = list_launch_paths };
        }
    },
    Response: type = struct {
        launch_path_summaries: ?[]struct {
            id: ?[]const u8 = null,
            constraint_summaries: ?[]ConstraintSummary = null,
            tags: ?[]Tag = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .constraint_summaries = "ConstraintSummaries",
                    .tags = "Tags",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_path_summaries = "LaunchPathSummaries",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_organization_portfolio_access: struct {
    action_name: []const u8 = "ListOrganizationPortfolioAccess",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        organization_node_type: []const u8,
        page_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .organization_node_type = "OrganizationNodeType",
                .page_token = "PageToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_portfolio_access) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_portfolio_access };
        }
    },
    Response: type = struct {
        organization_nodes: ?[]OrganizationNode = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_nodes = "OrganizationNodes",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const list_portfolio_access: struct {
    action_name: []const u8 = "ListPortfolioAccess",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        organization_parent_id: ?[]const u8 = null,
        page_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .organization_parent_id = "OrganizationParentId",
                .page_token = "PageToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_portfolio_access) } {
            return .{ .service_metadata = service_metadata, .action = list_portfolio_access };
        }
    },
    Response: type = struct {
        account_ids: ?[][]const u8 = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_portfolios: struct {
    action_name: []const u8 = "ListPortfolios",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        page_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .page_token = "PageToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_portfolios) } {
            return .{ .service_metadata = service_metadata, .action = list_portfolios };
        }
    },
    Response: type = struct {
        portfolio_details: ?[]PortfolioDetail = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_details = "PortfolioDetails",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
    },
} = .{};
pub const list_portfolios_for_product: struct {
    action_name: []const u8 = "ListPortfoliosForProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: []const u8,
        page_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
                .page_token = "PageToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_portfolios_for_product) } {
            return .{ .service_metadata = service_metadata, .action = list_portfolios_for_product };
        }
    },
    Response: type = struct {
        portfolio_details: ?[]PortfolioDetail = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_details = "PortfolioDetails",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_principals_for_portfolio: struct {
    action_name: []const u8 = "ListPrincipalsForPortfolio",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_principals_for_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = list_principals_for_portfolio };
        }
    },
    Response: type = struct {
        principals: ?[]struct {
            principal_arn: ?[]const u8 = null,
            principal_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .principal_arn = "PrincipalARN",
                    .principal_type = "PrincipalType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principals = "Principals",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_provisioned_product_plans: struct {
    action_name: []const u8 = "ListProvisionedProductPlans",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        provision_product_id: ?[]const u8 = null,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,
        access_level_filter: ?AccessLevelFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .provision_product_id = "ProvisionProductId",
                .page_size = "PageSize",
                .page_token = "PageToken",
                .access_level_filter = "AccessLevelFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_provisioned_product_plans) } {
            return .{ .service_metadata = service_metadata, .action = list_provisioned_product_plans };
        }
    },
    Response: type = struct {
        provisioned_product_plans: ?[]struct {
            plan_name: ?[]const u8 = null,
            plan_id: ?[]const u8 = null,
            provision_product_id: ?[]const u8 = null,
            provision_product_name: ?[]const u8 = null,
            plan_type: ?[]const u8 = null,
            provisioning_artifact_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .plan_name = "PlanName",
                    .plan_id = "PlanId",
                    .provision_product_id = "ProvisionProductId",
                    .provision_product_name = "ProvisionProductName",
                    .plan_type = "PlanType",
                    .provisioning_artifact_id = "ProvisioningArtifactId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_product_plans = "ProvisionedProductPlans",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_provisioning_artifacts: struct {
    action_name: []const u8 = "ListProvisioningArtifacts",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_provisioning_artifacts) } {
            return .{ .service_metadata = service_metadata, .action = list_provisioning_artifacts };
        }
    },
    Response: type = struct {
        provisioning_artifact_details: ?[]ProvisioningArtifactDetail = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioning_artifact_details = "ProvisioningArtifactDetails",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_provisioning_artifacts_for_service_action: struct {
    action_name: []const u8 = "ListProvisioningArtifactsForServiceAction",
    Request: type = struct {
        service_action_id: []const u8,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,
        accept_language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_action_id = "ServiceActionId",
                .page_size = "PageSize",
                .page_token = "PageToken",
                .accept_language = "AcceptLanguage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_provisioning_artifacts_for_service_action) } {
            return .{ .service_metadata = service_metadata, .action = list_provisioning_artifacts_for_service_action };
        }
    },
    Response: type = struct {
        provisioning_artifact_views: ?[]struct {
            product_view_summary: ?ProductViewSummary = null,
            provisioning_artifact: ?ProvisioningArtifact = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .product_view_summary = "ProductViewSummary",
                    .provisioning_artifact = "ProvisioningArtifact",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioning_artifact_views = "ProvisioningArtifactViews",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_record_history: struct {
    action_name: []const u8 = "ListRecordHistory",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        access_level_filter: ?AccessLevelFilter = null,
        search_filter: ?struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .access_level_filter = "AccessLevelFilter",
                .search_filter = "SearchFilter",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_record_history) } {
            return .{ .service_metadata = service_metadata, .action = list_record_history };
        }
    },
    Response: type = struct {
        record_details: ?[]RecordDetail = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .record_details = "RecordDetails",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
    },
} = .{};
pub const list_resources_for_tag_option: struct {
    action_name: []const u8 = "ListResourcesForTagOption",
    Request: type = struct {
        tag_option_id: []const u8,
        resource_type: ?[]const u8 = null,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub const http_query = .{
            .tag_option_id = "tagOptionId",
            .resource_type = "resourceType",
            .page_size = "pageSize",
            .page_token = "pageToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_option_id = "TagOptionId",
                .resource_type = "ResourceType",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources_for_tag_option) } {
            return .{ .service_metadata = service_metadata, .action = list_resources_for_tag_option };
        }
    },
    Response: type = struct {
        resource_details: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "ARN",
                    .name = "Name",
                    .description = "Description",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_details = "ResourceDetails",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
        TagOptionNotMigrated,
    },
} = .{};
pub const list_service_actions: struct {
    action_name: []const u8 = "ListServiceActions",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_service_actions) } {
            return .{ .service_metadata = service_metadata, .action = list_service_actions };
        }
    },
    Response: type = struct {
        service_action_summaries: ?[]ServiceActionSummary = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_action_summaries = "ServiceActionSummaries",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
    },
} = .{};
pub const list_service_actions_for_provisioning_artifact: struct {
    action_name: []const u8 = "ListServiceActionsForProvisioningArtifact",
    Request: type = struct {
        product_id: []const u8,
        provisioning_artifact_id: []const u8,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,
        accept_language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_id = "ProductId",
                .provisioning_artifact_id = "ProvisioningArtifactId",
                .page_size = "PageSize",
                .page_token = "PageToken",
                .accept_language = "AcceptLanguage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_service_actions_for_provisioning_artifact) } {
            return .{ .service_metadata = service_metadata, .action = list_service_actions_for_provisioning_artifact };
        }
    },
    Response: type = struct {
        service_action_summaries: ?[]ServiceActionSummary = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_action_summaries = "ServiceActionSummaries",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_stack_instances_for_provisioned_product: struct {
    action_name: []const u8 = "ListStackInstancesForProvisionedProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        provisioned_product_id: []const u8,
        page_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .provisioned_product_id = "ProvisionedProductId",
                .page_token = "PageToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_stack_instances_for_provisioned_product) } {
            return .{ .service_metadata = service_metadata, .action = list_stack_instances_for_provisioned_product };
        }
    },
    Response: type = struct {
        stack_instances: ?[]struct {
            account: ?[]const u8 = null,
            region: ?[]const u8 = null,
            stack_instance_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account = "Account",
                    .region = "Region",
                    .stack_instance_status = "StackInstanceStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stack_instances = "StackInstances",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const list_tag_options: struct {
    action_name: []const u8 = "ListTagOptions",
    Request: type = struct {
        filters: ?struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
            active: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                    .active = "Active",
                };
                return @field(mappings, field_name);
            }
        } = null,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tag_options) } {
            return .{ .service_metadata = service_metadata, .action = list_tag_options };
        }
    },
    Response: type = struct {
        tag_option_details: ?[]TagOptionDetail = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_option_details = "TagOptionDetails",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        TagOptionNotMigrated,
    },
} = .{};
pub const notify_provision_product_engine_workflow_result: struct {
    action_name: []const u8 = "NotifyProvisionProductEngineWorkflowResult",
    Request: type = struct {
        workflow_token: []const u8,
        record_id: []const u8,
        status: []const u8,
        failure_reason: ?[]const u8 = null,
        resource_identifier: ?struct {
            unique_tag: ?struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .key = "Key",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .unique_tag = "UniqueTag",
                };
                return @field(mappings, field_name);
            }
        } = null,
        outputs: ?[]RecordOutput = null,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_token = "WorkflowToken",
                .record_id = "RecordId",
                .status = "Status",
                .failure_reason = "FailureReason",
                .resource_identifier = "ResourceIdentifier",
                .outputs = "Outputs",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(notify_provision_product_engine_workflow_result) } {
            return .{ .service_metadata = service_metadata, .action = notify_provision_product_engine_workflow_result };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const notify_terminate_provisioned_product_engine_workflow_result: struct {
    action_name: []const u8 = "NotifyTerminateProvisionedProductEngineWorkflowResult",
    Request: type = struct {
        workflow_token: []const u8,
        record_id: []const u8,
        status: []const u8,
        failure_reason: ?[]const u8 = null,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_token = "WorkflowToken",
                .record_id = "RecordId",
                .status = "Status",
                .failure_reason = "FailureReason",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(notify_terminate_provisioned_product_engine_workflow_result) } {
            return .{ .service_metadata = service_metadata, .action = notify_terminate_provisioned_product_engine_workflow_result };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const notify_update_provisioned_product_engine_workflow_result: struct {
    action_name: []const u8 = "NotifyUpdateProvisionedProductEngineWorkflowResult",
    Request: type = struct {
        workflow_token: []const u8,
        record_id: []const u8,
        status: []const u8,
        failure_reason: ?[]const u8 = null,
        outputs: ?[]RecordOutput = null,
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_token = "WorkflowToken",
                .record_id = "RecordId",
                .status = "Status",
                .failure_reason = "FailureReason",
                .outputs = "Outputs",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(notify_update_provisioned_product_engine_workflow_result) } {
            return .{ .service_metadata = service_metadata, .action = notify_update_provisioned_product_engine_workflow_result };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const provision_product: struct {
    action_name: []const u8 = "ProvisionProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: ?[]const u8 = null,
        product_name: ?[]const u8 = null,
        provisioning_artifact_id: ?[]const u8 = null,
        provisioning_artifact_name: ?[]const u8 = null,
        path_id: ?[]const u8 = null,
        path_name: ?[]const u8 = null,
        provisioned_product_name: []const u8,
        provisioning_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        provisioning_preferences: ?struct {
            stack_set_accounts: ?[][]const u8 = null,
            stack_set_regions: ?[][]const u8 = null,
            stack_set_failure_tolerance_count: ?i64 = null,
            stack_set_failure_tolerance_percentage: ?i64 = null,
            stack_set_max_concurrency_count: ?i64 = null,
            stack_set_max_concurrency_percentage: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stack_set_accounts = "StackSetAccounts",
                    .stack_set_regions = "StackSetRegions",
                    .stack_set_failure_tolerance_count = "StackSetFailureToleranceCount",
                    .stack_set_failure_tolerance_percentage = "StackSetFailureTolerancePercentage",
                    .stack_set_max_concurrency_count = "StackSetMaxConcurrencyCount",
                    .stack_set_max_concurrency_percentage = "StackSetMaxConcurrencyPercentage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]Tag = null,
        notification_arns: ?[][]const u8 = null,
        provision_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
                .product_name = "ProductName",
                .provisioning_artifact_id = "ProvisioningArtifactId",
                .provisioning_artifact_name = "ProvisioningArtifactName",
                .path_id = "PathId",
                .path_name = "PathName",
                .provisioned_product_name = "ProvisionedProductName",
                .provisioning_parameters = "ProvisioningParameters",
                .provisioning_preferences = "ProvisioningPreferences",
                .tags = "Tags",
                .notification_arns = "NotificationArns",
                .provision_token = "ProvisionToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(provision_product) } {
            return .{ .service_metadata = service_metadata, .action = provision_product };
        }
    },
    Response: type = struct {
        record_detail: ?RecordDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .record_detail = "RecordDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const reject_portfolio_share: struct {
    action_name: []const u8 = "RejectPortfolioShare",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        portfolio_share_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .portfolio_share_type = "PortfolioShareType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reject_portfolio_share) } {
            return .{ .service_metadata = service_metadata, .action = reject_portfolio_share };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const scan_provisioned_products: struct {
    action_name: []const u8 = "ScanProvisionedProducts",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        access_level_filter: ?AccessLevelFilter = null,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .access_level_filter = "AccessLevelFilter",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(scan_provisioned_products) } {
            return .{ .service_metadata = service_metadata, .action = scan_provisioned_products };
        }
    },
    Response: type = struct {
        provisioned_products: ?[]ProvisionedProductDetail = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_products = "ProvisionedProducts",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
    },
} = .{};
pub const search_products: struct {
    action_name: []const u8 = "SearchProducts",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        page_size: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .filters = "Filters",
                .page_size = "PageSize",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_products) } {
            return .{ .service_metadata = service_metadata, .action = search_products };
        }
    },
    Response: type = struct {
        product_view_summaries: ?[]ProductViewSummary = null,
        product_view_aggregations: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                value: ?[]const u8 = null,
                approximate_count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .value = "Value",
                        .approximate_count = "ApproximateCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_view_summaries = "ProductViewSummaries",
                .product_view_aggregations = "ProductViewAggregations",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "product_view_aggregations", field_name))
                return try serializeMap(self.product_view_aggregations, self.fieldNameFor("product_view_aggregations"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameters,
    },
} = .{};
pub const search_products_as_admin: struct {
    action_name: []const u8 = "SearchProductsAsAdmin",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: ?[]const u8 = null,
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        page_token: ?[]const u8 = null,
        page_size: ?i64 = null,
        product_source: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .filters = "Filters",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .page_token = "PageToken",
                .page_size = "PageSize",
                .product_source = "ProductSource",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_products_as_admin) } {
            return .{ .service_metadata = service_metadata, .action = search_products_as_admin };
        }
    },
    Response: type = struct {
        product_view_details: ?[]ProductViewDetail = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_view_details = "ProductViewDetails",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const search_provisioned_products: struct {
    action_name: []const u8 = "SearchProvisionedProducts",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        access_level_filter: ?AccessLevelFilter = null,
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        page_size: ?i64 = null,
        page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .access_level_filter = "AccessLevelFilter",
                .filters = "Filters",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .page_size = "PageSize",
                .page_token = "PageToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filters", field_name))
                return try serializeMap(self.filters, self.fieldNameFor("filters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_provisioned_products) } {
            return .{ .service_metadata = service_metadata, .action = search_provisioned_products };
        }
    },
    Response: type = struct {
        provisioned_products: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            type: ?[]const u8 = null,
            id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            created_time: ?i64 = null,
            idempotency_token: ?[]const u8 = null,
            last_record_id: ?[]const u8 = null,
            last_provisioning_record_id: ?[]const u8 = null,
            last_successful_provisioning_record_id: ?[]const u8 = null,
            tags: ?[]Tag = null,
            physical_id: ?[]const u8 = null,
            product_id: ?[]const u8 = null,
            product_name: ?[]const u8 = null,
            provisioning_artifact_id: ?[]const u8 = null,
            provisioning_artifact_name: ?[]const u8 = null,
            user_arn: ?[]const u8 = null,
            user_arn_session: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "Arn",
                    .type = "Type",
                    .id = "Id",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .created_time = "CreatedTime",
                    .idempotency_token = "IdempotencyToken",
                    .last_record_id = "LastRecordId",
                    .last_provisioning_record_id = "LastProvisioningRecordId",
                    .last_successful_provisioning_record_id = "LastSuccessfulProvisioningRecordId",
                    .tags = "Tags",
                    .physical_id = "PhysicalId",
                    .product_id = "ProductId",
                    .product_name = "ProductName",
                    .provisioning_artifact_id = "ProvisioningArtifactId",
                    .provisioning_artifact_name = "ProvisioningArtifactName",
                    .user_arn = "UserArn",
                    .user_arn_session = "UserArnSession",
                };
                return @field(mappings, field_name);
            }
        } = null,
        total_results_count: ?i64 = null,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_products = "ProvisionedProducts",
                .total_results_count = "TotalResultsCount",
                .next_page_token = "NextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
    },
} = .{};
pub const terminate_provisioned_product: struct {
    action_name: []const u8 = "TerminateProvisionedProduct",
    Request: type = struct {
        provisioned_product_name: ?[]const u8 = null,
        provisioned_product_id: ?[]const u8 = null,
        terminate_token: []const u8,
        ignore_errors: ?bool = null,
        accept_language: ?[]const u8 = null,
        retain_physical_resources: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_product_name = "ProvisionedProductName",
                .provisioned_product_id = "ProvisionedProductId",
                .terminate_token = "TerminateToken",
                .ignore_errors = "IgnoreErrors",
                .accept_language = "AcceptLanguage",
                .retain_physical_resources = "RetainPhysicalResources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_provisioned_product) } {
            return .{ .service_metadata = service_metadata, .action = terminate_provisioned_product };
        }
    },
    Response: type = struct {
        record_detail: ?RecordDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .record_detail = "RecordDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_constraint: struct {
    action_name: []const u8 = "UpdateConstraint",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: []const u8,
        description: ?[]const u8 = null,
        parameters: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
                .description = "Description",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_constraint) } {
            return .{ .service_metadata = service_metadata, .action = update_constraint };
        }
    },
    Response: type = struct {
        constraint_detail: ?ConstraintDetail = null,
        constraint_parameters: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .constraint_detail = "ConstraintDetail",
                .constraint_parameters = "ConstraintParameters",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const update_portfolio: struct {
    action_name: []const u8 = "UpdatePortfolio",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: []const u8,
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        provider_name: ?[]const u8 = null,
        add_tags: ?[]Tag = null,
        remove_tags: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
                .display_name = "DisplayName",
                .description = "Description",
                .provider_name = "ProviderName",
                .add_tags = "AddTags",
                .remove_tags = "RemoveTags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = update_portfolio };
        }
    },
    Response: type = struct {
        portfolio_detail: ?PortfolioDetail = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_detail = "PortfolioDetail",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        LimitExceeded,
        ResourceNotFound,
        TagOptionNotMigrated,
    },
} = .{};
pub const update_portfolio_share: struct {
    action_name: []const u8 = "UpdatePortfolioShare",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        portfolio_id: []const u8,
        account_id: ?[]const u8 = null,
        organization_node: ?OrganizationNode = null,
        share_tag_options: ?bool = null,
        share_principals: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .portfolio_id = "PortfolioId",
                .account_id = "AccountId",
                .organization_node = "OrganizationNode",
                .share_tag_options = "ShareTagOptions",
                .share_principals = "SharePrincipals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_portfolio_share) } {
            return .{ .service_metadata = service_metadata, .action = update_portfolio_share };
        }
    },
    Response: type = struct {
        portfolio_share_token: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .portfolio_share_token = "PortfolioShareToken",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        InvalidState,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const update_product: struct {
    action_name: []const u8 = "UpdateProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        id: []const u8,
        name: ?[]const u8 = null,
        owner: ?[]const u8 = null,
        description: ?[]const u8 = null,
        distributor: ?[]const u8 = null,
        support_description: ?[]const u8 = null,
        support_email: ?[]const u8 = null,
        support_url: ?[]const u8 = null,
        add_tags: ?[]Tag = null,
        remove_tags: ?[][]const u8 = null,
        source_connection: ?SourceConnection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .id = "Id",
                .name = "Name",
                .owner = "Owner",
                .description = "Description",
                .distributor = "Distributor",
                .support_description = "SupportDescription",
                .support_email = "SupportEmail",
                .support_url = "SupportUrl",
                .add_tags = "AddTags",
                .remove_tags = "RemoveTags",
                .source_connection = "SourceConnection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_product) } {
            return .{ .service_metadata = service_metadata, .action = update_product };
        }
    },
    Response: type = struct {
        product_view_detail: ?ProductViewDetail = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_view_detail = "ProductViewDetail",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
        TagOptionNotMigrated,
    },
} = .{};
pub const update_provisioned_product: struct {
    action_name: []const u8 = "UpdateProvisionedProduct",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        provisioned_product_name: ?[]const u8 = null,
        provisioned_product_id: ?[]const u8 = null,
        product_id: ?[]const u8 = null,
        product_name: ?[]const u8 = null,
        provisioning_artifact_id: ?[]const u8 = null,
        provisioning_artifact_name: ?[]const u8 = null,
        path_id: ?[]const u8 = null,
        path_name: ?[]const u8 = null,
        provisioning_parameters: ?[]UpdateProvisioningParameter = null,
        provisioning_preferences: ?struct {
            stack_set_accounts: ?[][]const u8 = null,
            stack_set_regions: ?[][]const u8 = null,
            stack_set_failure_tolerance_count: ?i64 = null,
            stack_set_failure_tolerance_percentage: ?i64 = null,
            stack_set_max_concurrency_count: ?i64 = null,
            stack_set_max_concurrency_percentage: ?i64 = null,
            stack_set_operation_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stack_set_accounts = "StackSetAccounts",
                    .stack_set_regions = "StackSetRegions",
                    .stack_set_failure_tolerance_count = "StackSetFailureToleranceCount",
                    .stack_set_failure_tolerance_percentage = "StackSetFailureTolerancePercentage",
                    .stack_set_max_concurrency_count = "StackSetMaxConcurrencyCount",
                    .stack_set_max_concurrency_percentage = "StackSetMaxConcurrencyPercentage",
                    .stack_set_operation_type = "StackSetOperationType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]Tag = null,
        update_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .provisioned_product_name = "ProvisionedProductName",
                .provisioned_product_id = "ProvisionedProductId",
                .product_id = "ProductId",
                .product_name = "ProductName",
                .provisioning_artifact_id = "ProvisioningArtifactId",
                .provisioning_artifact_name = "ProvisioningArtifactName",
                .path_id = "PathId",
                .path_name = "PathName",
                .provisioning_parameters = "ProvisioningParameters",
                .provisioning_preferences = "ProvisioningPreferences",
                .tags = "Tags",
                .update_token = "UpdateToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_provisioned_product) } {
            return .{ .service_metadata = service_metadata, .action = update_provisioned_product };
        }
    },
    Response: type = struct {
        record_detail: ?RecordDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .record_detail = "RecordDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const update_provisioned_product_properties: struct {
    action_name: []const u8 = "UpdateProvisionedProductProperties",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        provisioned_product_id: []const u8,
        provisioned_product_properties: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        idempotency_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .provisioned_product_id = "ProvisionedProductId",
                .provisioned_product_properties = "ProvisionedProductProperties",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "provisioned_product_properties", field_name))
                return try serializeMap(self.provisioned_product_properties, self.fieldNameFor("provisioned_product_properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_provisioned_product_properties) } {
            return .{ .service_metadata = service_metadata, .action = update_provisioned_product_properties };
        }
    },
    Response: type = struct {
        provisioned_product_id: ?[]const u8 = null,
        provisioned_product_properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        record_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioned_product_id = "ProvisionedProductId",
                .provisioned_product_properties = "ProvisionedProductProperties",
                .record_id = "RecordId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "provisioned_product_properties", field_name))
                return try serializeMap(self.provisioned_product_properties, self.fieldNameFor("provisioned_product_properties"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        InvalidState,
        ResourceNotFound,
    },
} = .{};
pub const update_provisioning_artifact: struct {
    action_name: []const u8 = "UpdateProvisioningArtifact",
    Request: type = struct {
        accept_language: ?[]const u8 = null,
        product_id: []const u8,
        provisioning_artifact_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        active: ?bool = null,
        guidance: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accept_language = "AcceptLanguage",
                .product_id = "ProductId",
                .provisioning_artifact_id = "ProvisioningArtifactId",
                .name = "Name",
                .description = "Description",
                .active = "Active",
                .guidance = "Guidance",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_provisioning_artifact) } {
            return .{ .service_metadata = service_metadata, .action = update_provisioning_artifact };
        }
    },
    Response: type = struct {
        provisioning_artifact_detail: ?ProvisioningArtifactDetail = null,
        info: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provisioning_artifact_detail = "ProvisioningArtifactDetail",
                .info = "Info",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "info", field_name))
                return try serializeMap(self.info, self.fieldNameFor("info"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const update_service_action: struct {
    action_name: []const u8 = "UpdateServiceAction",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        definition: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        description: ?[]const u8 = null,
        accept_language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .definition = "Definition",
                .description = "Description",
                .accept_language = "AcceptLanguage",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "definition", field_name))
                return try serializeMap(self.definition, self.fieldNameFor("definition"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_service_action) } {
            return .{ .service_metadata = service_metadata, .action = update_service_action };
        }
    },
    Response: type = struct {
        service_action_detail: ?ServiceActionDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_action_detail = "ServiceActionDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameters,
        ResourceNotFound,
    },
} = .{};
pub const update_tag_option: struct {
    action_name: []const u8 = "UpdateTagOption",
    Request: type = struct {
        id: []const u8,
        value: ?[]const u8 = null,
        active: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .value = "Value",
                .active = "Active",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_tag_option) } {
            return .{ .service_metadata = service_metadata, .action = update_tag_option };
        }
    },
    Response: type = struct {
        tag_option_detail: ?TagOptionDetail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_option_detail = "TagOptionDetail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InvalidParameters,
        ResourceNotFound,
        TagOptionNotMigrated,
    },
} = .{};

pub const TagOptionDetail = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,
    active: ?bool = null,
    id: ?[]const u8 = null,
    owner: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
            .active = "Active",
            .id = "Id",
            .owner = "Owner",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceActionDetail = struct {
    service_action_summary: ?ServiceActionSummary = null,
    definition: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_action_summary = "ServiceActionSummary",
            .definition = "Definition",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "definition", field_name))
            return try serializeMap(self.definition, self.fieldNameFor("definition"), options, out_stream);
        return false;
    }
};

pub const ServiceActionSummary = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    definition_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .description = "Description",
            .definition_type = "DefinitionType",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisioningArtifactDetail = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    created_time: ?i64 = null,
    active: ?bool = null,
    guidance: ?[]const u8 = null,
    source_revision: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .description = "Description",
            .type = "Type",
            .created_time = "CreatedTime",
            .active = "Active",
            .guidance = "Guidance",
            .source_revision = "SourceRevision",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordDetail = struct {
    record_id: ?[]const u8 = null,
    provisioned_product_name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_time: ?i64 = null,
    updated_time: ?i64 = null,
    provisioned_product_type: ?[]const u8 = null,
    record_type: ?[]const u8 = null,
    provisioned_product_id: ?[]const u8 = null,
    product_id: ?[]const u8 = null,
    provisioning_artifact_id: ?[]const u8 = null,
    path_id: ?[]const u8 = null,
    record_errors: ?[]RecordError = null,
    record_tags: ?[]RecordTag = null,
    launch_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .record_id = "RecordId",
            .provisioned_product_name = "ProvisionedProductName",
            .status = "Status",
            .created_time = "CreatedTime",
            .updated_time = "UpdatedTime",
            .provisioned_product_type = "ProvisionedProductType",
            .record_type = "RecordType",
            .provisioned_product_id = "ProvisionedProductId",
            .product_id = "ProductId",
            .provisioning_artifact_id = "ProvisioningArtifactId",
            .path_id = "PathId",
            .record_errors = "RecordErrors",
            .record_tags = "RecordTags",
            .launch_role_arn = "LaunchRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordTag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordError = struct {
    code: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateProvisioningParameter = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,
    use_previous_value: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
            .use_previous_value = "UsePreviousValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ProductViewDetail = struct {
    product_view_summary: ?ProductViewSummary = null,
    status: ?[]const u8 = null,
    product_arn: ?[]const u8 = null,
    created_time: ?i64 = null,
    source_connection: ?SourceConnectionDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_view_summary = "ProductViewSummary",
            .status = "Status",
            .product_arn = "ProductARN",
            .created_time = "CreatedTime",
            .source_connection = "SourceConnection",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceConnectionDetail = struct {
    type: ?[]const u8 = null,
    connection_parameters: ?SourceConnectionParameters = null,
    last_sync: ?LastSync = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .connection_parameters = "ConnectionParameters",
            .last_sync = "LastSync",
        };
        return @field(mappings, field_name);
    }
};

pub const LastSync = struct {
    last_sync_time: ?i64 = null,
    last_sync_status: ?[]const u8 = null,
    last_sync_status_message: ?[]const u8 = null,
    last_successful_sync_time: ?i64 = null,
    last_successful_sync_provisioning_artifact_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .last_sync_time = "LastSyncTime",
            .last_sync_status = "LastSyncStatus",
            .last_sync_status_message = "LastSyncStatusMessage",
            .last_successful_sync_time = "LastSuccessfulSyncTime",
            .last_successful_sync_provisioning_artifact_id = "LastSuccessfulSyncProvisioningArtifactId",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceConnectionParameters = struct {
    code_star: ?CodeStarParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code_star = "CodeStar",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeStarParameters = struct {
    connection_arn: []const u8,
    repository: []const u8,
    branch: []const u8,
    artifact_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_arn = "ConnectionArn",
            .repository = "Repository",
            .branch = "Branch",
            .artifact_path = "ArtifactPath",
        };
        return @field(mappings, field_name);
    }
};

pub const ProductViewSummary = struct {
    id: ?[]const u8 = null,
    product_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    short_description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    distributor: ?[]const u8 = null,
    has_default_path: ?bool = null,
    support_email: ?[]const u8 = null,
    support_description: ?[]const u8 = null,
    support_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .product_id = "ProductId",
            .name = "Name",
            .owner = "Owner",
            .short_description = "ShortDescription",
            .type = "Type",
            .distributor = "Distributor",
            .has_default_path = "HasDefaultPath",
            .support_email = "SupportEmail",
            .support_description = "SupportDescription",
            .support_url = "SupportUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceConnection = struct {
    type: ?[]const u8 = null,
    connection_parameters: SourceConnectionParameters,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .connection_parameters = "ConnectionParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const OrganizationNode = struct {
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const PortfolioDetail = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    display_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_time: ?i64 = null,
    provider_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "ARN",
            .display_name = "DisplayName",
            .description = "Description",
            .created_time = "CreatedTime",
            .provider_name = "ProviderName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConstraintDetail = struct {
    constraint_id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    description: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    product_id: ?[]const u8 = null,
    portfolio_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .constraint_id = "ConstraintId",
            .type = "Type",
            .description = "Description",
            .owner = "Owner",
            .product_id = "ProductId",
            .portfolio_id = "PortfolioId",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessLevelFilter = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisionedProductDetail = struct {
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    type: ?[]const u8 = null,
    id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    created_time: ?i64 = null,
    idempotency_token: ?[]const u8 = null,
    last_record_id: ?[]const u8 = null,
    last_provisioning_record_id: ?[]const u8 = null,
    last_successful_provisioning_record_id: ?[]const u8 = null,
    product_id: ?[]const u8 = null,
    provisioning_artifact_id: ?[]const u8 = null,
    launch_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .arn = "Arn",
            .type = "Type",
            .id = "Id",
            .status = "Status",
            .status_message = "StatusMessage",
            .created_time = "CreatedTime",
            .idempotency_token = "IdempotencyToken",
            .last_record_id = "LastRecordId",
            .last_provisioning_record_id = "LastProvisioningRecordId",
            .last_successful_provisioning_record_id = "LastSuccessfulProvisioningRecordId",
            .product_id = "ProductId",
            .provisioning_artifact_id = "ProvisioningArtifactId",
            .launch_role_arn = "LaunchRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordOutput = struct {
    output_key: ?[]const u8 = null,
    output_value: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_key = "OutputKey",
            .output_value = "OutputValue",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisioningArtifact = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_time: ?i64 = null,
    guidance: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .description = "Description",
            .created_time = "CreatedTime",
            .guidance = "Guidance",
        };
        return @field(mappings, field_name);
    }
};

pub const ConstraintSummary = struct {
    type: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const BudgetDetail = struct {
    budget_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .budget_name = "BudgetName",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisioningArtifactOutput = struct {
    key: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisioningArtifactParameter = struct {
    parameter_key: ?[]const u8 = null,
    default_value: ?[]const u8 = null,
    parameter_type: ?[]const u8 = null,
    is_no_echo: ?bool = null,
    description: ?[]const u8 = null,
    parameter_constraints: ?ParameterConstraints = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_key = "ParameterKey",
            .default_value = "DefaultValue",
            .parameter_type = "ParameterType",
            .is_no_echo = "IsNoEcho",
            .description = "Description",
            .parameter_constraints = "ParameterConstraints",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterConstraints = struct {
    allowed_values: ?[][]const u8 = null,
    allowed_pattern: ?[]const u8 = null,
    constraint_description: ?[]const u8 = null,
    max_length: ?[]const u8 = null,
    min_length: ?[]const u8 = null,
    max_value: ?[]const u8 = null,
    min_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allowed_values = "AllowedValues",
            .allowed_pattern = "AllowedPattern",
            .constraint_description = "ConstraintDescription",
            .max_length = "MaxLength",
            .min_length = "MinLength",
            .max_value = "MaxValue",
            .min_value = "MinValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisioningArtifactProperties = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    info: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    type: ?[]const u8 = null,
    disable_template_validation: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .info = "Info",
            .type = "Type",
            .disable_template_validation = "DisableTemplateValidation",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "info", field_name))
            return try serializeMap(self.info, self.fieldNameFor("info"), options, out_stream);
        return false;
    }
};

pub const FailedServiceActionAssociation = struct {
    service_action_id: ?[]const u8 = null,
    product_id: ?[]const u8 = null,
    provisioning_artifact_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_action_id = "ServiceActionId",
            .product_id = "ProductId",
            .provisioning_artifact_id = "ProvisioningArtifactId",
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceActionAssociation = struct {
    service_action_id: []const u8,
    product_id: []const u8,
    provisioning_artifact_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_action_id = "ServiceActionId",
            .product_id = "ProductId",
            .provisioning_artifact_id = "ProvisioningArtifactId",
        };
        return @field(mappings, field_name);
    }
};
