const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-06-24";
pub const sdk_id: []const u8 = "Service Catalog AppRegistry";
pub const arn_namespace: ?[]const u8 = "servicecatalog";
pub const endpoint_prefix: []const u8 = "servicecatalog-appregistry";
pub const sigv4_name: []const u8 = "servicecatalog";
pub const name: []const u8 = "AWS242AppRegistry";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-06-24",
    sdk_id: []const u8 = "Service Catalog AppRegistry",
    arn_namespace: ?[]const u8 = "servicecatalog",
    endpoint_prefix: []const u8 = "servicecatalog-appregistry",
    sigv4_name: []const u8 = "servicecatalog",
    name: []const u8 = "AWS242AppRegistry",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_attribute_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/applications/{application}/attribute-groups/{attributeGroup}",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateAttributeGroup",
    Request: type = struct {
        application: []const u8,
        attribute_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .attribute_group = "attributeGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_attribute_group) } {
            return .{ .service_metadata = service_metadata, .action = associate_attribute_group };
        }
    },
    Response: type = struct {
        application_arn: ?[]const u8 = null,
        attribute_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "applicationArn",
                .attribute_group_arn = "attributeGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const associate_resource: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/applications/{application}/resources/{resourceType}/{resource}",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateResource",
    Request: type = struct {
        application: []const u8,
        resource_type: []const u8,
        resource: []const u8,
        options: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .resource_type = "resourceType",
                .resource = "resource",
                .options = "options",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_resource) } {
            return .{ .service_metadata = service_metadata, .action = associate_resource };
        }
    },
    Response: type = struct {
        application_arn: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        options: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "applicationArn",
                .resource_arn = "resourceArn",
                .options = "options",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/applications",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateApplication",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application) } {
            return .{ .service_metadata = service_metadata, .action = create_application };
        }
    },
    Response: type = struct {
        application: ?Application = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_attribute_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/attribute-groups",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAttributeGroup",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        attributes: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .attributes = "attributes",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_attribute_group) } {
            return .{ .service_metadata = service_metadata, .action = create_attribute_group };
        }
    },
    Response: type = struct {
        attribute_group: ?AttributeGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_group = "attributeGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_application: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{application}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApplication",
    Request: type = struct {
        application: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_application };
        }
    },
    Response: type = struct {
        application: ?ApplicationSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const delete_attribute_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/attribute-groups/{attributeGroup}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAttributeGroup",
    Request: type = struct {
        attribute_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_group = "attributeGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_attribute_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_attribute_group };
        }
    },
    Response: type = struct {
        attribute_group: ?AttributeGroupSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_group = "attributeGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const disassociate_attribute_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{application}/attribute-groups/{attributeGroup}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateAttributeGroup",
    Request: type = struct {
        application: []const u8,
        attribute_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .attribute_group = "attributeGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_attribute_group) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_attribute_group };
        }
    },
    Response: type = struct {
        application_arn: ?[]const u8 = null,
        attribute_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "applicationArn",
                .attribute_group_arn = "attributeGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const disassociate_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/applications/{application}/resources/{resourceType}/{resource}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateResource",
    Request: type = struct {
        application: []const u8,
        resource_type: []const u8,
        resource: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .resource_type = "resourceType",
                .resource = "resource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_resource) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_resource };
        }
    },
    Response: type = struct {
        application_arn: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "applicationArn",
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_application: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{application}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplication",
    Request: type = struct {
        application: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application) } {
            return .{ .service_metadata = service_metadata, .action = get_application };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_update_time: ?i64 = null,
        associated_resource_count: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        integrations: ?struct {
            resource_group: ?ResourceGroup = null,
            application_tag_resource_group: ?ResourceGroup = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_group = "resourceGroup",
                    .application_tag_resource_group = "applicationTagResourceGroup",
                };
                return @field(mappings, field_name);
            }
        } = null,
        application_tag: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .name = "name",
                .description = "description",
                .creation_time = "creationTime",
                .last_update_time = "lastUpdateTime",
                .associated_resource_count = "associatedResourceCount",
                .tags = "tags",
                .integrations = "integrations",
                .application_tag = "applicationTag",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "application_tag", field_name))
                return try serializeMap(self.application_tag, self.fieldNameFor("application_tag"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_associated_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{application}/resources/{resourceType}/{resource}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAssociatedResource",
    Request: type = struct {
        application: []const u8,
        resource_type: []const u8,
        resource: []const u8,
        next_token: ?[]const u8 = null,
        resource_tag_status: ?[][]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .resource_tag_status = "resourceTagStatus",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .resource_type = "resourceType",
                .resource = "resource",
                .next_token = "nextToken",
                .resource_tag_status = "resourceTagStatus",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_associated_resource) } {
            return .{ .service_metadata = service_metadata, .action = get_associated_resource };
        }
    },
    Response: type = struct {
        resource: ?struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            association_time: ?i64 = null,
            integrations: ?struct {
                resource_group: ?ResourceGroup = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_group = "resourceGroup",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                    .association_time = "associationTime",
                    .integrations = "integrations",
                };
                return @field(mappings, field_name);
            }
        } = null,
        options: ?[][]const u8 = null,
        application_tag_result: ?struct {
            application_tag_status: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            resources: ?[]struct {
                resource_arn: ?[]const u8 = null,
                error_message: ?[]const u8 = null,
                status: ?[]const u8 = null,
                resource_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_arn = "resourceArn",
                        .error_message = "errorMessage",
                        .status = "status",
                        .resource_type = "resourceType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            next_token: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_tag_status = "applicationTagStatus",
                    .error_message = "errorMessage",
                    .resources = "resources",
                    .next_token = "nextToken",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "resource",
                .options = "options",
                .application_tag_result = "applicationTagResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_attribute_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/attribute-groups/{attributeGroup}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAttributeGroup",
    Request: type = struct {
        attribute_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_group = "attributeGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_attribute_group) } {
            return .{ .service_metadata = service_metadata, .action = get_attribute_group };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        attributes: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_update_time: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        created_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .name = "name",
                .description = "description",
                .attributes = "attributes",
                .creation_time = "creationTime",
                .last_update_time = "lastUpdateTime",
                .tags = "tags",
                .created_by = "createdBy",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfiguration",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration };
        }
    },
    Response: type = struct {
        configuration: ?AppRegistryConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "configuration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
    },
} = .{};
pub const list_applications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplications",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_applications };
        }
    },
    Response: type = struct {
        applications: ?[]ApplicationSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applications = "applications",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_associated_attribute_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{application}/attribute-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssociatedAttributeGroups",
    Request: type = struct {
        application: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associated_attribute_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_associated_attribute_groups };
        }
    },
    Response: type = struct {
        attribute_groups: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_groups = "attributeGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_associated_resources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{application}/resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAssociatedResources",
    Request: type = struct {
        application: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associated_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_associated_resources };
        }
    },
    Response: type = struct {
        resources: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            resource_details: ?struct {
                tag_value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .tag_value = "tagValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            options: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .arn = "arn",
                    .resource_type = "resourceType",
                    .resource_details = "resourceDetails",
                    .options = "options",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "resources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_attribute_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/attribute-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAttributeGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_attribute_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_attribute_groups };
        }
    },
    Response: type = struct {
        attribute_groups: ?[]AttributeGroupSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_groups = "attributeGroups",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_attribute_groups_for_application: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/applications/{application}/attribute-group-details",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAttributeGroupsForApplication",
    Request: type = struct {
        application: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_attribute_groups_for_application) } {
            return .{ .service_metadata = service_metadata, .action = list_attribute_groups_for_application };
        }
    },
    Response: type = struct {
        attribute_groups_details: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            created_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .name = "name",
                    .created_by = "createdBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_groups_details = "attributeGroupsDetails",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfiguration",
    Request: type = struct {
        configuration: AppRegistryConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InternalServer,
        Validation,
    },
} = .{};
pub const sync_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sync/{resourceType}/{resource}",
        .success_code = 200,
    };

    action_name: []const u8 = "SyncResource",
    Request: type = struct {
        resource_type: []const u8,
        resource: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type = "resourceType",
                .resource = "resource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(sync_resource) } {
            return .{ .service_metadata = service_metadata, .action = sync_resource };
        }
    },
    Response: type = struct {
        application_arn: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        action_taken: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "applicationArn",
                .resource_arn = "resourceArn",
                .action_taken = "actionTaken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_application: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/applications/{application}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApplication",
    Request: type = struct {
        application: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
                .name = "name",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application) } {
            return .{ .service_metadata = service_metadata, .action = update_application };
        }
    },
    Response: type = struct {
        application: ?Application = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "application",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_attribute_group: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/attribute-groups/{attributeGroup}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAttributeGroup",
    Request: type = struct {
        attribute_group: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        attributes: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_group = "attributeGroup",
                .name = "name",
                .description = "description",
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_attribute_group) } {
            return .{ .service_metadata = service_metadata, .action = update_attribute_group };
        }
    },
    Response: type = struct {
        attribute_group: ?AttributeGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute_group = "attributeGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const AttributeGroup = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_update_time: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .name = "name",
            .description = "description",
            .creation_time = "creationTime",
            .last_update_time = "lastUpdateTime",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Application = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_update_time: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    application_tag: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .name = "name",
            .description = "description",
            .creation_time = "creationTime",
            .last_update_time = "lastUpdateTime",
            .tags = "tags",
            .application_tag = "applicationTag",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        if (std.mem.eql(u8, "application_tag", field_name))
            return try serializeMap(self.application_tag, self.fieldNameFor("application_tag"), options, out_stream);
        return false;
    }
};

pub const AppRegistryConfiguration = struct {
    tag_query_configuration: ?TagQueryConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_query_configuration = "tagQueryConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TagQueryConfiguration = struct {
    tag_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_key = "tagKey",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeGroupSummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_update_time: ?i64 = null,
    created_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .name = "name",
            .description = "description",
            .creation_time = "creationTime",
            .last_update_time = "lastUpdateTime",
            .created_by = "createdBy",
        };
        return @field(mappings, field_name);
    }
};

pub const ApplicationSummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_update_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .arn = "arn",
            .name = "name",
            .description = "description",
            .creation_time = "creationTime",
            .last_update_time = "lastUpdateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceGroup = struct {
    state: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "state",
            .arn = "arn",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};
