const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-03-14";
pub const sdk_id: []const u8 = "ServiceDiscovery";
pub const arn_namespace: ?[]const u8 = "servicediscovery";
pub const endpoint_prefix: []const u8 = "servicediscovery";
pub const sigv4_name: []const u8 = "servicediscovery";
pub const name: []const u8 = "Route53AutoNaming_v20170314";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-03-14",
    sdk_id: []const u8 = "ServiceDiscovery",
    arn_namespace: ?[]const u8 = "servicediscovery",
    endpoint_prefix: []const u8 = "servicediscovery",
    sigv4_name: []const u8 = "servicediscovery",
    name: []const u8 = "Route53AutoNaming_v20170314",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_http_namespace: struct {
    action_name: []const u8 = "CreateHttpNamespace",
    Request: type = struct {
        name: []const u8,
        creator_request_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .creator_request_id = "CreatorRequestId",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_http_namespace) } {
            return .{ .service_metadata = service_metadata, .action = create_http_namespace };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateRequest,
        InvalidInput,
        NamespaceAlreadyExists,
        ResourceLimitExceeded,
        TooManyTags,
    },
} = .{};
pub const create_private_dns_namespace: struct {
    action_name: []const u8 = "CreatePrivateDnsNamespace",
    Request: type = struct {
        name: []const u8,
        creator_request_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        vpc: []const u8,
        tags: ?[]Tag = null,
        properties: ?struct {
            dns_properties: struct {
                soa: SOA,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .soa = "SOA",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dns_properties = "DnsProperties",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .creator_request_id = "CreatorRequestId",
                .description = "Description",
                .vpc = "Vpc",
                .tags = "Tags",
                .properties = "Properties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_private_dns_namespace) } {
            return .{ .service_metadata = service_metadata, .action = create_private_dns_namespace };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateRequest,
        InvalidInput,
        NamespaceAlreadyExists,
        ResourceLimitExceeded,
        TooManyTags,
    },
} = .{};
pub const create_public_dns_namespace: struct {
    action_name: []const u8 = "CreatePublicDnsNamespace",
    Request: type = struct {
        name: []const u8,
        creator_request_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        properties: ?struct {
            dns_properties: struct {
                soa: SOA,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .soa = "SOA",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dns_properties = "DnsProperties",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .creator_request_id = "CreatorRequestId",
                .description = "Description",
                .tags = "Tags",
                .properties = "Properties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_public_dns_namespace) } {
            return .{ .service_metadata = service_metadata, .action = create_public_dns_namespace };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateRequest,
        InvalidInput,
        NamespaceAlreadyExists,
        ResourceLimitExceeded,
        TooManyTags,
    },
} = .{};
pub const create_service: struct {
    action_name: []const u8 = "CreateService",
    Request: type = struct {
        name: []const u8,
        namespace_id: ?[]const u8 = null,
        creator_request_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        dns_config: ?DnsConfig = null,
        health_check_config: ?HealthCheckConfig = null,
        health_check_custom_config: ?HealthCheckCustomConfig = null,
        tags: ?[]Tag = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .namespace_id = "NamespaceId",
                .creator_request_id = "CreatorRequestId",
                .description = "Description",
                .dns_config = "DnsConfig",
                .health_check_config = "HealthCheckConfig",
                .health_check_custom_config = "HealthCheckCustomConfig",
                .tags = "Tags",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_service) } {
            return .{ .service_metadata = service_metadata, .action = create_service };
        }
    },
    Response: type = struct {
        service: ?Service = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "Service",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NamespaceNotFound,
        ResourceLimitExceeded,
        ServiceAlreadyExists,
        TooManyTags,
    },
} = .{};
pub const delete_namespace: struct {
    action_name: []const u8 = "DeleteNamespace",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_namespace) } {
            return .{ .service_metadata = service_metadata, .action = delete_namespace };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateRequest,
        InvalidInput,
        NamespaceNotFound,
        ResourceInUse,
    },
} = .{};
pub const delete_service: struct {
    action_name: []const u8 = "DeleteService",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_service) } {
            return .{ .service_metadata = service_metadata, .action = delete_service };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ServiceNotFound,
    },
} = .{};
pub const deregister_instance: struct {
    action_name: []const u8 = "DeregisterInstance",
    Request: type = struct {
        service_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_id = "ServiceId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_instance) } {
            return .{ .service_metadata = service_metadata, .action = deregister_instance };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateRequest,
        InstanceNotFound,
        InvalidInput,
        ResourceInUse,
        ServiceNotFound,
    },
} = .{};
pub const discover_instances: struct {
    action_name: []const u8 = "DiscoverInstances",
    Request: type = struct {
        namespace_name: []const u8,
        service_name: []const u8,
        max_results: ?i64 = null,
        query_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        optional_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        health_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespace_name = "NamespaceName",
                .service_name = "ServiceName",
                .max_results = "MaxResults",
                .query_parameters = "QueryParameters",
                .optional_parameters = "OptionalParameters",
                .health_status = "HealthStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "query_parameters", field_name))
                return try serializeMap(self.query_parameters, self.fieldNameFor("query_parameters"), options, out_stream);
            if (std.mem.eql(u8, "optional_parameters", field_name))
                return try serializeMap(self.optional_parameters, self.fieldNameFor("optional_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(discover_instances) } {
            return .{ .service_metadata = service_metadata, .action = discover_instances };
        }
    },
    Response: type = struct {
        instances: ?[]struct {
            instance_id: ?[]const u8 = null,
            namespace_name: ?[]const u8 = null,
            service_name: ?[]const u8 = null,
            health_status: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "InstanceId",
                    .namespace_name = "NamespaceName",
                    .service_name = "ServiceName",
                    .health_status = "HealthStatus",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,
        instances_revision: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "Instances",
                .instances_revision = "InstancesRevision",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NamespaceNotFound,
        RequestLimitExceeded,
        ServiceNotFound,
    },
} = .{};
pub const discover_instances_revision: struct {
    action_name: []const u8 = "DiscoverInstancesRevision",
    Request: type = struct {
        namespace_name: []const u8,
        service_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespace_name = "NamespaceName",
                .service_name = "ServiceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(discover_instances_revision) } {
            return .{ .service_metadata = service_metadata, .action = discover_instances_revision };
        }
    },
    Response: type = struct {
        instances_revision: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances_revision = "InstancesRevision",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NamespaceNotFound,
        RequestLimitExceeded,
        ServiceNotFound,
    },
} = .{};
pub const get_instance: struct {
    action_name: []const u8 = "GetInstance",
    Request: type = struct {
        service_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_id = "ServiceId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_instance) } {
            return .{ .service_metadata = service_metadata, .action = get_instance };
        }
    },
    Response: type = struct {
        instance: ?struct {
            id: []const u8,
            creator_request_id: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .creator_request_id = "CreatorRequestId",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance = "Instance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InstanceNotFound,
        InvalidInput,
        ServiceNotFound,
    },
} = .{};
pub const get_instances_health_status: struct {
    action_name: []const u8 = "GetInstancesHealthStatus",
    Request: type = struct {
        service_id: []const u8,
        instances: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_id = "ServiceId",
                .instances = "Instances",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_instances_health_status) } {
            return .{ .service_metadata = service_metadata, .action = get_instances_health_status };
        }
    },
    Response: type = struct {
        status: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "status", field_name))
                return try serializeMap(self.status, self.fieldNameFor("status"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InstanceNotFound,
        InvalidInput,
        ServiceNotFound,
    },
} = .{};
pub const get_namespace: struct {
    action_name: []const u8 = "GetNamespace",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_namespace) } {
            return .{ .service_metadata = service_metadata, .action = get_namespace };
        }
    },
    Response: type = struct {
        namespace: ?struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            service_count: ?i64 = null,
            properties: ?NamespaceProperties = null,
            create_date: ?i64 = null,
            creator_request_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .type = "Type",
                    .description = "Description",
                    .service_count = "ServiceCount",
                    .properties = "Properties",
                    .create_date = "CreateDate",
                    .creator_request_id = "CreatorRequestId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        NamespaceNotFound,
    },
} = .{};
pub const get_operation: struct {
    action_name: []const u8 = "GetOperation",
    Request: type = struct {
        operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_operation) } {
            return .{ .service_metadata = service_metadata, .action = get_operation };
        }
    },
    Response: type = struct {
        operation: ?struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            create_date: ?i64 = null,
            update_date: ?i64 = null,
            targets: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                    .status = "Status",
                    .error_message = "ErrorMessage",
                    .error_code = "ErrorCode",
                    .create_date = "CreateDate",
                    .update_date = "UpdateDate",
                    .targets = "Targets",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "targets", field_name))
                    return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation = "Operation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        OperationNotFound,
    },
} = .{};
pub const get_service: struct {
    action_name: []const u8 = "GetService",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service) } {
            return .{ .service_metadata = service_metadata, .action = get_service };
        }
    },
    Response: type = struct {
        service: ?Service = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service = "Service",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ServiceNotFound,
    },
} = .{};
pub const list_instances: struct {
    action_name: []const u8 = "ListInstances",
    Request: type = struct {
        service_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_id = "ServiceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_instances };
        }
    },
    Response: type = struct {
        instances: ?[]struct {
            id: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "Instances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ServiceNotFound,
    },
} = .{};
pub const list_namespaces: struct {
    action_name: []const u8 = "ListNamespaces",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            condition: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                    .condition = "Condition",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_namespaces) } {
            return .{ .service_metadata = service_metadata, .action = list_namespaces };
        }
    },
    Response: type = struct {
        namespaces: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            service_count: ?i64 = null,
            properties: ?NamespaceProperties = null,
            create_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .type = "Type",
                    .description = "Description",
                    .service_count = "ServiceCount",
                    .properties = "Properties",
                    .create_date = "CreateDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespaces = "Namespaces",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
    },
} = .{};
pub const list_operations: struct {
    action_name: []const u8 = "ListOperations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            condition: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                    .condition = "Condition",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_operations) } {
            return .{ .service_metadata = service_metadata, .action = list_operations };
        }
    },
    Response: type = struct {
        operations: ?[]struct {
            id: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operations = "Operations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
    },
} = .{};
pub const list_services: struct {
    action_name: []const u8 = "ListServices",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            condition: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                    .condition = "Condition",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_services) } {
            return .{ .service_metadata = service_metadata, .action = list_services };
        }
    },
    Response: type = struct {
        services: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            instance_count: ?i64 = null,
            dns_config: ?DnsConfig = null,
            health_check_config: ?HealthCheckConfig = null,
            health_check_custom_config: ?HealthCheckCustomConfig = null,
            create_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .type = "Type",
                    .description = "Description",
                    .instance_count = "InstanceCount",
                    .dns_config = "DnsConfig",
                    .health_check_config = "HealthCheckConfig",
                    .health_check_custom_config = "HealthCheckCustomConfig",
                    .create_date = "CreateDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .services = "Services",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const register_instance: struct {
    action_name: []const u8 = "RegisterInstance",
    Request: type = struct {
        service_id: []const u8,
        instance_id: []const u8,
        creator_request_id: ?[]const u8 = null,
        attributes: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_id = "ServiceId",
                .instance_id = "InstanceId",
                .creator_request_id = "CreatorRequestId",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_instance) } {
            return .{ .service_metadata = service_metadata, .action = register_instance };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateRequest,
        InvalidInput,
        ResourceInUse,
        ResourceLimitExceeded,
        ServiceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const update_http_namespace: struct {
    action_name: []const u8 = "UpdateHttpNamespace",
    Request: type = struct {
        id: []const u8,
        updater_request_id: ?[]const u8 = null,
        namespace: struct {
            description: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .updater_request_id = "UpdaterRequestId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_http_namespace) } {
            return .{ .service_metadata = service_metadata, .action = update_http_namespace };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateRequest,
        InvalidInput,
        NamespaceNotFound,
        ResourceInUse,
    },
} = .{};
pub const update_instance_custom_health_status: struct {
    action_name: []const u8 = "UpdateInstanceCustomHealthStatus",
    Request: type = struct {
        service_id: []const u8,
        instance_id: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_id = "ServiceId",
                .instance_id = "InstanceId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_instance_custom_health_status) } {
            return .{ .service_metadata = service_metadata, .action = update_instance_custom_health_status };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CustomHealthNotFound,
        InstanceNotFound,
        InvalidInput,
        ServiceNotFound,
    },
} = .{};
pub const update_private_dns_namespace: struct {
    action_name: []const u8 = "UpdatePrivateDnsNamespace",
    Request: type = struct {
        id: []const u8,
        updater_request_id: ?[]const u8 = null,
        namespace: struct {
            description: ?[]const u8 = null,
            properties: ?struct {
                dns_properties: struct {
                    soa: SOAChange,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .soa = "SOA",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .dns_properties = "DnsProperties",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .properties = "Properties",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .updater_request_id = "UpdaterRequestId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_private_dns_namespace) } {
            return .{ .service_metadata = service_metadata, .action = update_private_dns_namespace };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateRequest,
        InvalidInput,
        NamespaceNotFound,
        ResourceInUse,
    },
} = .{};
pub const update_public_dns_namespace: struct {
    action_name: []const u8 = "UpdatePublicDnsNamespace",
    Request: type = struct {
        id: []const u8,
        updater_request_id: ?[]const u8 = null,
        namespace: struct {
            description: ?[]const u8 = null,
            properties: ?struct {
                dns_properties: struct {
                    soa: SOAChange,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .soa = "SOA",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .dns_properties = "DnsProperties",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .properties = "Properties",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .updater_request_id = "UpdaterRequestId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_public_dns_namespace) } {
            return .{ .service_metadata = service_metadata, .action = update_public_dns_namespace };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateRequest,
        InvalidInput,
        NamespaceNotFound,
        ResourceInUse,
    },
} = .{};
pub const update_service: struct {
    action_name: []const u8 = "UpdateService",
    Request: type = struct {
        id: []const u8,
        service: struct {
            description: ?[]const u8 = null,
            dns_config: ?struct {
                dns_records: []DnsRecord,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .dns_records = "DnsRecords",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            health_check_config: ?HealthCheckConfig = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .dns_config = "DnsConfig",
                    .health_check_config = "HealthCheckConfig",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .service = "Service",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_service) } {
            return .{ .service_metadata = service_metadata, .action = update_service };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateRequest,
        InvalidInput,
        ServiceNotFound,
    },
} = .{};

pub const HealthCheckConfig = struct {
    type: []const u8,
    resource_path: ?[]const u8 = null,
    failure_threshold: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .resource_path = "ResourcePath",
            .failure_threshold = "FailureThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const DnsRecord = struct {
    type: []const u8,
    ttl: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .ttl = "TTL",
        };
        return @field(mappings, field_name);
    }
};

pub const SOAChange = struct {
    ttl: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ttl = "TTL",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const HealthCheckCustomConfig = struct {
    failure_threshold: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failure_threshold = "FailureThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const DnsConfig = struct {
    namespace_id: ?[]const u8 = null,
    routing_policy: ?[]const u8 = null,
    dns_records: []DnsRecord,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace_id = "NamespaceId",
            .routing_policy = "RoutingPolicy",
            .dns_records = "DnsRecords",
        };
        return @field(mappings, field_name);
    }
};

pub const NamespaceProperties = struct {
    dns_properties: ?DnsProperties = null,
    http_properties: ?HttpProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dns_properties = "DnsProperties",
            .http_properties = "HttpProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpProperties = struct {
    http_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_name = "HttpName",
        };
        return @field(mappings, field_name);
    }
};

pub const DnsProperties = struct {
    hosted_zone_id: ?[]const u8 = null,
    soa: ?SOA = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hosted_zone_id = "HostedZoneId",
            .soa = "SOA",
        };
        return @field(mappings, field_name);
    }
};

pub const SOA = struct {
    ttl: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ttl = "TTL",
        };
        return @field(mappings, field_name);
    }
};

pub const Service = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    namespace_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    instance_count: ?i64 = null,
    dns_config: ?DnsConfig = null,
    type: ?[]const u8 = null,
    health_check_config: ?HealthCheckConfig = null,
    health_check_custom_config: ?HealthCheckCustomConfig = null,
    create_date: ?i64 = null,
    creator_request_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
            .namespace_id = "NamespaceId",
            .description = "Description",
            .instance_count = "InstanceCount",
            .dns_config = "DnsConfig",
            .type = "Type",
            .health_check_config = "HealthCheckConfig",
            .health_check_custom_config = "HealthCheckCustomConfig",
            .create_date = "CreateDate",
            .creator_request_id = "CreatorRequestId",
        };
        return @field(mappings, field_name);
    }
};
