const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2010-12-01";
pub const sdk_id: []const u8 = "SES";
pub const arn_namespace: ?[]const u8 = "ses";
pub const endpoint_prefix: []const u8 = "email";
pub const sigv4_name: []const u8 = "ses";
pub const name: []const u8 = "SimpleEmailService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query;

pub const service_metadata: struct {
    version: []const u8 = "2010-12-01",
    sdk_id: []const u8 = "SES",
    arn_namespace: ?[]const u8 = "ses",
    endpoint_prefix: []const u8 = "email",
    sigv4_name: []const u8 = "ses",
    name: []const u8 = "SimpleEmailService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query,
} = .{};
pub const clone_receipt_rule_set: struct {
    action_name: []const u8 = "CloneReceiptRuleSet",
    Request: type = struct {
        rule_set_name: []const u8,
        original_rule_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
                .original_rule_set_name = "OriginalRuleSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(clone_receipt_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = clone_receipt_rule_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        LimitExceeded,
        RuleSetDoesNotExist,
    },
} = .{};
pub const create_configuration_set: struct {
    action_name: []const u8 = "CreateConfigurationSet",
    Request: type = struct {
        configuration_set: ConfigurationSet,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set = "ConfigurationSet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetAlreadyExists,
        InvalidConfigurationSet,
        LimitExceeded,
    },
} = .{};
pub const create_configuration_set_event_destination: struct {
    action_name: []const u8 = "CreateConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination: EventDestination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination = "EventDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
        EventDestinationAlreadyExists,
        InvalidCloudWatchDestination,
        InvalidFirehoseDestination,
        InvalidSNSDestination,
        LimitExceeded,
    },
} = .{};
pub const create_configuration_set_tracking_options: struct {
    action_name: []const u8 = "CreateConfigurationSetTrackingOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        tracking_options: TrackingOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .tracking_options = "TrackingOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_set_tracking_options) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_set_tracking_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
        InvalidTrackingOptions,
        TrackingOptionsAlreadyExists,
    },
} = .{};
pub const create_custom_verification_email_template: struct {
    action_name: []const u8 = "CreateCustomVerificationEmailTemplate",
    Request: type = struct {
        template_name: []const u8,
        from_email_address: []const u8,
        template_subject: []const u8,
        template_content: []const u8,
        success_redirection_url: []const u8,
        failure_redirection_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .from_email_address = "FromEmailAddress",
                .template_subject = "TemplateSubject",
                .template_content = "TemplateContent",
                .success_redirection_url = "SuccessRedirectionURL",
                .failure_redirection_url = "FailureRedirectionURL",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_verification_email_template) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_verification_email_template };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CustomVerificationEmailInvalidContent,
        CustomVerificationEmailTemplateAlreadyExists,
        FromEmailAddressNotVerified,
        LimitExceeded,
    },
} = .{};
pub const create_receipt_filter: struct {
    action_name: []const u8 = "CreateReceiptFilter",
    Request: type = struct {
        filter: ReceiptFilter,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_receipt_filter) } {
            return .{ .service_metadata = service_metadata, .action = create_receipt_filter };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        LimitExceeded,
    },
} = .{};
pub const create_receipt_rule: struct {
    action_name: []const u8 = "CreateReceiptRule",
    Request: type = struct {
        rule_set_name: []const u8,
        after: ?[]const u8 = null,
        rule: ReceiptRule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
                .after = "After",
                .rule = "Rule",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_receipt_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_receipt_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidLambdaFunction,
        InvalidS3Configuration,
        InvalidSnsTopic,
        LimitExceeded,
        RuleDoesNotExist,
        RuleSetDoesNotExist,
    },
} = .{};
pub const create_receipt_rule_set: struct {
    action_name: []const u8 = "CreateReceiptRuleSet",
    Request: type = struct {
        rule_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_receipt_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = create_receipt_rule_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        LimitExceeded,
    },
} = .{};
pub const create_template: struct {
    action_name: []const u8 = "CreateTemplate",
    Request: type = struct {
        template: Template,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template = "Template",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_template) } {
            return .{ .service_metadata = service_metadata, .action = create_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidTemplate,
        LimitExceeded,
    },
} = .{};
pub const delete_configuration_set: struct {
    action_name: []const u8 = "DeleteConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
    },
} = .{};
pub const delete_configuration_set_event_destination: struct {
    action_name: []const u8 = "DeleteConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
        EventDestinationDoesNotExist,
    },
} = .{};
pub const delete_configuration_set_tracking_options: struct {
    action_name: []const u8 = "DeleteConfigurationSetTrackingOptions",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_set_tracking_options) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_set_tracking_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
        TrackingOptionsDoesNotExist,
    },
} = .{};
pub const delete_custom_verification_email_template: struct {
    action_name: []const u8 = "DeleteCustomVerificationEmailTemplate",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_verification_email_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_verification_email_template };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_identity: struct {
    action_name: []const u8 = "DeleteIdentity",
    Request: type = struct {
        identity: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity = "Identity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_identity) } {
            return .{ .service_metadata = service_metadata, .action = delete_identity };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_identity_policy: struct {
    action_name: []const u8 = "DeleteIdentityPolicy",
    Request: type = struct {
        identity: []const u8,
        policy_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity = "Identity",
                .policy_name = "PolicyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_identity_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_identity_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_receipt_filter: struct {
    action_name: []const u8 = "DeleteReceiptFilter",
    Request: type = struct {
        filter_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter_name = "FilterName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_receipt_filter) } {
            return .{ .service_metadata = service_metadata, .action = delete_receipt_filter };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_receipt_rule: struct {
    action_name: []const u8 = "DeleteReceiptRule",
    Request: type = struct {
        rule_set_name: []const u8,
        rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
                .rule_name = "RuleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_receipt_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_receipt_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RuleSetDoesNotExist,
    },
} = .{};
pub const delete_receipt_rule_set: struct {
    action_name: []const u8 = "DeleteReceiptRuleSet",
    Request: type = struct {
        rule_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_receipt_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_receipt_rule_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CannotDelete,
    },
} = .{};
pub const delete_template: struct {
    action_name: []const u8 = "DeleteTemplate",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_verified_email_address: struct {
    action_name: []const u8 = "DeleteVerifiedEmailAddress",
    Request: type = struct {
        email_address: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_address = "EmailAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_verified_email_address) } {
            return .{ .service_metadata = service_metadata, .action = delete_verified_email_address };
        }
    },
    Response: type = struct {},
} = .{};
pub const describe_active_receipt_rule_set: struct {
    action_name: []const u8 = "DescribeActiveReceiptRuleSet",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_active_receipt_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_active_receipt_rule_set };
        }
    },
    Response: type = struct {
        metadata: ?ReceiptRuleSetMetadata = null,
        rules: ?[]ReceiptRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata = "Metadata",
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_configuration_set: struct {
    action_name: []const u8 = "DescribeConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,
        configuration_set_attribute_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .configuration_set_attribute_names = "ConfigurationSetAttributeNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration_set };
        }
    },
    Response: type = struct {
        configuration_set: ?ConfigurationSet = null,
        event_destinations: ?[]EventDestination = null,
        tracking_options: ?TrackingOptions = null,
        delivery_options: ?DeliveryOptions = null,
        reputation_options: ?struct {
            sending_enabled: ?bool = null,
            reputation_metrics_enabled: ?bool = null,
            last_fresh_start: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sending_enabled = "SendingEnabled",
                    .reputation_metrics_enabled = "ReputationMetricsEnabled",
                    .last_fresh_start = "LastFreshStart",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set = "ConfigurationSet",
                .event_destinations = "EventDestinations",
                .tracking_options = "TrackingOptions",
                .delivery_options = "DeliveryOptions",
                .reputation_options = "ReputationOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
    },
} = .{};
pub const describe_receipt_rule: struct {
    action_name: []const u8 = "DescribeReceiptRule",
    Request: type = struct {
        rule_set_name: []const u8,
        rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
                .rule_name = "RuleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_receipt_rule) } {
            return .{ .service_metadata = service_metadata, .action = describe_receipt_rule };
        }
    },
    Response: type = struct {
        rule: ?ReceiptRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule = "Rule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RuleDoesNotExist,
        RuleSetDoesNotExist,
    },
} = .{};
pub const describe_receipt_rule_set: struct {
    action_name: []const u8 = "DescribeReceiptRuleSet",
    Request: type = struct {
        rule_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_receipt_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_receipt_rule_set };
        }
    },
    Response: type = struct {
        metadata: ?ReceiptRuleSetMetadata = null,
        rules: ?[]ReceiptRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata = "Metadata",
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RuleSetDoesNotExist,
    },
} = .{};
pub const get_account_sending_enabled: struct {
    action_name: []const u8 = "GetAccountSendingEnabled",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_sending_enabled) } {
            return .{ .service_metadata = service_metadata, .action = get_account_sending_enabled };
        }
    },
    Response: type = struct {
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_custom_verification_email_template: struct {
    action_name: []const u8 = "GetCustomVerificationEmailTemplate",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_custom_verification_email_template) } {
            return .{ .service_metadata = service_metadata, .action = get_custom_verification_email_template };
        }
    },
    Response: type = struct {
        template_name: ?[]const u8 = null,
        from_email_address: ?[]const u8 = null,
        template_subject: ?[]const u8 = null,
        template_content: ?[]const u8 = null,
        success_redirection_url: ?[]const u8 = null,
        failure_redirection_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .from_email_address = "FromEmailAddress",
                .template_subject = "TemplateSubject",
                .template_content = "TemplateContent",
                .success_redirection_url = "SuccessRedirectionURL",
                .failure_redirection_url = "FailureRedirectionURL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomVerificationEmailTemplateDoesNotExist,
    },
} = .{};
pub const get_identity_dkim_attributes: struct {
    action_name: []const u8 = "GetIdentityDkimAttributes",
    Request: type = struct {
        identities: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identities = "Identities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_identity_dkim_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_identity_dkim_attributes };
        }
    },
    Response: type = struct {
        dkim_attributes: []struct {
            key: ?[]const u8 = null,
            value: ?struct {
                dkim_enabled: bool,
                dkim_verification_status: []const u8,
                dkim_tokens: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .dkim_enabled = "DkimEnabled",
                        .dkim_verification_status = "DkimVerificationStatus",
                        .dkim_tokens = "DkimTokens",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dkim_attributes = "DkimAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "dkim_attributes", field_name))
                return try serializeMap(self.dkim_attributes, self.fieldNameFor("dkim_attributes"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const get_identity_mail_from_domain_attributes: struct {
    action_name: []const u8 = "GetIdentityMailFromDomainAttributes",
    Request: type = struct {
        identities: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identities = "Identities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_identity_mail_from_domain_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_identity_mail_from_domain_attributes };
        }
    },
    Response: type = struct {
        mail_from_domain_attributes: []struct {
            key: ?[]const u8 = null,
            value: ?struct {
                mail_from_domain: []const u8,
                mail_from_domain_status: []const u8,
                behavior_on_mx_failure: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .mail_from_domain = "MailFromDomain",
                        .mail_from_domain_status = "MailFromDomainStatus",
                        .behavior_on_mx_failure = "BehaviorOnMXFailure",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mail_from_domain_attributes = "MailFromDomainAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "mail_from_domain_attributes", field_name))
                return try serializeMap(self.mail_from_domain_attributes, self.fieldNameFor("mail_from_domain_attributes"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const get_identity_notification_attributes: struct {
    action_name: []const u8 = "GetIdentityNotificationAttributes",
    Request: type = struct {
        identities: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identities = "Identities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_identity_notification_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_identity_notification_attributes };
        }
    },
    Response: type = struct {
        notification_attributes: []struct {
            key: ?[]const u8 = null,
            value: ?struct {
                bounce_topic: []const u8,
                complaint_topic: []const u8,
                delivery_topic: []const u8,
                forwarding_enabled: bool,
                headers_in_bounce_notifications_enabled: ?bool = null,
                headers_in_complaint_notifications_enabled: ?bool = null,
                headers_in_delivery_notifications_enabled: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bounce_topic = "BounceTopic",
                        .complaint_topic = "ComplaintTopic",
                        .delivery_topic = "DeliveryTopic",
                        .forwarding_enabled = "ForwardingEnabled",
                        .headers_in_bounce_notifications_enabled = "HeadersInBounceNotificationsEnabled",
                        .headers_in_complaint_notifications_enabled = "HeadersInComplaintNotificationsEnabled",
                        .headers_in_delivery_notifications_enabled = "HeadersInDeliveryNotificationsEnabled",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notification_attributes = "NotificationAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "notification_attributes", field_name))
                return try serializeMap(self.notification_attributes, self.fieldNameFor("notification_attributes"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const get_identity_policies: struct {
    action_name: []const u8 = "GetIdentityPolicies",
    Request: type = struct {
        identity: []const u8,
        policy_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity = "Identity",
                .policy_names = "PolicyNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_identity_policies) } {
            return .{ .service_metadata = service_metadata, .action = get_identity_policies };
        }
    },
    Response: type = struct {
        policies: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policies = "Policies",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "policies", field_name))
                return try serializeMap(self.policies, self.fieldNameFor("policies"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const get_identity_verification_attributes: struct {
    action_name: []const u8 = "GetIdentityVerificationAttributes",
    Request: type = struct {
        identities: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identities = "Identities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_identity_verification_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_identity_verification_attributes };
        }
    },
    Response: type = struct {
        verification_attributes: []struct {
            key: ?[]const u8 = null,
            value: ?struct {
                verification_status: []const u8,
                verification_token: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .verification_status = "VerificationStatus",
                        .verification_token = "VerificationToken",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verification_attributes = "VerificationAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "verification_attributes", field_name))
                return try serializeMap(self.verification_attributes, self.fieldNameFor("verification_attributes"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const get_send_quota: struct {
    action_name: []const u8 = "GetSendQuota",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_send_quota) } {
            return .{ .service_metadata = service_metadata, .action = get_send_quota };
        }
    },
    Response: type = struct {
        max24_hour_send: ?f64 = null,
        max_send_rate: ?f64 = null,
        sent_last24_hours: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max24_hour_send = "Max24HourSend",
                .max_send_rate = "MaxSendRate",
                .sent_last24_hours = "SentLast24Hours",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_send_statistics: struct {
    action_name: []const u8 = "GetSendStatistics",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_send_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_send_statistics };
        }
    },
    Response: type = struct {
        send_data_points: ?[]struct {
            timestamp: ?i64 = null,
            delivery_attempts: ?i64 = null,
            bounces: ?i64 = null,
            complaints: ?i64 = null,
            rejects: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .delivery_attempts = "DeliveryAttempts",
                    .bounces = "Bounces",
                    .complaints = "Complaints",
                    .rejects = "Rejects",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .send_data_points = "SendDataPoints",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_template: struct {
    action_name: []const u8 = "GetTemplate",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_template) } {
            return .{ .service_metadata = service_metadata, .action = get_template };
        }
    },
    Response: type = struct {
        template: ?Template = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template = "Template",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        TemplateDoesNotExist,
    },
} = .{};
pub const list_configuration_sets: struct {
    action_name: []const u8 = "ListConfigurationSets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configuration_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_configuration_sets };
        }
    },
    Response: type = struct {
        configuration_sets: ?[]ConfigurationSet = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_sets = "ConfigurationSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_custom_verification_email_templates: struct {
    action_name: []const u8 = "ListCustomVerificationEmailTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_verification_email_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_verification_email_templates };
        }
    },
    Response: type = struct {
        custom_verification_email_templates: ?[]struct {
            template_name: ?[]const u8 = null,
            from_email_address: ?[]const u8 = null,
            template_subject: ?[]const u8 = null,
            success_redirection_url: ?[]const u8 = null,
            failure_redirection_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .template_name = "TemplateName",
                    .from_email_address = "FromEmailAddress",
                    .template_subject = "TemplateSubject",
                    .success_redirection_url = "SuccessRedirectionURL",
                    .failure_redirection_url = "FailureRedirectionURL",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_verification_email_templates = "CustomVerificationEmailTemplates",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_identities: struct {
    action_name: []const u8 = "ListIdentities",
    Request: type = struct {
        identity_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_type = "IdentityType",
                .next_token = "NextToken",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_identities) } {
            return .{ .service_metadata = service_metadata, .action = list_identities };
        }
    },
    Response: type = struct {
        identities: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identities = "Identities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_identity_policies: struct {
    action_name: []const u8 = "ListIdentityPolicies",
    Request: type = struct {
        identity: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity = "Identity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_identity_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_identity_policies };
        }
    },
    Response: type = struct {
        policy_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_names = "PolicyNames",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_receipt_filters: struct {
    action_name: []const u8 = "ListReceiptFilters",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_receipt_filters) } {
            return .{ .service_metadata = service_metadata, .action = list_receipt_filters };
        }
    },
    Response: type = struct {
        filters: ?[]ReceiptFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_receipt_rule_sets: struct {
    action_name: []const u8 = "ListReceiptRuleSets",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_receipt_rule_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_receipt_rule_sets };
        }
    },
    Response: type = struct {
        rule_sets: ?[]ReceiptRuleSetMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_sets = "RuleSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_templates: struct {
    action_name: []const u8 = "ListTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_items: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_templates };
        }
    },
    Response: type = struct {
        templates_metadata: ?[]struct {
            name: ?[]const u8 = null,
            created_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .templates_metadata = "TemplatesMetadata",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_verified_email_addresses: struct {
    action_name: []const u8 = "ListVerifiedEmailAddresses",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_verified_email_addresses) } {
            return .{ .service_metadata = service_metadata, .action = list_verified_email_addresses };
        }
    },
    Response: type = struct {
        verified_email_addresses: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verified_email_addresses = "VerifiedEmailAddresses",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_configuration_set_delivery_options: struct {
    action_name: []const u8 = "PutConfigurationSetDeliveryOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        delivery_options: ?DeliveryOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .delivery_options = "DeliveryOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_delivery_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_delivery_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
        InvalidDeliveryOptions,
    },
} = .{};
pub const put_identity_policy: struct {
    action_name: []const u8 = "PutIdentityPolicy",
    Request: type = struct {
        identity: []const u8,
        policy_name: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity = "Identity",
                .policy_name = "PolicyName",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_identity_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_identity_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPolicy,
    },
} = .{};
pub const reorder_receipt_rule_set: struct {
    action_name: []const u8 = "ReorderReceiptRuleSet",
    Request: type = struct {
        rule_set_name: []const u8,
        rule_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
                .rule_names = "RuleNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reorder_receipt_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = reorder_receipt_rule_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RuleDoesNotExist,
        RuleSetDoesNotExist,
    },
} = .{};
pub const send_bounce: struct {
    action_name: []const u8 = "SendBounce",
    Request: type = struct {
        original_message_id: []const u8,
        bounce_sender: []const u8,
        explanation: ?[]const u8 = null,
        message_dsn: ?struct {
            reporting_mta: []const u8,
            arrival_date: ?i64 = null,
            extension_fields: ?[]ExtensionField = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reporting_mta = "ReportingMta",
                    .arrival_date = "ArrivalDate",
                    .extension_fields = "ExtensionFields",
                };
                return @field(mappings, field_name);
            }
        } = null,
        bounced_recipient_info_list: []struct {
            recipient: []const u8,
            recipient_arn: ?[]const u8 = null,
            bounce_type: ?[]const u8 = null,
            recipient_dsn_fields: ?struct {
                final_recipient: ?[]const u8 = null,
                action: []const u8,
                remote_mta: ?[]const u8 = null,
                status: []const u8,
                diagnostic_code: ?[]const u8 = null,
                last_attempt_date: ?i64 = null,
                extension_fields: ?[]ExtensionField = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .final_recipient = "FinalRecipient",
                        .action = "Action",
                        .remote_mta = "RemoteMta",
                        .status = "Status",
                        .diagnostic_code = "DiagnosticCode",
                        .last_attempt_date = "LastAttemptDate",
                        .extension_fields = "ExtensionFields",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recipient = "Recipient",
                    .recipient_arn = "RecipientArn",
                    .bounce_type = "BounceType",
                    .recipient_dsn_fields = "RecipientDsnFields",
                };
                return @field(mappings, field_name);
            }
        },
        bounce_sender_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .original_message_id = "OriginalMessageId",
                .bounce_sender = "BounceSender",
                .explanation = "Explanation",
                .message_dsn = "MessageDsn",
                .bounced_recipient_info_list = "BouncedRecipientInfoList",
                .bounce_sender_arn = "BounceSenderArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_bounce) } {
            return .{ .service_metadata = service_metadata, .action = send_bounce };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        MessageRejected,
    },
} = .{};
pub const send_bulk_templated_email: struct {
    action_name: []const u8 = "SendBulkTemplatedEmail",
    Request: type = struct {
        source: []const u8,
        source_arn: ?[]const u8 = null,
        reply_to_addresses: ?[][]const u8 = null,
        return_path: ?[]const u8 = null,
        return_path_arn: ?[]const u8 = null,
        configuration_set_name: ?[]const u8 = null,
        default_tags: ?[]MessageTag = null,
        template: []const u8,
        template_arn: ?[]const u8 = null,
        default_template_data: ?[]const u8 = null,
        destinations: []struct {
            destination: Destination,
            replacement_tags: ?[]MessageTag = null,
            replacement_template_data: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .destination = "Destination",
                    .replacement_tags = "ReplacementTags",
                    .replacement_template_data = "ReplacementTemplateData",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "Source",
                .source_arn = "SourceArn",
                .reply_to_addresses = "ReplyToAddresses",
                .return_path = "ReturnPath",
                .return_path_arn = "ReturnPathArn",
                .configuration_set_name = "ConfigurationSetName",
                .default_tags = "DefaultTags",
                .template = "Template",
                .template_arn = "TemplateArn",
                .default_template_data = "DefaultTemplateData",
                .destinations = "Destinations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_bulk_templated_email) } {
            return .{ .service_metadata = service_metadata, .action = send_bulk_templated_email };
        }
    },
    Response: type = struct {
        status: []struct {
            status: ?[]const u8 = null,
            @"error": ?[]const u8 = null,
            message_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "Status",
                    .@"error" = "Error",
                    .message_id = "MessageId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountSendingPaused,
        ConfigurationSetDoesNotExist,
        ConfigurationSetSendingPaused,
        MailFromDomainNotVerified,
        MessageRejected,
        TemplateDoesNotExist,
    },
} = .{};
pub const send_custom_verification_email: struct {
    action_name: []const u8 = "SendCustomVerificationEmail",
    Request: type = struct {
        email_address: []const u8,
        template_name: []const u8,
        configuration_set_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_address = "EmailAddress",
                .template_name = "TemplateName",
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_custom_verification_email) } {
            return .{ .service_metadata = service_metadata, .action = send_custom_verification_email };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
        CustomVerificationEmailTemplateDoesNotExist,
        FromEmailAddressNotVerified,
        MessageRejected,
        ProductionAccessNotGranted,
    },
} = .{};
pub const send_email: struct {
    action_name: []const u8 = "SendEmail",
    Request: type = struct {
        source: []const u8,
        destination: Destination,
        message: struct {
            subject: Content,
            body: struct {
                text: ?Content = null,
                html: ?Content = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .text = "Text",
                        .html = "Html",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .subject = "Subject",
                    .body = "Body",
                };
                return @field(mappings, field_name);
            }
        },
        reply_to_addresses: ?[][]const u8 = null,
        return_path: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        return_path_arn: ?[]const u8 = null,
        tags: ?[]MessageTag = null,
        configuration_set_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "Source",
                .destination = "Destination",
                .message = "Message",
                .reply_to_addresses = "ReplyToAddresses",
                .return_path = "ReturnPath",
                .source_arn = "SourceArn",
                .return_path_arn = "ReturnPathArn",
                .tags = "Tags",
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_email) } {
            return .{ .service_metadata = service_metadata, .action = send_email };
        }
    },
    Response: type = struct {
        message_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountSendingPaused,
        ConfigurationSetDoesNotExist,
        ConfigurationSetSendingPaused,
        MailFromDomainNotVerified,
        MessageRejected,
    },
} = .{};
pub const send_raw_email: struct {
    action_name: []const u8 = "SendRawEmail",
    Request: type = struct {
        source: ?[]const u8 = null,
        destinations: ?[][]const u8 = null,
        raw_message: struct {
            data: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .data = "Data",
                };
                return @field(mappings, field_name);
            }
        },
        from_arn: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        return_path_arn: ?[]const u8 = null,
        tags: ?[]MessageTag = null,
        configuration_set_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "Source",
                .destinations = "Destinations",
                .raw_message = "RawMessage",
                .from_arn = "FromArn",
                .source_arn = "SourceArn",
                .return_path_arn = "ReturnPathArn",
                .tags = "Tags",
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_raw_email) } {
            return .{ .service_metadata = service_metadata, .action = send_raw_email };
        }
    },
    Response: type = struct {
        message_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountSendingPaused,
        ConfigurationSetDoesNotExist,
        ConfigurationSetSendingPaused,
        MailFromDomainNotVerified,
        MessageRejected,
    },
} = .{};
pub const send_templated_email: struct {
    action_name: []const u8 = "SendTemplatedEmail",
    Request: type = struct {
        source: []const u8,
        destination: Destination,
        reply_to_addresses: ?[][]const u8 = null,
        return_path: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        return_path_arn: ?[]const u8 = null,
        tags: ?[]MessageTag = null,
        configuration_set_name: ?[]const u8 = null,
        template: []const u8,
        template_arn: ?[]const u8 = null,
        template_data: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "Source",
                .destination = "Destination",
                .reply_to_addresses = "ReplyToAddresses",
                .return_path = "ReturnPath",
                .source_arn = "SourceArn",
                .return_path_arn = "ReturnPathArn",
                .tags = "Tags",
                .configuration_set_name = "ConfigurationSetName",
                .template = "Template",
                .template_arn = "TemplateArn",
                .template_data = "TemplateData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_templated_email) } {
            return .{ .service_metadata = service_metadata, .action = send_templated_email };
        }
    },
    Response: type = struct {
        message_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountSendingPaused,
        ConfigurationSetDoesNotExist,
        ConfigurationSetSendingPaused,
        MailFromDomainNotVerified,
        MessageRejected,
        TemplateDoesNotExist,
    },
} = .{};
pub const set_active_receipt_rule_set: struct {
    action_name: []const u8 = "SetActiveReceiptRuleSet",
    Request: type = struct {
        rule_set_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_active_receipt_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = set_active_receipt_rule_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RuleSetDoesNotExist,
    },
} = .{};
pub const set_identity_dkim_enabled: struct {
    action_name: []const u8 = "SetIdentityDkimEnabled",
    Request: type = struct {
        identity: []const u8,
        dkim_enabled: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity = "Identity",
                .dkim_enabled = "DkimEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_identity_dkim_enabled) } {
            return .{ .service_metadata = service_metadata, .action = set_identity_dkim_enabled };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const set_identity_feedback_forwarding_enabled: struct {
    action_name: []const u8 = "SetIdentityFeedbackForwardingEnabled",
    Request: type = struct {
        identity: []const u8,
        forwarding_enabled: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity = "Identity",
                .forwarding_enabled = "ForwardingEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_identity_feedback_forwarding_enabled) } {
            return .{ .service_metadata = service_metadata, .action = set_identity_feedback_forwarding_enabled };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const set_identity_headers_in_notifications_enabled: struct {
    action_name: []const u8 = "SetIdentityHeadersInNotificationsEnabled",
    Request: type = struct {
        identity: []const u8,
        notification_type: []const u8,
        enabled: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity = "Identity",
                .notification_type = "NotificationType",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_identity_headers_in_notifications_enabled) } {
            return .{ .service_metadata = service_metadata, .action = set_identity_headers_in_notifications_enabled };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const set_identity_mail_from_domain: struct {
    action_name: []const u8 = "SetIdentityMailFromDomain",
    Request: type = struct {
        identity: []const u8,
        mail_from_domain: ?[]const u8 = null,
        behavior_on_mx_failure: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity = "Identity",
                .mail_from_domain = "MailFromDomain",
                .behavior_on_mx_failure = "BehaviorOnMXFailure",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_identity_mail_from_domain) } {
            return .{ .service_metadata = service_metadata, .action = set_identity_mail_from_domain };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const set_identity_notification_topic: struct {
    action_name: []const u8 = "SetIdentityNotificationTopic",
    Request: type = struct {
        identity: []const u8,
        notification_type: []const u8,
        sns_topic: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity = "Identity",
                .notification_type = "NotificationType",
                .sns_topic = "SnsTopic",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_identity_notification_topic) } {
            return .{ .service_metadata = service_metadata, .action = set_identity_notification_topic };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const set_receipt_rule_position: struct {
    action_name: []const u8 = "SetReceiptRulePosition",
    Request: type = struct {
        rule_set_name: []const u8,
        rule_name: []const u8,
        after: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
                .rule_name = "RuleName",
                .after = "After",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_receipt_rule_position) } {
            return .{ .service_metadata = service_metadata, .action = set_receipt_rule_position };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RuleDoesNotExist,
        RuleSetDoesNotExist,
    },
} = .{};
pub const test_render_template: struct {
    action_name: []const u8 = "TestRenderTemplate",
    Request: type = struct {
        template_name: []const u8,
        template_data: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .template_data = "TemplateData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_render_template) } {
            return .{ .service_metadata = service_metadata, .action = test_render_template };
        }
    },
    Response: type = struct {
        rendered_template: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rendered_template = "RenderedTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRenderingParameter,
        MissingRenderingAttribute,
        TemplateDoesNotExist,
    },
} = .{};
pub const update_account_sending_enabled: struct {
    action_name: []const u8 = "UpdateAccountSendingEnabled",
    Request: type = struct {
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_sending_enabled) } {
            return .{ .service_metadata = service_metadata, .action = update_account_sending_enabled };
        }
    },
    Response: type = struct {},
} = .{};
pub const update_configuration_set_event_destination: struct {
    action_name: []const u8 = "UpdateConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination: EventDestination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination = "EventDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
        EventDestinationDoesNotExist,
        InvalidCloudWatchDestination,
        InvalidFirehoseDestination,
        InvalidSNSDestination,
    },
} = .{};
pub const update_configuration_set_reputation_metrics_enabled: struct {
    action_name: []const u8 = "UpdateConfigurationSetReputationMetricsEnabled",
    Request: type = struct {
        configuration_set_name: []const u8,
        enabled: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration_set_reputation_metrics_enabled) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration_set_reputation_metrics_enabled };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
    },
} = .{};
pub const update_configuration_set_sending_enabled: struct {
    action_name: []const u8 = "UpdateConfigurationSetSendingEnabled",
    Request: type = struct {
        configuration_set_name: []const u8,
        enabled: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration_set_sending_enabled) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration_set_sending_enabled };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
    },
} = .{};
pub const update_configuration_set_tracking_options: struct {
    action_name: []const u8 = "UpdateConfigurationSetTrackingOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        tracking_options: TrackingOptions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .tracking_options = "TrackingOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration_set_tracking_options) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration_set_tracking_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConfigurationSetDoesNotExist,
        InvalidTrackingOptions,
        TrackingOptionsDoesNotExist,
    },
} = .{};
pub const update_custom_verification_email_template: struct {
    action_name: []const u8 = "UpdateCustomVerificationEmailTemplate",
    Request: type = struct {
        template_name: []const u8,
        from_email_address: ?[]const u8 = null,
        template_subject: ?[]const u8 = null,
        template_content: ?[]const u8 = null,
        success_redirection_url: ?[]const u8 = null,
        failure_redirection_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .from_email_address = "FromEmailAddress",
                .template_subject = "TemplateSubject",
                .template_content = "TemplateContent",
                .success_redirection_url = "SuccessRedirectionURL",
                .failure_redirection_url = "FailureRedirectionURL",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_custom_verification_email_template) } {
            return .{ .service_metadata = service_metadata, .action = update_custom_verification_email_template };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CustomVerificationEmailInvalidContent,
        CustomVerificationEmailTemplateDoesNotExist,
        FromEmailAddressNotVerified,
    },
} = .{};
pub const update_receipt_rule: struct {
    action_name: []const u8 = "UpdateReceiptRule",
    Request: type = struct {
        rule_set_name: []const u8,
        rule: ReceiptRule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_set_name = "RuleSetName",
                .rule = "Rule",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_receipt_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_receipt_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLambdaFunction,
        InvalidS3Configuration,
        InvalidSnsTopic,
        LimitExceeded,
        RuleDoesNotExist,
        RuleSetDoesNotExist,
    },
} = .{};
pub const update_template: struct {
    action_name: []const u8 = "UpdateTemplate",
    Request: type = struct {
        template: Template,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template = "Template",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_template) } {
            return .{ .service_metadata = service_metadata, .action = update_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTemplate,
        TemplateDoesNotExist,
    },
} = .{};
pub const verify_domain_dkim: struct {
    action_name: []const u8 = "VerifyDomainDkim",
    Request: type = struct {
        domain: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "Domain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_domain_dkim) } {
            return .{ .service_metadata = service_metadata, .action = verify_domain_dkim };
        }
    },
    Response: type = struct {
        dkim_tokens: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dkim_tokens = "DkimTokens",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const verify_domain_identity: struct {
    action_name: []const u8 = "VerifyDomainIdentity",
    Request: type = struct {
        domain: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "Domain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_domain_identity) } {
            return .{ .service_metadata = service_metadata, .action = verify_domain_identity };
        }
    },
    Response: type = struct {
        verification_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .verification_token = "VerificationToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const verify_email_address: struct {
    action_name: []const u8 = "VerifyEmailAddress",
    Request: type = struct {
        email_address: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_address = "EmailAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_email_address) } {
            return .{ .service_metadata = service_metadata, .action = verify_email_address };
        }
    },
    Response: type = struct {},
} = .{};
pub const verify_email_identity: struct {
    action_name: []const u8 = "VerifyEmailIdentity",
    Request: type = struct {
        email_address: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_address = "EmailAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_email_identity) } {
            return .{ .service_metadata = service_metadata, .action = verify_email_identity };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};

pub const Template = struct {
    template_name: []const u8,
    subject_part: ?[]const u8 = null,
    text_part: ?[]const u8 = null,
    html_part: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .template_name = "TemplateName",
            .subject_part = "SubjectPart",
            .text_part = "TextPart",
            .html_part = "HtmlPart",
        };
        return @field(mappings, field_name);
    }
};

pub const ReceiptRule = struct {
    name: []const u8,
    enabled: ?bool = null,
    tls_policy: ?[]const u8 = null,
    recipients: ?[][]const u8 = null,
    actions: ?[]ReceiptAction = null,
    scan_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .enabled = "Enabled",
            .tls_policy = "TlsPolicy",
            .recipients = "Recipients",
            .actions = "Actions",
            .scan_enabled = "ScanEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ReceiptAction = struct {
    s3_action: ?S3Action = null,
    bounce_action: ?BounceAction = null,
    workmail_action: ?WorkmailAction = null,
    lambda_action: ?LambdaAction = null,
    stop_action: ?StopAction = null,
    add_header_action: ?AddHeaderAction = null,
    sns_action: ?SNSAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_action = "S3Action",
            .bounce_action = "BounceAction",
            .workmail_action = "WorkmailAction",
            .lambda_action = "LambdaAction",
            .stop_action = "StopAction",
            .add_header_action = "AddHeaderAction",
            .sns_action = "SNSAction",
        };
        return @field(mappings, field_name);
    }
};

pub const SNSAction = struct {
    topic_arn: []const u8,
    encoding: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
            .encoding = "Encoding",
        };
        return @field(mappings, field_name);
    }
};

pub const AddHeaderAction = struct {
    header_name: []const u8,
    header_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_name = "HeaderName",
            .header_value = "HeaderValue",
        };
        return @field(mappings, field_name);
    }
};

pub const StopAction = struct {
    scope: []const u8,
    topic_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scope = "Scope",
            .topic_arn = "TopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaAction = struct {
    topic_arn: ?[]const u8 = null,
    function_arn: []const u8,
    invocation_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
            .function_arn = "FunctionArn",
            .invocation_type = "InvocationType",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkmailAction = struct {
    topic_arn: ?[]const u8 = null,
    organization_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
            .organization_arn = "OrganizationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const BounceAction = struct {
    topic_arn: ?[]const u8 = null,
    smtp_reply_code: []const u8,
    status_code: ?[]const u8 = null,
    message: []const u8,
    sender: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
            .smtp_reply_code = "SmtpReplyCode",
            .status_code = "StatusCode",
            .message = "Message",
            .sender = "Sender",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Action = struct {
    topic_arn: ?[]const u8 = null,
    bucket_name: []const u8,
    object_key_prefix: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
            .bucket_name = "BucketName",
            .object_key_prefix = "ObjectKeyPrefix",
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const TrackingOptions = struct {
    custom_redirect_domain: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_redirect_domain = "CustomRedirectDomain",
        };
        return @field(mappings, field_name);
    }
};

pub const EventDestination = struct {
    name: []const u8,
    enabled: ?bool = null,
    matching_event_types: [][]const u8,
    kinesis_firehose_destination: ?KinesisFirehoseDestination = null,
    cloud_watch_destination: ?CloudWatchDestination = null,
    sns_destination: ?SNSDestination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .enabled = "Enabled",
            .matching_event_types = "MatchingEventTypes",
            .kinesis_firehose_destination = "KinesisFirehoseDestination",
            .cloud_watch_destination = "CloudWatchDestination",
            .sns_destination = "SNSDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const SNSDestination = struct {
    topic_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicARN",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchDestination = struct {
    dimension_configurations: []CloudWatchDimensionConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_configurations = "DimensionConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchDimensionConfiguration = struct {
    dimension_name: []const u8,
    dimension_value_source: []const u8,
    default_dimension_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_name = "DimensionName",
            .dimension_value_source = "DimensionValueSource",
            .default_dimension_value = "DefaultDimensionValue",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisFirehoseDestination = struct {
    iam_role_arn: []const u8,
    delivery_stream_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iam_role_arn = "IAMRoleARN",
            .delivery_stream_arn = "DeliveryStreamARN",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageTag = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Destination = struct {
    to_addresses: ?[][]const u8 = null,
    cc_addresses: ?[][]const u8 = null,
    bcc_addresses: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .to_addresses = "ToAddresses",
            .cc_addresses = "CcAddresses",
            .bcc_addresses = "BccAddresses",
        };
        return @field(mappings, field_name);
    }
};

pub const Content = struct {
    data: []const u8,
    charset: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
            .charset = "Charset",
        };
        return @field(mappings, field_name);
    }
};

pub const ExtensionField = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DeliveryOptions = struct {
    tls_policy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tls_policy = "TlsPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const ReceiptRuleSetMetadata = struct {
    name: ?[]const u8 = null,
    created_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .created_timestamp = "CreatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const ReceiptFilter = struct {
    name: []const u8,
    ip_filter: ReceiptIpFilter,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .ip_filter = "IpFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const ReceiptIpFilter = struct {
    policy: []const u8,
    cidr: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy = "Policy",
            .cidr = "Cidr",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationSet = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};
