const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-09-27";
pub const sdk_id: []const u8 = "SESv2";
pub const arn_namespace: ?[]const u8 = "ses";
pub const endpoint_prefix: []const u8 = "email";
pub const sigv4_name: []const u8 = "ses";
pub const name: []const u8 = "SimpleEmailService_v2";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-09-27",
    sdk_id: []const u8 = "SESv2",
    arn_namespace: ?[]const u8 = "ses",
    endpoint_prefix: []const u8 = "email",
    sigv4_name: []const u8 = "ses",
    name: []const u8 = "SimpleEmailService_v2",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_get_metric_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/metrics/batch",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetMetricData",
    Request: type = struct {
        queries: []struct {
            id: []const u8,
            namespace: []const u8,
            metric: []const u8,
            dimensions: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            start_date: i64,
            end_date: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .namespace = "Namespace",
                    .metric = "Metric",
                    .dimensions = "Dimensions",
                    .start_date = "StartDate",
                    .end_date = "EndDate",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "dimensions", field_name))
                    return try serializeMap(self.dimensions, self.fieldNameFor("dimensions"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queries = "Queries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_metric_data) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_metric_data };
        }
    },
    Response: type = struct {
        results: ?[]struct {
            id: ?[]const u8 = null,
            timestamps: ?[]i64 = null,
            values: ?[]i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .timestamps = "Timestamps",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]struct {
            id: ?[]const u8 = null,
            code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .code = "Code",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServiceError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const cancel_export_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/export-jobs/{JobId}/cancel",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelExportJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_export_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_export_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_configuration_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/configuration-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,
        tracking_options: ?TrackingOptions = null,
        delivery_options: ?DeliveryOptions = null,
        reputation_options: ?ReputationOptions = null,
        sending_options: ?SendingOptions = null,
        tags: ?[]Tag = null,
        suppression_options: ?SuppressionOptions = null,
        vdm_options: ?VdmOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .tracking_options = "TrackingOptions",
                .delivery_options = "DeliveryOptions",
                .reputation_options = "ReputationOptions",
                .sending_options = "SendingOptions",
                .tags = "Tags",
                .suppression_options = "SuppressionOptions",
                .vdm_options = "VdmOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        ConcurrentModification,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_configuration_set_event_destination: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}/event-destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,
        event_destination: EventDestinationDefinition,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
                .event_destination = "EventDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_contact: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/contact-lists/{ContactListName}/contacts",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateContact",
    Request: type = struct {
        contact_list_name: []const u8,
        email_address: []const u8,
        topic_preferences: ?[]TopicPreference = null,
        unsubscribe_all: ?bool = null,
        attributes_data: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
                .email_address = "EmailAddress",
                .topic_preferences = "TopicPreferences",
                .unsubscribe_all = "UnsubscribeAll",
                .attributes_data = "AttributesData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_contact) } {
            return .{ .service_metadata = service_metadata, .action = create_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_contact_list: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/contact-lists",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateContactList",
    Request: type = struct {
        contact_list_name: []const u8,
        topics: ?[]Topic = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
                .topics = "Topics",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_contact_list) } {
            return .{ .service_metadata = service_metadata, .action = create_contact_list };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        LimitExceeded,
        TooManyRequests,
    },
} = .{};
pub const create_custom_verification_email_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/custom-verification-email-templates",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCustomVerificationEmailTemplate",
    Request: type = struct {
        template_name: []const u8,
        from_email_address: []const u8,
        template_subject: []const u8,
        template_content: []const u8,
        success_redirection_url: []const u8,
        failure_redirection_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .from_email_address = "FromEmailAddress",
                .template_subject = "TemplateSubject",
                .template_content = "TemplateContent",
                .success_redirection_url = "SuccessRedirectionURL",
                .failure_redirection_url = "FailureRedirectionURL",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_verification_email_template) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_verification_email_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_dedicated_ip_pool: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/dedicated-ip-pools",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDedicatedIpPool",
    Request: type = struct {
        pool_name: []const u8,
        tags: ?[]Tag = null,
        scaling_mode: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_name = "PoolName",
                .tags = "Tags",
                .scaling_mode = "ScalingMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dedicated_ip_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_dedicated_ip_pool };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        ConcurrentModification,
        LimitExceeded,
        TooManyRequests,
    },
} = .{};
pub const create_deliverability_test_report: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/deliverability-dashboard/test",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDeliverabilityTestReport",
    Request: type = struct {
        report_name: ?[]const u8 = null,
        from_email_address: []const u8,
        content: EmailContent,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_name = "ReportName",
                .from_email_address = "FromEmailAddress",
                .content = "Content",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_deliverability_test_report) } {
            return .{ .service_metadata = service_metadata, .action = create_deliverability_test_report };
        }
    },
    Response: type = struct {
        report_id: []const u8,
        deliverability_test_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "ReportId",
                .deliverability_test_status = "DeliverabilityTestStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountSuspended,
        BadRequest,
        ConcurrentModification,
        LimitExceeded,
        MailFromDomainNotVerified,
        MessageRejected,
        NotFound,
        SendingPaused,
        TooManyRequests,
    },
} = .{};
pub const create_email_identity: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/identities",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEmailIdentity",
    Request: type = struct {
        email_identity: []const u8,
        tags: ?[]Tag = null,
        dkim_signing_attributes: ?DkimSigningAttributes = null,
        configuration_set_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .tags = "Tags",
                .dkim_signing_attributes = "DkimSigningAttributes",
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_email_identity) } {
            return .{ .service_metadata = service_metadata, .action = create_email_identity };
        }
    },
    Response: type = struct {
        identity_type: ?[]const u8 = null,
        verified_for_sending_status: ?bool = null,
        dkim_attributes: ?DkimAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_type = "IdentityType",
                .verified_for_sending_status = "VerifiedForSendingStatus",
                .dkim_attributes = "DkimAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        ConcurrentModification,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_email_identity_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/identities/{EmailIdentity}/policies/{PolicyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEmailIdentityPolicy",
    Request: type = struct {
        email_identity: []const u8,
        policy_name: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .policy_name = "PolicyName",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_email_identity_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_email_identity_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_email_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/templates",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEmailTemplate",
    Request: type = struct {
        template_name: []const u8,
        template_content: EmailTemplateContent,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .template_content = "TemplateContent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_email_template) } {
            return .{ .service_metadata = service_metadata, .action = create_email_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        LimitExceeded,
        TooManyRequests,
    },
} = .{};
pub const create_export_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/export-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateExportJob",
    Request: type = struct {
        export_data_source: ExportDataSource,
        export_destination: ExportDestination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_data_source = "ExportDataSource",
                .export_destination = "ExportDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_export_job) } {
            return .{ .service_metadata = service_metadata, .action = create_export_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const create_import_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/import-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateImportJob",
    Request: type = struct {
        import_destination: ImportDestination,
        import_data_source: ImportDataSource,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_destination = "ImportDestination",
                .import_data_source = "ImportDataSource",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_import_job) } {
            return .{ .service_metadata = service_metadata, .action = create_import_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        LimitExceeded,
        TooManyRequests,
    },
} = .{};
pub const delete_configuration_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_configuration_set_event_destination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}/event-destinations/{EventDestinationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_contact: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/contact-lists/{ContactListName}/contacts/{EmailAddress}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteContact",
    Request: type = struct {
        contact_list_name: []const u8,
        email_address: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
                .email_address = "EmailAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_contact) } {
            return .{ .service_metadata = service_metadata, .action = delete_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_contact_list: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/contact-lists/{ContactListName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteContactList",
    Request: type = struct {
        contact_list_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_contact_list) } {
            return .{ .service_metadata = service_metadata, .action = delete_contact_list };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_custom_verification_email_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/custom-verification-email-templates/{TemplateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCustomVerificationEmailTemplate",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_verification_email_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_verification_email_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_dedicated_ip_pool: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/dedicated-ip-pools/{PoolName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDedicatedIpPool",
    Request: type = struct {
        pool_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_name = "PoolName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dedicated_ip_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_dedicated_ip_pool };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_email_identity: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/identities/{EmailIdentity}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEmailIdentity",
    Request: type = struct {
        email_identity: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_email_identity) } {
            return .{ .service_metadata = service_metadata, .action = delete_email_identity };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_email_identity_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/identities/{EmailIdentity}/policies/{PolicyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEmailIdentityPolicy",
    Request: type = struct {
        email_identity: []const u8,
        policy_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .policy_name = "PolicyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_email_identity_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_email_identity_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_email_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/templates/{TemplateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEmailTemplate",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_email_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_email_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_suppressed_destination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/suppression/addresses/{EmailAddress}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSuppressedDestination",
    Request: type = struct {
        email_address: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_address = "EmailAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_suppressed_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_suppressed_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/account",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account) } {
            return .{ .service_metadata = service_metadata, .action = get_account };
        }
    },
    Response: type = struct {
        dedicated_ip_auto_warmup_enabled: ?bool = null,
        enforcement_status: ?[]const u8 = null,
        production_access_enabled: ?bool = null,
        send_quota: ?struct {
            max24_hour_send: ?f64 = null,
            max_send_rate: ?f64 = null,
            sent_last24_hours: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .max24_hour_send = "Max24HourSend",
                    .max_send_rate = "MaxSendRate",
                    .sent_last24_hours = "SentLast24Hours",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sending_enabled: ?bool = null,
        suppression_attributes: ?struct {
            suppressed_reasons: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .suppressed_reasons = "SuppressedReasons",
                };
                return @field(mappings, field_name);
            }
        } = null,
        details: ?struct {
            mail_type: ?[]const u8 = null,
            website_url: ?[]const u8 = null,
            contact_language: ?[]const u8 = null,
            use_case_description: ?[]const u8 = null,
            additional_contact_email_addresses: ?[][]const u8 = null,
            review_details: ?struct {
                status: ?[]const u8 = null,
                case_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "Status",
                        .case_id = "CaseId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mail_type = "MailType",
                    .website_url = "WebsiteURL",
                    .contact_language = "ContactLanguage",
                    .use_case_description = "UseCaseDescription",
                    .additional_contact_email_addresses = "AdditionalContactEmailAddresses",
                    .review_details = "ReviewDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,
        vdm_attributes: ?VdmAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_ip_auto_warmup_enabled = "DedicatedIpAutoWarmupEnabled",
                .enforcement_status = "EnforcementStatus",
                .production_access_enabled = "ProductionAccessEnabled",
                .send_quota = "SendQuota",
                .sending_enabled = "SendingEnabled",
                .suppression_attributes = "SuppressionAttributes",
                .details = "Details",
                .vdm_attributes = "VdmAttributes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const get_blacklist_reports: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/deliverability-dashboard/blacklist-report",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBlacklistReports",
    Request: type = struct {
        blacklist_item_names: [][]const u8,

        pub const http_query = .{
            .blacklist_item_names = "BlacklistItemNames",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blacklist_item_names = "BlacklistItemNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_blacklist_reports) } {
            return .{ .service_metadata = service_metadata, .action = get_blacklist_reports };
        }
    },
    Response: type = struct {
        blacklist_report: []struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                rbl_name: ?[]const u8 = null,
                listing_time: ?i64 = null,
                description: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .rbl_name = "RblName",
                        .listing_time = "ListingTime",
                        .description = "Description",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .blacklist_report = "BlacklistReport",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "blacklist_report", field_name))
                return try serializeMap(self.blacklist_report, self.fieldNameFor("blacklist_report"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_configuration_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfigurationSet",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration_set) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration_set };
        }
    },
    Response: type = struct {
        configuration_set_name: ?[]const u8 = null,
        tracking_options: ?TrackingOptions = null,
        delivery_options: ?DeliveryOptions = null,
        reputation_options: ?ReputationOptions = null,
        sending_options: ?SendingOptions = null,
        tags: ?[]Tag = null,
        suppression_options: ?SuppressionOptions = null,
        vdm_options: ?VdmOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .tracking_options = "TrackingOptions",
                .delivery_options = "DeliveryOptions",
                .reputation_options = "ReputationOptions",
                .sending_options = "SendingOptions",
                .tags = "Tags",
                .suppression_options = "SuppressionOptions",
                .vdm_options = "VdmOptions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_configuration_set_event_destinations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}/event-destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConfigurationSetEventDestinations",
    Request: type = struct {
        configuration_set_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_configuration_set_event_destinations) } {
            return .{ .service_metadata = service_metadata, .action = get_configuration_set_event_destinations };
        }
    },
    Response: type = struct {
        event_destinations: ?[]struct {
            name: []const u8,
            enabled: ?bool = null,
            matching_event_types: [][]const u8,
            kinesis_firehose_destination: ?KinesisFirehoseDestination = null,
            cloud_watch_destination: ?CloudWatchDestination = null,
            sns_destination: ?SnsDestination = null,
            pinpoint_destination: ?PinpointDestination = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .enabled = "Enabled",
                    .matching_event_types = "MatchingEventTypes",
                    .kinesis_firehose_destination = "KinesisFirehoseDestination",
                    .cloud_watch_destination = "CloudWatchDestination",
                    .sns_destination = "SnsDestination",
                    .pinpoint_destination = "PinpointDestination",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_destinations = "EventDestinations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_contact: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/contact-lists/{ContactListName}/contacts/{EmailAddress}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetContact",
    Request: type = struct {
        contact_list_name: []const u8,
        email_address: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
                .email_address = "EmailAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_contact) } {
            return .{ .service_metadata = service_metadata, .action = get_contact };
        }
    },
    Response: type = struct {
        contact_list_name: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        topic_preferences: ?[]TopicPreference = null,
        topic_default_preferences: ?[]TopicPreference = null,
        unsubscribe_all: ?bool = null,
        attributes_data: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        last_updated_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
                .email_address = "EmailAddress",
                .topic_preferences = "TopicPreferences",
                .topic_default_preferences = "TopicDefaultPreferences",
                .unsubscribe_all = "UnsubscribeAll",
                .attributes_data = "AttributesData",
                .created_timestamp = "CreatedTimestamp",
                .last_updated_timestamp = "LastUpdatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_contact_list: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/contact-lists/{ContactListName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetContactList",
    Request: type = struct {
        contact_list_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_contact_list) } {
            return .{ .service_metadata = service_metadata, .action = get_contact_list };
        }
    },
    Response: type = struct {
        contact_list_name: ?[]const u8 = null,
        topics: ?[]Topic = null,
        description: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        last_updated_timestamp: ?i64 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
                .topics = "Topics",
                .description = "Description",
                .created_timestamp = "CreatedTimestamp",
                .last_updated_timestamp = "LastUpdatedTimestamp",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_custom_verification_email_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/custom-verification-email-templates/{TemplateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCustomVerificationEmailTemplate",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_custom_verification_email_template) } {
            return .{ .service_metadata = service_metadata, .action = get_custom_verification_email_template };
        }
    },
    Response: type = struct {
        template_name: ?[]const u8 = null,
        from_email_address: ?[]const u8 = null,
        template_subject: ?[]const u8 = null,
        template_content: ?[]const u8 = null,
        success_redirection_url: ?[]const u8 = null,
        failure_redirection_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .from_email_address = "FromEmailAddress",
                .template_subject = "TemplateSubject",
                .template_content = "TemplateContent",
                .success_redirection_url = "SuccessRedirectionURL",
                .failure_redirection_url = "FailureRedirectionURL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_dedicated_ip: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/dedicated-ips/{Ip}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDedicatedIp",
    Request: type = struct {
        ip: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip = "Ip",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dedicated_ip) } {
            return .{ .service_metadata = service_metadata, .action = get_dedicated_ip };
        }
    },
    Response: type = struct {
        dedicated_ip: ?DedicatedIp = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_ip = "DedicatedIp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_dedicated_ip_pool: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/dedicated-ip-pools/{PoolName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDedicatedIpPool",
    Request: type = struct {
        pool_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_name = "PoolName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dedicated_ip_pool) } {
            return .{ .service_metadata = service_metadata, .action = get_dedicated_ip_pool };
        }
    },
    Response: type = struct {
        dedicated_ip_pool: ?struct {
            pool_name: []const u8,
            scaling_mode: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pool_name = "PoolName",
                    .scaling_mode = "ScalingMode",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_ip_pool = "DedicatedIpPool",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_dedicated_ips: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/dedicated-ips",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDedicatedIps",
    Request: type = struct {
        pool_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .pool_name = "PoolName",
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_name = "PoolName",
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dedicated_ips) } {
            return .{ .service_metadata = service_metadata, .action = get_dedicated_ips };
        }
    },
    Response: type = struct {
        dedicated_ips: ?[]DedicatedIp = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_ips = "DedicatedIps",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_deliverability_dashboard_options: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/deliverability-dashboard",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeliverabilityDashboardOptions",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deliverability_dashboard_options) } {
            return .{ .service_metadata = service_metadata, .action = get_deliverability_dashboard_options };
        }
    },
    Response: type = struct {
        dashboard_enabled: bool,
        subscription_expiry_date: ?i64 = null,
        account_status: ?[]const u8 = null,
        active_subscribed_domains: ?[]DomainDeliverabilityTrackingOption = null,
        pending_expiration_subscribed_domains: ?[]DomainDeliverabilityTrackingOption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_enabled = "DashboardEnabled",
                .subscription_expiry_date = "SubscriptionExpiryDate",
                .account_status = "AccountStatus",
                .active_subscribed_domains = "ActiveSubscribedDomains",
                .pending_expiration_subscribed_domains = "PendingExpirationSubscribedDomains",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        LimitExceeded,
        TooManyRequests,
    },
} = .{};
pub const get_deliverability_test_report: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/deliverability-dashboard/test-reports/{ReportId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeliverabilityTestReport",
    Request: type = struct {
        report_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_id = "ReportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deliverability_test_report) } {
            return .{ .service_metadata = service_metadata, .action = get_deliverability_test_report };
        }
    },
    Response: type = struct {
        deliverability_test_report: DeliverabilityTestReport,
        overall_placement: PlacementStatistics,
        isp_placements: []struct {
            isp_name: ?[]const u8 = null,
            placement_statistics: ?PlacementStatistics = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .isp_name = "IspName",
                    .placement_statistics = "PlacementStatistics",
                };
                return @field(mappings, field_name);
            }
        },
        message: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deliverability_test_report = "DeliverabilityTestReport",
                .overall_placement = "OverallPlacement",
                .isp_placements = "IspPlacements",
                .message = "Message",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_domain_deliverability_campaign: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/deliverability-dashboard/campaigns/{CampaignId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainDeliverabilityCampaign",
    Request: type = struct {
        campaign_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .campaign_id = "CampaignId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_deliverability_campaign) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_deliverability_campaign };
        }
    },
    Response: type = struct {
        domain_deliverability_campaign: DomainDeliverabilityCampaign,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_deliverability_campaign = "DomainDeliverabilityCampaign",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_domain_statistics_report: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/deliverability-dashboard/statistics-report/{Domain}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainStatisticsReport",
    Request: type = struct {
        domain: []const u8,
        start_date: i64,
        end_date: i64,

        pub const http_query = .{
            .start_date = "StartDate",
            .end_date = "EndDate",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "Domain",
                .start_date = "StartDate",
                .end_date = "EndDate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_statistics_report) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_statistics_report };
        }
    },
    Response: type = struct {
        overall_volume: struct {
            volume_statistics: ?VolumeStatistics = null,
            read_rate_percent: ?f64 = null,
            domain_isp_placements: ?[]DomainIspPlacement = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .volume_statistics = "VolumeStatistics",
                    .read_rate_percent = "ReadRatePercent",
                    .domain_isp_placements = "DomainIspPlacements",
                };
                return @field(mappings, field_name);
            }
        },
        daily_volumes: []struct {
            start_date: ?i64 = null,
            volume_statistics: ?VolumeStatistics = null,
            domain_isp_placements: ?[]DomainIspPlacement = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_date = "StartDate",
                    .volume_statistics = "VolumeStatistics",
                    .domain_isp_placements = "DomainIspPlacements",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .overall_volume = "OverallVolume",
                .daily_volumes = "DailyVolumes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_email_identity: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/identities/{EmailIdentity}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEmailIdentity",
    Request: type = struct {
        email_identity: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_email_identity) } {
            return .{ .service_metadata = service_metadata, .action = get_email_identity };
        }
    },
    Response: type = struct {
        identity_type: ?[]const u8 = null,
        feedback_forwarding_status: ?bool = null,
        verified_for_sending_status: ?bool = null,
        dkim_attributes: ?DkimAttributes = null,
        mail_from_attributes: ?struct {
            mail_from_domain: []const u8,
            mail_from_domain_status: []const u8,
            behavior_on_mx_failure: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mail_from_domain = "MailFromDomain",
                    .mail_from_domain_status = "MailFromDomainStatus",
                    .behavior_on_mx_failure = "BehaviorOnMxFailure",
                };
                return @field(mappings, field_name);
            }
        } = null,
        policies: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]Tag = null,
        configuration_set_name: ?[]const u8 = null,
        verification_status: ?[]const u8 = null,
        verification_info: ?struct {
            last_checked_timestamp: ?i64 = null,
            last_success_timestamp: ?i64 = null,
            error_type: ?[]const u8 = null,
            soa_record: ?struct {
                primary_name_server: ?[]const u8 = null,
                admin_email: ?[]const u8 = null,
                serial_number: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .primary_name_server = "PrimaryNameServer",
                        .admin_email = "AdminEmail",
                        .serial_number = "SerialNumber",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .last_checked_timestamp = "LastCheckedTimestamp",
                    .last_success_timestamp = "LastSuccessTimestamp",
                    .error_type = "ErrorType",
                    .soa_record = "SOARecord",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_type = "IdentityType",
                .feedback_forwarding_status = "FeedbackForwardingStatus",
                .verified_for_sending_status = "VerifiedForSendingStatus",
                .dkim_attributes = "DkimAttributes",
                .mail_from_attributes = "MailFromAttributes",
                .policies = "Policies",
                .tags = "Tags",
                .configuration_set_name = "ConfigurationSetName",
                .verification_status = "VerificationStatus",
                .verification_info = "VerificationInfo",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "policies", field_name))
                return try serializeMap(self.policies, self.fieldNameFor("policies"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_email_identity_policies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/identities/{EmailIdentity}/policies",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEmailIdentityPolicies",
    Request: type = struct {
        email_identity: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_email_identity_policies) } {
            return .{ .service_metadata = service_metadata, .action = get_email_identity_policies };
        }
    },
    Response: type = struct {
        policies: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policies = "Policies",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "policies", field_name))
                return try serializeMap(self.policies, self.fieldNameFor("policies"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_email_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/templates/{TemplateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEmailTemplate",
    Request: type = struct {
        template_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_email_template) } {
            return .{ .service_metadata = service_metadata, .action = get_email_template };
        }
    },
    Response: type = struct {
        template_name: []const u8,
        template_content: EmailTemplateContent,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .template_content = "TemplateContent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_export_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/export-jobs/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetExportJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_export_job) } {
            return .{ .service_metadata = service_metadata, .action = get_export_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        export_source_type: ?[]const u8 = null,
        job_status: ?[]const u8 = null,
        export_destination: ?ExportDestination = null,
        export_data_source: ?ExportDataSource = null,
        created_timestamp: ?i64 = null,
        completed_timestamp: ?i64 = null,
        failure_info: ?FailureInfo = null,
        statistics: ?struct {
            processed_records_count: ?i64 = null,
            exported_records_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .processed_records_count = "ProcessedRecordsCount",
                    .exported_records_count = "ExportedRecordsCount",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .export_source_type = "ExportSourceType",
                .job_status = "JobStatus",
                .export_destination = "ExportDestination",
                .export_data_source = "ExportDataSource",
                .created_timestamp = "CreatedTimestamp",
                .completed_timestamp = "CompletedTimestamp",
                .failure_info = "FailureInfo",
                .statistics = "Statistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_import_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/import-jobs/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImportJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_import_job) } {
            return .{ .service_metadata = service_metadata, .action = get_import_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        import_destination: ?ImportDestination = null,
        import_data_source: ?ImportDataSource = null,
        failure_info: ?FailureInfo = null,
        job_status: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        completed_timestamp: ?i64 = null,
        processed_records_count: ?i64 = null,
        failed_records_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .import_destination = "ImportDestination",
                .import_data_source = "ImportDataSource",
                .failure_info = "FailureInfo",
                .job_status = "JobStatus",
                .created_timestamp = "CreatedTimestamp",
                .completed_timestamp = "CompletedTimestamp",
                .processed_records_count = "ProcessedRecordsCount",
                .failed_records_count = "FailedRecordsCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_message_insights: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/insights/{MessageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMessageInsights",
    Request: type = struct {
        message_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_message_insights) } {
            return .{ .service_metadata = service_metadata, .action = get_message_insights };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,
        from_email_address: ?[]const u8 = null,
        subject: ?[]const u8 = null,
        email_tags: ?[]MessageTag = null,
        insights: ?[]struct {
            destination: ?[]const u8 = null,
            isp: ?[]const u8 = null,
            events: ?[]struct {
                timestamp: ?i64 = null,
                type: ?[]const u8 = null,
                details: ?struct {
                    bounce: ?struct {
                        bounce_type: ?[]const u8 = null,
                        bounce_sub_type: ?[]const u8 = null,
                        diagnostic_code: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .bounce_type = "BounceType",
                                .bounce_sub_type = "BounceSubType",
                                .diagnostic_code = "DiagnosticCode",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    complaint: ?struct {
                        complaint_sub_type: ?[]const u8 = null,
                        complaint_feedback_type: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .complaint_sub_type = "ComplaintSubType",
                                .complaint_feedback_type = "ComplaintFeedbackType",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bounce = "Bounce",
                            .complaint = "Complaint",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .timestamp = "Timestamp",
                        .type = "Type",
                        .details = "Details",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .destination = "Destination",
                    .isp = "Isp",
                    .events = "Events",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
                .from_email_address = "FromEmailAddress",
                .subject = "Subject",
                .email_tags = "EmailTags",
                .insights = "Insights",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_suppressed_destination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/suppression/addresses/{EmailAddress}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSuppressedDestination",
    Request: type = struct {
        email_address: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_address = "EmailAddress",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_suppressed_destination) } {
            return .{ .service_metadata = service_metadata, .action = get_suppressed_destination };
        }
    },
    Response: type = struct {
        suppressed_destination: struct {
            email_address: []const u8,
            reason: []const u8,
            last_update_time: i64,
            attributes: ?struct {
                message_id: ?[]const u8 = null,
                feedback_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .message_id = "MessageId",
                        .feedback_id = "FeedbackId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .email_address = "EmailAddress",
                    .reason = "Reason",
                    .last_update_time = "LastUpdateTime",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suppressed_destination = "SuppressedDestination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_configuration_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/configuration-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConfigurationSets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configuration_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_configuration_sets };
        }
    },
    Response: type = struct {
        configuration_sets: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_sets = "ConfigurationSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_contact_lists: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/contact-lists",
        .success_code = 200,
    };

    action_name: []const u8 = "ListContactLists",
    Request: type = struct {
        page_size: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "PageSize",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .page_size = "PageSize",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contact_lists) } {
            return .{ .service_metadata = service_metadata, .action = list_contact_lists };
        }
    },
    Response: type = struct {
        contact_lists: ?[]struct {
            contact_list_name: ?[]const u8 = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .contact_list_name = "ContactListName",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_lists = "ContactLists",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_contacts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/contact-lists/{ContactListName}/contacts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListContacts",
    Request: type = struct {
        contact_list_name: []const u8,
        filter: ?struct {
            filtered_status: ?[]const u8 = null,
            topic_filter: ?struct {
                topic_name: ?[]const u8 = null,
                use_default_if_preference_unavailable: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .topic_name = "TopicName",
                        .use_default_if_preference_unavailable = "UseDefaultIfPreferenceUnavailable",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .filtered_status = "FilteredStatus",
                    .topic_filter = "TopicFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        page_size: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .page_size = "PageSize",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
                .filter = "Filter",
                .page_size = "PageSize",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contacts) } {
            return .{ .service_metadata = service_metadata, .action = list_contacts };
        }
    },
    Response: type = struct {
        contacts: ?[]struct {
            email_address: ?[]const u8 = null,
            topic_preferences: ?[]TopicPreference = null,
            topic_default_preferences: ?[]TopicPreference = null,
            unsubscribe_all: ?bool = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .email_address = "EmailAddress",
                    .topic_preferences = "TopicPreferences",
                    .topic_default_preferences = "TopicDefaultPreferences",
                    .unsubscribe_all = "UnsubscribeAll",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contacts = "Contacts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_custom_verification_email_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/custom-verification-email-templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCustomVerificationEmailTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_custom_verification_email_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_custom_verification_email_templates };
        }
    },
    Response: type = struct {
        custom_verification_email_templates: ?[]struct {
            template_name: ?[]const u8 = null,
            from_email_address: ?[]const u8 = null,
            template_subject: ?[]const u8 = null,
            success_redirection_url: ?[]const u8 = null,
            failure_redirection_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .template_name = "TemplateName",
                    .from_email_address = "FromEmailAddress",
                    .template_subject = "TemplateSubject",
                    .success_redirection_url = "SuccessRedirectionURL",
                    .failure_redirection_url = "FailureRedirectionURL",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_verification_email_templates = "CustomVerificationEmailTemplates",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_dedicated_ip_pools: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/dedicated-ip-pools",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDedicatedIpPools",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dedicated_ip_pools) } {
            return .{ .service_metadata = service_metadata, .action = list_dedicated_ip_pools };
        }
    },
    Response: type = struct {
        dedicated_ip_pools: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_ip_pools = "DedicatedIpPools",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_deliverability_test_reports: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/deliverability-dashboard/test-reports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeliverabilityTestReports",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_deliverability_test_reports) } {
            return .{ .service_metadata = service_metadata, .action = list_deliverability_test_reports };
        }
    },
    Response: type = struct {
        deliverability_test_reports: []DeliverabilityTestReport,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deliverability_test_reports = "DeliverabilityTestReports",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_domain_deliverability_campaigns: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/deliverability-dashboard/domains/{SubscribedDomain}/campaigns",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomainDeliverabilityCampaigns",
    Request: type = struct {
        start_date: i64,
        end_date: i64,
        subscribed_domain: []const u8,
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .start_date = "StartDate",
            .end_date = "EndDate",
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_date = "StartDate",
                .end_date = "EndDate",
                .subscribed_domain = "SubscribedDomain",
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domain_deliverability_campaigns) } {
            return .{ .service_metadata = service_metadata, .action = list_domain_deliverability_campaigns };
        }
    },
    Response: type = struct {
        domain_deliverability_campaigns: []DomainDeliverabilityCampaign,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_deliverability_campaigns = "DomainDeliverabilityCampaigns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_email_identities: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/identities",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEmailIdentities",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_email_identities) } {
            return .{ .service_metadata = service_metadata, .action = list_email_identities };
        }
    },
    Response: type = struct {
        email_identities: ?[]struct {
            identity_type: ?[]const u8 = null,
            identity_name: ?[]const u8 = null,
            sending_enabled: ?bool = null,
            verification_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .identity_type = "IdentityType",
                    .identity_name = "IdentityName",
                    .sending_enabled = "SendingEnabled",
                    .verification_status = "VerificationStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identities = "EmailIdentities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_email_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEmailTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_email_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_email_templates };
        }
    },
    Response: type = struct {
        templates_metadata: ?[]struct {
            template_name: ?[]const u8 = null,
            created_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .template_name = "TemplateName",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .templates_metadata = "TemplatesMetadata",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_export_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/list-export-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListExportJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,
        export_source_type: ?[]const u8 = null,
        job_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .page_size = "PageSize",
                .export_source_type = "ExportSourceType",
                .job_status = "JobStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_export_jobs };
        }
    },
    Response: type = struct {
        export_jobs: ?[]struct {
            job_id: ?[]const u8 = null,
            export_source_type: ?[]const u8 = null,
            job_status: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            completed_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .export_source_type = "ExportSourceType",
                    .job_status = "JobStatus",
                    .created_timestamp = "CreatedTimestamp",
                    .completed_timestamp = "CompletedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_jobs = "ExportJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_import_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/import-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImportJobs",
    Request: type = struct {
        import_destination_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_destination_type = "ImportDestinationType",
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_import_jobs };
        }
    },
    Response: type = struct {
        import_jobs: ?[]struct {
            job_id: ?[]const u8 = null,
            import_destination: ?ImportDestination = null,
            job_status: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            processed_records_count: ?i64 = null,
            failed_records_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .import_destination = "ImportDestination",
                    .job_status = "JobStatus",
                    .created_timestamp = "CreatedTimestamp",
                    .processed_records_count = "ProcessedRecordsCount",
                    .failed_records_count = "FailedRecordsCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_jobs = "ImportJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const list_recommendations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/vdm/recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecommendations",
    Request: type = struct {
        filter: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filter = "Filter",
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filter", field_name))
                return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendations };
        }
    },
    Response: type = struct {
        recommendations: ?[]struct {
            resource_arn: ?[]const u8 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            impact: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "ResourceArn",
                    .type = "Type",
                    .description = "Description",
                    .status = "Status",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .impact = "Impact",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendations = "Recommendations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const list_suppressed_destinations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/suppression/addresses",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSuppressedDestinations",
    Request: type = struct {
        reasons: ?[][]const u8 = null,
        start_date: ?i64 = null,
        end_date: ?i64 = null,
        next_token: ?[]const u8 = null,
        page_size: ?i64 = null,

        pub const http_query = .{
            .reasons = "Reason",
            .start_date = "StartDate",
            .end_date = "EndDate",
            .next_token = "NextToken",
            .page_size = "PageSize",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reasons = "Reasons",
                .start_date = "StartDate",
                .end_date = "EndDate",
                .next_token = "NextToken",
                .page_size = "PageSize",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_suppressed_destinations) } {
            return .{ .service_metadata = service_metadata, .action = list_suppressed_destinations };
        }
    },
    Response: type = struct {
        suppressed_destination_summaries: ?[]struct {
            email_address: []const u8,
            reason: []const u8,
            last_update_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .email_address = "EmailAddress",
                    .reason = "Reason",
                    .last_update_time = "LastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suppressed_destination_summaries = "SuppressedDestinationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InvalidNextToken,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v2/email/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "ResourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_account_dedicated_ip_warmup_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/account/dedicated-ips/warmup",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccountDedicatedIpWarmupAttributes",
    Request: type = struct {
        auto_warmup_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_warmup_enabled = "AutoWarmupEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_dedicated_ip_warmup_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_account_dedicated_ip_warmup_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const put_account_details: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/account/details",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccountDetails",
    Request: type = struct {
        mail_type: []const u8,
        website_url: []const u8,
        contact_language: ?[]const u8 = null,
        use_case_description: []const u8,
        additional_contact_email_addresses: ?[][]const u8 = null,
        production_access_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mail_type = "MailType",
                .website_url = "WebsiteURL",
                .contact_language = "ContactLanguage",
                .use_case_description = "UseCaseDescription",
                .additional_contact_email_addresses = "AdditionalContactEmailAddresses",
                .production_access_enabled = "ProductionAccessEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_details) } {
            return .{ .service_metadata = service_metadata, .action = put_account_details };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        TooManyRequests,
    },
} = .{};
pub const put_account_sending_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/account/sending",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccountSendingAttributes",
    Request: type = struct {
        sending_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sending_enabled = "SendingEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_sending_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_account_sending_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const put_account_suppression_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/account/suppression",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccountSuppressionAttributes",
    Request: type = struct {
        suppressed_reasons: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .suppressed_reasons = "SuppressedReasons",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_suppression_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_account_suppression_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const put_account_vdm_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/account/vdm",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccountVdmAttributes",
    Request: type = struct {
        vdm_attributes: VdmAttributes,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vdm_attributes = "VdmAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_account_vdm_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_account_vdm_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const put_configuration_set_delivery_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}/delivery-options",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfigurationSetDeliveryOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        tls_policy: ?[]const u8 = null,
        sending_pool_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .tls_policy = "TlsPolicy",
                .sending_pool_name = "SendingPoolName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_delivery_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_delivery_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_configuration_set_reputation_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}/reputation-options",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfigurationSetReputationOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        reputation_metrics_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .reputation_metrics_enabled = "ReputationMetricsEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_reputation_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_reputation_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_configuration_set_sending_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}/sending",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfigurationSetSendingOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        sending_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .sending_enabled = "SendingEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_sending_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_sending_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_configuration_set_suppression_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}/suppression-options",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfigurationSetSuppressionOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        suppressed_reasons: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .suppressed_reasons = "SuppressedReasons",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_suppression_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_suppression_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_configuration_set_tracking_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}/tracking-options",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfigurationSetTrackingOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        custom_redirect_domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .custom_redirect_domain = "CustomRedirectDomain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_tracking_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_tracking_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_configuration_set_vdm_options: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}/vdm-options",
        .success_code = 200,
    };

    action_name: []const u8 = "PutConfigurationSetVdmOptions",
    Request: type = struct {
        configuration_set_name: []const u8,
        vdm_options: ?VdmOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .vdm_options = "VdmOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_configuration_set_vdm_options) } {
            return .{ .service_metadata = service_metadata, .action = put_configuration_set_vdm_options };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_dedicated_ip_in_pool: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/dedicated-ips/{Ip}/pool",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDedicatedIpInPool",
    Request: type = struct {
        ip: []const u8,
        destination_pool_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip = "Ip",
                .destination_pool_name = "DestinationPoolName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_dedicated_ip_in_pool) } {
            return .{ .service_metadata = service_metadata, .action = put_dedicated_ip_in_pool };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_dedicated_ip_pool_scaling_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/dedicated-ip-pools/{PoolName}/scaling",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDedicatedIpPoolScalingAttributes",
    Request: type = struct {
        pool_name: []const u8,
        scaling_mode: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_name = "PoolName",
                .scaling_mode = "ScalingMode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_dedicated_ip_pool_scaling_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_dedicated_ip_pool_scaling_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_dedicated_ip_warmup_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/dedicated-ips/{Ip}/warmup",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDedicatedIpWarmupAttributes",
    Request: type = struct {
        ip: []const u8,
        warmup_percentage: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip = "Ip",
                .warmup_percentage = "WarmupPercentage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_dedicated_ip_warmup_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_dedicated_ip_warmup_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_deliverability_dashboard_option: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/deliverability-dashboard",
        .success_code = 200,
    };

    action_name: []const u8 = "PutDeliverabilityDashboardOption",
    Request: type = struct {
        dashboard_enabled: bool,
        subscribed_domains: ?[]DomainDeliverabilityTrackingOption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_enabled = "DashboardEnabled",
                .subscribed_domains = "SubscribedDomains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_deliverability_dashboard_option) } {
            return .{ .service_metadata = service_metadata, .action = put_deliverability_dashboard_option };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        BadRequest,
        LimitExceeded,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_email_identity_configuration_set_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/identities/{EmailIdentity}/configuration-set",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEmailIdentityConfigurationSetAttributes",
    Request: type = struct {
        email_identity: []const u8,
        configuration_set_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_email_identity_configuration_set_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_email_identity_configuration_set_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_email_identity_dkim_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/identities/{EmailIdentity}/dkim",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEmailIdentityDkimAttributes",
    Request: type = struct {
        email_identity: []const u8,
        signing_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .signing_enabled = "SigningEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_email_identity_dkim_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_email_identity_dkim_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_email_identity_dkim_signing_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/email/identities/{EmailIdentity}/dkim/signing",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEmailIdentityDkimSigningAttributes",
    Request: type = struct {
        email_identity: []const u8,
        signing_attributes_origin: []const u8,
        signing_attributes: ?DkimSigningAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .signing_attributes_origin = "SigningAttributesOrigin",
                .signing_attributes = "SigningAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_email_identity_dkim_signing_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_email_identity_dkim_signing_attributes };
        }
    },
    Response: type = struct {
        dkim_status: ?[]const u8 = null,
        dkim_tokens: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dkim_status = "DkimStatus",
                .dkim_tokens = "DkimTokens",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_email_identity_feedback_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/identities/{EmailIdentity}/feedback",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEmailIdentityFeedbackAttributes",
    Request: type = struct {
        email_identity: []const u8,
        email_forwarding_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .email_forwarding_enabled = "EmailForwardingEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_email_identity_feedback_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_email_identity_feedback_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_email_identity_mail_from_attributes: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/identities/{EmailIdentity}/mail-from",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEmailIdentityMailFromAttributes",
    Request: type = struct {
        email_identity: []const u8,
        mail_from_domain: ?[]const u8 = null,
        behavior_on_mx_failure: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .mail_from_domain = "MailFromDomain",
                .behavior_on_mx_failure = "BehaviorOnMxFailure",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_email_identity_mail_from_attributes) } {
            return .{ .service_metadata = service_metadata, .action = put_email_identity_mail_from_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_suppressed_destination: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/suppression/addresses",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSuppressedDestination",
    Request: type = struct {
        email_address: []const u8,
        reason: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_address = "EmailAddress",
                .reason = "Reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_suppressed_destination) } {
            return .{ .service_metadata = service_metadata, .action = put_suppressed_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        TooManyRequests,
    },
} = .{};
pub const send_bulk_email: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/outbound-bulk-emails",
        .success_code = 200,
    };

    action_name: []const u8 = "SendBulkEmail",
    Request: type = struct {
        from_email_address: ?[]const u8 = null,
        from_email_address_identity_arn: ?[]const u8 = null,
        reply_to_addresses: ?[][]const u8 = null,
        feedback_forwarding_email_address: ?[]const u8 = null,
        feedback_forwarding_email_address_identity_arn: ?[]const u8 = null,
        default_email_tags: ?[]MessageTag = null,
        default_content: struct {
            template: ?Template = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .template = "Template",
                };
                return @field(mappings, field_name);
            }
        },
        bulk_email_entries: []struct {
            destination: Destination,
            replacement_tags: ?[]MessageTag = null,
            replacement_email_content: ?struct {
                replacement_template: ?struct {
                    replacement_template_data: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .replacement_template_data = "ReplacementTemplateData",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .replacement_template = "ReplacementTemplate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .destination = "Destination",
                    .replacement_tags = "ReplacementTags",
                    .replacement_email_content = "ReplacementEmailContent",
                };
                return @field(mappings, field_name);
            }
        },
        configuration_set_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .from_email_address = "FromEmailAddress",
                .from_email_address_identity_arn = "FromEmailAddressIdentityArn",
                .reply_to_addresses = "ReplyToAddresses",
                .feedback_forwarding_email_address = "FeedbackForwardingEmailAddress",
                .feedback_forwarding_email_address_identity_arn = "FeedbackForwardingEmailAddressIdentityArn",
                .default_email_tags = "DefaultEmailTags",
                .default_content = "DefaultContent",
                .bulk_email_entries = "BulkEmailEntries",
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_bulk_email) } {
            return .{ .service_metadata = service_metadata, .action = send_bulk_email };
        }
    },
    Response: type = struct {
        bulk_email_entry_results: []struct {
            status: ?[]const u8 = null,
            @"error": ?[]const u8 = null,
            message_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "Status",
                    .@"error" = "Error",
                    .message_id = "MessageId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bulk_email_entry_results = "BulkEmailEntryResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountSuspended,
        BadRequest,
        LimitExceeded,
        MailFromDomainNotVerified,
        MessageRejected,
        NotFound,
        SendingPaused,
        TooManyRequests,
    },
} = .{};
pub const send_custom_verification_email: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/outbound-custom-verification-emails",
        .success_code = 200,
    };

    action_name: []const u8 = "SendCustomVerificationEmail",
    Request: type = struct {
        email_address: []const u8,
        template_name: []const u8,
        configuration_set_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_address = "EmailAddress",
                .template_name = "TemplateName",
                .configuration_set_name = "ConfigurationSetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_custom_verification_email) } {
            return .{ .service_metadata = service_metadata, .action = send_custom_verification_email };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        LimitExceeded,
        MailFromDomainNotVerified,
        MessageRejected,
        NotFound,
        SendingPaused,
        TooManyRequests,
    },
} = .{};
pub const send_email: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/outbound-emails",
        .success_code = 200,
    };

    action_name: []const u8 = "SendEmail",
    Request: type = struct {
        from_email_address: ?[]const u8 = null,
        from_email_address_identity_arn: ?[]const u8 = null,
        destination: ?Destination = null,
        reply_to_addresses: ?[][]const u8 = null,
        feedback_forwarding_email_address: ?[]const u8 = null,
        feedback_forwarding_email_address_identity_arn: ?[]const u8 = null,
        content: EmailContent,
        email_tags: ?[]MessageTag = null,
        configuration_set_name: ?[]const u8 = null,
        list_management_options: ?struct {
            contact_list_name: []const u8,
            topic_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .contact_list_name = "ContactListName",
                    .topic_name = "TopicName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .from_email_address = "FromEmailAddress",
                .from_email_address_identity_arn = "FromEmailAddressIdentityArn",
                .destination = "Destination",
                .reply_to_addresses = "ReplyToAddresses",
                .feedback_forwarding_email_address = "FeedbackForwardingEmailAddress",
                .feedback_forwarding_email_address_identity_arn = "FeedbackForwardingEmailAddressIdentityArn",
                .content = "Content",
                .email_tags = "EmailTags",
                .configuration_set_name = "ConfigurationSetName",
                .list_management_options = "ListManagementOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_email) } {
            return .{ .service_metadata = service_metadata, .action = send_email };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccountSuspended,
        BadRequest,
        LimitExceeded,
        MailFromDomainNotVerified,
        MessageRejected,
        NotFound,
        SendingPaused,
        TooManyRequests,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const test_render_email_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v2/email/templates/{TemplateName}/render",
        .success_code = 200,
    };

    action_name: []const u8 = "TestRenderEmailTemplate",
    Request: type = struct {
        template_name: []const u8,
        template_data: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .template_data = "TemplateData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_render_email_template) } {
            return .{ .service_metadata = service_metadata, .action = test_render_email_template };
        }
    },
    Response: type = struct {
        rendered_template: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rendered_template = "RenderedTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v2/email/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "ResourceArn",
            .tag_keys = "TagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_configuration_set_event_destination: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/configuration-sets/{ConfigurationSetName}/event-destinations/{EventDestinationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConfigurationSetEventDestination",
    Request: type = struct {
        configuration_set_name: []const u8,
        event_destination_name: []const u8,
        event_destination: EventDestinationDefinition,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration_set_name = "ConfigurationSetName",
                .event_destination_name = "EventDestinationName",
                .event_destination = "EventDestination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration_set_event_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration_set_event_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_contact: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/contact-lists/{ContactListName}/contacts/{EmailAddress}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContact",
    Request: type = struct {
        contact_list_name: []const u8,
        email_address: []const u8,
        topic_preferences: ?[]TopicPreference = null,
        unsubscribe_all: ?bool = null,
        attributes_data: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
                .email_address = "EmailAddress",
                .topic_preferences = "TopicPreferences",
                .unsubscribe_all = "UnsubscribeAll",
                .attributes_data = "AttributesData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact) } {
            return .{ .service_metadata = service_metadata, .action = update_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_contact_list: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/contact-lists/{ContactListName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactList",
    Request: type = struct {
        contact_list_name: []const u8,
        topics: ?[]Topic = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_list_name = "ContactListName",
                .topics = "Topics",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_list) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_list };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_custom_verification_email_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/custom-verification-email-templates/{TemplateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCustomVerificationEmailTemplate",
    Request: type = struct {
        template_name: []const u8,
        from_email_address: []const u8,
        template_subject: []const u8,
        template_content: []const u8,
        success_redirection_url: []const u8,
        failure_redirection_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .from_email_address = "FromEmailAddress",
                .template_subject = "TemplateSubject",
                .template_content = "TemplateContent",
                .success_redirection_url = "SuccessRedirectionURL",
                .failure_redirection_url = "FailureRedirectionURL",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_custom_verification_email_template) } {
            return .{ .service_metadata = service_metadata, .action = update_custom_verification_email_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_email_identity_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/identities/{EmailIdentity}/policies/{PolicyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEmailIdentityPolicy",
    Request: type = struct {
        email_identity: []const u8,
        policy_name: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .email_identity = "EmailIdentity",
                .policy_name = "PolicyName",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_email_identity_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_email_identity_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_email_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v2/email/templates/{TemplateName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEmailTemplate",
    Request: type = struct {
        template_name: []const u8,
        template_content: EmailTemplateContent,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .template_content = "TemplateContent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_email_template) } {
            return .{ .service_metadata = service_metadata, .action = update_email_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const EmailTemplateContent = struct {
    subject: ?[]const u8 = null,
    text: ?[]const u8 = null,
    html: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subject = "Subject",
            .text = "Text",
            .html = "Html",
        };
        return @field(mappings, field_name);
    }
};

pub const Topic = struct {
    topic_name: []const u8,
    display_name: []const u8,
    description: ?[]const u8 = null,
    default_subscription_status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_name = "TopicName",
            .display_name = "DisplayName",
            .description = "Description",
            .default_subscription_status = "DefaultSubscriptionStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const TopicPreference = struct {
    topic_name: []const u8,
    subscription_status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_name = "TopicName",
            .subscription_status = "SubscriptionStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const EventDestinationDefinition = struct {
    enabled: ?bool = null,
    matching_event_types: ?[][]const u8 = null,
    kinesis_firehose_destination: ?KinesisFirehoseDestination = null,
    cloud_watch_destination: ?CloudWatchDestination = null,
    sns_destination: ?SnsDestination = null,
    pinpoint_destination: ?PinpointDestination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .matching_event_types = "MatchingEventTypes",
            .kinesis_firehose_destination = "KinesisFirehoseDestination",
            .cloud_watch_destination = "CloudWatchDestination",
            .sns_destination = "SnsDestination",
            .pinpoint_destination = "PinpointDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const PinpointDestination = struct {
    application_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .application_arn = "ApplicationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SnsDestination = struct {
    topic_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchDestination = struct {
    dimension_configurations: []CloudWatchDimensionConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_configurations = "DimensionConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchDimensionConfiguration = struct {
    dimension_name: []const u8,
    dimension_value_source: []const u8,
    default_dimension_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimension_name = "DimensionName",
            .dimension_value_source = "DimensionValueSource",
            .default_dimension_value = "DefaultDimensionValue",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisFirehoseDestination = struct {
    iam_role_arn: []const u8,
    delivery_stream_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .iam_role_arn = "IamRoleArn",
            .delivery_stream_arn = "DeliveryStreamArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageTag = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const EmailContent = struct {
    simple: ?Message = null,
    raw: ?RawMessage = null,
    template: ?Template = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .simple = "Simple",
            .raw = "Raw",
            .template = "Template",
        };
        return @field(mappings, field_name);
    }
};

pub const Template = struct {
    template_name: ?[]const u8 = null,
    template_arn: ?[]const u8 = null,
    template_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .template_name = "TemplateName",
            .template_arn = "TemplateArn",
            .template_data = "TemplateData",
        };
        return @field(mappings, field_name);
    }
};

pub const RawMessage = struct {
    data: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
        };
        return @field(mappings, field_name);
    }
};

pub const Message = struct {
    subject: Content,
    body: Body,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subject = "Subject",
            .body = "Body",
        };
        return @field(mappings, field_name);
    }
};

pub const Body = struct {
    text: ?Content = null,
    html: ?Content = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .html = "Html",
        };
        return @field(mappings, field_name);
    }
};

pub const Content = struct {
    data: []const u8,
    charset: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
            .charset = "Charset",
        };
        return @field(mappings, field_name);
    }
};

pub const Destination = struct {
    to_addresses: ?[][]const u8 = null,
    cc_addresses: ?[][]const u8 = null,
    bcc_addresses: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .to_addresses = "ToAddresses",
            .cc_addresses = "CcAddresses",
            .bcc_addresses = "BccAddresses",
        };
        return @field(mappings, field_name);
    }
};

pub const DkimSigningAttributes = struct {
    domain_signing_selector: ?[]const u8 = null,
    domain_signing_private_key: ?[]const u8 = null,
    next_signing_key_length: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_signing_selector = "DomainSigningSelector",
            .domain_signing_private_key = "DomainSigningPrivateKey",
            .next_signing_key_length = "NextSigningKeyLength",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainDeliverabilityTrackingOption = struct {
    domain: ?[]const u8 = null,
    subscription_start_date: ?i64 = null,
    inbox_placement_tracking_option: ?InboxPlacementTrackingOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
            .subscription_start_date = "SubscriptionStartDate",
            .inbox_placement_tracking_option = "InboxPlacementTrackingOption",
        };
        return @field(mappings, field_name);
    }
};

pub const InboxPlacementTrackingOption = struct {
    global: ?bool = null,
    tracked_isps: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .global = "Global",
            .tracked_isps = "TrackedIsps",
        };
        return @field(mappings, field_name);
    }
};

pub const VdmOptions = struct {
    dashboard_options: ?DashboardOptions = null,
    guardian_options: ?GuardianOptions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dashboard_options = "DashboardOptions",
            .guardian_options = "GuardianOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const GuardianOptions = struct {
    optimized_shared_delivery: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .optimized_shared_delivery = "OptimizedSharedDelivery",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardOptions = struct {
    engagement_metrics: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .engagement_metrics = "EngagementMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const VdmAttributes = struct {
    vdm_enabled: []const u8,
    dashboard_attributes: ?DashboardAttributes = null,
    guardian_attributes: ?GuardianAttributes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vdm_enabled = "VdmEnabled",
            .dashboard_attributes = "DashboardAttributes",
            .guardian_attributes = "GuardianAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const GuardianAttributes = struct {
    optimized_shared_delivery: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .optimized_shared_delivery = "OptimizedSharedDelivery",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardAttributes = struct {
    engagement_metrics: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .engagement_metrics = "EngagementMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportDestination = struct {
    suppression_list_destination: ?SuppressionListDestination = null,
    contact_list_destination: ?ContactListDestination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .suppression_list_destination = "SuppressionListDestination",
            .contact_list_destination = "ContactListDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const ContactListDestination = struct {
    contact_list_name: []const u8,
    contact_list_import_action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .contact_list_name = "ContactListName",
            .contact_list_import_action = "ContactListImportAction",
        };
        return @field(mappings, field_name);
    }
};

pub const SuppressionListDestination = struct {
    suppression_list_import_action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .suppression_list_import_action = "SuppressionListImportAction",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainDeliverabilityCampaign = struct {
    campaign_id: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    subject: ?[]const u8 = null,
    from_address: ?[]const u8 = null,
    sending_ips: ?[][]const u8 = null,
    first_seen_date_time: ?i64 = null,
    last_seen_date_time: ?i64 = null,
    inbox_count: ?i64 = null,
    spam_count: ?i64 = null,
    read_rate: ?f64 = null,
    delete_rate: ?f64 = null,
    read_delete_rate: ?f64 = null,
    projected_volume: ?i64 = null,
    esps: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .campaign_id = "CampaignId",
            .image_url = "ImageUrl",
            .subject = "Subject",
            .from_address = "FromAddress",
            .sending_ips = "SendingIps",
            .first_seen_date_time = "FirstSeenDateTime",
            .last_seen_date_time = "LastSeenDateTime",
            .inbox_count = "InboxCount",
            .spam_count = "SpamCount",
            .read_rate = "ReadRate",
            .delete_rate = "DeleteRate",
            .read_delete_rate = "ReadDeleteRate",
            .projected_volume = "ProjectedVolume",
            .esps = "Esps",
        };
        return @field(mappings, field_name);
    }
};

pub const DeliverabilityTestReport = struct {
    report_id: ?[]const u8 = null,
    report_name: ?[]const u8 = null,
    subject: ?[]const u8 = null,
    from_email_address: ?[]const u8 = null,
    create_date: ?i64 = null,
    deliverability_test_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report_id = "ReportId",
            .report_name = "ReportName",
            .subject = "Subject",
            .from_email_address = "FromEmailAddress",
            .create_date = "CreateDate",
            .deliverability_test_status = "DeliverabilityTestStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const FailureInfo = struct {
    failed_records_s3_url: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failed_records_s3_url = "FailedRecordsS3Url",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportDataSource = struct {
    s3_url: []const u8,
    data_format: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_url = "S3Url",
            .data_format = "DataFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportDataSource = struct {
    metrics_data_source: ?MetricsDataSource = null,
    message_insights_data_source: ?MessageInsightsDataSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metrics_data_source = "MetricsDataSource",
            .message_insights_data_source = "MessageInsightsDataSource",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageInsightsDataSource = struct {
    start_date: i64,
    end_date: i64,
    include: ?MessageInsightsFilters = null,
    exclude: ?MessageInsightsFilters = null,
    max_results: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_date = "StartDate",
            .end_date = "EndDate",
            .include = "Include",
            .exclude = "Exclude",
            .max_results = "MaxResults",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageInsightsFilters = struct {
    from_email_address: ?[][]const u8 = null,
    destination: ?[][]const u8 = null,
    subject: ?[][]const u8 = null,
    isp: ?[][]const u8 = null,
    last_delivery_event: ?[][]const u8 = null,
    last_engagement_event: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_email_address = "FromEmailAddress",
            .destination = "Destination",
            .subject = "Subject",
            .isp = "Isp",
            .last_delivery_event = "LastDeliveryEvent",
            .last_engagement_event = "LastEngagementEvent",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricsDataSource = struct {
    dimensions: []struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    },
    namespace: []const u8,
    metrics: []ExportMetric,
    start_date: i64,
    end_date: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimensions = "Dimensions",
            .namespace = "Namespace",
            .metrics = "Metrics",
            .start_date = "StartDate",
            .end_date = "EndDate",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "dimensions", field_name))
            return try serializeMap(self.dimensions, self.fieldNameFor("dimensions"), options, out_stream);
        return false;
    }
};

pub const ExportMetric = struct {
    name: ?[]const u8 = null,
    aggregation: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .aggregation = "Aggregation",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportDestination = struct {
    data_format: []const u8,
    s3_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_format = "DataFormat",
            .s3_url = "S3Url",
        };
        return @field(mappings, field_name);
    }
};

pub const DkimAttributes = struct {
    signing_enabled: ?bool = null,
    status: ?[]const u8 = null,
    tokens: ?[][]const u8 = null,
    signing_attributes_origin: ?[]const u8 = null,
    next_signing_key_length: ?[]const u8 = null,
    current_signing_key_length: ?[]const u8 = null,
    last_key_generation_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signing_enabled = "SigningEnabled",
            .status = "Status",
            .tokens = "Tokens",
            .signing_attributes_origin = "SigningAttributesOrigin",
            .next_signing_key_length = "NextSigningKeyLength",
            .current_signing_key_length = "CurrentSigningKeyLength",
            .last_key_generation_timestamp = "LastKeyGenerationTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainIspPlacement = struct {
    isp_name: ?[]const u8 = null,
    inbox_raw_count: ?i64 = null,
    spam_raw_count: ?i64 = null,
    inbox_percentage: ?f64 = null,
    spam_percentage: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .isp_name = "IspName",
            .inbox_raw_count = "InboxRawCount",
            .spam_raw_count = "SpamRawCount",
            .inbox_percentage = "InboxPercentage",
            .spam_percentage = "SpamPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeStatistics = struct {
    inbox_raw_count: ?i64 = null,
    spam_raw_count: ?i64 = null,
    projected_inbox: ?i64 = null,
    projected_spam: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inbox_raw_count = "InboxRawCount",
            .spam_raw_count = "SpamRawCount",
            .projected_inbox = "ProjectedInbox",
            .projected_spam = "ProjectedSpam",
        };
        return @field(mappings, field_name);
    }
};

pub const PlacementStatistics = struct {
    inbox_percentage: ?f64 = null,
    spam_percentage: ?f64 = null,
    missing_percentage: ?f64 = null,
    spf_percentage: ?f64 = null,
    dkim_percentage: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inbox_percentage = "InboxPercentage",
            .spam_percentage = "SpamPercentage",
            .missing_percentage = "MissingPercentage",
            .spf_percentage = "SpfPercentage",
            .dkim_percentage = "DkimPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const DedicatedIp = struct {
    ip: []const u8,
    warmup_status: []const u8,
    warmup_percentage: i64,
    pool_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip = "Ip",
            .warmup_status = "WarmupStatus",
            .warmup_percentage = "WarmupPercentage",
            .pool_name = "PoolName",
        };
        return @field(mappings, field_name);
    }
};

pub const SuppressionOptions = struct {
    suppressed_reasons: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .suppressed_reasons = "SuppressedReasons",
        };
        return @field(mappings, field_name);
    }
};

pub const SendingOptions = struct {
    sending_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sending_enabled = "SendingEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ReputationOptions = struct {
    reputation_metrics_enabled: ?bool = null,
    last_fresh_start: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reputation_metrics_enabled = "ReputationMetricsEnabled",
            .last_fresh_start = "LastFreshStart",
        };
        return @field(mappings, field_name);
    }
};

pub const DeliveryOptions = struct {
    tls_policy: ?[]const u8 = null,
    sending_pool_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tls_policy = "TlsPolicy",
            .sending_pool_name = "SendingPoolName",
        };
        return @field(mappings, field_name);
    }
};

pub const TrackingOptions = struct {
    custom_redirect_domain: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_redirect_domain = "CustomRedirectDomain",
        };
        return @field(mappings, field_name);
    }
};
