const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-08-25";
pub const sdk_id: []const u8 = "signer";
pub const arn_namespace: ?[]const u8 = "signer";
pub const endpoint_prefix: []const u8 = "signer";
pub const sigv4_name: []const u8 = "signer";
pub const name: []const u8 = "WallabyService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-08-25",
    sdk_id: []const u8 = "signer",
    arn_namespace: ?[]const u8 = "signer",
    endpoint_prefix: []const u8 = "signer",
    sigv4_name: []const u8 = "signer",
    name: []const u8 = "WallabyService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const add_profile_permission: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/signing-profiles/{profileName}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "AddProfilePermission",
    Request: type = struct {
        profile_name: []const u8,
        profile_version: ?[]const u8 = null,
        action: []const u8,
        principal: []const u8,
        revision_id: ?[]const u8 = null,
        statement_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name = "profileName",
                .profile_version = "profileVersion",
                .action = "action",
                .principal = "principal",
                .revision_id = "revisionId",
                .statement_id = "statementId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_profile_permission) } {
            return .{ .service_metadata = service_metadata, .action = add_profile_permission };
        }
    },
    Response: type = struct {
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServiceError,
        ResourceNotFound,
        ServiceLimitExceeded,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const cancel_signing_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/signing-profiles/{profileName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelSigningProfile",
    Request: type = struct {
        profile_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name = "profileName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_signing_profile) } {
            return .{ .service_metadata = service_metadata, .action = cancel_signing_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_signing_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/signing-jobs/{jobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSigningJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_signing_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_signing_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        source: ?Source = null,
        signing_material: ?SigningMaterial = null,
        platform_id: ?[]const u8 = null,
        platform_display_name: ?[]const u8 = null,
        profile_name: ?[]const u8 = null,
        profile_version: ?[]const u8 = null,
        overrides: ?SigningPlatformOverrides = null,
        signing_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        created_at: ?i64 = null,
        completed_at: ?i64 = null,
        signature_expires_at: ?i64 = null,
        requested_by: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        revocation_record: ?struct {
            reason: ?[]const u8 = null,
            revoked_at: ?i64 = null,
            revoked_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reason = "reason",
                    .revoked_at = "revokedAt",
                    .revoked_by = "revokedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        signed_object: ?SignedObject = null,
        job_owner: ?[]const u8 = null,
        job_invoker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .source = "source",
                .signing_material = "signingMaterial",
                .platform_id = "platformId",
                .platform_display_name = "platformDisplayName",
                .profile_name = "profileName",
                .profile_version = "profileVersion",
                .overrides = "overrides",
                .signing_parameters = "signingParameters",
                .created_at = "createdAt",
                .completed_at = "completedAt",
                .signature_expires_at = "signatureExpiresAt",
                .requested_by = "requestedBy",
                .status = "status",
                .status_reason = "statusReason",
                .revocation_record = "revocationRecord",
                .signed_object = "signedObject",
                .job_owner = "jobOwner",
                .job_invoker = "jobInvoker",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "signing_parameters", field_name))
                return try serializeMap(self.signing_parameters, self.fieldNameFor("signing_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_revocation_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/revocations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRevocationStatus",
    Request: type = struct {
        signature_timestamp: i64,
        platform_id: []const u8,
        profile_version_arn: []const u8,
        job_arn: []const u8,
        certificate_hashes: [][]const u8,

        pub const http_query = .{
            .signature_timestamp = "signatureTimestamp",
            .platform_id = "platformId",
            .profile_version_arn = "profileVersionArn",
            .job_arn = "jobArn",
            .certificate_hashes = "certificateHashes",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .signature_timestamp = "signatureTimestamp",
                .platform_id = "platformId",
                .profile_version_arn = "profileVersionArn",
                .job_arn = "jobArn",
                .certificate_hashes = "certificateHashes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_revocation_status) } {
            return .{ .service_metadata = service_metadata, .action = get_revocation_status };
        }
    },
    Response: type = struct {
        revoked_entities: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .revoked_entities = "revokedEntities",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const get_signing_platform: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/signing-platforms/{platformId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSigningPlatform",
    Request: type = struct {
        platform_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_id = "platformId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_signing_platform) } {
            return .{ .service_metadata = service_metadata, .action = get_signing_platform };
        }
    },
    Response: type = struct {
        platform_id: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        partner: ?[]const u8 = null,
        target: ?[]const u8 = null,
        category: ?[]const u8 = null,
        signing_configuration: ?SigningConfiguration = null,
        signing_image_format: ?SigningImageFormat = null,
        max_size_in_mb: ?i64 = null,
        revocation_supported: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_id = "platformId",
                .display_name = "displayName",
                .partner = "partner",
                .target = "target",
                .category = "category",
                .signing_configuration = "signingConfiguration",
                .signing_image_format = "signingImageFormat",
                .max_size_in_mb = "maxSizeInMB",
                .revocation_supported = "revocationSupported",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const get_signing_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/signing-profiles/{profileName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSigningProfile",
    Request: type = struct {
        profile_name: []const u8,
        profile_owner: ?[]const u8 = null,

        pub const http_query = .{
            .profile_owner = "profileOwner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name = "profileName",
                .profile_owner = "profileOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_signing_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_signing_profile };
        }
    },
    Response: type = struct {
        profile_name: ?[]const u8 = null,
        profile_version: ?[]const u8 = null,
        profile_version_arn: ?[]const u8 = null,
        revocation_record: ?struct {
            revocation_effective_from: ?i64 = null,
            revoked_at: ?i64 = null,
            revoked_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .revocation_effective_from = "revocationEffectiveFrom",
                    .revoked_at = "revokedAt",
                    .revoked_by = "revokedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        signing_material: ?SigningMaterial = null,
        platform_id: ?[]const u8 = null,
        platform_display_name: ?[]const u8 = null,
        signature_validity_period: ?SignatureValidityPeriod = null,
        overrides: ?SigningPlatformOverrides = null,
        signing_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name = "profileName",
                .profile_version = "profileVersion",
                .profile_version_arn = "profileVersionArn",
                .revocation_record = "revocationRecord",
                .signing_material = "signingMaterial",
                .platform_id = "platformId",
                .platform_display_name = "platformDisplayName",
                .signature_validity_period = "signatureValidityPeriod",
                .overrides = "overrides",
                .signing_parameters = "signingParameters",
                .status = "status",
                .status_reason = "statusReason",
                .arn = "arn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "signing_parameters", field_name))
                return try serializeMap(self.signing_parameters, self.fieldNameFor("signing_parameters"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_profile_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/signing-profiles/{profileName}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProfilePermissions",
    Request: type = struct {
        profile_name: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name = "profileName",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profile_permissions) } {
            return .{ .service_metadata = service_metadata, .action = list_profile_permissions };
        }
    },
    Response: type = struct {
        revision_id: ?[]const u8 = null,
        policy_size_bytes: ?i64 = null,
        permissions: ?[]struct {
            action: ?[]const u8 = null,
            principal: ?[]const u8 = null,
            statement_id: ?[]const u8 = null,
            profile_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "action",
                    .principal = "principal",
                    .statement_id = "statementId",
                    .profile_version = "profileVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .revision_id = "revisionId",
                .policy_size_bytes = "policySizeBytes",
                .permissions = "permissions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_signing_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/signing-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSigningJobs",
    Request: type = struct {
        status: ?[]const u8 = null,
        platform_id: ?[]const u8 = null,
        requested_by: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        is_revoked: ?bool = null,
        signature_expires_before: ?i64 = null,
        signature_expires_after: ?i64 = null,
        job_invoker: ?[]const u8 = null,

        pub const http_query = .{
            .status = "status",
            .platform_id = "platformId",
            .requested_by = "requestedBy",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .is_revoked = "isRevoked",
            .signature_expires_before = "signatureExpiresBefore",
            .signature_expires_after = "signatureExpiresAfter",
            .job_invoker = "jobInvoker",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .platform_id = "platformId",
                .requested_by = "requestedBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .is_revoked = "isRevoked",
                .signature_expires_before = "signatureExpiresBefore",
                .signature_expires_after = "signatureExpiresAfter",
                .job_invoker = "jobInvoker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_signing_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_signing_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            job_id: ?[]const u8 = null,
            source: ?Source = null,
            signed_object: ?SignedObject = null,
            signing_material: ?SigningMaterial = null,
            created_at: ?i64 = null,
            status: ?[]const u8 = null,
            is_revoked: ?bool = null,
            profile_name: ?[]const u8 = null,
            profile_version: ?[]const u8 = null,
            platform_id: ?[]const u8 = null,
            platform_display_name: ?[]const u8 = null,
            signature_expires_at: ?i64 = null,
            job_owner: ?[]const u8 = null,
            job_invoker: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "jobId",
                    .source = "source",
                    .signed_object = "signedObject",
                    .signing_material = "signingMaterial",
                    .created_at = "createdAt",
                    .status = "status",
                    .is_revoked = "isRevoked",
                    .profile_name = "profileName",
                    .profile_version = "profileVersion",
                    .platform_id = "platformId",
                    .platform_display_name = "platformDisplayName",
                    .signature_expires_at = "signatureExpiresAt",
                    .job_owner = "jobOwner",
                    .job_invoker = "jobInvoker",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_signing_platforms: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/signing-platforms",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSigningPlatforms",
    Request: type = struct {
        category: ?[]const u8 = null,
        partner: ?[]const u8 = null,
        target: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .category = "category",
            .partner = "partner",
            .target = "target",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category = "category",
                .partner = "partner",
                .target = "target",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_signing_platforms) } {
            return .{ .service_metadata = service_metadata, .action = list_signing_platforms };
        }
    },
    Response: type = struct {
        platforms: ?[]struct {
            platform_id: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            partner: ?[]const u8 = null,
            target: ?[]const u8 = null,
            category: ?[]const u8 = null,
            signing_configuration: ?SigningConfiguration = null,
            signing_image_format: ?SigningImageFormat = null,
            max_size_in_mb: ?i64 = null,
            revocation_supported: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .platform_id = "platformId",
                    .display_name = "displayName",
                    .partner = "partner",
                    .target = "target",
                    .category = "category",
                    .signing_configuration = "signingConfiguration",
                    .signing_image_format = "signingImageFormat",
                    .max_size_in_mb = "maxSizeInMB",
                    .revocation_supported = "revocationSupported",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platforms = "platforms",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const list_signing_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/signing-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSigningProfiles",
    Request: type = struct {
        include_canceled: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        platform_id: ?[]const u8 = null,
        statuses: ?[][]const u8 = null,

        pub const http_query = .{
            .include_canceled = "includeCanceled",
            .max_results = "maxResults",
            .next_token = "nextToken",
            .platform_id = "platformId",
            .statuses = "statuses",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .include_canceled = "includeCanceled",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .platform_id = "platformId",
                .statuses = "statuses",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_signing_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_signing_profiles };
        }
    },
    Response: type = struct {
        profiles: ?[]struct {
            profile_name: ?[]const u8 = null,
            profile_version: ?[]const u8 = null,
            profile_version_arn: ?[]const u8 = null,
            signing_material: ?SigningMaterial = null,
            signature_validity_period: ?SignatureValidityPeriod = null,
            platform_id: ?[]const u8 = null,
            platform_display_name: ?[]const u8 = null,
            signing_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            status: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .profile_name = "profileName",
                    .profile_version = "profileVersion",
                    .profile_version_arn = "profileVersionArn",
                    .signing_material = "signingMaterial",
                    .signature_validity_period = "signatureValidityPeriod",
                    .platform_id = "platformId",
                    .platform_display_name = "platformDisplayName",
                    .signing_parameters = "signingParameters",
                    .status = "status",
                    .arn = "arn",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "signing_parameters", field_name))
                    return try serializeMap(self.signing_parameters, self.fieldNameFor("signing_parameters"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profiles = "profiles",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        TooManyRequests,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServiceError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const put_signing_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/signing-profiles/{profileName}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSigningProfile",
    Request: type = struct {
        profile_name: []const u8,
        signing_material: ?SigningMaterial = null,
        signature_validity_period: ?SignatureValidityPeriod = null,
        platform_id: []const u8,
        overrides: ?SigningPlatformOverrides = null,
        signing_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name = "profileName",
                .signing_material = "signingMaterial",
                .signature_validity_period = "signatureValidityPeriod",
                .platform_id = "platformId",
                .overrides = "overrides",
                .signing_parameters = "signingParameters",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "signing_parameters", field_name))
                return try serializeMap(self.signing_parameters, self.fieldNameFor("signing_parameters"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_signing_profile) } {
            return .{ .service_metadata = service_metadata, .action = put_signing_profile };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        profile_version: ?[]const u8 = null,
        profile_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .profile_version = "profileVersion",
                .profile_version_arn = "profileVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const remove_profile_permission: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/signing-profiles/{profileName}/permissions/{statementId}",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveProfilePermission",
    Request: type = struct {
        profile_name: []const u8,
        revision_id: []const u8,
        statement_id: []const u8,

        pub const http_query = .{
            .revision_id = "revisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name = "profileName",
                .revision_id = "revisionId",
                .statement_id = "statementId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_profile_permission) } {
            return .{ .service_metadata = service_metadata, .action = remove_profile_permission };
        }
    },
    Response: type = struct {
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServiceError,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const revoke_signature: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/signing-jobs/{jobId}/revoke",
        .success_code = 200,
    };

    action_name: []const u8 = "RevokeSignature",
    Request: type = struct {
        job_id: []const u8,
        job_owner: ?[]const u8 = null,
        reason: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .job_owner = "jobOwner",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_signature) } {
            return .{ .service_metadata = service_metadata, .action = revoke_signature };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const revoke_signing_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/signing-profiles/{profileName}/revoke",
        .success_code = 200,
    };

    action_name: []const u8 = "RevokeSigningProfile",
    Request: type = struct {
        profile_name: []const u8,
        profile_version: []const u8,
        reason: []const u8,
        effective_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name = "profileName",
                .profile_version = "profileVersion",
                .reason = "reason",
                .effective_time = "effectiveTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_signing_profile) } {
            return .{ .service_metadata = service_metadata, .action = revoke_signing_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const sign_payload: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/signing-jobs/with-payload",
        .success_code = 200,
    };

    action_name: []const u8 = "SignPayload",
    Request: type = struct {
        profile_name: []const u8,
        profile_owner: ?[]const u8 = null,
        payload: []const u8,
        payload_format: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name = "profileName",
                .profile_owner = "profileOwner",
                .payload = "payload",
                .payload_format = "payloadFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(sign_payload) } {
            return .{ .service_metadata = service_metadata, .action = sign_payload };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        job_owner: ?[]const u8 = null,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        signature: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .job_owner = "jobOwner",
                .metadata = "metadata",
                .signature = "signature",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        ResourceNotFound,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const start_signing_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/signing-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "StartSigningJob",
    Request: type = struct {
        source: Source,
        destination: struct {
            s3: ?struct {
                bucket_name: ?[]const u8 = null,
                prefix: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bucket_name = "bucketName",
                        .prefix = "prefix",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3 = "s3",
                };
                return @field(mappings, field_name);
            }
        },
        profile_name: []const u8,
        client_request_token: []const u8,
        profile_owner: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "source",
                .destination = "destination",
                .profile_name = "profileName",
                .client_request_token = "clientRequestToken",
                .profile_owner = "profileOwner",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_signing_job) } {
            return .{ .service_metadata = service_metadata, .action = start_signing_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        job_owner: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .job_owner = "jobOwner",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        ResourceNotFound,
        Throttling,
        TooManyRequests,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServiceError,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServiceError,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const Source = struct {
    s3: ?S3Source = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "s3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Source = struct {
    bucket_name: []const u8,
    key: []const u8,
    version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .key = "key",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const SigningPlatformOverrides = struct {
    signing_configuration: ?SigningConfigurationOverrides = null,
    signing_image_format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signing_configuration = "signingConfiguration",
            .signing_image_format = "signingImageFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const SigningConfigurationOverrides = struct {
    encryption_algorithm: ?[]const u8 = null,
    hash_algorithm: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_algorithm = "encryptionAlgorithm",
            .hash_algorithm = "hashAlgorithm",
        };
        return @field(mappings, field_name);
    }
};

pub const SignatureValidityPeriod = struct {
    value: ?i64 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const SigningMaterial = struct {
    certificate_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_arn = "certificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SigningImageFormat = struct {
    supported_formats: [][]const u8,
    default_format: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .supported_formats = "supportedFormats",
            .default_format = "defaultFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const SigningConfiguration = struct {
    encryption_algorithm_options: EncryptionAlgorithmOptions,
    hash_algorithm_options: HashAlgorithmOptions,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_algorithm_options = "encryptionAlgorithmOptions",
            .hash_algorithm_options = "hashAlgorithmOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const HashAlgorithmOptions = struct {
    allowed_values: [][]const u8,
    default_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allowed_values = "allowedValues",
            .default_value = "defaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionAlgorithmOptions = struct {
    allowed_values: [][]const u8,
    default_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allowed_values = "allowedValues",
            .default_value = "defaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const SignedObject = struct {
    s3: ?S3SignedObject = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3 = "s3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SignedObject = struct {
    bucket_name: ?[]const u8 = null,
    key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .key = "key",
        };
        return @field(mappings, field_name);
    }
};
