const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-10-24";
pub const sdk_id: []const u8 = "SMS";
pub const arn_namespace: ?[]const u8 = "sms";
pub const endpoint_prefix: []const u8 = "sms";
pub const sigv4_name: []const u8 = "sms";
pub const name: []const u8 = "AWSServerMigrationService_V2016_10_24";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-10-24",
    sdk_id: []const u8 = "SMS",
    arn_namespace: ?[]const u8 = "sms",
    endpoint_prefix: []const u8 = "sms",
    sigv4_name: []const u8 = "sms",
    name: []const u8 = "AWSServerMigrationService_V2016_10_24",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_app: struct {
    action_name: []const u8 = "CreateApp",
    Request: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_name: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        server_groups: ?[]ServerGroup = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .role_name = "roleName",
                .client_token = "clientToken",
                .server_groups = "serverGroups",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app) } {
            return .{ .service_metadata = service_metadata, .action = create_app };
        }
    },
    Response: type = struct {
        app_summary: ?AppSummary = null,
        server_groups: ?[]ServerGroup = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_summary = "appSummary",
                .server_groups = "serverGroups",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const create_replication_job: struct {
    action_name: []const u8 = "CreateReplicationJob",
    Request: type = struct {
        server_id: []const u8,
        seed_replication_time: i64,
        frequency: ?i64 = null,
        run_once: ?bool = null,
        license_type: ?[]const u8 = null,
        role_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        number_of_recent_amis_to_keep: ?i64 = null,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "serverId",
                .seed_replication_time = "seedReplicationTime",
                .frequency = "frequency",
                .run_once = "runOnce",
                .license_type = "licenseType",
                .role_name = "roleName",
                .description = "description",
                .number_of_recent_amis_to_keep = "numberOfRecentAmisToKeep",
                .encrypted = "encrypted",
                .kms_key_id = "kmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_job) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_job };
        }
    },
    Response: type = struct {
        replication_job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_job_id = "replicationJobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        NoConnectorsAvailable,
        OperationNotPermitted,
        ReplicationJobAlreadyExists,
        ServerCannotBeReplicated,
        TemporarilyUnavailable,
        UnauthorizedOperation,
    },
} = .{};
pub const delete_app: struct {
    action_name: []const u8 = "DeleteApp",
    Request: type = struct {
        app_id: ?[]const u8 = null,
        force_stop_app_replication: ?bool = null,
        force_terminate_app: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .force_stop_app_replication = "forceStopAppReplication",
                .force_terminate_app = "forceTerminateApp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app) } {
            return .{ .service_metadata = service_metadata, .action = delete_app };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const delete_app_launch_configuration: struct {
    action_name: []const u8 = "DeleteAppLaunchConfiguration",
    Request: type = struct {
        app_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_launch_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_launch_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const delete_app_replication_configuration: struct {
    action_name: []const u8 = "DeleteAppReplicationConfiguration",
    Request: type = struct {
        app_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_replication_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_replication_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const delete_app_validation_configuration: struct {
    action_name: []const u8 = "DeleteAppValidationConfiguration",
    Request: type = struct {
        app_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_validation_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_validation_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const delete_replication_job: struct {
    action_name: []const u8 = "DeleteReplicationJob",
    Request: type = struct {
        replication_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_job_id = "replicationJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        ReplicationJobNotFound,
        UnauthorizedOperation,
    },
} = .{};
pub const delete_server_catalog: struct {
    action_name: []const u8 = "DeleteServerCatalog",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_server_catalog) } {
            return .{ .service_metadata = service_metadata, .action = delete_server_catalog };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const disassociate_connector: struct {
    action_name: []const u8 = "DisassociateConnector",
    Request: type = struct {
        connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_id = "connectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_connector) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_connector };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const generate_change_set: struct {
    action_name: []const u8 = "GenerateChangeSet",
    Request: type = struct {
        app_id: ?[]const u8 = null,
        changeset_format: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .changeset_format = "changesetFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_change_set) } {
            return .{ .service_metadata = service_metadata, .action = generate_change_set };
        }
    },
    Response: type = struct {
        s3_location: ?S3Location = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_location = "s3Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const generate_template: struct {
    action_name: []const u8 = "GenerateTemplate",
    Request: type = struct {
        app_id: ?[]const u8 = null,
        template_format: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .template_format = "templateFormat",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_template) } {
            return .{ .service_metadata = service_metadata, .action = generate_template };
        }
    },
    Response: type = struct {
        s3_location: ?S3Location = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_location = "s3Location",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const get_app: struct {
    action_name: []const u8 = "GetApp",
    Request: type = struct {
        app_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app) } {
            return .{ .service_metadata = service_metadata, .action = get_app };
        }
    },
    Response: type = struct {
        app_summary: ?AppSummary = null,
        server_groups: ?[]ServerGroup = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_summary = "appSummary",
                .server_groups = "serverGroups",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const get_app_launch_configuration: struct {
    action_name: []const u8 = "GetAppLaunchConfiguration",
    Request: type = struct {
        app_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app_launch_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_app_launch_configuration };
        }
    },
    Response: type = struct {
        app_id: ?[]const u8 = null,
        role_name: ?[]const u8 = null,
        auto_launch: ?bool = null,
        server_group_launch_configurations: ?[]ServerGroupLaunchConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .role_name = "roleName",
                .auto_launch = "autoLaunch",
                .server_group_launch_configurations = "serverGroupLaunchConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const get_app_replication_configuration: struct {
    action_name: []const u8 = "GetAppReplicationConfiguration",
    Request: type = struct {
        app_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app_replication_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_app_replication_configuration };
        }
    },
    Response: type = struct {
        server_group_replication_configurations: ?[]ServerGroupReplicationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_group_replication_configurations = "serverGroupReplicationConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const get_app_validation_configuration: struct {
    action_name: []const u8 = "GetAppValidationConfiguration",
    Request: type = struct {
        app_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app_validation_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_app_validation_configuration };
        }
    },
    Response: type = struct {
        app_validation_configurations: ?[]AppValidationConfiguration = null,
        server_group_validation_configurations: ?[]ServerGroupValidationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_validation_configurations = "appValidationConfigurations",
                .server_group_validation_configurations = "serverGroupValidationConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const get_app_validation_output: struct {
    action_name: []const u8 = "GetAppValidationOutput",
    Request: type = struct {
        app_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app_validation_output) } {
            return .{ .service_metadata = service_metadata, .action = get_app_validation_output };
        }
    },
    Response: type = struct {
        validation_output_list: ?[]struct {
            validation_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            latest_validation_time: ?i64 = null,
            app_validation_output: ?struct {
                ssm_output: ?struct {
                    s3_location: ?S3Location = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .s3_location = "s3Location",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ssm_output = "ssmOutput",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            server_validation_output: ?struct {
                server: ?Server = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .server = "server",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .validation_id = "validationId",
                    .name = "name",
                    .status = "status",
                    .status_message = "statusMessage",
                    .latest_validation_time = "latestValidationTime",
                    .app_validation_output = "appValidationOutput",
                    .server_validation_output = "serverValidationOutput",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .validation_output_list = "validationOutputList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const get_connectors: struct {
    action_name: []const u8 = "GetConnectors",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connectors) } {
            return .{ .service_metadata = service_metadata, .action = get_connectors };
        }
    },
    Response: type = struct {
        connector_list: ?[]struct {
            connector_id: ?[]const u8 = null,
            version: ?[]const u8 = null,
            status: ?[]const u8 = null,
            capability_list: ?[][]const u8 = null,
            vm_manager_name: ?[]const u8 = null,
            vm_manager_type: ?[]const u8 = null,
            vm_manager_id: ?[]const u8 = null,
            ip_address: ?[]const u8 = null,
            mac_address: ?[]const u8 = null,
            associated_on: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connector_id = "connectorId",
                    .version = "version",
                    .status = "status",
                    .capability_list = "capabilityList",
                    .vm_manager_name = "vmManagerName",
                    .vm_manager_type = "vmManagerType",
                    .vm_manager_id = "vmManagerId",
                    .ip_address = "ipAddress",
                    .mac_address = "macAddress",
                    .associated_on = "associatedOn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_list = "connectorList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        UnauthorizedOperation,
    },
} = .{};
pub const get_replication_jobs: struct {
    action_name: []const u8 = "GetReplicationJobs",
    Request: type = struct {
        replication_job_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_job_id = "replicationJobId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_replication_jobs) } {
            return .{ .service_metadata = service_metadata, .action = get_replication_jobs };
        }
    },
    Response: type = struct {
        replication_job_list: ?[]ReplicationJob = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_job_list = "replicationJobList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MissingRequiredParameter,
        UnauthorizedOperation,
    },
} = .{};
pub const get_replication_runs: struct {
    action_name: []const u8 = "GetReplicationRuns",
    Request: type = struct {
        replication_job_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_job_id = "replicationJobId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_replication_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_replication_runs };
        }
    },
    Response: type = struct {
        replication_job: ?ReplicationJob = null,
        replication_run_list: ?[]ReplicationRun = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_job = "replicationJob",
                .replication_run_list = "replicationRunList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MissingRequiredParameter,
        UnauthorizedOperation,
    },
} = .{};
pub const get_servers: struct {
    action_name: []const u8 = "GetServers",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        vm_server_address_list: ?[]VmServerAddress = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .vm_server_address_list = "vmServerAddressList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_servers) } {
            return .{ .service_metadata = service_metadata, .action = get_servers };
        }
    },
    Response: type = struct {
        last_modified_on: ?i64 = null,
        server_catalog_status: ?[]const u8 = null,
        server_list: ?[]Server = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .last_modified_on = "lastModifiedOn",
                .server_catalog_status = "serverCatalogStatus",
                .server_list = "serverList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        UnauthorizedOperation,
    },
} = .{};
pub const import_app_catalog: struct {
    action_name: []const u8 = "ImportAppCatalog",
    Request: type = struct {
        role_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_name = "roleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_app_catalog) } {
            return .{ .service_metadata = service_metadata, .action = import_app_catalog };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const import_server_catalog: struct {
    action_name: []const u8 = "ImportServerCatalog",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_server_catalog) } {
            return .{ .service_metadata = service_metadata, .action = import_server_catalog };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MissingRequiredParameter,
        NoConnectorsAvailable,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const launch_app: struct {
    action_name: []const u8 = "LaunchApp",
    Request: type = struct {
        app_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(launch_app) } {
            return .{ .service_metadata = service_metadata, .action = launch_app };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const list_apps: struct {
    action_name: []const u8 = "ListApps",
    Request: type = struct {
        app_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_ids = "appIds",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_apps) } {
            return .{ .service_metadata = service_metadata, .action = list_apps };
        }
    },
    Response: type = struct {
        apps: ?[]AppSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apps = "apps",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const notify_app_validation_output: struct {
    action_name: []const u8 = "NotifyAppValidationOutput",
    Request: type = struct {
        app_id: []const u8,
        notification_context: ?struct {
            validation_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .validation_id = "validationId",
                    .status = "status",
                    .status_message = "statusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .notification_context = "notificationContext",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(notify_app_validation_output) } {
            return .{ .service_metadata = service_metadata, .action = notify_app_validation_output };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const put_app_launch_configuration: struct {
    action_name: []const u8 = "PutAppLaunchConfiguration",
    Request: type = struct {
        app_id: ?[]const u8 = null,
        role_name: ?[]const u8 = null,
        auto_launch: ?bool = null,
        server_group_launch_configurations: ?[]ServerGroupLaunchConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .role_name = "roleName",
                .auto_launch = "autoLaunch",
                .server_group_launch_configurations = "serverGroupLaunchConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_app_launch_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_app_launch_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const put_app_replication_configuration: struct {
    action_name: []const u8 = "PutAppReplicationConfiguration",
    Request: type = struct {
        app_id: ?[]const u8 = null,
        server_group_replication_configurations: ?[]ServerGroupReplicationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .server_group_replication_configurations = "serverGroupReplicationConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_app_replication_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_app_replication_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const put_app_validation_configuration: struct {
    action_name: []const u8 = "PutAppValidationConfiguration",
    Request: type = struct {
        app_id: []const u8,
        app_validation_configurations: ?[]AppValidationConfiguration = null,
        server_group_validation_configurations: ?[]ServerGroupValidationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .app_validation_configurations = "appValidationConfigurations",
                .server_group_validation_configurations = "serverGroupValidationConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_app_validation_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_app_validation_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const start_app_replication: struct {
    action_name: []const u8 = "StartAppReplication",
    Request: type = struct {
        app_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_app_replication) } {
            return .{ .service_metadata = service_metadata, .action = start_app_replication };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const start_on_demand_app_replication: struct {
    action_name: []const u8 = "StartOnDemandAppReplication",
    Request: type = struct {
        app_id: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_on_demand_app_replication) } {
            return .{ .service_metadata = service_metadata, .action = start_on_demand_app_replication };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const start_on_demand_replication_run: struct {
    action_name: []const u8 = "StartOnDemandReplicationRun",
    Request: type = struct {
        replication_job_id: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_job_id = "replicationJobId",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_on_demand_replication_run) } {
            return .{ .service_metadata = service_metadata, .action = start_on_demand_replication_run };
        }
    },
    Response: type = struct {
        replication_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_run_id = "replicationRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DryRunOperation,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        ReplicationRunLimitExceeded,
        UnauthorizedOperation,
    },
} = .{};
pub const stop_app_replication: struct {
    action_name: []const u8 = "StopAppReplication",
    Request: type = struct {
        app_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_app_replication) } {
            return .{ .service_metadata = service_metadata, .action = stop_app_replication };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const terminate_app: struct {
    action_name: []const u8 = "TerminateApp",
    Request: type = struct {
        app_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_app) } {
            return .{ .service_metadata = service_metadata, .action = terminate_app };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const update_app: struct {
    action_name: []const u8 = "UpdateApp",
    Request: type = struct {
        app_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_name: ?[]const u8 = null,
        server_groups: ?[]ServerGroup = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_id = "appId",
                .name = "name",
                .description = "description",
                .role_name = "roleName",
                .server_groups = "serverGroups",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app) } {
            return .{ .service_metadata = service_metadata, .action = update_app };
        }
    },
    Response: type = struct {
        app_summary: ?AppSummary = null,
        server_groups: ?[]ServerGroup = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_summary = "appSummary",
                .server_groups = "serverGroups",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        UnauthorizedOperation,
    },
} = .{};
pub const update_replication_job: struct {
    action_name: []const u8 = "UpdateReplicationJob",
    Request: type = struct {
        replication_job_id: []const u8,
        frequency: ?i64 = null,
        next_replication_run_start_time: ?i64 = null,
        license_type: ?[]const u8 = null,
        role_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        number_of_recent_amis_to_keep: ?i64 = null,
        encrypted: ?bool = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_job_id = "replicationJobId",
                .frequency = "frequency",
                .next_replication_run_start_time = "nextReplicationRunStartTime",
                .license_type = "licenseType",
                .role_name = "roleName",
                .description = "description",
                .number_of_recent_amis_to_keep = "numberOfRecentAmisToKeep",
                .encrypted = "encrypted",
                .kms_key_id = "kmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_replication_job) } {
            return .{ .service_metadata = service_metadata, .action = update_replication_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        InvalidParameter,
        MissingRequiredParameter,
        OperationNotPermitted,
        ReplicationJobNotFound,
        ServerCannotBeReplicated,
        TemporarilyUnavailable,
        UnauthorizedOperation,
    },
} = .{};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerGroup = struct {
    server_group_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    server_list: ?[]Server = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_group_id = "serverGroupId",
            .name = "name",
            .server_list = "serverList",
        };
        return @field(mappings, field_name);
    }
};

pub const Server = struct {
    server_id: ?[]const u8 = null,
    server_type: ?[]const u8 = null,
    vm_server: ?VmServer = null,
    replication_job_id: ?[]const u8 = null,
    replication_job_terminated: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_id = "serverId",
            .server_type = "serverType",
            .vm_server = "vmServer",
            .replication_job_id = "replicationJobId",
            .replication_job_terminated = "replicationJobTerminated",
        };
        return @field(mappings, field_name);
    }
};

pub const VmServer = struct {
    vm_server_address: ?VmServerAddress = null,
    vm_name: ?[]const u8 = null,
    vm_manager_name: ?[]const u8 = null,
    vm_manager_type: ?[]const u8 = null,
    vm_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vm_server_address = "vmServerAddress",
            .vm_name = "vmName",
            .vm_manager_name = "vmManagerName",
            .vm_manager_type = "vmManagerType",
            .vm_path = "vmPath",
        };
        return @field(mappings, field_name);
    }
};

pub const VmServerAddress = struct {
    vm_manager_id: ?[]const u8 = null,
    vm_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vm_manager_id = "vmManagerId",
            .vm_id = "vmId",
        };
        return @field(mappings, field_name);
    }
};

pub const AppSummary = struct {
    app_id: ?[]const u8 = null,
    imported_app_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    replication_configuration_status: ?[]const u8 = null,
    replication_status: ?[]const u8 = null,
    replication_status_message: ?[]const u8 = null,
    latest_replication_time: ?i64 = null,
    launch_configuration_status: ?[]const u8 = null,
    launch_status: ?[]const u8 = null,
    launch_status_message: ?[]const u8 = null,
    launch_details: ?LaunchDetails = null,
    creation_time: ?i64 = null,
    last_modified: ?i64 = null,
    role_name: ?[]const u8 = null,
    total_server_groups: ?i64 = null,
    total_servers: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_id = "appId",
            .imported_app_id = "importedAppId",
            .name = "name",
            .description = "description",
            .status = "status",
            .status_message = "statusMessage",
            .replication_configuration_status = "replicationConfigurationStatus",
            .replication_status = "replicationStatus",
            .replication_status_message = "replicationStatusMessage",
            .latest_replication_time = "latestReplicationTime",
            .launch_configuration_status = "launchConfigurationStatus",
            .launch_status = "launchStatus",
            .launch_status_message = "launchStatusMessage",
            .launch_details = "launchDetails",
            .creation_time = "creationTime",
            .last_modified = "lastModified",
            .role_name = "roleName",
            .total_server_groups = "totalServerGroups",
            .total_servers = "totalServers",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchDetails = struct {
    latest_launch_time: ?i64 = null,
    stack_name: ?[]const u8 = null,
    stack_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .latest_launch_time = "latestLaunchTime",
            .stack_name = "stackName",
            .stack_id = "stackId",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerGroupValidationConfiguration = struct {
    server_group_id: ?[]const u8 = null,
    server_validation_configurations: ?[]ServerValidationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_group_id = "serverGroupId",
            .server_validation_configurations = "serverValidationConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerValidationConfiguration = struct {
    server: ?Server = null,
    validation_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    server_validation_strategy: ?[]const u8 = null,
    user_data_validation_parameters: ?UserDataValidationParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server = "server",
            .validation_id = "validationId",
            .name = "name",
            .server_validation_strategy = "serverValidationStrategy",
            .user_data_validation_parameters = "userDataValidationParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const UserDataValidationParameters = struct {
    source: ?Source = null,
    script_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .script_type = "scriptType",
        };
        return @field(mappings, field_name);
    }
};

pub const Source = struct {
    s3_location: ?S3Location = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_location = "s3Location",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Location = struct {
    bucket: ?[]const u8 = null,
    key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key = "key",
        };
        return @field(mappings, field_name);
    }
};

pub const AppValidationConfiguration = struct {
    validation_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    app_validation_strategy: ?[]const u8 = null,
    ssm_validation_parameters: ?SSMValidationParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .validation_id = "validationId",
            .name = "name",
            .app_validation_strategy = "appValidationStrategy",
            .ssm_validation_parameters = "ssmValidationParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const SSMValidationParameters = struct {
    source: ?Source = null,
    instance_id: ?[]const u8 = null,
    script_type: ?[]const u8 = null,
    command: ?[]const u8 = null,
    execution_timeout_seconds: ?i64 = null,
    output_s3_bucket_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .instance_id = "instanceId",
            .script_type = "scriptType",
            .command = "command",
            .execution_timeout_seconds = "executionTimeoutSeconds",
            .output_s3_bucket_name = "outputS3BucketName",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerGroupReplicationConfiguration = struct {
    server_group_id: ?[]const u8 = null,
    server_replication_configurations: ?[]ServerReplicationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_group_id = "serverGroupId",
            .server_replication_configurations = "serverReplicationConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerReplicationConfiguration = struct {
    server: ?Server = null,
    server_replication_parameters: ?ServerReplicationParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server = "server",
            .server_replication_parameters = "serverReplicationParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerReplicationParameters = struct {
    seed_time: ?i64 = null,
    frequency: ?i64 = null,
    run_once: ?bool = null,
    license_type: ?[]const u8 = null,
    number_of_recent_amis_to_keep: ?i64 = null,
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .seed_time = "seedTime",
            .frequency = "frequency",
            .run_once = "runOnce",
            .license_type = "licenseType",
            .number_of_recent_amis_to_keep = "numberOfRecentAmisToKeep",
            .encrypted = "encrypted",
            .kms_key_id = "kmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerGroupLaunchConfiguration = struct {
    server_group_id: ?[]const u8 = null,
    launch_order: ?i64 = null,
    server_launch_configurations: ?[]ServerLaunchConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_group_id = "serverGroupId",
            .launch_order = "launchOrder",
            .server_launch_configurations = "serverLaunchConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerLaunchConfiguration = struct {
    server: ?Server = null,
    logical_id: ?[]const u8 = null,
    vpc: ?[]const u8 = null,
    subnet: ?[]const u8 = null,
    security_group: ?[]const u8 = null,
    ec2_key_name: ?[]const u8 = null,
    user_data: ?UserData = null,
    instance_type: ?[]const u8 = null,
    associate_public_ip_address: ?bool = null,
    iam_instance_profile_name: ?[]const u8 = null,
    configure_script: ?S3Location = null,
    configure_script_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server = "server",
            .logical_id = "logicalId",
            .vpc = "vpc",
            .subnet = "subnet",
            .security_group = "securityGroup",
            .ec2_key_name = "ec2KeyName",
            .user_data = "userData",
            .instance_type = "instanceType",
            .associate_public_ip_address = "associatePublicIpAddress",
            .iam_instance_profile_name = "iamInstanceProfileName",
            .configure_script = "configureScript",
            .configure_script_type = "configureScriptType",
        };
        return @field(mappings, field_name);
    }
};

pub const UserData = struct {
    s3_location: ?S3Location = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_location = "s3Location",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationRun = struct {
    replication_run_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    type: ?[]const u8 = null,
    stage_details: ?ReplicationRunStageDetails = null,
    status_message: ?[]const u8 = null,
    ami_id: ?[]const u8 = null,
    scheduled_start_time: ?i64 = null,
    completed_time: ?i64 = null,
    description: ?[]const u8 = null,
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_run_id = "replicationRunId",
            .state = "state",
            .type = "type",
            .stage_details = "stageDetails",
            .status_message = "statusMessage",
            .ami_id = "amiId",
            .scheduled_start_time = "scheduledStartTime",
            .completed_time = "completedTime",
            .description = "description",
            .encrypted = "encrypted",
            .kms_key_id = "kmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationRunStageDetails = struct {
    stage: ?[]const u8 = null,
    stage_progress: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stage = "stage",
            .stage_progress = "stageProgress",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationJob = struct {
    replication_job_id: ?[]const u8 = null,
    server_id: ?[]const u8 = null,
    server_type: ?[]const u8 = null,
    vm_server: ?VmServer = null,
    seed_replication_time: ?i64 = null,
    frequency: ?i64 = null,
    run_once: ?bool = null,
    next_replication_run_start_time: ?i64 = null,
    license_type: ?[]const u8 = null,
    role_name: ?[]const u8 = null,
    latest_ami_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    description: ?[]const u8 = null,
    number_of_recent_amis_to_keep: ?i64 = null,
    encrypted: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    replication_run_list: ?[]ReplicationRun = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_job_id = "replicationJobId",
            .server_id = "serverId",
            .server_type = "serverType",
            .vm_server = "vmServer",
            .seed_replication_time = "seedReplicationTime",
            .frequency = "frequency",
            .run_once = "runOnce",
            .next_replication_run_start_time = "nextReplicationRunStartTime",
            .license_type = "licenseType",
            .role_name = "roleName",
            .latest_ami_id = "latestAmiId",
            .state = "state",
            .status_message = "statusMessage",
            .description = "description",
            .number_of_recent_amis_to_keep = "numberOfRecentAmisToKeep",
            .encrypted = "encrypted",
            .kms_key_id = "kmsKeyId",
            .replication_run_list = "replicationRunList",
        };
        return @field(mappings, field_name);
    }
};
