const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-06-30";
pub const sdk_id: []const u8 = "Snowball";
pub const arn_namespace: ?[]const u8 = "snowball";
pub const endpoint_prefix: []const u8 = "snowball";
pub const sigv4_name: []const u8 = "snowball";
pub const name: []const u8 = "AWSIESnowballJobManagementService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-06-30",
    sdk_id: []const u8 = "Snowball",
    arn_namespace: ?[]const u8 = "snowball",
    endpoint_prefix: []const u8 = "snowball",
    sigv4_name: []const u8 = "snowball",
    name: []const u8 = "AWSIESnowballJobManagementService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const cancel_cluster: struct {
    action_name: []const u8 = "CancelCluster",
    Request: type = struct {
        cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_cluster) } {
            return .{ .service_metadata = service_metadata, .action = cancel_cluster };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidJobState,
        InvalidResource,
        KMSRequestFailed,
    },
} = .{};
pub const cancel_job: struct {
    action_name: []const u8 = "CancelJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidJobState,
        InvalidResource,
        KMSRequestFailed,
    },
} = .{};
pub const create_address: struct {
    action_name: []const u8 = "CreateAddress",
    Request: type = struct {
        address: Address,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address = "Address",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_address) } {
            return .{ .service_metadata = service_metadata, .action = create_address };
        }
    },
    Response: type = struct {
        address_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address_id = "AddressId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        UnsupportedAddress,
    },
} = .{};
pub const create_cluster: struct {
    action_name: []const u8 = "CreateCluster",
    Request: type = struct {
        job_type: []const u8,
        resources: ?JobResource = null,
        on_device_service_configuration: ?OnDeviceServiceConfiguration = null,
        description: ?[]const u8 = null,
        address_id: []const u8,
        kms_key_arn: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        snowball_type: []const u8,
        shipping_option: []const u8,
        notification: ?Notification = null,
        forwarding_address_id: ?[]const u8 = null,
        tax_documents: ?TaxDocuments = null,
        remote_management: ?[]const u8 = null,
        initial_cluster_size: ?i64 = null,
        force_create_jobs: ?bool = null,
        long_term_pricing_ids: ?[][]const u8 = null,
        snowball_capacity_preference: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_type = "JobType",
                .resources = "Resources",
                .on_device_service_configuration = "OnDeviceServiceConfiguration",
                .description = "Description",
                .address_id = "AddressId",
                .kms_key_arn = "KmsKeyARN",
                .role_arn = "RoleARN",
                .snowball_type = "SnowballType",
                .shipping_option = "ShippingOption",
                .notification = "Notification",
                .forwarding_address_id = "ForwardingAddressId",
                .tax_documents = "TaxDocuments",
                .remote_management = "RemoteManagement",
                .initial_cluster_size = "InitialClusterSize",
                .force_create_jobs = "ForceCreateJobs",
                .long_term_pricing_ids = "LongTermPricingIds",
                .snowball_capacity_preference = "SnowballCapacityPreference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster };
        }
    },
    Response: type = struct {
        cluster_id: ?[]const u8 = null,
        job_list_entries: ?[]JobListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .job_list_entries = "JobListEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Ec2RequestFailed,
        InvalidInputCombination,
        InvalidResource,
        KMSRequestFailed,
    },
} = .{};
pub const create_job: struct {
    action_name: []const u8 = "CreateJob",
    Request: type = struct {
        job_type: ?[]const u8 = null,
        resources: ?JobResource = null,
        on_device_service_configuration: ?OnDeviceServiceConfiguration = null,
        description: ?[]const u8 = null,
        address_id: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        snowball_capacity_preference: ?[]const u8 = null,
        shipping_option: ?[]const u8 = null,
        notification: ?Notification = null,
        cluster_id: ?[]const u8 = null,
        snowball_type: ?[]const u8 = null,
        forwarding_address_id: ?[]const u8 = null,
        tax_documents: ?TaxDocuments = null,
        device_configuration: ?DeviceConfiguration = null,
        remote_management: ?[]const u8 = null,
        long_term_pricing_id: ?[]const u8 = null,
        impact_level: ?[]const u8 = null,
        pickup_details: ?PickupDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_type = "JobType",
                .resources = "Resources",
                .on_device_service_configuration = "OnDeviceServiceConfiguration",
                .description = "Description",
                .address_id = "AddressId",
                .kms_key_arn = "KmsKeyARN",
                .role_arn = "RoleARN",
                .snowball_capacity_preference = "SnowballCapacityPreference",
                .shipping_option = "ShippingOption",
                .notification = "Notification",
                .cluster_id = "ClusterId",
                .snowball_type = "SnowballType",
                .forwarding_address_id = "ForwardingAddressId",
                .tax_documents = "TaxDocuments",
                .device_configuration = "DeviceConfiguration",
                .remote_management = "RemoteManagement",
                .long_term_pricing_id = "LongTermPricingId",
                .impact_level = "ImpactLevel",
                .pickup_details = "PickupDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job) } {
            return .{ .service_metadata = service_metadata, .action = create_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterLimitExceeded,
        Ec2RequestFailed,
        InvalidInputCombination,
        InvalidResource,
        KMSRequestFailed,
    },
} = .{};
pub const create_long_term_pricing: struct {
    action_name: []const u8 = "CreateLongTermPricing",
    Request: type = struct {
        long_term_pricing_type: []const u8,
        is_long_term_pricing_auto_renew: ?bool = null,
        snowball_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .long_term_pricing_type = "LongTermPricingType",
                .is_long_term_pricing_auto_renew = "IsLongTermPricingAutoRenew",
                .snowball_type = "SnowballType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_long_term_pricing) } {
            return .{ .service_metadata = service_metadata, .action = create_long_term_pricing };
        }
    },
    Response: type = struct {
        long_term_pricing_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .long_term_pricing_id = "LongTermPricingId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResource,
    },
} = .{};
pub const create_return_shipping_label: struct {
    action_name: []const u8 = "CreateReturnShippingLabel",
    Request: type = struct {
        job_id: []const u8,
        shipping_option: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .shipping_option = "ShippingOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_return_shipping_label) } {
            return .{ .service_metadata = service_metadata, .action = create_return_shipping_label };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InvalidInputCombination,
        InvalidJobState,
        InvalidResource,
        ReturnShippingLabelAlreadyExists,
    },
} = .{};
pub const describe_address: struct {
    action_name: []const u8 = "DescribeAddress",
    Request: type = struct {
        address_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address_id = "AddressId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_address) } {
            return .{ .service_metadata = service_metadata, .action = describe_address };
        }
    },
    Response: type = struct {
        address: ?Address = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .address = "Address",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResource,
    },
} = .{};
pub const describe_addresses: struct {
    action_name: []const u8 = "DescribeAddresses",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_addresses) } {
            return .{ .service_metadata = service_metadata, .action = describe_addresses };
        }
    },
    Response: type = struct {
        addresses: ?[]Address = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addresses = "Addresses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidResource,
    },
} = .{};
pub const describe_cluster: struct {
    action_name: []const u8 = "DescribeCluster",
    Request: type = struct {
        cluster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster };
        }
    },
    Response: type = struct {
        cluster_metadata: ?struct {
            cluster_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            kms_key_arn: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            cluster_state: ?[]const u8 = null,
            job_type: ?[]const u8 = null,
            snowball_type: ?[]const u8 = null,
            creation_date: ?i64 = null,
            resources: ?JobResource = null,
            address_id: ?[]const u8 = null,
            shipping_option: ?[]const u8 = null,
            notification: ?Notification = null,
            forwarding_address_id: ?[]const u8 = null,
            tax_documents: ?TaxDocuments = null,
            on_device_service_configuration: ?OnDeviceServiceConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cluster_id = "ClusterId",
                    .description = "Description",
                    .kms_key_arn = "KmsKeyARN",
                    .role_arn = "RoleARN",
                    .cluster_state = "ClusterState",
                    .job_type = "JobType",
                    .snowball_type = "SnowballType",
                    .creation_date = "CreationDate",
                    .resources = "Resources",
                    .address_id = "AddressId",
                    .shipping_option = "ShippingOption",
                    .notification = "Notification",
                    .forwarding_address_id = "ForwardingAddressId",
                    .tax_documents = "TaxDocuments",
                    .on_device_service_configuration = "OnDeviceServiceConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_metadata = "ClusterMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResource,
    },
} = .{};
pub const describe_job: struct {
    action_name: []const u8 = "DescribeJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_job };
        }
    },
    Response: type = struct {
        job_metadata: ?JobMetadata = null,
        sub_job_metadata: ?[]JobMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_metadata = "JobMetadata",
                .sub_job_metadata = "SubJobMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResource,
    },
} = .{};
pub const describe_return_shipping_label: struct {
    action_name: []const u8 = "DescribeReturnShippingLabel",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_return_shipping_label) } {
            return .{ .service_metadata = service_metadata, .action = describe_return_shipping_label };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        expiration_date: ?i64 = null,
        return_shipping_label_uri: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .expiration_date = "ExpirationDate",
                .return_shipping_label_uri = "ReturnShippingLabelURI",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InvalidJobState,
        InvalidResource,
    },
} = .{};
pub const get_job_manifest: struct {
    action_name: []const u8 = "GetJobManifest",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_manifest) } {
            return .{ .service_metadata = service_metadata, .action = get_job_manifest };
        }
    },
    Response: type = struct {
        manifest_uri: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .manifest_uri = "ManifestURI",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidJobState,
        InvalidResource,
    },
} = .{};
pub const get_job_unlock_code: struct {
    action_name: []const u8 = "GetJobUnlockCode",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_unlock_code) } {
            return .{ .service_metadata = service_metadata, .action = get_job_unlock_code };
        }
    },
    Response: type = struct {
        unlock_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unlock_code = "UnlockCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidJobState,
        InvalidResource,
    },
} = .{};
pub const get_snowball_usage: struct {
    action_name: []const u8 = "GetSnowballUsage",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_snowball_usage) } {
            return .{ .service_metadata = service_metadata, .action = get_snowball_usage };
        }
    },
    Response: type = struct {
        snowball_limit: ?i64 = null,
        snowballs_in_use: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snowball_limit = "SnowballLimit",
                .snowballs_in_use = "SnowballsInUse",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_software_updates: struct {
    action_name: []const u8 = "GetSoftwareUpdates",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_software_updates) } {
            return .{ .service_metadata = service_metadata, .action = get_software_updates };
        }
    },
    Response: type = struct {
        updates_uri: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .updates_uri = "UpdatesURI",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidJobState,
        InvalidResource,
    },
} = .{};
pub const list_cluster_jobs: struct {
    action_name: []const u8 = "ListClusterJobs",
    Request: type = struct {
        cluster_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cluster_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_cluster_jobs };
        }
    },
    Response: type = struct {
        job_list_entries: ?[]JobListEntry = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_list_entries = "JobListEntries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidResource,
    },
} = .{};
pub const list_clusters: struct {
    action_name: []const u8 = "ListClusters",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_clusters) } {
            return .{ .service_metadata = service_metadata, .action = list_clusters };
        }
    },
    Response: type = struct {
        cluster_list_entries: ?[]struct {
            cluster_id: ?[]const u8 = null,
            cluster_state: ?[]const u8 = null,
            creation_date: ?i64 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cluster_id = "ClusterId",
                    .cluster_state = "ClusterState",
                    .creation_date = "CreationDate",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_list_entries = "ClusterListEntries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
    },
} = .{};
pub const list_compatible_images: struct {
    action_name: []const u8 = "ListCompatibleImages",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_compatible_images) } {
            return .{ .service_metadata = service_metadata, .action = list_compatible_images };
        }
    },
    Response: type = struct {
        compatible_images: ?[]struct {
            ami_id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ami_id = "AmiId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compatible_images = "CompatibleImages",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Ec2RequestFailed,
        InvalidNextToken,
    },
} = .{};
pub const list_jobs: struct {
    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        job_list_entries: ?[]JobListEntry = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_list_entries = "JobListEntries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
    },
} = .{};
pub const list_long_term_pricing: struct {
    action_name: []const u8 = "ListLongTermPricing",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_long_term_pricing) } {
            return .{ .service_metadata = service_metadata, .action = list_long_term_pricing };
        }
    },
    Response: type = struct {
        long_term_pricing_entries: ?[]struct {
            long_term_pricing_id: ?[]const u8 = null,
            long_term_pricing_end_date: ?i64 = null,
            long_term_pricing_start_date: ?i64 = null,
            long_term_pricing_type: ?[]const u8 = null,
            current_active_job: ?[]const u8 = null,
            replacement_job: ?[]const u8 = null,
            is_long_term_pricing_auto_renew: ?bool = null,
            long_term_pricing_status: ?[]const u8 = null,
            snowball_type: ?[]const u8 = null,
            job_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .long_term_pricing_id = "LongTermPricingId",
                    .long_term_pricing_end_date = "LongTermPricingEndDate",
                    .long_term_pricing_start_date = "LongTermPricingStartDate",
                    .long_term_pricing_type = "LongTermPricingType",
                    .current_active_job = "CurrentActiveJob",
                    .replacement_job = "ReplacementJob",
                    .is_long_term_pricing_auto_renew = "IsLongTermPricingAutoRenew",
                    .long_term_pricing_status = "LongTermPricingStatus",
                    .snowball_type = "SnowballType",
                    .job_ids = "JobIds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .long_term_pricing_entries = "LongTermPricingEntries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidResource,
    },
} = .{};
pub const list_pickup_locations: struct {
    action_name: []const u8 = "ListPickupLocations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pickup_locations) } {
            return .{ .service_metadata = service_metadata, .action = list_pickup_locations };
        }
    },
    Response: type = struct {
        addresses: ?[]Address = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .addresses = "Addresses",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResource,
    },
} = .{};
pub const list_service_versions: struct {
    action_name: []const u8 = "ListServiceVersions",
    Request: type = struct {
        service_name: []const u8,
        dependent_services: ?[]DependentService = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_name = "ServiceName",
                .dependent_services = "DependentServices",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_service_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_service_versions };
        }
    },
    Response: type = struct {
        service_versions: []ServiceVersion,
        service_name: []const u8,
        dependent_services: ?[]DependentService = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_versions = "ServiceVersions",
                .service_name = "ServiceName",
                .dependent_services = "DependentServices",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
        InvalidResource,
    },
} = .{};
pub const update_cluster: struct {
    action_name: []const u8 = "UpdateCluster",
    Request: type = struct {
        cluster_id: []const u8,
        role_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        resources: ?JobResource = null,
        on_device_service_configuration: ?OnDeviceServiceConfiguration = null,
        address_id: ?[]const u8 = null,
        shipping_option: ?[]const u8 = null,
        notification: ?Notification = null,
        forwarding_address_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_id = "ClusterId",
                .role_arn = "RoleARN",
                .description = "Description",
                .resources = "Resources",
                .on_device_service_configuration = "OnDeviceServiceConfiguration",
                .address_id = "AddressId",
                .shipping_option = "ShippingOption",
                .notification = "Notification",
                .forwarding_address_id = "ForwardingAddressId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cluster) } {
            return .{ .service_metadata = service_metadata, .action = update_cluster };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Ec2RequestFailed,
        InvalidInputCombination,
        InvalidJobState,
        InvalidResource,
        KMSRequestFailed,
    },
} = .{};
pub const update_job: struct {
    action_name: []const u8 = "UpdateJob",
    Request: type = struct {
        job_id: []const u8,
        role_arn: ?[]const u8 = null,
        notification: ?Notification = null,
        resources: ?JobResource = null,
        on_device_service_configuration: ?OnDeviceServiceConfiguration = null,
        address_id: ?[]const u8 = null,
        shipping_option: ?[]const u8 = null,
        description: ?[]const u8 = null,
        snowball_capacity_preference: ?[]const u8 = null,
        forwarding_address_id: ?[]const u8 = null,
        pickup_details: ?PickupDetails = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .role_arn = "RoleARN",
                .notification = "Notification",
                .resources = "Resources",
                .on_device_service_configuration = "OnDeviceServiceConfiguration",
                .address_id = "AddressId",
                .shipping_option = "ShippingOption",
                .description = "Description",
                .snowball_capacity_preference = "SnowballCapacityPreference",
                .forwarding_address_id = "ForwardingAddressId",
                .pickup_details = "PickupDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job) } {
            return .{ .service_metadata = service_metadata, .action = update_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ClusterLimitExceeded,
        Ec2RequestFailed,
        InvalidInputCombination,
        InvalidJobState,
        InvalidResource,
        KMSRequestFailed,
    },
} = .{};
pub const update_job_shipment_state: struct {
    action_name: []const u8 = "UpdateJobShipmentState",
    Request: type = struct {
        job_id: []const u8,
        shipment_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .shipment_state = "ShipmentState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job_shipment_state) } {
            return .{ .service_metadata = service_metadata, .action = update_job_shipment_state };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidJobState,
        InvalidResource,
    },
} = .{};
pub const update_long_term_pricing: struct {
    action_name: []const u8 = "UpdateLongTermPricing",
    Request: type = struct {
        long_term_pricing_id: []const u8,
        replacement_job: ?[]const u8 = null,
        is_long_term_pricing_auto_renew: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .long_term_pricing_id = "LongTermPricingId",
                .replacement_job = "ReplacementJob",
                .is_long_term_pricing_auto_renew = "IsLongTermPricingAutoRenew",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_long_term_pricing) } {
            return .{ .service_metadata = service_metadata, .action = update_long_term_pricing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResource,
    },
} = .{};

pub const PickupDetails = struct {
    name: ?[]const u8 = null,
    phone_number: ?[]const u8 = null,
    email: ?[]const u8 = null,
    identification_number: ?[]const u8 = null,
    identification_expiration_date: ?i64 = null,
    identification_issuing_org: ?[]const u8 = null,
    device_pickup_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .phone_number = "PhoneNumber",
            .email = "Email",
            .identification_number = "IdentificationNumber",
            .identification_expiration_date = "IdentificationExpirationDate",
            .identification_issuing_org = "IdentificationIssuingOrg",
            .device_pickup_id = "DevicePickupId",
        };
        return @field(mappings, field_name);
    }
};

pub const OnDeviceServiceConfiguration = struct {
    nfs_on_device_service: ?NFSOnDeviceServiceConfiguration = null,
    tgw_on_device_service: ?TGWOnDeviceServiceConfiguration = null,
    eks_on_device_service: ?EKSOnDeviceServiceConfiguration = null,
    s3_on_device_service: ?S3OnDeviceServiceConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nfs_on_device_service = "NFSOnDeviceService",
            .tgw_on_device_service = "TGWOnDeviceService",
            .eks_on_device_service = "EKSOnDeviceService",
            .s3_on_device_service = "S3OnDeviceService",
        };
        return @field(mappings, field_name);
    }
};

pub const S3OnDeviceServiceConfiguration = struct {
    storage_limit: ?f64 = null,
    storage_unit: ?[]const u8 = null,
    service_size: ?i64 = null,
    fault_tolerance: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_limit = "StorageLimit",
            .storage_unit = "StorageUnit",
            .service_size = "ServiceSize",
            .fault_tolerance = "FaultTolerance",
        };
        return @field(mappings, field_name);
    }
};

pub const EKSOnDeviceServiceConfiguration = struct {
    kubernetes_version: ?[]const u8 = null,
    eks_anywhere_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kubernetes_version = "KubernetesVersion",
            .eks_anywhere_version = "EKSAnywhereVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const TGWOnDeviceServiceConfiguration = struct {
    storage_limit: ?i64 = null,
    storage_unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_limit = "StorageLimit",
            .storage_unit = "StorageUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const NFSOnDeviceServiceConfiguration = struct {
    storage_limit: ?i64 = null,
    storage_unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_limit = "StorageLimit",
            .storage_unit = "StorageUnit",
        };
        return @field(mappings, field_name);
    }
};

pub const JobResource = struct {
    s3_resources: ?[]S3Resource = null,
    lambda_resources: ?[]LambdaResource = null,
    ec2_ami_resources: ?[]Ec2AmiResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_resources = "S3Resources",
            .lambda_resources = "LambdaResources",
            .ec2_ami_resources = "Ec2AmiResources",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2AmiResource = struct {
    ami_id: []const u8,
    snowball_ami_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ami_id = "AmiId",
            .snowball_ami_id = "SnowballAmiId",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaResource = struct {
    lambda_arn: ?[]const u8 = null,
    event_triggers: ?[]EventTriggerDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_arn = "LambdaArn",
            .event_triggers = "EventTriggers",
        };
        return @field(mappings, field_name);
    }
};

pub const EventTriggerDefinition = struct {
    event_resource_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_resource_arn = "EventResourceARN",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Resource = struct {
    bucket_arn: ?[]const u8 = null,
    key_range: ?KeyRange = null,
    target_on_device_services: ?[]TargetOnDeviceService = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_arn = "BucketArn",
            .key_range = "KeyRange",
            .target_on_device_services = "TargetOnDeviceServices",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetOnDeviceService = struct {
    service_name: ?[]const u8 = null,
    transfer_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_name = "ServiceName",
            .transfer_option = "TransferOption",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyRange = struct {
    begin_marker: ?[]const u8 = null,
    end_marker: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .begin_marker = "BeginMarker",
            .end_marker = "EndMarker",
        };
        return @field(mappings, field_name);
    }
};

pub const Notification = struct {
    sns_topic_arn: ?[]const u8 = null,
    job_states_to_notify: ?[][]const u8 = null,
    notify_all: ?bool = null,
    device_pickup_sns_topic_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_topic_arn = "SnsTopicARN",
            .job_states_to_notify = "JobStatesToNotify",
            .notify_all = "NotifyAll",
            .device_pickup_sns_topic_arn = "DevicePickupSnsTopicARN",
        };
        return @field(mappings, field_name);
    }
};

pub const DependentService = struct {
    service_name: ?[]const u8 = null,
    service_version: ?ServiceVersion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_name = "ServiceName",
            .service_version = "ServiceVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceVersion = struct {
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const Address = struct {
    address_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    company: ?[]const u8 = null,
    street1: ?[]const u8 = null,
    street2: ?[]const u8 = null,
    street3: ?[]const u8 = null,
    city: ?[]const u8 = null,
    state_or_province: ?[]const u8 = null,
    prefecture_or_district: ?[]const u8 = null,
    landmark: ?[]const u8 = null,
    country: ?[]const u8 = null,
    postal_code: ?[]const u8 = null,
    phone_number: ?[]const u8 = null,
    is_restricted: ?bool = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address_id = "AddressId",
            .name = "Name",
            .company = "Company",
            .street1 = "Street1",
            .street2 = "Street2",
            .street3 = "Street3",
            .city = "City",
            .state_or_province = "StateOrProvince",
            .prefecture_or_district = "PrefectureOrDistrict",
            .landmark = "Landmark",
            .country = "Country",
            .postal_code = "PostalCode",
            .phone_number = "PhoneNumber",
            .is_restricted = "IsRestricted",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const JobListEntry = struct {
    job_id: ?[]const u8 = null,
    job_state: ?[]const u8 = null,
    is_master: ?bool = null,
    job_type: ?[]const u8 = null,
    snowball_type: ?[]const u8 = null,
    creation_date: ?i64 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "JobId",
            .job_state = "JobState",
            .is_master = "IsMaster",
            .job_type = "JobType",
            .snowball_type = "SnowballType",
            .creation_date = "CreationDate",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const JobMetadata = struct {
    job_id: ?[]const u8 = null,
    job_state: ?[]const u8 = null,
    job_type: ?[]const u8 = null,
    snowball_type: ?[]const u8 = null,
    creation_date: ?i64 = null,
    resources: ?JobResource = null,
    description: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    address_id: ?[]const u8 = null,
    shipping_details: ?ShippingDetails = null,
    snowball_capacity_preference: ?[]const u8 = null,
    notification: ?Notification = null,
    data_transfer_progress: ?DataTransfer = null,
    job_log_info: ?JobLogs = null,
    cluster_id: ?[]const u8 = null,
    forwarding_address_id: ?[]const u8 = null,
    tax_documents: ?TaxDocuments = null,
    device_configuration: ?DeviceConfiguration = null,
    remote_management: ?[]const u8 = null,
    long_term_pricing_id: ?[]const u8 = null,
    on_device_service_configuration: ?OnDeviceServiceConfiguration = null,
    impact_level: ?[]const u8 = null,
    pickup_details: ?PickupDetails = null,
    snowball_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "JobId",
            .job_state = "JobState",
            .job_type = "JobType",
            .snowball_type = "SnowballType",
            .creation_date = "CreationDate",
            .resources = "Resources",
            .description = "Description",
            .kms_key_arn = "KmsKeyARN",
            .role_arn = "RoleARN",
            .address_id = "AddressId",
            .shipping_details = "ShippingDetails",
            .snowball_capacity_preference = "SnowballCapacityPreference",
            .notification = "Notification",
            .data_transfer_progress = "DataTransferProgress",
            .job_log_info = "JobLogInfo",
            .cluster_id = "ClusterId",
            .forwarding_address_id = "ForwardingAddressId",
            .tax_documents = "TaxDocuments",
            .device_configuration = "DeviceConfiguration",
            .remote_management = "RemoteManagement",
            .long_term_pricing_id = "LongTermPricingId",
            .on_device_service_configuration = "OnDeviceServiceConfiguration",
            .impact_level = "ImpactLevel",
            .pickup_details = "PickupDetails",
            .snowball_id = "SnowballId",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceConfiguration = struct {
    snowcone_device_configuration: ?SnowconeDeviceConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .snowcone_device_configuration = "SnowconeDeviceConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SnowconeDeviceConfiguration = struct {
    wireless_connection: ?WirelessConnection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .wireless_connection = "WirelessConnection",
        };
        return @field(mappings, field_name);
    }
};

pub const WirelessConnection = struct {
    is_wifi_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_wifi_enabled = "IsWifiEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const TaxDocuments = struct {
    ind: ?INDTaxDocuments = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ind = "IND",
        };
        return @field(mappings, field_name);
    }
};

pub const INDTaxDocuments = struct {
    gstin: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gstin = "GSTIN",
        };
        return @field(mappings, field_name);
    }
};

pub const JobLogs = struct {
    job_completion_report_uri: ?[]const u8 = null,
    job_success_log_uri: ?[]const u8 = null,
    job_failure_log_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_completion_report_uri = "JobCompletionReportURI",
            .job_success_log_uri = "JobSuccessLogURI",
            .job_failure_log_uri = "JobFailureLogURI",
        };
        return @field(mappings, field_name);
    }
};

pub const DataTransfer = struct {
    bytes_transferred: ?i64 = null,
    objects_transferred: ?i64 = null,
    total_bytes: ?i64 = null,
    total_objects: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bytes_transferred = "BytesTransferred",
            .objects_transferred = "ObjectsTransferred",
            .total_bytes = "TotalBytes",
            .total_objects = "TotalObjects",
        };
        return @field(mappings, field_name);
    }
};

pub const ShippingDetails = struct {
    shipping_option: ?[]const u8 = null,
    inbound_shipment: ?Shipment = null,
    outbound_shipment: ?Shipment = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .shipping_option = "ShippingOption",
            .inbound_shipment = "InboundShipment",
            .outbound_shipment = "OutboundShipment",
        };
        return @field(mappings, field_name);
    }
};

pub const Shipment = struct {
    status: ?[]const u8 = null,
    tracking_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .tracking_number = "TrackingNumber",
        };
        return @field(mappings, field_name);
    }
};
