const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2010-03-31";
pub const sdk_id: []const u8 = "SNS";
pub const arn_namespace: ?[]const u8 = "sns";
pub const endpoint_prefix: []const u8 = "sns";
pub const sigv4_name: []const u8 = "sns";
pub const name: []const u8 = "AmazonSimpleNotificationService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query;

pub const service_metadata: struct {
    version: []const u8 = "2010-03-31",
    sdk_id: []const u8 = "SNS",
    arn_namespace: ?[]const u8 = "sns",
    endpoint_prefix: []const u8 = "sns",
    sigv4_name: []const u8 = "sns",
    name: []const u8 = "AmazonSimpleNotificationService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query,
} = .{};
pub const add_permission: struct {
    action_name: []const u8 = "AddPermission",
    Request: type = struct {
        topic_arn: []const u8,
        label: []const u8,
        aws_account_id: [][]const u8,
        action_name: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
                .label = "Label",
                .aws_account_id = "AWSAccountId",
                .action_name = "ActionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_permission) } {
            return .{ .service_metadata = service_metadata, .action = add_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        NotFound,
    },
} = .{};
pub const check_if_phone_number_is_opted_out: struct {
    action_name: []const u8 = "CheckIfPhoneNumberIsOptedOut",
    Request: type = struct {
        phone_number: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "phoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(check_if_phone_number_is_opted_out) } {
            return .{ .service_metadata = service_metadata, .action = check_if_phone_number_is_opted_out };
        }
    },
    Response: type = struct {
        is_opted_out: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_opted_out = "isOptedOut",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        Throttled,
    },
} = .{};
pub const confirm_subscription: struct {
    action_name: []const u8 = "ConfirmSubscription",
    Request: type = struct {
        topic_arn: []const u8,
        token: []const u8,
        authenticate_on_unsubscribe: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
                .token = "Token",
                .authenticate_on_unsubscribe = "AuthenticateOnUnsubscribe",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(confirm_subscription) } {
            return .{ .service_metadata = service_metadata, .action = confirm_subscription };
        }
    },
    Response: type = struct {
        subscription_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_arn = "SubscriptionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        FilterPolicyLimitExceeded,
        InternalError,
        InvalidParameter,
        NotFound,
        ReplayLimitExceeded,
        SubscriptionLimitExceeded,
    },
} = .{};
pub const create_platform_application: struct {
    action_name: []const u8 = "CreatePlatformApplication",
    Request: type = struct {
        name: []const u8,
        platform: []const u8,
        attributes: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .platform = "Platform",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_platform_application) } {
            return .{ .service_metadata = service_metadata, .action = create_platform_application };
        }
    },
    Response: type = struct {
        platform_application_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_application_arn = "PlatformApplicationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
    },
} = .{};
pub const create_platform_endpoint: struct {
    action_name: []const u8 = "CreatePlatformEndpoint",
    Request: type = struct {
        platform_application_arn: []const u8,
        token: []const u8,
        custom_user_data: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_application_arn = "PlatformApplicationArn",
                .token = "Token",
                .custom_user_data = "CustomUserData",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_platform_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_platform_endpoint };
        }
    },
    Response: type = struct {
        endpoint_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        NotFound,
    },
} = .{};
pub const create_sms_sandbox_phone_number: struct {
    action_name: []const u8 = "CreateSMSSandboxPhoneNumber",
    Request: type = struct {
        phone_number: []const u8,
        language_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "PhoneNumber",
                .language_code = "LanguageCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sms_sandbox_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = create_sms_sandbox_phone_number };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        OptedOut,
        Throttled,
        UserError,
    },
} = .{};
pub const create_topic: struct {
    action_name: []const u8 = "CreateTopic",
    Request: type = struct {
        name: []const u8,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]Tag = null,
        data_protection_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .attributes = "Attributes",
                .tags = "Tags",
                .data_protection_policy = "DataProtectionPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_topic) } {
            return .{ .service_metadata = service_metadata, .action = create_topic };
        }
    },
    Response: type = struct {
        topic_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        ConcurrentAccess,
        InternalError,
        InvalidParameter,
        InvalidSecurity,
        StaleTag,
        TagLimitExceeded,
        TagPolicy,
        TopicLimitExceeded,
    },
} = .{};
pub const delete_endpoint: struct {
    action_name: []const u8 = "DeleteEndpoint",
    Request: type = struct {
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_endpoint };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
    },
} = .{};
pub const delete_platform_application: struct {
    action_name: []const u8 = "DeletePlatformApplication",
    Request: type = struct {
        platform_application_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_application_arn = "PlatformApplicationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_platform_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_platform_application };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
    },
} = .{};
pub const delete_sms_sandbox_phone_number: struct {
    action_name: []const u8 = "DeleteSMSSandboxPhoneNumber",
    Request: type = struct {
        phone_number: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "PhoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sms_sandbox_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = delete_sms_sandbox_phone_number };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        ResourceNotFound,
        Throttled,
        UserError,
    },
} = .{};
pub const delete_topic: struct {
    action_name: []const u8 = "DeleteTopic",
    Request: type = struct {
        topic_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_topic) } {
            return .{ .service_metadata = service_metadata, .action = delete_topic };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        ConcurrentAccess,
        InternalError,
        InvalidParameter,
        InvalidState,
        NotFound,
        StaleTag,
        TagPolicy,
    },
} = .{};
pub const get_data_protection_policy: struct {
    action_name: []const u8 = "GetDataProtectionPolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_protection_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_data_protection_policy };
        }
    },
    Response: type = struct {
        data_protection_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_protection_policy = "DataProtectionPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        InvalidSecurity,
        NotFound,
    },
} = .{};
pub const get_endpoint_attributes: struct {
    action_name: []const u8 = "GetEndpointAttributes",
    Request: type = struct {
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_endpoint_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_endpoint_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        NotFound,
    },
} = .{};
pub const get_platform_application_attributes: struct {
    action_name: []const u8 = "GetPlatformApplicationAttributes",
    Request: type = struct {
        platform_application_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_application_arn = "PlatformApplicationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_platform_application_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_platform_application_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        NotFound,
    },
} = .{};
pub const get_sms_attributes: struct {
    action_name: []const u8 = "GetSMSAttributes",
    Request: type = struct {
        attributes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sms_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_sms_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        Throttled,
    },
} = .{};
pub const get_sms_sandbox_account_status: struct {
    action_name: []const u8 = "GetSMSSandboxAccountStatus",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sms_sandbox_account_status) } {
            return .{ .service_metadata = service_metadata, .action = get_sms_sandbox_account_status };
        }
    },
    Response: type = struct {
        is_in_sandbox: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_in_sandbox = "IsInSandbox",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        Throttled,
    },
} = .{};
pub const get_subscription_attributes: struct {
    action_name: []const u8 = "GetSubscriptionAttributes",
    Request: type = struct {
        subscription_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_arn = "SubscriptionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_subscription_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_subscription_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        NotFound,
    },
} = .{};
pub const get_topic_attributes: struct {
    action_name: []const u8 = "GetTopicAttributes",
    Request: type = struct {
        topic_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_topic_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_topic_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        InvalidSecurity,
        NotFound,
    },
} = .{};
pub const list_endpoints_by_platform_application: struct {
    action_name: []const u8 = "ListEndpointsByPlatformApplication",
    Request: type = struct {
        platform_application_arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_application_arn = "PlatformApplicationArn",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_endpoints_by_platform_application) } {
            return .{ .service_metadata = service_metadata, .action = list_endpoints_by_platform_application };
        }
    },
    Response: type = struct {
        endpoints: ?[]struct {
            endpoint_arn: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .endpoint_arn = "EndpointArn",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "Endpoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        NotFound,
    },
} = .{};
pub const list_origination_numbers: struct {
    action_name: []const u8 = "ListOriginationNumbers",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_origination_numbers) } {
            return .{ .service_metadata = service_metadata, .action = list_origination_numbers };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        phone_numbers: ?[]struct {
            created_at: ?i64 = null,
            phone_number: ?[]const u8 = null,
            status: ?[]const u8 = null,
            iso2_country_code: ?[]const u8 = null,
            route_type: ?[]const u8 = null,
            number_capabilities: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_at = "CreatedAt",
                    .phone_number = "PhoneNumber",
                    .status = "Status",
                    .iso2_country_code = "Iso2CountryCode",
                    .route_type = "RouteType",
                    .number_capabilities = "NumberCapabilities",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .phone_numbers = "PhoneNumbers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        Throttled,
        Validation,
    },
} = .{};
pub const list_phone_numbers_opted_out: struct {
    action_name: []const u8 = "ListPhoneNumbersOptedOut",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_phone_numbers_opted_out) } {
            return .{ .service_metadata = service_metadata, .action = list_phone_numbers_opted_out };
        }
    },
    Response: type = struct {
        phone_numbers: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_numbers = "phoneNumbers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        Throttled,
    },
} = .{};
pub const list_platform_applications: struct {
    action_name: []const u8 = "ListPlatformApplications",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_platform_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_platform_applications };
        }
    },
    Response: type = struct {
        platform_applications: ?[]struct {
            platform_application_arn: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .platform_application_arn = "PlatformApplicationArn",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_applications = "PlatformApplications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
    },
} = .{};
pub const list_sms_sandbox_phone_numbers: struct {
    action_name: []const u8 = "ListSMSSandboxPhoneNumbers",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sms_sandbox_phone_numbers) } {
            return .{ .service_metadata = service_metadata, .action = list_sms_sandbox_phone_numbers };
        }
    },
    Response: type = struct {
        phone_numbers: []struct {
            phone_number: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .phone_number = "PhoneNumber",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_numbers = "PhoneNumbers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        ResourceNotFound,
        Throttled,
    },
} = .{};
pub const list_subscriptions: struct {
    action_name: []const u8 = "ListSubscriptions",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = list_subscriptions };
        }
    },
    Response: type = struct {
        subscriptions: ?[]Subscription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscriptions = "Subscriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
    },
} = .{};
pub const list_subscriptions_by_topic: struct {
    action_name: []const u8 = "ListSubscriptionsByTopic",
    Request: type = struct {
        topic_arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_subscriptions_by_topic) } {
            return .{ .service_metadata = service_metadata, .action = list_subscriptions_by_topic };
        }
    },
    Response: type = struct {
        subscriptions: ?[]Subscription = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscriptions = "Subscriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        NotFound,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        ConcurrentAccess,
        InvalidParameter,
        ResourceNotFound,
        TagPolicy,
    },
} = .{};
pub const list_topics: struct {
    action_name: []const u8 = "ListTopics",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_topics) } {
            return .{ .service_metadata = service_metadata, .action = list_topics };
        }
    },
    Response: type = struct {
        topics: ?[]struct {
            topic_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .topic_arn = "TopicArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topics = "Topics",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
    },
} = .{};
pub const opt_in_phone_number: struct {
    action_name: []const u8 = "OptInPhoneNumber",
    Request: type = struct {
        phone_number: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "phoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(opt_in_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = opt_in_phone_number };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        Throttled,
    },
} = .{};
pub const publish: struct {
    action_name: []const u8 = "Publish",
    Request: type = struct {
        topic_arn: ?[]const u8 = null,
        target_arn: ?[]const u8 = null,
        phone_number: ?[]const u8 = null,
        message: []const u8,
        subject: ?[]const u8 = null,
        message_structure: ?[]const u8 = null,
        message_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MessageAttributeValue = null,
        } = null,
        message_deduplication_id: ?[]const u8 = null,
        message_group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
                .target_arn = "TargetArn",
                .phone_number = "PhoneNumber",
                .message = "Message",
                .subject = "Subject",
                .message_structure = "MessageStructure",
                .message_attributes = "MessageAttributes",
                .message_deduplication_id = "MessageDeduplicationId",
                .message_group_id = "MessageGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "message_attributes", field_name))
                return try serializeMap(self.message_attributes, self.fieldNameFor("message_attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish) } {
            return .{ .service_metadata = service_metadata, .action = publish };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,
        sequence_number: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
                .sequence_number = "SequenceNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        EndpointDisabled,
        InternalError,
        InvalidParameter,
        InvalidParameterValue,
        InvalidSecurity,
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        KMSOptInRequired,
        KMSThrottling,
        NotFound,
        PlatformApplicationDisabled,
        Validation,
    },
} = .{};
pub const publish_batch: struct {
    action_name: []const u8 = "PublishBatch",
    Request: type = struct {
        topic_arn: []const u8,
        publish_batch_request_entries: []struct {
            id: []const u8,
            message: []const u8,
            subject: ?[]const u8 = null,
            message_structure: ?[]const u8 = null,
            message_attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MessageAttributeValue = null,
            } = null,
            message_deduplication_id: ?[]const u8 = null,
            message_group_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .message = "Message",
                    .subject = "Subject",
                    .message_structure = "MessageStructure",
                    .message_attributes = "MessageAttributes",
                    .message_deduplication_id = "MessageDeduplicationId",
                    .message_group_id = "MessageGroupId",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "message_attributes", field_name))
                    return try serializeMap(self.message_attributes, self.fieldNameFor("message_attributes"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
                .publish_batch_request_entries = "PublishBatchRequestEntries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(publish_batch) } {
            return .{ .service_metadata = service_metadata, .action = publish_batch };
        }
    },
    Response: type = struct {
        successful: ?[]struct {
            id: ?[]const u8 = null,
            message_id: ?[]const u8 = null,
            sequence_number: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .message_id = "MessageId",
                    .sequence_number = "SequenceNumber",
                };
                return @field(mappings, field_name);
            }
        } = null,
        failed: ?[]struct {
            id: []const u8,
            code: []const u8,
            message: ?[]const u8 = null,
            sender_fault: bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .code = "Code",
                    .message = "Message",
                    .sender_fault = "SenderFault",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "Successful",
                .failed = "Failed",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        BatchEntryIdsNotDistinct,
        BatchRequestTooLong,
        EmptyBatchRequest,
        EndpointDisabled,
        InternalError,
        InvalidBatchEntryId,
        InvalidParameter,
        InvalidParameterValue,
        InvalidSecurity,
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        KMSOptInRequired,
        KMSThrottling,
        NotFound,
        PlatformApplicationDisabled,
        TooManyEntriesInBatchRequest,
        Validation,
    },
} = .{};
pub const put_data_protection_policy: struct {
    action_name: []const u8 = "PutDataProtectionPolicy",
    Request: type = struct {
        resource_arn: []const u8,
        data_protection_policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .data_protection_policy = "DataProtectionPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_data_protection_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_data_protection_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        InvalidSecurity,
        NotFound,
    },
} = .{};
pub const remove_permission: struct {
    action_name: []const u8 = "RemovePermission",
    Request: type = struct {
        topic_arn: []const u8,
        label: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
                .label = "Label",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_permission) } {
            return .{ .service_metadata = service_metadata, .action = remove_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        NotFound,
    },
} = .{};
pub const set_endpoint_attributes: struct {
    action_name: []const u8 = "SetEndpointAttributes",
    Request: type = struct {
        endpoint_arn: []const u8,
        attributes: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_endpoint_attributes) } {
            return .{ .service_metadata = service_metadata, .action = set_endpoint_attributes };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        NotFound,
    },
} = .{};
pub const set_platform_application_attributes: struct {
    action_name: []const u8 = "SetPlatformApplicationAttributes",
    Request: type = struct {
        platform_application_arn: []const u8,
        attributes: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform_application_arn = "PlatformApplicationArn",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_platform_application_attributes) } {
            return .{ .service_metadata = service_metadata, .action = set_platform_application_attributes };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        NotFound,
    },
} = .{};
pub const set_sms_attributes: struct {
    action_name: []const u8 = "SetSMSAttributes",
    Request: type = struct {
        attributes: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_sms_attributes) } {
            return .{ .service_metadata = service_metadata, .action = set_sms_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        Throttled,
    },
} = .{};
pub const set_subscription_attributes: struct {
    action_name: []const u8 = "SetSubscriptionAttributes",
    Request: type = struct {
        subscription_arn: []const u8,
        attribute_name: []const u8,
        attribute_value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_arn = "SubscriptionArn",
                .attribute_name = "AttributeName",
                .attribute_value = "AttributeValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_subscription_attributes) } {
            return .{ .service_metadata = service_metadata, .action = set_subscription_attributes };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        FilterPolicyLimitExceeded,
        InternalError,
        InvalidParameter,
        NotFound,
        ReplayLimitExceeded,
    },
} = .{};
pub const set_topic_attributes: struct {
    action_name: []const u8 = "SetTopicAttributes",
    Request: type = struct {
        topic_arn: []const u8,
        attribute_name: []const u8,
        attribute_value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
                .attribute_name = "AttributeName",
                .attribute_value = "AttributeValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_topic_attributes) } {
            return .{ .service_metadata = service_metadata, .action = set_topic_attributes };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        InvalidSecurity,
        NotFound,
    },
} = .{};
pub const subscribe: struct {
    action_name: []const u8 = "Subscribe",
    Request: type = struct {
        topic_arn: []const u8,
        protocol: []const u8,
        endpoint: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        return_subscription_arn: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .topic_arn = "TopicArn",
                .protocol = "Protocol",
                .endpoint = "Endpoint",
                .attributes = "Attributes",
                .return_subscription_arn = "ReturnSubscriptionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(subscribe) } {
            return .{ .service_metadata = service_metadata, .action = subscribe };
        }
    },
    Response: type = struct {
        subscription_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_arn = "SubscriptionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        FilterPolicyLimitExceeded,
        InternalError,
        InvalidParameter,
        InvalidSecurity,
        NotFound,
        ReplayLimitExceeded,
        SubscriptionLimitExceeded,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        ConcurrentAccess,
        InvalidParameter,
        ResourceNotFound,
        StaleTag,
        TagLimitExceeded,
        TagPolicy,
    },
} = .{};
pub const unsubscribe: struct {
    action_name: []const u8 = "Unsubscribe",
    Request: type = struct {
        subscription_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_arn = "SubscriptionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(unsubscribe) } {
            return .{ .service_metadata = service_metadata, .action = unsubscribe };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        InvalidSecurity,
        NotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        ConcurrentAccess,
        InvalidParameter,
        ResourceNotFound,
        StaleTag,
        TagLimitExceeded,
        TagPolicy,
    },
} = .{};
pub const verify_sms_sandbox_phone_number: struct {
    action_name: []const u8 = "VerifySMSSandboxPhoneNumber",
    Request: type = struct {
        phone_number: []const u8,
        one_time_password: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "PhoneNumber",
                .one_time_password = "OneTimePassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(verify_sms_sandbox_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = verify_sms_sandbox_phone_number };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AuthorizationError,
        InternalError,
        InvalidParameter,
        ResourceNotFound,
        Throttled,
        Verification,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageAttributeValue = struct {
    data_type: []const u8,
    string_value: ?[]const u8 = null,
    binary_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_type = "DataType",
            .string_value = "StringValue",
            .binary_value = "BinaryValue",
        };
        return @field(mappings, field_name);
    }
};

pub const Subscription = struct {
    subscription_arn: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    protocol: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,
    topic_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subscription_arn = "SubscriptionArn",
            .owner = "Owner",
            .protocol = "Protocol",
            .endpoint = "Endpoint",
            .topic_arn = "TopicArn",
        };
        return @field(mappings, field_name);
    }
};
