const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2012-11-05";
pub const sdk_id: []const u8 = "SQS";
pub const arn_namespace: ?[]const u8 = "sqs";
pub const endpoint_prefix: []const u8 = "sqs";
pub const sigv4_name: []const u8 = "sqs";
pub const name: []const u8 = "AmazonSQS";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2012-11-05",
    sdk_id: []const u8 = "SQS",
    arn_namespace: ?[]const u8 = "sqs",
    endpoint_prefix: []const u8 = "sqs",
    sigv4_name: []const u8 = "sqs",
    name: []const u8 = "AmazonSQS",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const add_permission: struct {
    action_name: []const u8 = "AddPermission",
    Request: type = struct {
        queue_url: []const u8,
        label: []const u8,
        aws_account_ids: [][]const u8,
        actions: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .label = "Label",
                .aws_account_ids = "AWSAccountId",
                .actions = "ActionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_permission) } {
            return .{ .service_metadata = service_metadata, .action = add_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        OverLimit,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const cancel_message_move_task: struct {
    action_name: []const u8 = "CancelMessageMoveTask",
    Request: type = struct {
        task_handle: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_handle = "TaskHandle",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_message_move_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_message_move_task };
        }
    },
    Response: type = struct {
        approximate_number_of_messages_moved: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .approximate_number_of_messages_moved = "ApproximateNumberOfMessagesMoved",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        RequestThrottled,
        ResourceNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const change_message_visibility: struct {
    action_name: []const u8 = "ChangeMessageVisibility",
    Request: type = struct {
        queue_url: []const u8,
        receipt_handle: []const u8,
        visibility_timeout: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .receipt_handle = "ReceiptHandle",
                .visibility_timeout = "VisibilityTimeout",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(change_message_visibility) } {
            return .{ .service_metadata = service_metadata, .action = change_message_visibility };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        MessageNotInflight,
        QueueDoesNotExist,
        ReceiptHandleIsInvalid,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const change_message_visibility_batch: struct {
    action_name: []const u8 = "ChangeMessageVisibilityBatch",
    Request: type = struct {
        queue_url: []const u8,
        entries: []struct {
            id: []const u8,
            receipt_handle: []const u8,
            visibility_timeout: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .receipt_handle = "ReceiptHandle",
                    .visibility_timeout = "VisibilityTimeout",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .entries = "ChangeMessageVisibilityBatchRequestEntry",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(change_message_visibility_batch) } {
            return .{ .service_metadata = service_metadata, .action = change_message_visibility_batch };
        }
    },
    Response: type = struct {
        successful: []struct {
            id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        },
        failed: []BatchResultErrorEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "ChangeMessageVisibilityBatchResultEntry",
                .failed = "BatchResultErrorEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BatchEntryIdsNotDistinct,
        EmptyBatchRequest,
        InvalidAddress,
        InvalidBatchEntryId,
        InvalidSecurity,
        QueueDoesNotExist,
        RequestThrottled,
        TooManyEntriesInBatchRequest,
        UnsupportedOperation,
    },
} = .{};
pub const create_queue: struct {
    action_name: []const u8 = "CreateQueue",
    Request: type = struct {
        queue_name: []const u8,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_name = "QueueName",
                .attributes = "Attribute",
                .tags = "Tag",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_queue) } {
            return .{ .service_metadata = service_metadata, .action = create_queue };
        }
    },
    Response: type = struct {
        queue_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidAttributeName,
        InvalidAttributeValue,
        InvalidSecurity,
        QueueDeletedRecently,
        QueueNameExists,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const delete_message: struct {
    action_name: []const u8 = "DeleteMessage",
    Request: type = struct {
        queue_url: []const u8,
        receipt_handle: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .receipt_handle = "ReceiptHandle",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_message) } {
            return .{ .service_metadata = service_metadata, .action = delete_message };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidAddress,
        InvalidIdFormat,
        InvalidSecurity,
        QueueDoesNotExist,
        ReceiptHandleIsInvalid,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const delete_message_batch: struct {
    action_name: []const u8 = "DeleteMessageBatch",
    Request: type = struct {
        queue_url: []const u8,
        entries: []struct {
            id: []const u8,
            receipt_handle: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .receipt_handle = "ReceiptHandle",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .entries = "DeleteMessageBatchRequestEntry",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_message_batch) } {
            return .{ .service_metadata = service_metadata, .action = delete_message_batch };
        }
    },
    Response: type = struct {
        successful: []struct {
            id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        },
        failed: []BatchResultErrorEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "DeleteMessageBatchResultEntry",
                .failed = "BatchResultErrorEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BatchEntryIdsNotDistinct,
        EmptyBatchRequest,
        InvalidAddress,
        InvalidBatchEntryId,
        InvalidSecurity,
        QueueDoesNotExist,
        RequestThrottled,
        TooManyEntriesInBatchRequest,
        UnsupportedOperation,
    },
} = .{};
pub const delete_queue: struct {
    action_name: []const u8 = "DeleteQueue",
    Request: type = struct {
        queue_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_queue) } {
            return .{ .service_metadata = service_metadata, .action = delete_queue };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const get_queue_attributes: struct {
    action_name: []const u8 = "GetQueueAttributes",
    Request: type = struct {
        queue_url: []const u8,
        attribute_names: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .attribute_names = "AttributeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_queue_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_queue_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attribute",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidAttributeName,
        InvalidSecurity,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const get_queue_url: struct {
    action_name: []const u8 = "GetQueueUrl",
    Request: type = struct {
        queue_name: []const u8,
        queue_owner_aws_account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_name = "QueueName",
                .queue_owner_aws_account_id = "QueueOwnerAWSAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_queue_url) } {
            return .{ .service_metadata = service_metadata, .action = get_queue_url };
        }
    },
    Response: type = struct {
        queue_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const list_dead_letter_source_queues: struct {
    action_name: []const u8 = "ListDeadLetterSourceQueues",
    Request: type = struct {
        queue_url: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dead_letter_source_queues) } {
            return .{ .service_metadata = service_metadata, .action = list_dead_letter_source_queues };
        }
    },
    Response: type = struct {
        queue_urls: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_urls = "QueueUrl",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const list_message_move_tasks: struct {
    action_name: []const u8 = "ListMessageMoveTasks",
    Request: type = struct {
        source_arn: []const u8,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_arn = "SourceArn",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_message_move_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_message_move_tasks };
        }
    },
    Response: type = struct {
        results: ?[]struct {
            task_handle: ?[]const u8 = null,
            status: ?[]const u8 = null,
            source_arn: ?[]const u8 = null,
            destination_arn: ?[]const u8 = null,
            max_number_of_messages_per_second: ?i64 = null,
            approximate_number_of_messages_moved: ?i64 = null,
            approximate_number_of_messages_to_move: ?i64 = null,
            failure_reason: ?[]const u8 = null,
            started_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_handle = "TaskHandle",
                    .status = "Status",
                    .source_arn = "SourceArn",
                    .destination_arn = "DestinationArn",
                    .max_number_of_messages_per_second = "MaxNumberOfMessagesPerSecond",
                    .approximate_number_of_messages_moved = "ApproximateNumberOfMessagesMoved",
                    .approximate_number_of_messages_to_move = "ApproximateNumberOfMessagesToMove",
                    .failure_reason = "FailureReason",
                    .started_timestamp = "StartedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "ListMessageMoveTasksResultEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        RequestThrottled,
        ResourceNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const list_queues: struct {
    action_name: []const u8 = "ListQueues",
    Request: type = struct {
        queue_name_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_name_prefix = "QueueNamePrefix",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_queues) } {
            return .{ .service_metadata = service_metadata, .action = list_queues };
        }
    },
    Response: type = struct {
        queue_urls: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_urls = "QueueUrl",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const list_queue_tags: struct {
    action_name: []const u8 = "ListQueueTags",
    Request: type = struct {
        queue_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_queue_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_queue_tags };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tag",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const purge_queue: struct {
    action_name: []const u8 = "PurgeQueue",
    Request: type = struct {
        queue_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(purge_queue) } {
            return .{ .service_metadata = service_metadata, .action = purge_queue };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        PurgeQueueInProgress,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const receive_message: struct {
    action_name: []const u8 = "ReceiveMessage",
    Request: type = struct {
        queue_url: []const u8,
        attribute_names: ?[][]const u8 = null,
        message_attribute_names: ?[][]const u8 = null,
        max_number_of_messages: ?i64 = null,
        visibility_timeout: ?i64 = null,
        wait_time_seconds: ?i64 = null,
        receive_request_attempt_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .attribute_names = "AttributeName",
                .message_attribute_names = "MessageAttributeName",
                .max_number_of_messages = "MaxNumberOfMessages",
                .visibility_timeout = "VisibilityTimeout",
                .wait_time_seconds = "WaitTimeSeconds",
                .receive_request_attempt_id = "ReceiveRequestAttemptId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(receive_message) } {
            return .{ .service_metadata = service_metadata, .action = receive_message };
        }
    },
    Response: type = struct {
        messages: ?[]struct {
            message_id: ?[]const u8 = null,
            receipt_handle: ?[]const u8 = null,
            md5_of_body: ?[]const u8 = null,
            body: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            md5_of_message_attributes: ?[]const u8 = null,
            message_attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MessageAttributeValue = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "MessageId",
                    .receipt_handle = "ReceiptHandle",
                    .md5_of_body = "MD5OfBody",
                    .body = "Body",
                    .attributes = "Attribute",
                    .md5_of_message_attributes = "MD5OfMessageAttributes",
                    .message_attributes = "MessageAttribute",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                if (std.mem.eql(u8, "message_attributes", field_name))
                    return try serializeMap(self.message_attributes, self.fieldNameFor("message_attributes"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .messages = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        KmsAccessDenied,
        KmsDisabled,
        KmsInvalidKeyUsage,
        KmsInvalidState,
        KmsNotFound,
        KmsOptInRequired,
        KmsThrottled,
        OverLimit,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const remove_permission: struct {
    action_name: []const u8 = "RemovePermission",
    Request: type = struct {
        queue_url: []const u8,
        label: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .label = "Label",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_permission) } {
            return .{ .service_metadata = service_metadata, .action = remove_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const send_message: struct {
    action_name: []const u8 = "SendMessage",
    Request: type = struct {
        queue_url: []const u8,
        message_body: []const u8,
        delay_seconds: ?i64 = null,
        message_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MessageAttributeValue = null,
        } = null,
        message_system_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MessageSystemAttributeValue = null,
        } = null,
        message_deduplication_id: ?[]const u8 = null,
        message_group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .message_body = "MessageBody",
                .delay_seconds = "DelaySeconds",
                .message_attributes = "MessageAttribute",
                .message_system_attributes = "MessageSystemAttribute",
                .message_deduplication_id = "MessageDeduplicationId",
                .message_group_id = "MessageGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "message_attributes", field_name))
                return try serializeMap(self.message_attributes, self.fieldNameFor("message_attributes"), options, out_stream);
            if (std.mem.eql(u8, "message_system_attributes", field_name))
                return try serializeMap(self.message_system_attributes, self.fieldNameFor("message_system_attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_message) } {
            return .{ .service_metadata = service_metadata, .action = send_message };
        }
    },
    Response: type = struct {
        md5_of_message_body: ?[]const u8 = null,
        md5_of_message_attributes: ?[]const u8 = null,
        md5_of_message_system_attributes: ?[]const u8 = null,
        message_id: ?[]const u8 = null,
        sequence_number: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .md5_of_message_body = "MD5OfMessageBody",
                .md5_of_message_attributes = "MD5OfMessageAttributes",
                .md5_of_message_system_attributes = "MD5OfMessageSystemAttributes",
                .message_id = "MessageId",
                .sequence_number = "SequenceNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidMessageContents,
        InvalidSecurity,
        KmsAccessDenied,
        KmsDisabled,
        KmsInvalidKeyUsage,
        KmsInvalidState,
        KmsNotFound,
        KmsOptInRequired,
        KmsThrottled,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const send_message_batch: struct {
    action_name: []const u8 = "SendMessageBatch",
    Request: type = struct {
        queue_url: []const u8,
        entries: []struct {
            id: []const u8,
            message_body: []const u8,
            delay_seconds: ?i64 = null,
            message_attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MessageAttributeValue = null,
            } = null,
            message_system_attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MessageSystemAttributeValue = null,
            } = null,
            message_deduplication_id: ?[]const u8 = null,
            message_group_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .message_body = "MessageBody",
                    .delay_seconds = "DelaySeconds",
                    .message_attributes = "MessageAttribute",
                    .message_system_attributes = "MessageSystemAttribute",
                    .message_deduplication_id = "MessageDeduplicationId",
                    .message_group_id = "MessageGroupId",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "message_attributes", field_name))
                    return try serializeMap(self.message_attributes, self.fieldNameFor("message_attributes"), options, out_stream);
                if (std.mem.eql(u8, "message_system_attributes", field_name))
                    return try serializeMap(self.message_system_attributes, self.fieldNameFor("message_system_attributes"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .entries = "SendMessageBatchRequestEntry",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_message_batch) } {
            return .{ .service_metadata = service_metadata, .action = send_message_batch };
        }
    },
    Response: type = struct {
        successful: []struct {
            id: []const u8,
            message_id: []const u8,
            md5_of_message_body: []const u8,
            md5_of_message_attributes: ?[]const u8 = null,
            md5_of_message_system_attributes: ?[]const u8 = null,
            sequence_number: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .message_id = "MessageId",
                    .md5_of_message_body = "MD5OfMessageBody",
                    .md5_of_message_attributes = "MD5OfMessageAttributes",
                    .md5_of_message_system_attributes = "MD5OfMessageSystemAttributes",
                    .sequence_number = "SequenceNumber",
                };
                return @field(mappings, field_name);
            }
        },
        failed: []BatchResultErrorEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "SendMessageBatchResultEntry",
                .failed = "BatchResultErrorEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BatchEntryIdsNotDistinct,
        BatchRequestTooLong,
        EmptyBatchRequest,
        InvalidAddress,
        InvalidBatchEntryId,
        InvalidSecurity,
        KmsAccessDenied,
        KmsDisabled,
        KmsInvalidKeyUsage,
        KmsInvalidState,
        KmsNotFound,
        KmsOptInRequired,
        KmsThrottled,
        QueueDoesNotExist,
        RequestThrottled,
        TooManyEntriesInBatchRequest,
        UnsupportedOperation,
    },
} = .{};
pub const set_queue_attributes: struct {
    action_name: []const u8 = "SetQueueAttributes",
    Request: type = struct {
        queue_url: []const u8,
        attributes: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .attributes = "Attribute",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_queue_attributes) } {
            return .{ .service_metadata = service_metadata, .action = set_queue_attributes };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidAddress,
        InvalidAttributeName,
        InvalidAttributeValue,
        InvalidSecurity,
        OverLimit,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const start_message_move_task: struct {
    action_name: []const u8 = "StartMessageMoveTask",
    Request: type = struct {
        source_arn: []const u8,
        destination_arn: ?[]const u8 = null,
        max_number_of_messages_per_second: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_arn = "SourceArn",
                .destination_arn = "DestinationArn",
                .max_number_of_messages_per_second = "MaxNumberOfMessagesPerSecond",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_message_move_task) } {
            return .{ .service_metadata = service_metadata, .action = start_message_move_task };
        }
    },
    Response: type = struct {
        task_handle: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_handle = "TaskHandle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        RequestThrottled,
        ResourceNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const tag_queue: struct {
    action_name: []const u8 = "TagQueue",
    Request: type = struct {
        queue_url: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .tags = "Tag",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_queue) } {
            return .{ .service_metadata = service_metadata, .action = tag_queue };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};
pub const untag_queue: struct {
    action_name: []const u8 = "UntagQueue",
    Request: type = struct {
        queue_url: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_url = "QueueUrl",
                .tag_keys = "TagKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_queue) } {
            return .{ .service_metadata = service_metadata, .action = untag_queue };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidAddress,
        InvalidSecurity,
        QueueDoesNotExist,
        RequestThrottled,
        UnsupportedOperation,
    },
} = .{};

pub const BatchResultErrorEntry = struct {
    id: []const u8,
    sender_fault: bool,
    code: []const u8,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .sender_fault = "SenderFault",
            .code = "Code",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageSystemAttributeValue = struct {
    string_value: ?[]const u8 = null,
    binary_value: ?[]const u8 = null,
    string_list_values: ?[][]const u8 = null,
    binary_list_values: ?[][]const u8 = null,
    data_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "StringValue",
            .binary_value = "BinaryValue",
            .string_list_values = "StringListValue",
            .binary_list_values = "BinaryListValue",
            .data_type = "DataType",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageAttributeValue = struct {
    string_value: ?[]const u8 = null,
    binary_value: ?[]const u8 = null,
    string_list_values: ?[][]const u8 = null,
    binary_list_values: ?[][]const u8 = null,
    data_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "StringValue",
            .binary_value = "BinaryValue",
            .string_list_values = "StringListValue",
            .binary_list_values = "BinaryListValue",
            .data_type = "DataType",
        };
        return @field(mappings, field_name);
    }
};
