const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-10";
pub const sdk_id: []const u8 = "SSM Incidents";
pub const arn_namespace: ?[]const u8 = "ssm-incidents";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "ssm-incidents";
pub const name: []const u8 = "SSMIncidents";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-10",
    sdk_id: []const u8 = "SSM Incidents",
    arn_namespace: ?[]const u8 = "ssm-incidents",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "ssm-incidents",
    name: []const u8 = "SSMIncidents",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_get_incident_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/batchGetIncidentFindings",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetIncidentFindings",
    Request: type = struct {
        incident_record_arn: []const u8,
        finding_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incident_record_arn = "incidentRecordArn",
                .finding_ids = "findingIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_incident_findings) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_incident_findings };
        }
    },
    Response: type = struct {
        findings: []struct {
            id: []const u8,
            creation_time: i64,
            last_modified_time: i64,
            details: ?union {
                code_deploy_deployment: ?struct {
                    start_time: i64,
                    end_time: ?i64 = null,
                    deployment_group_arn: []const u8,
                    deployment_id: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .start_time = "startTime",
                            .end_time = "endTime",
                            .deployment_group_arn = "deploymentGroupArn",
                            .deployment_id = "deploymentId",
                        };
                        return @field(mappings, field_name);
                    }
                },
                cloud_formation_stack_update: ?struct {
                    start_time: i64,
                    end_time: ?i64 = null,
                    stack_arn: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .start_time = "startTime",
                            .end_time = "endTime",
                            .stack_arn = "stackArn",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code_deploy_deployment = "codeDeployDeployment",
                        .cloud_formation_stack_update = "cloudFormationStackUpdate",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .creation_time = "creationTime",
                    .last_modified_time = "lastModifiedTime",
                    .details = "details",
                };
                return @field(mappings, field_name);
            }
        },
        errors: []struct {
            finding_id: []const u8,
            code: []const u8,
            message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .finding_id = "findingId",
                    .code = "code",
                    .message = "message",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_replication_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createReplicationSet",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateReplicationSet",
    Request: type = struct {
        regions: []struct {
            key: ?[]const u8 = null,
            value: ?struct {
                sse_kms_key_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .sse_kms_key_id = "sseKmsKeyId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        },
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regions = "regions",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "regions", field_name))
                return try serializeMap(self.regions, self.fieldNameFor("regions"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_set) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_set };
        }
    },
    Response: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_response_plan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createResponsePlan",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateResponsePlan",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        name: []const u8,
        display_name: ?[]const u8 = null,
        incident_template: IncidentTemplate,
        chat_channel: ?ChatChannel = null,
        engagements: ?[][]const u8 = null,
        actions: ?[]Action = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        integrations: ?[]Integration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .name = "name",
                .display_name = "displayName",
                .incident_template = "incidentTemplate",
                .chat_channel = "chatChannel",
                .engagements = "engagements",
                .actions = "actions",
                .tags = "tags",
                .integrations = "integrations",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_response_plan) } {
            return .{ .service_metadata = service_metadata, .action = create_response_plan };
        }
    },
    Response: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_timeline_event: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createTimelineEvent",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateTimelineEvent",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        incident_record_arn: []const u8,
        event_time: i64,
        event_type: []const u8,
        event_data: []const u8,
        event_references: ?[]EventReference = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .incident_record_arn = "incidentRecordArn",
                .event_time = "eventTime",
                .event_type = "eventType",
                .event_data = "eventData",
                .event_references = "eventReferences",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_timeline_event) } {
            return .{ .service_metadata = service_metadata, .action = create_timeline_event };
        }
    },
    Response: type = struct {
        incident_record_arn: []const u8,
        event_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incident_record_arn = "incidentRecordArn",
                .event_id = "eventId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_incident_record: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteIncidentRecord",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIncidentRecord",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_incident_record) } {
            return .{ .service_metadata = service_metadata, .action = delete_incident_record };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_replication_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteReplicationSet",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteReplicationSet",
    Request: type = struct {
        arn: []const u8,

        pub const http_query = .{
            .arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resource_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteResourcePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .policy_id = "policyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_response_plan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteResponsePlan",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteResponsePlan",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_response_plan) } {
            return .{ .service_metadata = service_metadata, .action = delete_response_plan };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_timeline_event: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteTimelineEvent",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteTimelineEvent",
    Request: type = struct {
        incident_record_arn: []const u8,
        event_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incident_record_arn = "incidentRecordArn",
                .event_id = "eventId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_timeline_event) } {
            return .{ .service_metadata = service_metadata, .action = delete_timeline_event };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_incident_record: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/getIncidentRecord",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIncidentRecord",
    Request: type = struct {
        arn: []const u8,

        pub const http_query = .{
            .arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_incident_record) } {
            return .{ .service_metadata = service_metadata, .action = get_incident_record };
        }
    },
    Response: type = struct {
        incident_record: struct {
            arn: []const u8,
            title: []const u8,
            summary: ?[]const u8 = null,
            status: []const u8,
            impact: i64,
            creation_time: i64,
            resolved_time: ?i64 = null,
            last_modified_time: i64,
            last_modified_by: []const u8,
            automation_executions: ?[]union {
                ssm_execution_arn: ?[]const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ssm_execution_arn = "ssmExecutionArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            incident_record_source: IncidentRecordSource,
            dedupe_string: []const u8,
            chat_channel: ?ChatChannel = null,
            notification_targets: ?[]NotificationTargetItem = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .title = "title",
                    .summary = "summary",
                    .status = "status",
                    .impact = "impact",
                    .creation_time = "creationTime",
                    .resolved_time = "resolvedTime",
                    .last_modified_time = "lastModifiedTime",
                    .last_modified_by = "lastModifiedBy",
                    .automation_executions = "automationExecutions",
                    .incident_record_source = "incidentRecordSource",
                    .dedupe_string = "dedupeString",
                    .chat_channel = "chatChannel",
                    .notification_targets = "notificationTargets",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incident_record = "incidentRecord",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_replication_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/getReplicationSet",
        .success_code = 200,
    };

    action_name: []const u8 = "GetReplicationSet",
    Request: type = struct {
        arn: []const u8,

        pub const http_query = .{
            .arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_replication_set) } {
            return .{ .service_metadata = service_metadata, .action = get_replication_set };
        }
    },
    Response: type = struct {
        replication_set: struct {
            arn: ?[]const u8 = null,
            region_map: []struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    sse_kms_key_id: ?[]const u8 = null,
                    status: []const u8,
                    status_message: ?[]const u8 = null,
                    status_update_date_time: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .sse_kms_key_id = "sseKmsKeyId",
                            .status = "status",
                            .status_message = "statusMessage",
                            .status_update_date_time = "statusUpdateDateTime",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
            },
            status: []const u8,
            deletion_protected: bool,
            created_time: i64,
            created_by: []const u8,
            last_modified_time: i64,
            last_modified_by: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .region_map = "regionMap",
                    .status = "status",
                    .deletion_protected = "deletionProtected",
                    .created_time = "createdTime",
                    .created_by = "createdBy",
                    .last_modified_time = "lastModifiedTime",
                    .last_modified_by = "lastModifiedBy",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "region_map", field_name))
                    return try serializeMap(self.region_map, self.fieldNameFor("region_map"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_set = "replicationSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_policies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/getResourcePolicies",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourcePolicies",
    Request: type = struct {
        resource_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policies) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policies };
        }
    },
    Response: type = struct {
        resource_policies: []struct {
            policy_document: []const u8,
            policy_id: []const u8,
            ram_resource_share_region: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_document = "policyDocument",
                    .policy_id = "policyId",
                    .ram_resource_share_region = "ramResourceShareRegion",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_policies = "resourcePolicies",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_response_plan: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/getResponsePlan",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResponsePlan",
    Request: type = struct {
        arn: []const u8,

        pub const http_query = .{
            .arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_response_plan) } {
            return .{ .service_metadata = service_metadata, .action = get_response_plan };
        }
    },
    Response: type = struct {
        arn: []const u8,
        name: []const u8,
        display_name: ?[]const u8 = null,
        incident_template: IncidentTemplate,
        chat_channel: ?ChatChannel = null,
        engagements: ?[][]const u8 = null,
        actions: ?[]Action = null,
        integrations: ?[]Integration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .name = "name",
                .display_name = "displayName",
                .incident_template = "incidentTemplate",
                .chat_channel = "chatChannel",
                .engagements = "engagements",
                .actions = "actions",
                .integrations = "integrations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_timeline_event: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/getTimelineEvent",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTimelineEvent",
    Request: type = struct {
        incident_record_arn: []const u8,
        event_id: []const u8,

        pub const http_query = .{
            .incident_record_arn = "incidentRecordArn",
            .event_id = "eventId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incident_record_arn = "incidentRecordArn",
                .event_id = "eventId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_timeline_event) } {
            return .{ .service_metadata = service_metadata, .action = get_timeline_event };
        }
    },
    Response: type = struct {
        event: struct {
            incident_record_arn: []const u8,
            event_id: []const u8,
            event_time: i64,
            event_updated_time: i64,
            event_type: []const u8,
            event_data: []const u8,
            event_references: ?[]EventReference = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .incident_record_arn = "incidentRecordArn",
                    .event_id = "eventId",
                    .event_time = "eventTime",
                    .event_updated_time = "eventUpdatedTime",
                    .event_type = "eventType",
                    .event_data = "eventData",
                    .event_references = "eventReferences",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event = "event",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_incident_findings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listIncidentFindings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIncidentFindings",
    Request: type = struct {
        incident_record_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incident_record_arn = "incidentRecordArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_incident_findings) } {
            return .{ .service_metadata = service_metadata, .action = list_incident_findings };
        }
    },
    Response: type = struct {
        findings: []struct {
            id: []const u8,
            last_modified_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .last_modified_time = "lastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .findings = "findings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_incident_records: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listIncidentRecords",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIncidentRecords",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_incident_records) } {
            return .{ .service_metadata = service_metadata, .action = list_incident_records };
        }
    },
    Response: type = struct {
        incident_record_summaries: []struct {
            arn: []const u8,
            title: []const u8,
            status: []const u8,
            impact: i64,
            creation_time: i64,
            resolved_time: ?i64 = null,
            incident_record_source: IncidentRecordSource,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .title = "title",
                    .status = "status",
                    .impact = "impact",
                    .creation_time = "creationTime",
                    .resolved_time = "resolvedTime",
                    .incident_record_source = "incidentRecordSource",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incident_record_summaries = "incidentRecordSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_related_items: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listRelatedItems",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRelatedItems",
    Request: type = struct {
        incident_record_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incident_record_arn = "incidentRecordArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_related_items) } {
            return .{ .service_metadata = service_metadata, .action = list_related_items };
        }
    },
    Response: type = struct {
        related_items: []RelatedItem,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .related_items = "relatedItems",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_replication_sets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listReplicationSets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReplicationSets",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_replication_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_replication_sets };
        }
    },
    Response: type = struct {
        replication_set_arns: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_set_arns = "replicationSetArns",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_response_plans: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listResponsePlans",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResponsePlans",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_response_plans) } {
            return .{ .service_metadata = service_metadata, .action = list_response_plans };
        }
    },
    Response: type = struct {
        response_plan_summaries: []struct {
            arn: []const u8,
            name: []const u8,
            display_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .display_name = "displayName",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .response_plan_summaries = "responsePlanSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_timeline_events: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listTimelineEvents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTimelineEvents",
    Request: type = struct {
        incident_record_arn: []const u8,
        filters: ?[]Filter = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incident_record_arn = "incidentRecordArn",
                .filters = "filters",
                .sort_by = "sortBy",
                .sort_order = "sortOrder",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_timeline_events) } {
            return .{ .service_metadata = service_metadata, .action = list_timeline_events };
        }
    },
    Response: type = struct {
        event_summaries: []struct {
            incident_record_arn: []const u8,
            event_id: []const u8,
            event_time: i64,
            event_updated_time: i64,
            event_type: []const u8,
            event_references: ?[]EventReference = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .incident_record_arn = "incidentRecordArn",
                    .event_id = "eventId",
                    .event_time = "eventTime",
                    .event_updated_time = "eventUpdatedTime",
                    .event_type = "eventType",
                    .event_references = "eventReferences",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_summaries = "eventSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const put_resource_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/putResourcePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        policy_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_id = "policyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_incident: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/startIncident",
        .success_code = 200,
    };

    action_name: []const u8 = "StartIncident",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        response_plan_arn: []const u8,
        title: ?[]const u8 = null,
        impact: ?i64 = null,
        trigger_details: ?struct {
            source: []const u8,
            trigger_arn: ?[]const u8 = null,
            timestamp: i64,
            raw_data: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source = "source",
                    .trigger_arn = "triggerArn",
                    .timestamp = "timestamp",
                    .raw_data = "rawData",
                };
                return @field(mappings, field_name);
            }
        } = null,
        related_items: ?[]RelatedItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .response_plan_arn = "responsePlanArn",
                .title = "title",
                .impact = "impact",
                .trigger_details = "triggerDetails",
                .related_items = "relatedItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_incident) } {
            return .{ .service_metadata = service_metadata, .action = start_incident };
        }
    },
    Response: type = struct {
        incident_record_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .incident_record_arn = "incidentRecordArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_deletion_protection: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateDeletionProtection",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateDeletionProtection",
    Request: type = struct {
        arn: []const u8,
        deletion_protected: bool,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .deletion_protected = "deletionProtected",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_deletion_protection) } {
            return .{ .service_metadata = service_metadata, .action = update_deletion_protection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_incident_record: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateIncidentRecord",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateIncidentRecord",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        arn: []const u8,
        title: ?[]const u8 = null,
        summary: ?[]const u8 = null,
        impact: ?i64 = null,
        status: ?[]const u8 = null,
        chat_channel: ?ChatChannel = null,
        notification_targets: ?[]NotificationTargetItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .arn = "arn",
                .title = "title",
                .summary = "summary",
                .impact = "impact",
                .status = "status",
                .chat_channel = "chatChannel",
                .notification_targets = "notificationTargets",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_incident_record) } {
            return .{ .service_metadata = service_metadata, .action = update_incident_record };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_related_items: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateRelatedItems",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateRelatedItems",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        incident_record_arn: []const u8,
        related_items_update: union {
            item_to_add: ?RelatedItem,
            item_to_remove: ?ItemIdentifier,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .item_to_add = "itemToAdd",
                    .item_to_remove = "itemToRemove",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .incident_record_arn = "incidentRecordArn",
                .related_items_update = "relatedItemsUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_related_items) } {
            return .{ .service_metadata = service_metadata, .action = update_related_items };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_replication_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateReplicationSet",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateReplicationSet",
    Request: type = struct {
        arn: []const u8,
        actions: []union {
            add_region_action: ?struct {
                region_name: []const u8,
                sse_kms_key_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .region_name = "regionName",
                        .sse_kms_key_id = "sseKmsKeyId",
                    };
                    return @field(mappings, field_name);
                }
            },
            delete_region_action: ?struct {
                region_name: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .region_name = "regionName",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add_region_action = "addRegionAction",
                    .delete_region_action = "deleteRegionAction",
                };
                return @field(mappings, field_name);
            }
        },
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .actions = "actions",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_replication_set) } {
            return .{ .service_metadata = service_metadata, .action = update_replication_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_response_plan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateResponsePlan",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateResponsePlan",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        arn: []const u8,
        display_name: ?[]const u8 = null,
        incident_template_title: ?[]const u8 = null,
        incident_template_impact: ?i64 = null,
        incident_template_summary: ?[]const u8 = null,
        incident_template_dedupe_string: ?[]const u8 = null,
        incident_template_notification_targets: ?[]NotificationTargetItem = null,
        chat_channel: ?ChatChannel = null,
        engagements: ?[][]const u8 = null,
        actions: ?[]Action = null,
        incident_template_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        integrations: ?[]Integration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .arn = "arn",
                .display_name = "displayName",
                .incident_template_title = "incidentTemplateTitle",
                .incident_template_impact = "incidentTemplateImpact",
                .incident_template_summary = "incidentTemplateSummary",
                .incident_template_dedupe_string = "incidentTemplateDedupeString",
                .incident_template_notification_targets = "incidentTemplateNotificationTargets",
                .chat_channel = "chatChannel",
                .engagements = "engagements",
                .actions = "actions",
                .incident_template_tags = "incidentTemplateTags",
                .integrations = "integrations",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "incident_template_tags", field_name))
                return try serializeMap(self.incident_template_tags, self.fieldNameFor("incident_template_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_response_plan) } {
            return .{ .service_metadata = service_metadata, .action = update_response_plan };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_timeline_event: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateTimelineEvent",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateTimelineEvent",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        incident_record_arn: []const u8,
        event_id: []const u8,
        event_time: ?i64 = null,
        event_type: ?[]const u8 = null,
        event_data: ?[]const u8 = null,
        event_references: ?[]EventReference = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .incident_record_arn = "incidentRecordArn",
                .event_id = "eventId",
                .event_time = "eventTime",
                .event_type = "eventType",
                .event_data = "eventData",
                .event_references = "eventReferences",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_timeline_event) } {
            return .{ .service_metadata = service_metadata, .action = update_timeline_event };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const EventReference = union {
    resource: ?[]const u8,
    related_item_id: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource = "resource",
            .related_item_id = "relatedItemId",
        };
        return @field(mappings, field_name);
    }
};

pub const Integration = union {
    pager_duty_configuration: ?PagerDutyConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pager_duty_configuration = "pagerDutyConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const PagerDutyConfiguration = struct {
    name: []const u8,
    secret_id: []const u8,
    pager_duty_incident_configuration: PagerDutyIncidentConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .secret_id = "secretId",
            .pager_duty_incident_configuration = "pagerDutyIncidentConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const PagerDutyIncidentConfiguration = struct {
    service_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_id = "serviceId",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = union {
    ssm_automation: ?SsmAutomation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ssm_automation = "ssmAutomation",
        };
        return @field(mappings, field_name);
    }
};

pub const SsmAutomation = struct {
    role_arn: []const u8,
    document_name: []const u8,
    document_version: ?[]const u8 = null,
    target_account: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[][]const u8 = null,
    } = null,
    dynamic_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?DynamicSsmParameterValue = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "roleArn",
            .document_name = "documentName",
            .document_version = "documentVersion",
            .target_account = "targetAccount",
            .parameters = "parameters",
            .dynamic_parameters = "dynamicParameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        if (std.mem.eql(u8, "dynamic_parameters", field_name))
            return try serializeMap(self.dynamic_parameters, self.fieldNameFor("dynamic_parameters"), options, out_stream);
        return false;
    }
};

pub const DynamicSsmParameterValue = union {
    variable: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .variable = "variable",
        };
        return @field(mappings, field_name);
    }
};

pub const ChatChannel = union {
    empty: ?EmptyChatChannel,
    chatbot_sns: ?[][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .empty = "empty",
            .chatbot_sns = "chatbotSns",
        };
        return @field(mappings, field_name);
    }
};

pub const EmptyChatChannel = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const NotificationTargetItem = union {
    sns_topic_arn: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_topic_arn = "snsTopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ItemIdentifier = struct {
    value: ItemValue,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const ItemValue = union {
    arn: ?[]const u8,
    url: ?[]const u8,
    metric_definition: ?[]const u8,
    pager_duty_incident_detail: ?PagerDutyIncidentDetail,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .url = "url",
            .metric_definition = "metricDefinition",
            .pager_duty_incident_detail = "pagerDutyIncidentDetail",
        };
        return @field(mappings, field_name);
    }
};

pub const PagerDutyIncidentDetail = struct {
    id: []const u8,
    auto_resolve: ?bool = null,
    secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .auto_resolve = "autoResolve",
            .secret_id = "secretId",
        };
        return @field(mappings, field_name);
    }
};

pub const RelatedItem = struct {
    identifier: ItemIdentifier,
    title: ?[]const u8 = null,
    generated_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "identifier",
            .title = "title",
            .generated_id = "generatedId",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    key: []const u8,
    condition: Condition,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .condition = "condition",
        };
        return @field(mappings, field_name);
    }
};

pub const Condition = union {
    before: ?i64,
    after: ?i64,
    equals: ?AttributeValueList,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .before = "before",
            .after = "after",
            .equals = "equals",
        };
        return @field(mappings, field_name);
    }
};

pub const AttributeValueList = union {
    string_values: ?[][]const u8,
    integer_values: ?[]i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_values = "stringValues",
            .integer_values = "integerValues",
        };
        return @field(mappings, field_name);
    }
};

pub const IncidentRecordSource = struct {
    created_by: []const u8,
    invoked_by: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    source: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .created_by = "createdBy",
            .invoked_by = "invokedBy",
            .resource_arn = "resourceArn",
            .source = "source",
        };
        return @field(mappings, field_name);
    }
};

pub const IncidentTemplate = struct {
    title: []const u8,
    impact: i64,
    summary: ?[]const u8 = null,
    dedupe_string: ?[]const u8 = null,
    notification_targets: ?[]NotificationTargetItem = null,
    incident_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title = "title",
            .impact = "impact",
            .summary = "summary",
            .dedupe_string = "dedupeString",
            .notification_targets = "notificationTargets",
            .incident_tags = "incidentTags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "incident_tags", field_name))
            return try serializeMap(self.incident_tags, self.fieldNameFor("incident_tags"), options, out_stream);
        return false;
    }
};
