const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-10";
pub const sdk_id: []const u8 = "Ssm Sap";
pub const arn_namespace: ?[]const u8 = "ssm-sap";
pub const endpoint_prefix: []const u8 = "ssm-sap";
pub const sigv4_name: []const u8 = "ssm-sap";
pub const name: []const u8 = "SsmSap";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-10",
    sdk_id: []const u8 = "Ssm Sap",
    arn_namespace: ?[]const u8 = "ssm-sap",
    endpoint_prefix: []const u8 = "ssm-sap",
    sigv4_name: []const u8 = "ssm-sap",
    name: []const u8 = "SsmSap",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_resource_permission: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/delete-resource-permission",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteResourcePermission",
    Request: type = struct {
        action_type: ?[]const u8 = null,
        source_resource_arn: ?[]const u8 = null,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type = "ActionType",
                .source_resource_arn = "SourceResourceArn",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_permission) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_permission };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const deregister_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deregister-application",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterApplication",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_application) } {
            return .{ .service_metadata = service_metadata, .action = deregister_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Unauthorized,
        Validation,
    },
} = .{};
pub const get_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-application",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApplication",
    Request: type = struct {
        application_id: ?[]const u8 = null,
        application_arn: ?[]const u8 = null,
        app_registry_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .application_arn = "ApplicationArn",
                .app_registry_arn = "AppRegistryArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application) } {
            return .{ .service_metadata = service_metadata, .action = get_application };
        }
    },
    Response: type = struct {
        application: ?Application = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "Application",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const get_component: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-component",
        .success_code = 200,
    };

    action_name: []const u8 = "GetComponent",
    Request: type = struct {
        application_id: []const u8,
        component_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .component_id = "ComponentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_component) } {
            return .{ .service_metadata = service_metadata, .action = get_component };
        }
    },
    Response: type = struct {
        component: ?struct {
            component_id: ?[]const u8 = null,
            sid: ?[]const u8 = null,
            system_number: ?[]const u8 = null,
            parent_component: ?[]const u8 = null,
            child_components: ?[][]const u8 = null,
            application_id: ?[]const u8 = null,
            component_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            sap_hostname: ?[]const u8 = null,
            sap_feature: ?[]const u8 = null,
            sap_kernel_version: ?[]const u8 = null,
            hdb_version: ?[]const u8 = null,
            resilience: ?struct {
                hsr_tier: ?[]const u8 = null,
                hsr_replication_mode: ?[]const u8 = null,
                hsr_operation_mode: ?[]const u8 = null,
                cluster_status: ?[]const u8 = null,
                enqueue_replication: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .hsr_tier = "HsrTier",
                        .hsr_replication_mode = "HsrReplicationMode",
                        .hsr_operation_mode = "HsrOperationMode",
                        .cluster_status = "ClusterStatus",
                        .enqueue_replication = "EnqueueReplication",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            associated_host: ?struct {
                hostname: ?[]const u8 = null,
                ec2_instance_id: ?[]const u8 = null,
                ip_addresses: ?[]struct {
                    ip_address: ?[]const u8 = null,
                    primary: ?bool = null,
                    allocation_type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .ip_address = "IpAddress",
                            .primary = "Primary",
                            .allocation_type = "AllocationType",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                os_version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .hostname = "Hostname",
                        .ec2_instance_id = "Ec2InstanceId",
                        .ip_addresses = "IpAddresses",
                        .os_version = "OsVersion",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            databases: ?[][]const u8 = null,
            hosts: ?[]struct {
                host_name: ?[]const u8 = null,
                host_ip: ?[]const u8 = null,
                ec2_instance_id: ?[]const u8 = null,
                instance_id: ?[]const u8 = null,
                host_role: ?[]const u8 = null,
                os_version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .host_name = "HostName",
                        .host_ip = "HostIp",
                        .ec2_instance_id = "EC2InstanceId",
                        .instance_id = "InstanceId",
                        .host_role = "HostRole",
                        .os_version = "OsVersion",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            primary_host: ?[]const u8 = null,
            database_connection: ?struct {
                database_connection_method: ?[]const u8 = null,
                database_arn: ?[]const u8 = null,
                connection_ip: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .database_connection_method = "DatabaseConnectionMethod",
                        .database_arn = "DatabaseArn",
                        .connection_ip = "ConnectionIp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_updated: ?i64 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .component_id = "ComponentId",
                    .sid = "Sid",
                    .system_number = "SystemNumber",
                    .parent_component = "ParentComponent",
                    .child_components = "ChildComponents",
                    .application_id = "ApplicationId",
                    .component_type = "ComponentType",
                    .status = "Status",
                    .sap_hostname = "SapHostname",
                    .sap_feature = "SapFeature",
                    .sap_kernel_version = "SapKernelVersion",
                    .hdb_version = "HdbVersion",
                    .resilience = "Resilience",
                    .associated_host = "AssociatedHost",
                    .databases = "Databases",
                    .hosts = "Hosts",
                    .primary_host = "PrimaryHost",
                    .database_connection = "DatabaseConnection",
                    .last_updated = "LastUpdated",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component = "Component",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        Unauthorized,
        Validation,
    },
} = .{};
pub const get_database: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-database",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDatabase",
    Request: type = struct {
        application_id: ?[]const u8 = null,
        component_id: ?[]const u8 = null,
        database_id: ?[]const u8 = null,
        database_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .component_id = "ComponentId",
                .database_id = "DatabaseId",
                .database_arn = "DatabaseArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_database) } {
            return .{ .service_metadata = service_metadata, .action = get_database };
        }
    },
    Response: type = struct {
        database: ?struct {
            application_id: ?[]const u8 = null,
            component_id: ?[]const u8 = null,
            credentials: ?[]ApplicationCredential = null,
            database_id: ?[]const u8 = null,
            database_name: ?[]const u8 = null,
            database_type: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            primary_host: ?[]const u8 = null,
            sql_port: ?i64 = null,
            last_updated: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .component_id = "ComponentId",
                    .credentials = "Credentials",
                    .database_id = "DatabaseId",
                    .database_name = "DatabaseName",
                    .database_type = "DatabaseType",
                    .arn = "Arn",
                    .status = "Status",
                    .primary_host = "PrimaryHost",
                    .sql_port = "SQLPort",
                    .last_updated = "LastUpdated",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database = "Database",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const get_operation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-operation",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOperation",
    Request: type = struct {
        operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_operation) } {
            return .{ .service_metadata = service_metadata, .action = get_operation };
        }
    },
    Response: type = struct {
        operation: ?Operation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation = "Operation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const get_resource_permission: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/get-resource-permission",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourcePermission",
    Request: type = struct {
        action_type: ?[]const u8 = null,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type = "ActionType",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_permission) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_permission };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_applications: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-applications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApplications",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_applications };
        }
    },
    Response: type = struct {
        applications: ?[]struct {
            id: ?[]const u8 = null,
            discovery_status: ?[]const u8 = null,
            type: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .discovery_status = "DiscoveryStatus",
                    .type = "Type",
                    .arn = "Arn",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applications = "Applications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_components: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-components",
        .success_code = 200,
    };

    action_name: []const u8 = "ListComponents",
    Request: type = struct {
        application_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_components) } {
            return .{ .service_metadata = service_metadata, .action = list_components };
        }
    },
    Response: type = struct {
        components: ?[]struct {
            application_id: ?[]const u8 = null,
            component_id: ?[]const u8 = null,
            component_type: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .component_id = "ComponentId",
                    .component_type = "ComponentType",
                    .tags = "Tags",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .components = "Components",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Unauthorized,
        Validation,
    },
} = .{};
pub const list_databases: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-databases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDatabases",
    Request: type = struct {
        application_id: ?[]const u8 = null,
        component_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .component_id = "ComponentId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_databases) } {
            return .{ .service_metadata = service_metadata, .action = list_databases };
        }
    },
    Response: type = struct {
        databases: ?[]struct {
            application_id: ?[]const u8 = null,
            component_id: ?[]const u8 = null,
            database_id: ?[]const u8 = null,
            database_type: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .component_id = "ComponentId",
                    .database_id = "DatabaseId",
                    .database_type = "DatabaseType",
                    .arn = "Arn",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .databases = "Databases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_operations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/list-operations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOperations",
    Request: type = struct {
        application_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_operations) } {
            return .{ .service_metadata = service_metadata, .action = list_operations };
        }
    },
    Response: type = struct {
        operations: ?[]Operation = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operations = "Operations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_resource_permission: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/put-resource-permission",
        .success_code = 200,
    };

    action_name: []const u8 = "PutResourcePermission",
    Request: type = struct {
        action_type: []const u8,
        source_resource_arn: []const u8,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_type = "ActionType",
                .source_resource_arn = "SourceResourceArn",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_permission) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_permission };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const register_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/register-application",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterApplication",
    Request: type = struct {
        application_id: []const u8,
        application_type: []const u8,
        instances: [][]const u8,
        sap_instance_number: ?[]const u8 = null,
        sid: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        credentials: ?[]ApplicationCredential = null,
        database_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .application_type = "ApplicationType",
                .instances = "Instances",
                .sap_instance_number = "SapInstanceNumber",
                .sid = "Sid",
                .tags = "Tags",
                .credentials = "Credentials",
                .database_arn = "DatabaseArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_application) } {
            return .{ .service_metadata = service_metadata, .action = register_application };
        }
    },
    Response: type = struct {
        application: ?Application = null,
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application = "Application",
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const start_application_refresh: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/start-application-refresh",
        .success_code = 200,
    };

    action_name: []const u8 = "StartApplicationRefresh",
    Request: type = struct {
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_application_refresh) } {
            return .{ .service_metadata = service_metadata, .action = start_application_refresh };
        }
    },
    Response: type = struct {
        operation_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operation_id = "OperationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Unauthorized,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_application_settings: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/update-application-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApplicationSettings",
    Request: type = struct {
        application_id: []const u8,
        credentials_to_add_or_update: ?[]ApplicationCredential = null,
        credentials_to_remove: ?[]ApplicationCredential = null,
        backint: ?struct {
            backint_mode: []const u8,
            ensure_no_backup_in_process: bool,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .backint_mode = "BackintMode",
                    .ensure_no_backup_in_process = "EnsureNoBackupInProcess",
                };
                return @field(mappings, field_name);
            }
        } = null,
        database_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_id = "ApplicationId",
                .credentials_to_add_or_update = "CredentialsToAddOrUpdate",
                .credentials_to_remove = "CredentialsToRemove",
                .backint = "Backint",
                .database_arn = "DatabaseArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_application_settings };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,
        operation_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
                .operation_ids = "OperationIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Unauthorized,
        Validation,
    },
} = .{};

pub const ApplicationCredential = struct {
    database_name: []const u8,
    credential_type: []const u8,
    secret_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .credential_type = "CredentialType",
            .secret_id = "SecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const Application = struct {
    id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    app_registry_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    discovery_status: ?[]const u8 = null,
    components: ?[][]const u8 = null,
    last_updated: ?i64 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .type = "Type",
            .arn = "Arn",
            .app_registry_arn = "AppRegistryArn",
            .status = "Status",
            .discovery_status = "DiscoveryStatus",
            .components = "Components",
            .last_updated = "LastUpdated",
            .status_message = "StatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const Operation = struct {
    id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    resource_type: ?[]const u8 = null,
    resource_id: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    last_updated_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .type = "Type",
            .status = "Status",
            .status_message = "StatusMessage",
            .properties = "Properties",
            .resource_type = "ResourceType",
            .resource_id = "ResourceId",
            .resource_arn = "ResourceArn",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .last_updated_time = "LastUpdatedTime",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "properties", field_name))
            return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
        return false;
    }
};

pub const Filter = struct {
    name: []const u8,
    value: []const u8,
    operator: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
            .operator = "Operator",
        };
        return @field(mappings, field_name);
    }
};
