const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-06-10";
pub const sdk_id: []const u8 = "SSO";
pub const arn_namespace: ?[]const u8 = "awsssoportal";
pub const endpoint_prefix: []const u8 = "portal.sso";
pub const sigv4_name: []const u8 = "awsssoportal";
pub const name: []const u8 = "SWBPortalService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-06-10",
    sdk_id: []const u8 = "SSO",
    arn_namespace: ?[]const u8 = "awsssoportal",
    endpoint_prefix: []const u8 = "portal.sso",
    sigv4_name: []const u8 = "awsssoportal",
    name: []const u8 = "SWBPortalService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const get_role_credentials: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/federation/credentials",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRoleCredentials",
    Request: type = struct {
        role_name: []const u8,
        account_id: []const u8,
        access_token: []const u8,

        pub const http_query = .{
            .role_name = "role_name",
            .account_id = "account_id",
        };

        pub const http_header = .{
            .access_token = "x-amz-sso_bearer_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_name = "roleName",
                .account_id = "accountId",
                .access_token = "accessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_role_credentials) } {
            return .{ .service_metadata = service_metadata, .action = get_role_credentials };
        }
    },
    Response: type = struct {
        role_credentials: ?struct {
            access_key_id: ?[]const u8 = null,
            secret_access_key: ?[]const u8 = null,
            session_token: ?[]const u8 = null,
            expiration: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_key_id = "accessKeyId",
                    .secret_access_key = "secretAccessKey",
                    .session_token = "sessionToken",
                    .expiration = "expiration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_credentials = "roleCredentials",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_account_roles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assignment/roles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccountRoles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        access_token: []const u8,
        account_id: []const u8,

        pub const http_query = .{
            .next_token = "next_token",
            .max_results = "max_result",
            .account_id = "account_id",
        };

        pub const http_header = .{
            .access_token = "x-amz-sso_bearer_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .access_token = "accessToken",
                .account_id = "accountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_roles) } {
            return .{ .service_metadata = service_metadata, .action = list_account_roles };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        role_list: ?[]struct {
            role_name: ?[]const u8 = null,
            account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .role_name = "roleName",
                    .account_id = "accountId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .role_list = "roleList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_accounts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/assignment/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccounts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        access_token: []const u8,

        pub const http_query = .{
            .next_token = "next_token",
            .max_results = "max_result",
        };

        pub const http_header = .{
            .access_token = "x-amz-sso_bearer_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .access_token = "accessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_accounts };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        account_list: ?[]struct {
            account_id: ?[]const u8 = null,
            account_name: ?[]const u8 = null,
            email_address: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .account_name = "accountName",
                    .email_address = "emailAddress",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .account_list = "accountList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const logout: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/logout",
        .success_code = 200,
    };

    action_name: []const u8 = "Logout",
    Request: type = struct {
        access_token: []const u8,
        pub const http_header = .{
            .access_token = "x-amz-sso_bearer_token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "accessToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(logout) } {
            return .{ .service_metadata = service_metadata, .action = logout };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidRequest,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
