const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-20";
pub const sdk_id: []const u8 = "SSO Admin";
pub const arn_namespace: ?[]const u8 = "sso";
pub const endpoint_prefix: []const u8 = "sso";
pub const sigv4_name: []const u8 = "sso";
pub const name: []const u8 = "SWBExternalService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-20",
    sdk_id: []const u8 = "SSO Admin",
    arn_namespace: ?[]const u8 = "sso",
    endpoint_prefix: []const u8 = "sso",
    sigv4_name: []const u8 = "sso",
    name: []const u8 = "SWBExternalService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const attach_customer_managed_policy_reference_to_permission_set: struct {
    action_name: []const u8 = "AttachCustomerManagedPolicyReferenceToPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        customer_managed_policy_reference: CustomerManagedPolicyReference,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .customer_managed_policy_reference = "CustomerManagedPolicyReference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_customer_managed_policy_reference_to_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = attach_customer_managed_policy_reference_to_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const attach_managed_policy_to_permission_set: struct {
    action_name: []const u8 = "AttachManagedPolicyToPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        managed_policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .managed_policy_arn = "ManagedPolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_managed_policy_to_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = attach_managed_policy_to_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_account_assignment: struct {
    action_name: []const u8 = "CreateAccountAssignment",
    Request: type = struct {
        instance_arn: []const u8,
        target_id: []const u8,
        target_type: []const u8,
        permission_set_arn: []const u8,
        principal_type: []const u8,
        principal_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .target_id = "TargetId",
                .target_type = "TargetType",
                .permission_set_arn = "PermissionSetArn",
                .principal_type = "PrincipalType",
                .principal_id = "PrincipalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_account_assignment) } {
            return .{ .service_metadata = service_metadata, .action = create_account_assignment };
        }
    },
    Response: type = struct {
        account_assignment_creation_status: ?AccountAssignmentOperationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignment_creation_status = "AccountAssignmentCreationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_application: struct {
    action_name: []const u8 = "CreateApplication",
    Request: type = struct {
        instance_arn: []const u8,
        application_provider_arn: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        portal_options: ?PortalOptions = null,
        tags: ?[]Tag = null,
        status: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .application_provider_arn = "ApplicationProviderArn",
                .name = "Name",
                .description = "Description",
                .portal_options = "PortalOptions",
                .tags = "Tags",
                .status = "Status",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application) } {
            return .{ .service_metadata = service_metadata, .action = create_application };
        }
    },
    Response: type = struct {
        application_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_application_assignment: struct {
    action_name: []const u8 = "CreateApplicationAssignment",
    Request: type = struct {
        application_arn: []const u8,
        principal_id: []const u8,
        principal_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
                .principal_id = "PrincipalId",
                .principal_type = "PrincipalType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_application_assignment) } {
            return .{ .service_metadata = service_metadata, .action = create_application_assignment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_instance: struct {
    action_name: []const u8 = "CreateInstance",
    Request: type = struct {
        name: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_instance };
        }
    },
    Response: type = struct {
        instance_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_instance_access_control_attribute_configuration: struct {
    action_name: []const u8 = "CreateInstanceAccessControlAttributeConfiguration",
    Request: type = struct {
        instance_arn: []const u8,
        instance_access_control_attribute_configuration: InstanceAccessControlAttributeConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .instance_access_control_attribute_configuration = "InstanceAccessControlAttributeConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_instance_access_control_attribute_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_instance_access_control_attribute_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_permission_set: struct {
    action_name: []const u8 = "CreatePermissionSet",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        instance_arn: []const u8,
        session_duration: ?[]const u8 = null,
        relay_state: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .instance_arn = "InstanceArn",
                .session_duration = "SessionDuration",
                .relay_state = "RelayState",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = create_permission_set };
        }
    },
    Response: type = struct {
        permission_set: ?PermissionSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_set = "PermissionSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_trusted_token_issuer: struct {
    action_name: []const u8 = "CreateTrustedTokenIssuer",
    Request: type = struct {
        instance_arn: []const u8,
        name: []const u8,
        trusted_token_issuer_type: []const u8,
        trusted_token_issuer_configuration: TrustedTokenIssuerConfiguration,
        client_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .name = "Name",
                .trusted_token_issuer_type = "TrustedTokenIssuerType",
                .trusted_token_issuer_configuration = "TrustedTokenIssuerConfiguration",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_trusted_token_issuer) } {
            return .{ .service_metadata = service_metadata, .action = create_trusted_token_issuer };
        }
    },
    Response: type = struct {
        trusted_token_issuer_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trusted_token_issuer_arn = "TrustedTokenIssuerArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_account_assignment: struct {
    action_name: []const u8 = "DeleteAccountAssignment",
    Request: type = struct {
        instance_arn: []const u8,
        target_id: []const u8,
        target_type: []const u8,
        permission_set_arn: []const u8,
        principal_type: []const u8,
        principal_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .target_id = "TargetId",
                .target_type = "TargetType",
                .permission_set_arn = "PermissionSetArn",
                .principal_type = "PrincipalType",
                .principal_id = "PrincipalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_account_assignment) } {
            return .{ .service_metadata = service_metadata, .action = delete_account_assignment };
        }
    },
    Response: type = struct {
        account_assignment_deletion_status: ?AccountAssignmentOperationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignment_deletion_status = "AccountAssignmentDeletionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_application: struct {
    action_name: []const u8 = "DeleteApplication",
    Request: type = struct {
        application_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_application_assignment: struct {
    action_name: []const u8 = "DeleteApplicationAssignment",
    Request: type = struct {
        application_arn: []const u8,
        principal_id: []const u8,
        principal_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
                .principal_id = "PrincipalId",
                .principal_type = "PrincipalType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_application_assignment) } {
            return .{ .service_metadata = service_metadata, .action = delete_application_assignment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_inline_policy_from_permission_set: struct {
    action_name: []const u8 = "DeleteInlinePolicyFromPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_inline_policy_from_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_inline_policy_from_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_instance: struct {
    action_name: []const u8 = "DeleteInstance",
    Request: type = struct {
        instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_instance };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_instance_access_control_attribute_configuration: struct {
    action_name: []const u8 = "DeleteInstanceAccessControlAttributeConfiguration",
    Request: type = struct {
        instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_instance_access_control_attribute_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_instance_access_control_attribute_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_permissions_boundary_from_permission_set: struct {
    action_name: []const u8 = "DeletePermissionsBoundaryFromPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_permissions_boundary_from_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_permissions_boundary_from_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_permission_set: struct {
    action_name: []const u8 = "DeletePermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_trusted_token_issuer: struct {
    action_name: []const u8 = "DeleteTrustedTokenIssuer",
    Request: type = struct {
        trusted_token_issuer_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trusted_token_issuer_arn = "TrustedTokenIssuerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_trusted_token_issuer) } {
            return .{ .service_metadata = service_metadata, .action = delete_trusted_token_issuer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_account_assignment_creation_status: struct {
    action_name: []const u8 = "DescribeAccountAssignmentCreationStatus",
    Request: type = struct {
        instance_arn: []const u8,
        account_assignment_creation_request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .account_assignment_creation_request_id = "AccountAssignmentCreationRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_assignment_creation_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_assignment_creation_status };
        }
    },
    Response: type = struct {
        account_assignment_creation_status: ?AccountAssignmentOperationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignment_creation_status = "AccountAssignmentCreationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_account_assignment_deletion_status: struct {
    action_name: []const u8 = "DescribeAccountAssignmentDeletionStatus",
    Request: type = struct {
        instance_arn: []const u8,
        account_assignment_deletion_request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .account_assignment_deletion_request_id = "AccountAssignmentDeletionRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_assignment_deletion_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_assignment_deletion_status };
        }
    },
    Response: type = struct {
        account_assignment_deletion_status: ?AccountAssignmentOperationStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignment_deletion_status = "AccountAssignmentDeletionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_application: struct {
    action_name: []const u8 = "DescribeApplication",
    Request: type = struct {
        application_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application) } {
            return .{ .service_metadata = service_metadata, .action = describe_application };
        }
    },
    Response: type = struct {
        application_arn: ?[]const u8 = null,
        application_provider_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        application_account: ?[]const u8 = null,
        instance_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        portal_options: ?PortalOptions = null,
        description: ?[]const u8 = null,
        created_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
                .application_provider_arn = "ApplicationProviderArn",
                .name = "Name",
                .application_account = "ApplicationAccount",
                .instance_arn = "InstanceArn",
                .status = "Status",
                .portal_options = "PortalOptions",
                .description = "Description",
                .created_date = "CreatedDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_application_assignment: struct {
    action_name: []const u8 = "DescribeApplicationAssignment",
    Request: type = struct {
        application_arn: []const u8,
        principal_id: []const u8,
        principal_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
                .principal_id = "PrincipalId",
                .principal_type = "PrincipalType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application_assignment) } {
            return .{ .service_metadata = service_metadata, .action = describe_application_assignment };
        }
    },
    Response: type = struct {
        principal_type: ?[]const u8 = null,
        principal_id: ?[]const u8 = null,
        application_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal_type = "PrincipalType",
                .principal_id = "PrincipalId",
                .application_arn = "ApplicationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_application_provider: struct {
    action_name: []const u8 = "DescribeApplicationProvider",
    Request: type = struct {
        application_provider_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_provider_arn = "ApplicationProviderArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application_provider) } {
            return .{ .service_metadata = service_metadata, .action = describe_application_provider };
        }
    },
    Response: type = struct {
        application_provider_arn: []const u8,
        federation_protocol: ?[]const u8 = null,
        display_data: ?DisplayData = null,
        resource_server_config: ?ResourceServerConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_provider_arn = "ApplicationProviderArn",
                .federation_protocol = "FederationProtocol",
                .display_data = "DisplayData",
                .resource_server_config = "ResourceServerConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_instance: struct {
    action_name: []const u8 = "DescribeInstance",
    Request: type = struct {
        instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance };
        }
    },
    Response: type = struct {
        instance_arn: ?[]const u8 = null,
        identity_store_id: ?[]const u8 = null,
        owner_account_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        created_date: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .identity_store_id = "IdentityStoreId",
                .owner_account_id = "OwnerAccountId",
                .name = "Name",
                .created_date = "CreatedDate",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_instance_access_control_attribute_configuration: struct {
    action_name: []const u8 = "DescribeInstanceAccessControlAttributeConfiguration",
    Request: type = struct {
        instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_access_control_attribute_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_access_control_attribute_configuration };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        instance_access_control_attribute_configuration: ?InstanceAccessControlAttributeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .status_reason = "StatusReason",
                .instance_access_control_attribute_configuration = "InstanceAccessControlAttributeConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_permission_set: struct {
    action_name: []const u8 = "DescribePermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_permission_set };
        }
    },
    Response: type = struct {
        permission_set: ?PermissionSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_set = "PermissionSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_permission_set_provisioning_status: struct {
    action_name: []const u8 = "DescribePermissionSetProvisioningStatus",
    Request: type = struct {
        instance_arn: []const u8,
        provision_permission_set_request_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .provision_permission_set_request_id = "ProvisionPermissionSetRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_permission_set_provisioning_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_permission_set_provisioning_status };
        }
    },
    Response: type = struct {
        permission_set_provisioning_status: ?PermissionSetProvisioningStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_set_provisioning_status = "PermissionSetProvisioningStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_trusted_token_issuer: struct {
    action_name: []const u8 = "DescribeTrustedTokenIssuer",
    Request: type = struct {
        trusted_token_issuer_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trusted_token_issuer_arn = "TrustedTokenIssuerArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trusted_token_issuer) } {
            return .{ .service_metadata = service_metadata, .action = describe_trusted_token_issuer };
        }
    },
    Response: type = struct {
        trusted_token_issuer_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        trusted_token_issuer_type: ?[]const u8 = null,
        trusted_token_issuer_configuration: ?TrustedTokenIssuerConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trusted_token_issuer_arn = "TrustedTokenIssuerArn",
                .name = "Name",
                .trusted_token_issuer_type = "TrustedTokenIssuerType",
                .trusted_token_issuer_configuration = "TrustedTokenIssuerConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const detach_customer_managed_policy_reference_from_permission_set: struct {
    action_name: []const u8 = "DetachCustomerManagedPolicyReferenceFromPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        customer_managed_policy_reference: CustomerManagedPolicyReference,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .customer_managed_policy_reference = "CustomerManagedPolicyReference",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_customer_managed_policy_reference_from_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = detach_customer_managed_policy_reference_from_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const detach_managed_policy_from_permission_set: struct {
    action_name: []const u8 = "DetachManagedPolicyFromPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        managed_policy_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .managed_policy_arn = "ManagedPolicyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_managed_policy_from_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = detach_managed_policy_from_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_application_assignment_configuration: struct {
    action_name: []const u8 = "GetApplicationAssignmentConfiguration",
    Request: type = struct {
        application_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_application_assignment_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_application_assignment_configuration };
        }
    },
    Response: type = struct {
        assignment_required: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assignment_required = "AssignmentRequired",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_inline_policy_for_permission_set: struct {
    action_name: []const u8 = "GetInlinePolicyForPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_inline_policy_for_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = get_inline_policy_for_permission_set };
        }
    },
    Response: type = struct {
        inline_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inline_policy = "InlinePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_permissions_boundary_for_permission_set: struct {
    action_name: []const u8 = "GetPermissionsBoundaryForPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_permissions_boundary_for_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = get_permissions_boundary_for_permission_set };
        }
    },
    Response: type = struct {
        permissions_boundary: ?PermissionsBoundary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions_boundary = "PermissionsBoundary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_account_assignment_creation_status: struct {
    action_name: []const u8 = "ListAccountAssignmentCreationStatus",
    Request: type = struct {
        instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filter: ?OperationStatusFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filter = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_assignment_creation_status) } {
            return .{ .service_metadata = service_metadata, .action = list_account_assignment_creation_status };
        }
    },
    Response: type = struct {
        account_assignments_creation_status: ?[]AccountAssignmentOperationStatusMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignments_creation_status = "AccountAssignmentsCreationStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_account_assignment_deletion_status: struct {
    action_name: []const u8 = "ListAccountAssignmentDeletionStatus",
    Request: type = struct {
        instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filter: ?OperationStatusFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filter = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_assignment_deletion_status) } {
            return .{ .service_metadata = service_metadata, .action = list_account_assignment_deletion_status };
        }
    },
    Response: type = struct {
        account_assignments_deletion_status: ?[]AccountAssignmentOperationStatusMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignments_deletion_status = "AccountAssignmentsDeletionStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_account_assignments: struct {
    action_name: []const u8 = "ListAccountAssignments",
    Request: type = struct {
        instance_arn: []const u8,
        account_id: []const u8,
        permission_set_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .account_id = "AccountId",
                .permission_set_arn = "PermissionSetArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_assignments) } {
            return .{ .service_metadata = service_metadata, .action = list_account_assignments };
        }
    },
    Response: type = struct {
        account_assignments: ?[]struct {
            account_id: ?[]const u8 = null,
            permission_set_arn: ?[]const u8 = null,
            principal_type: ?[]const u8 = null,
            principal_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .permission_set_arn = "PermissionSetArn",
                    .principal_type = "PrincipalType",
                    .principal_id = "PrincipalId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignments = "AccountAssignments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_account_assignments_for_principal: struct {
    action_name: []const u8 = "ListAccountAssignmentsForPrincipal",
    Request: type = struct {
        instance_arn: []const u8,
        principal_id: []const u8,
        principal_type: []const u8,
        filter: ?struct {
            account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .principal_id = "PrincipalId",
                .principal_type = "PrincipalType",
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_assignments_for_principal) } {
            return .{ .service_metadata = service_metadata, .action = list_account_assignments_for_principal };
        }
    },
    Response: type = struct {
        account_assignments: ?[]struct {
            account_id: ?[]const u8 = null,
            permission_set_arn: ?[]const u8 = null,
            principal_id: ?[]const u8 = null,
            principal_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .permission_set_arn = "PermissionSetArn",
                    .principal_id = "PrincipalId",
                    .principal_type = "PrincipalType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_assignments = "AccountAssignments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_accounts_for_provisioned_permission_set: struct {
    action_name: []const u8 = "ListAccountsForProvisionedPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        provisioning_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .provisioning_status = "ProvisioningStatus",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accounts_for_provisioned_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = list_accounts_for_provisioned_permission_set };
        }
    },
    Response: type = struct {
        account_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "AccountIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_application_assignments: struct {
    action_name: []const u8 = "ListApplicationAssignments",
    Request: type = struct {
        application_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_assignments) } {
            return .{ .service_metadata = service_metadata, .action = list_application_assignments };
        }
    },
    Response: type = struct {
        application_assignments: ?[]struct {
            application_arn: []const u8,
            principal_id: []const u8,
            principal_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_arn = "ApplicationArn",
                    .principal_id = "PrincipalId",
                    .principal_type = "PrincipalType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_assignments = "ApplicationAssignments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_application_assignments_for_principal: struct {
    action_name: []const u8 = "ListApplicationAssignmentsForPrincipal",
    Request: type = struct {
        instance_arn: []const u8,
        principal_id: []const u8,
        principal_type: []const u8,
        filter: ?struct {
            application_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_arn = "ApplicationArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .principal_id = "PrincipalId",
                .principal_type = "PrincipalType",
                .filter = "Filter",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_assignments_for_principal) } {
            return .{ .service_metadata = service_metadata, .action = list_application_assignments_for_principal };
        }
    },
    Response: type = struct {
        application_assignments: ?[]struct {
            application_arn: ?[]const u8 = null,
            principal_id: ?[]const u8 = null,
            principal_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_arn = "ApplicationArn",
                    .principal_id = "PrincipalId",
                    .principal_type = "PrincipalType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_assignments = "ApplicationAssignments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_application_providers: struct {
    action_name: []const u8 = "ListApplicationProviders",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_application_providers) } {
            return .{ .service_metadata = service_metadata, .action = list_application_providers };
        }
    },
    Response: type = struct {
        application_providers: ?[]struct {
            application_provider_arn: []const u8,
            federation_protocol: ?[]const u8 = null,
            display_data: ?DisplayData = null,
            resource_server_config: ?ResourceServerConfig = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_provider_arn = "ApplicationProviderArn",
                    .federation_protocol = "FederationProtocol",
                    .display_data = "DisplayData",
                    .resource_server_config = "ResourceServerConfig",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_providers = "ApplicationProviders",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_applications: struct {
    action_name: []const u8 = "ListApplications",
    Request: type = struct {
        instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filter: ?struct {
            application_account: ?[]const u8 = null,
            application_provider: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_account = "ApplicationAccount",
                    .application_provider = "ApplicationProvider",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filter = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_applications };
        }
    },
    Response: type = struct {
        applications: ?[]struct {
            application_arn: ?[]const u8 = null,
            application_provider_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            application_account: ?[]const u8 = null,
            instance_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            portal_options: ?PortalOptions = null,
            description: ?[]const u8 = null,
            created_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_arn = "ApplicationArn",
                    .application_provider_arn = "ApplicationProviderArn",
                    .name = "Name",
                    .application_account = "ApplicationAccount",
                    .instance_arn = "InstanceArn",
                    .status = "Status",
                    .portal_options = "PortalOptions",
                    .description = "Description",
                    .created_date = "CreatedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applications = "Applications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_customer_managed_policy_references_in_permission_set: struct {
    action_name: []const u8 = "ListCustomerManagedPolicyReferencesInPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_customer_managed_policy_references_in_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = list_customer_managed_policy_references_in_permission_set };
        }
    },
    Response: type = struct {
        customer_managed_policy_references: ?[]CustomerManagedPolicyReference = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .customer_managed_policy_references = "CustomerManagedPolicyReferences",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_instances: struct {
    action_name: []const u8 = "ListInstances",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_instances };
        }
    },
    Response: type = struct {
        instances: ?[]struct {
            instance_arn: ?[]const u8 = null,
            identity_store_id: ?[]const u8 = null,
            owner_account_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            created_date: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_arn = "InstanceArn",
                    .identity_store_id = "IdentityStoreId",
                    .owner_account_id = "OwnerAccountId",
                    .name = "Name",
                    .created_date = "CreatedDate",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instances = "Instances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_managed_policies_in_permission_set: struct {
    action_name: []const u8 = "ListManagedPoliciesInPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_managed_policies_in_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = list_managed_policies_in_permission_set };
        }
    },
    Response: type = struct {
        attached_managed_policies: ?[]struct {
            name: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attached_managed_policies = "AttachedManagedPolicies",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_permission_set_provisioning_status: struct {
    action_name: []const u8 = "ListPermissionSetProvisioningStatus",
    Request: type = struct {
        instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filter: ?OperationStatusFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filter = "Filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permission_set_provisioning_status) } {
            return .{ .service_metadata = service_metadata, .action = list_permission_set_provisioning_status };
        }
    },
    Response: type = struct {
        permission_sets_provisioning_status: ?[]struct {
            status: ?[]const u8 = null,
            request_id: ?[]const u8 = null,
            created_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .status = "Status",
                    .request_id = "RequestId",
                    .created_date = "CreatedDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_sets_provisioning_status = "PermissionSetsProvisioningStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_permission_sets: struct {
    action_name: []const u8 = "ListPermissionSets",
    Request: type = struct {
        instance_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permission_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_permission_sets };
        }
    },
    Response: type = struct {
        permission_sets: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_sets = "PermissionSets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_permission_sets_provisioned_to_account: struct {
    action_name: []const u8 = "ListPermissionSetsProvisionedToAccount",
    Request: type = struct {
        instance_arn: []const u8,
        account_id: []const u8,
        provisioning_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .account_id = "AccountId",
                .provisioning_status = "ProvisioningStatus",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_permission_sets_provisioned_to_account) } {
            return .{ .service_metadata = service_metadata, .action = list_permission_sets_provisioned_to_account };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        permission_sets: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .permission_sets = "PermissionSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        instance_arn: ?[]const u8 = null,
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_trusted_token_issuers: struct {
    action_name: []const u8 = "ListTrustedTokenIssuers",
    Request: type = struct {
        instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_trusted_token_issuers) } {
            return .{ .service_metadata = service_metadata, .action = list_trusted_token_issuers };
        }
    },
    Response: type = struct {
        trusted_token_issuers: ?[]struct {
            trusted_token_issuer_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            trusted_token_issuer_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .trusted_token_issuer_arn = "TrustedTokenIssuerArn",
                    .name = "Name",
                    .trusted_token_issuer_type = "TrustedTokenIssuerType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trusted_token_issuers = "TrustedTokenIssuers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const provision_permission_set: struct {
    action_name: []const u8 = "ProvisionPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        target_id: ?[]const u8 = null,
        target_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .target_id = "TargetId",
                .target_type = "TargetType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(provision_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = provision_permission_set };
        }
    },
    Response: type = struct {
        permission_set_provisioning_status: ?PermissionSetProvisioningStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permission_set_provisioning_status = "PermissionSetProvisioningStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_application_assignment_configuration: struct {
    action_name: []const u8 = "PutApplicationAssignmentConfiguration",
    Request: type = struct {
        application_arn: []const u8,
        assignment_required: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
                .assignment_required = "AssignmentRequired",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_application_assignment_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_application_assignment_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_inline_policy_to_permission_set: struct {
    action_name: []const u8 = "PutInlinePolicyToPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        inline_policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .inline_policy = "InlinePolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_inline_policy_to_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = put_inline_policy_to_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const put_permissions_boundary_to_permission_set: struct {
    action_name: []const u8 = "PutPermissionsBoundaryToPermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        permissions_boundary: PermissionsBoundary,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .permissions_boundary = "PermissionsBoundary",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_permissions_boundary_to_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = put_permissions_boundary_to_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        instance_arn: ?[]const u8 = null,
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        instance_arn: ?[]const u8 = null,
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_application: struct {
    action_name: []const u8 = "UpdateApplication",
    Request: type = struct {
        application_arn: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        portal_options: ?struct {
            sign_in_options: ?SignInOptions = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sign_in_options = "SignInOptions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_arn = "ApplicationArn",
                .name = "Name",
                .description = "Description",
                .status = "Status",
                .portal_options = "PortalOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_application) } {
            return .{ .service_metadata = service_metadata, .action = update_application };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_instance: struct {
    action_name: []const u8 = "UpdateInstance",
    Request: type = struct {
        name: []const u8,
        instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .instance_arn = "InstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_instance) } {
            return .{ .service_metadata = service_metadata, .action = update_instance };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_instance_access_control_attribute_configuration: struct {
    action_name: []const u8 = "UpdateInstanceAccessControlAttributeConfiguration",
    Request: type = struct {
        instance_arn: []const u8,
        instance_access_control_attribute_configuration: InstanceAccessControlAttributeConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .instance_access_control_attribute_configuration = "InstanceAccessControlAttributeConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_instance_access_control_attribute_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_instance_access_control_attribute_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_permission_set: struct {
    action_name: []const u8 = "UpdatePermissionSet",
    Request: type = struct {
        instance_arn: []const u8,
        permission_set_arn: []const u8,
        description: ?[]const u8 = null,
        session_duration: ?[]const u8 = null,
        relay_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "InstanceArn",
                .permission_set_arn = "PermissionSetArn",
                .description = "Description",
                .session_duration = "SessionDuration",
                .relay_state = "RelayState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_permission_set) } {
            return .{ .service_metadata = service_metadata, .action = update_permission_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_trusted_token_issuer: struct {
    action_name: []const u8 = "UpdateTrustedTokenIssuer",
    Request: type = struct {
        trusted_token_issuer_arn: []const u8,
        name: ?[]const u8 = null,
        trusted_token_issuer_configuration: ?union {
            oidc_jwt_configuration: ?struct {
                claim_attribute_path: ?[]const u8 = null,
                identity_store_attribute_path: ?[]const u8 = null,
                jwks_retrieval_option: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .claim_attribute_path = "ClaimAttributePath",
                        .identity_store_attribute_path = "IdentityStoreAttributePath",
                        .jwks_retrieval_option = "JwksRetrievalOption",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .oidc_jwt_configuration = "OidcJwtConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trusted_token_issuer_arn = "TrustedTokenIssuerArn",
                .name = "Name",
                .trusted_token_issuer_configuration = "TrustedTokenIssuerConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_trusted_token_issuer) } {
            return .{ .service_metadata = service_metadata, .action = update_trusted_token_issuer };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const InstanceAccessControlAttributeConfiguration = struct {
    access_control_attributes: []AccessControlAttribute,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_control_attributes = "AccessControlAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessControlAttribute = struct {
    key: []const u8,
    value: AccessControlAttributeValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessControlAttributeValue = struct {
    source: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
        };
        return @field(mappings, field_name);
    }
};

pub const SignInOptions = struct {
    origin: []const u8,
    application_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .origin = "Origin",
            .application_url = "ApplicationUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const PermissionsBoundary = struct {
    customer_managed_policy_reference: ?CustomerManagedPolicyReference = null,
    managed_policy_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_managed_policy_reference = "CustomerManagedPolicyReference",
            .managed_policy_arn = "ManagedPolicyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomerManagedPolicyReference = struct {
    name: []const u8,
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .path = "Path",
        };
        return @field(mappings, field_name);
    }
};

pub const PermissionSetProvisioningStatus = struct {
    status: ?[]const u8 = null,
    request_id: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    permission_set_arn: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    created_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .request_id = "RequestId",
            .account_id = "AccountId",
            .permission_set_arn = "PermissionSetArn",
            .failure_reason = "FailureReason",
            .created_date = "CreatedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const OperationStatusFilter = struct {
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const PortalOptions = struct {
    sign_in_options: ?SignInOptions = null,
    visibility: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sign_in_options = "SignInOptions",
            .visibility = "Visibility",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceServerConfig = struct {
    scopes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ResourceServerScopeDetails = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scopes = "Scopes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "scopes", field_name))
            return try serializeMap(self.scopes, self.fieldNameFor("scopes"), options, out_stream);
        return false;
    }
};

pub const ResourceServerScopeDetails = struct {
    long_description: ?[]const u8 = null,
    detailed_title: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .long_description = "LongDescription",
            .detailed_title = "DetailedTitle",
        };
        return @field(mappings, field_name);
    }
};

pub const DisplayData = struct {
    display_name: ?[]const u8 = null,
    icon_url: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .display_name = "DisplayName",
            .icon_url = "IconUrl",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountAssignmentOperationStatusMetadata = struct {
    status: ?[]const u8 = null,
    request_id: ?[]const u8 = null,
    created_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .request_id = "RequestId",
            .created_date = "CreatedDate",
        };
        return @field(mappings, field_name);
    }
};

pub const TrustedTokenIssuerConfiguration = union {
    oidc_jwt_configuration: ?OidcJwtConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .oidc_jwt_configuration = "OidcJwtConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const OidcJwtConfiguration = struct {
    issuer_url: []const u8,
    claim_attribute_path: []const u8,
    identity_store_attribute_path: []const u8,
    jwks_retrieval_option: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issuer_url = "IssuerUrl",
            .claim_attribute_path = "ClaimAttributePath",
            .identity_store_attribute_path = "IdentityStoreAttributePath",
            .jwks_retrieval_option = "JwksRetrievalOption",
        };
        return @field(mappings, field_name);
    }
};

pub const PermissionSet = struct {
    name: ?[]const u8 = null,
    permission_set_arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_date: ?i64 = null,
    session_duration: ?[]const u8 = null,
    relay_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .permission_set_arn = "PermissionSetArn",
            .description = "Description",
            .created_date = "CreatedDate",
            .session_duration = "SessionDuration",
            .relay_state = "RelayState",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountAssignmentOperationStatus = struct {
    status: ?[]const u8 = null,
    request_id: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    target_id: ?[]const u8 = null,
    target_type: ?[]const u8 = null,
    permission_set_arn: ?[]const u8 = null,
    principal_type: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,
    created_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .request_id = "RequestId",
            .failure_reason = "FailureReason",
            .target_id = "TargetId",
            .target_type = "TargetType",
            .permission_set_arn = "PermissionSetArn",
            .principal_type = "PrincipalType",
            .principal_id = "PrincipalId",
            .created_date = "CreatedDate",
        };
        return @field(mappings, field_name);
    }
};
