const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-06-10";
pub const sdk_id: []const u8 = "SSO OIDC";
pub const arn_namespace: ?[]const u8 = "sso-oauth";
pub const endpoint_prefix: []const u8 = "oidc";
pub const sigv4_name: []const u8 = "sso-oauth";
pub const name: []const u8 = "AWSSSOOIDCService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-06-10",
    sdk_id: []const u8 = "SSO OIDC",
    arn_namespace: ?[]const u8 = "sso-oauth",
    endpoint_prefix: []const u8 = "oidc",
    sigv4_name: []const u8 = "sso-oauth",
    name: []const u8 = "AWSSSOOIDCService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/token",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateToken",
    Request: type = struct {
        client_id: []const u8,
        client_secret: []const u8,
        grant_type: []const u8,
        device_code: ?[]const u8 = null,
        code: ?[]const u8 = null,
        refresh_token: ?[]const u8 = null,
        scope: ?[][]const u8 = null,
        redirect_uri: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_id = "clientId",
                .client_secret = "clientSecret",
                .grant_type = "grantType",
                .device_code = "deviceCode",
                .code = "code",
                .refresh_token = "refreshToken",
                .scope = "scope",
                .redirect_uri = "redirectUri",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_token) } {
            return .{ .service_metadata = service_metadata, .action = create_token };
        }
    },
    Response: type = struct {
        access_token: ?[]const u8 = null,
        token_type: ?[]const u8 = null,
        expires_in: ?i64 = null,
        refresh_token: ?[]const u8 = null,
        id_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "accessToken",
                .token_type = "tokenType",
                .expires_in = "expiresIn",
                .refresh_token = "refreshToken",
                .id_token = "idToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AuthorizationPending,
        ExpiredToken,
        InternalServer,
        InvalidClient,
        InvalidGrant,
        InvalidRequest,
        InvalidScope,
        SlowDown,
        UnauthorizedClient,
        UnsupportedGrantType,
    },
} = .{};
pub const create_token_with_iam: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/token?aws_iam=t",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTokenWithIAM",
    Request: type = struct {
        client_id: []const u8,
        grant_type: []const u8,
        code: ?[]const u8 = null,
        refresh_token: ?[]const u8 = null,
        assertion: ?[]const u8 = null,
        scope: ?[][]const u8 = null,
        redirect_uri: ?[]const u8 = null,
        subject_token: ?[]const u8 = null,
        subject_token_type: ?[]const u8 = null,
        requested_token_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_id = "clientId",
                .grant_type = "grantType",
                .code = "code",
                .refresh_token = "refreshToken",
                .assertion = "assertion",
                .scope = "scope",
                .redirect_uri = "redirectUri",
                .subject_token = "subjectToken",
                .subject_token_type = "subjectTokenType",
                .requested_token_type = "requestedTokenType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_token_with_iam) } {
            return .{ .service_metadata = service_metadata, .action = create_token_with_iam };
        }
    },
    Response: type = struct {
        access_token: ?[]const u8 = null,
        token_type: ?[]const u8 = null,
        expires_in: ?i64 = null,
        refresh_token: ?[]const u8 = null,
        id_token: ?[]const u8 = null,
        issued_token_type: ?[]const u8 = null,
        scope: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_token = "accessToken",
                .token_type = "tokenType",
                .expires_in = "expiresIn",
                .refresh_token = "refreshToken",
                .id_token = "idToken",
                .issued_token_type = "issuedTokenType",
                .scope = "scope",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AuthorizationPending,
        ExpiredToken,
        InternalServer,
        InvalidClient,
        InvalidGrant,
        InvalidRequest,
        InvalidRequestRegion,
        InvalidScope,
        SlowDown,
        UnauthorizedClient,
        UnsupportedGrantType,
    },
} = .{};
pub const register_client: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/client/register",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterClient",
    Request: type = struct {
        client_name: []const u8,
        client_type: []const u8,
        scopes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_name = "clientName",
                .client_type = "clientType",
                .scopes = "scopes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_client) } {
            return .{ .service_metadata = service_metadata, .action = register_client };
        }
    },
    Response: type = struct {
        client_id: ?[]const u8 = null,
        client_secret: ?[]const u8 = null,
        client_id_issued_at: ?i64 = null,
        client_secret_expires_at: ?i64 = null,
        authorization_endpoint: ?[]const u8 = null,
        token_endpoint: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_id = "clientId",
                .client_secret = "clientSecret",
                .client_id_issued_at = "clientIdIssuedAt",
                .client_secret_expires_at = "clientSecretExpiresAt",
                .authorization_endpoint = "authorizationEndpoint",
                .token_endpoint = "tokenEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidClientMetadata,
        InvalidRequest,
        InvalidScope,
    },
} = .{};
pub const start_device_authorization: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/device_authorization",
        .success_code = 200,
    };

    action_name: []const u8 = "StartDeviceAuthorization",
    Request: type = struct {
        client_id: []const u8,
        client_secret: []const u8,
        start_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_id = "clientId",
                .client_secret = "clientSecret",
                .start_url = "startUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_device_authorization) } {
            return .{ .service_metadata = service_metadata, .action = start_device_authorization };
        }
    },
    Response: type = struct {
        device_code: ?[]const u8 = null,
        user_code: ?[]const u8 = null,
        verification_uri: ?[]const u8 = null,
        verification_uri_complete: ?[]const u8 = null,
        expires_in: ?i64 = null,
        interval: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_code = "deviceCode",
                .user_code = "userCode",
                .verification_uri = "verificationUri",
                .verification_uri_complete = "verificationUriComplete",
                .expires_in = "expiresIn",
                .interval = "interval",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidClient,
        InvalidRequest,
        SlowDown,
        UnauthorizedClient,
    },
} = .{};
