const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2013-06-30";
pub const sdk_id: []const u8 = "Storage Gateway";
pub const arn_namespace: ?[]const u8 = "storagegateway";
pub const endpoint_prefix: []const u8 = "storagegateway";
pub const sigv4_name: []const u8 = "storagegateway";
pub const name: []const u8 = "StorageGateway_20130630";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2013-06-30",
    sdk_id: []const u8 = "Storage Gateway",
    arn_namespace: ?[]const u8 = "storagegateway",
    endpoint_prefix: []const u8 = "storagegateway",
    sigv4_name: []const u8 = "storagegateway",
    name: []const u8 = "StorageGateway_20130630",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const activate_gateway: struct {
    action_name: []const u8 = "ActivateGateway",
    Request: type = struct {
        activation_key: []const u8,
        gateway_name: []const u8,
        gateway_timezone: []const u8,
        gateway_region: []const u8,
        gateway_type: ?[]const u8 = null,
        tape_drive_type: ?[]const u8 = null,
        medium_changer_type: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activation_key = "ActivationKey",
                .gateway_name = "GatewayName",
                .gateway_timezone = "GatewayTimezone",
                .gateway_region = "GatewayRegion",
                .gateway_type = "GatewayType",
                .tape_drive_type = "TapeDriveType",
                .medium_changer_type = "MediumChangerType",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(activate_gateway) } {
            return .{ .service_metadata = service_metadata, .action = activate_gateway };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const add_cache: struct {
    action_name: []const u8 = "AddCache",
    Request: type = struct {
        gateway_arn: []const u8,
        disk_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .disk_ids = "DiskIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_cache) } {
            return .{ .service_metadata = service_metadata, .action = add_cache };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const add_tags_to_resource: struct {
    action_name: []const u8 = "AddTagsToResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_resource };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const add_upload_buffer: struct {
    action_name: []const u8 = "AddUploadBuffer",
    Request: type = struct {
        gateway_arn: []const u8,
        disk_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .disk_ids = "DiskIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_upload_buffer) } {
            return .{ .service_metadata = service_metadata, .action = add_upload_buffer };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const add_working_storage: struct {
    action_name: []const u8 = "AddWorkingStorage",
    Request: type = struct {
        gateway_arn: []const u8,
        disk_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .disk_ids = "DiskIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_working_storage) } {
            return .{ .service_metadata = service_metadata, .action = add_working_storage };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const assign_tape_pool: struct {
    action_name: []const u8 = "AssignTapePool",
    Request: type = struct {
        tape_arn: []const u8,
        pool_id: []const u8,
        bypass_governance_retention: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
                .pool_id = "PoolId",
                .bypass_governance_retention = "BypassGovernanceRetention",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(assign_tape_pool) } {
            return .{ .service_metadata = service_metadata, .action = assign_tape_pool };
        }
    },
    Response: type = struct {
        tape_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const associate_file_system: struct {
    action_name: []const u8 = "AssociateFileSystem",
    Request: type = struct {
        user_name: []const u8,
        password: []const u8,
        client_token: []const u8,
        gateway_arn: []const u8,
        location_arn: []const u8,
        tags: ?[]Tag = null,
        audit_destination_arn: ?[]const u8 = null,
        cache_attributes: ?CacheAttributes = null,
        endpoint_network_configuration: ?EndpointNetworkConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .password = "Password",
                .client_token = "ClientToken",
                .gateway_arn = "GatewayARN",
                .location_arn = "LocationARN",
                .tags = "Tags",
                .audit_destination_arn = "AuditDestinationARN",
                .cache_attributes = "CacheAttributes",
                .endpoint_network_configuration = "EndpointNetworkConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_file_system) } {
            return .{ .service_metadata = service_metadata, .action = associate_file_system };
        }
    },
    Response: type = struct {
        file_system_association_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_association_arn = "FileSystemAssociationARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const attach_volume: struct {
    action_name: []const u8 = "AttachVolume",
    Request: type = struct {
        gateway_arn: []const u8,
        target_name: ?[]const u8 = null,
        volume_arn: []const u8,
        network_interface_id: []const u8,
        disk_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .target_name = "TargetName",
                .volume_arn = "VolumeARN",
                .network_interface_id = "NetworkInterfaceId",
                .disk_id = "DiskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(attach_volume) } {
            return .{ .service_metadata = service_metadata, .action = attach_volume };
        }
    },
    Response: type = struct {
        volume_arn: ?[]const u8 = null,
        target_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
                .target_arn = "TargetARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const cancel_archival: struct {
    action_name: []const u8 = "CancelArchival",
    Request: type = struct {
        gateway_arn: []const u8,
        tape_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .tape_arn = "TapeARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_archival) } {
            return .{ .service_metadata = service_metadata, .action = cancel_archival };
        }
    },
    Response: type = struct {
        tape_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const cancel_retrieval: struct {
    action_name: []const u8 = "CancelRetrieval",
    Request: type = struct {
        gateway_arn: []const u8,
        tape_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .tape_arn = "TapeARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_retrieval) } {
            return .{ .service_metadata = service_metadata, .action = cancel_retrieval };
        }
    },
    Response: type = struct {
        tape_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const create_cachedi_scsi_volume: struct {
    action_name: []const u8 = "CreateCachediSCSIVolume",
    Request: type = struct {
        gateway_arn: []const u8,
        volume_size_in_bytes: i64,
        snapshot_id: ?[]const u8 = null,
        target_name: []const u8,
        source_volume_arn: ?[]const u8 = null,
        network_interface_id: []const u8,
        client_token: []const u8,
        kms_encrypted: ?bool = null,
        kms_key: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .volume_size_in_bytes = "VolumeSizeInBytes",
                .snapshot_id = "SnapshotId",
                .target_name = "TargetName",
                .source_volume_arn = "SourceVolumeARN",
                .network_interface_id = "NetworkInterfaceId",
                .client_token = "ClientToken",
                .kms_encrypted = "KMSEncrypted",
                .kms_key = "KMSKey",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cachedi_scsi_volume) } {
            return .{ .service_metadata = service_metadata, .action = create_cachedi_scsi_volume };
        }
    },
    Response: type = struct {
        volume_arn: ?[]const u8 = null,
        target_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
                .target_arn = "TargetARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const create_nfs_file_share: struct {
    action_name: []const u8 = "CreateNFSFileShare",
    Request: type = struct {
        client_token: []const u8,
        nfs_file_share_defaults: ?NFSFileShareDefaults = null,
        gateway_arn: []const u8,
        kms_encrypted: ?bool = null,
        kms_key: ?[]const u8 = null,
        role: []const u8,
        location_arn: []const u8,
        default_storage_class: ?[]const u8 = null,
        object_acl: ?[]const u8 = null,
        client_list: ?[][]const u8 = null,
        squash: ?[]const u8 = null,
        read_only: ?bool = null,
        guess_mime_type_enabled: ?bool = null,
        requester_pays: ?bool = null,
        tags: ?[]Tag = null,
        file_share_name: ?[]const u8 = null,
        cache_attributes: ?CacheAttributes = null,
        notification_policy: ?[]const u8 = null,
        vpc_endpoint_dns_name: ?[]const u8 = null,
        bucket_region: ?[]const u8 = null,
        audit_destination_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .nfs_file_share_defaults = "NFSFileShareDefaults",
                .gateway_arn = "GatewayARN",
                .kms_encrypted = "KMSEncrypted",
                .kms_key = "KMSKey",
                .role = "Role",
                .location_arn = "LocationARN",
                .default_storage_class = "DefaultStorageClass",
                .object_acl = "ObjectACL",
                .client_list = "ClientList",
                .squash = "Squash",
                .read_only = "ReadOnly",
                .guess_mime_type_enabled = "GuessMIMETypeEnabled",
                .requester_pays = "RequesterPays",
                .tags = "Tags",
                .file_share_name = "FileShareName",
                .cache_attributes = "CacheAttributes",
                .notification_policy = "NotificationPolicy",
                .vpc_endpoint_dns_name = "VPCEndpointDNSName",
                .bucket_region = "BucketRegion",
                .audit_destination_arn = "AuditDestinationARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_nfs_file_share) } {
            return .{ .service_metadata = service_metadata, .action = create_nfs_file_share };
        }
    },
    Response: type = struct {
        file_share_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const create_smb_file_share: struct {
    action_name: []const u8 = "CreateSMBFileShare",
    Request: type = struct {
        client_token: []const u8,
        gateway_arn: []const u8,
        kms_encrypted: ?bool = null,
        kms_key: ?[]const u8 = null,
        role: []const u8,
        location_arn: []const u8,
        default_storage_class: ?[]const u8 = null,
        object_acl: ?[]const u8 = null,
        read_only: ?bool = null,
        guess_mime_type_enabled: ?bool = null,
        requester_pays: ?bool = null,
        smbacl_enabled: ?bool = null,
        access_based_enumeration: ?bool = null,
        admin_user_list: ?[][]const u8 = null,
        valid_user_list: ?[][]const u8 = null,
        invalid_user_list: ?[][]const u8 = null,
        audit_destination_arn: ?[]const u8 = null,
        authentication: ?[]const u8 = null,
        case_sensitivity: ?[]const u8 = null,
        tags: ?[]Tag = null,
        file_share_name: ?[]const u8 = null,
        cache_attributes: ?CacheAttributes = null,
        notification_policy: ?[]const u8 = null,
        vpc_endpoint_dns_name: ?[]const u8 = null,
        bucket_region: ?[]const u8 = null,
        oplocks_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .gateway_arn = "GatewayARN",
                .kms_encrypted = "KMSEncrypted",
                .kms_key = "KMSKey",
                .role = "Role",
                .location_arn = "LocationARN",
                .default_storage_class = "DefaultStorageClass",
                .object_acl = "ObjectACL",
                .read_only = "ReadOnly",
                .guess_mime_type_enabled = "GuessMIMETypeEnabled",
                .requester_pays = "RequesterPays",
                .smbacl_enabled = "SMBACLEnabled",
                .access_based_enumeration = "AccessBasedEnumeration",
                .admin_user_list = "AdminUserList",
                .valid_user_list = "ValidUserList",
                .invalid_user_list = "InvalidUserList",
                .audit_destination_arn = "AuditDestinationARN",
                .authentication = "Authentication",
                .case_sensitivity = "CaseSensitivity",
                .tags = "Tags",
                .file_share_name = "FileShareName",
                .cache_attributes = "CacheAttributes",
                .notification_policy = "NotificationPolicy",
                .vpc_endpoint_dns_name = "VPCEndpointDNSName",
                .bucket_region = "BucketRegion",
                .oplocks_enabled = "OplocksEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_smb_file_share) } {
            return .{ .service_metadata = service_metadata, .action = create_smb_file_share };
        }
    },
    Response: type = struct {
        file_share_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const create_snapshot: struct {
    action_name: []const u8 = "CreateSnapshot",
    Request: type = struct {
        volume_arn: []const u8,
        snapshot_description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
                .snapshot_description = "SnapshotDescription",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_snapshot) } {
            return .{ .service_metadata = service_metadata, .action = create_snapshot };
        }
    },
    Response: type = struct {
        volume_arn: ?[]const u8 = null,
        snapshot_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
                .snapshot_id = "SnapshotId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
        ServiceUnavailableError,
    },
} = .{};
pub const create_snapshot_from_volume_recovery_point: struct {
    action_name: []const u8 = "CreateSnapshotFromVolumeRecoveryPoint",
    Request: type = struct {
        volume_arn: []const u8,
        snapshot_description: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
                .snapshot_description = "SnapshotDescription",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_snapshot_from_volume_recovery_point) } {
            return .{ .service_metadata = service_metadata, .action = create_snapshot_from_volume_recovery_point };
        }
    },
    Response: type = struct {
        snapshot_id: ?[]const u8 = null,
        volume_arn: ?[]const u8 = null,
        volume_recovery_point_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .snapshot_id = "SnapshotId",
                .volume_arn = "VolumeARN",
                .volume_recovery_point_time = "VolumeRecoveryPointTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
        ServiceUnavailableError,
    },
} = .{};
pub const create_storedi_scsi_volume: struct {
    action_name: []const u8 = "CreateStorediSCSIVolume",
    Request: type = struct {
        gateway_arn: []const u8,
        disk_id: []const u8,
        snapshot_id: ?[]const u8 = null,
        preserve_existing_data: bool,
        target_name: []const u8,
        network_interface_id: []const u8,
        kms_encrypted: ?bool = null,
        kms_key: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .disk_id = "DiskId",
                .snapshot_id = "SnapshotId",
                .preserve_existing_data = "PreserveExistingData",
                .target_name = "TargetName",
                .network_interface_id = "NetworkInterfaceId",
                .kms_encrypted = "KMSEncrypted",
                .kms_key = "KMSKey",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_storedi_scsi_volume) } {
            return .{ .service_metadata = service_metadata, .action = create_storedi_scsi_volume };
        }
    },
    Response: type = struct {
        volume_arn: ?[]const u8 = null,
        volume_size_in_bytes: ?i64 = null,
        target_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
                .volume_size_in_bytes = "VolumeSizeInBytes",
                .target_arn = "TargetARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const create_tape_pool: struct {
    action_name: []const u8 = "CreateTapePool",
    Request: type = struct {
        pool_name: []const u8,
        storage_class: []const u8,
        retention_lock_type: ?[]const u8 = null,
        retention_lock_time_in_days: ?i64 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_name = "PoolName",
                .storage_class = "StorageClass",
                .retention_lock_type = "RetentionLockType",
                .retention_lock_time_in_days = "RetentionLockTimeInDays",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tape_pool) } {
            return .{ .service_metadata = service_metadata, .action = create_tape_pool };
        }
    },
    Response: type = struct {
        pool_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_arn = "PoolARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const create_tapes: struct {
    action_name: []const u8 = "CreateTapes",
    Request: type = struct {
        gateway_arn: []const u8,
        tape_size_in_bytes: i64,
        client_token: []const u8,
        num_tapes_to_create: i64,
        tape_barcode_prefix: []const u8,
        kms_encrypted: ?bool = null,
        kms_key: ?[]const u8 = null,
        pool_id: ?[]const u8 = null,
        worm: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .tape_size_in_bytes = "TapeSizeInBytes",
                .client_token = "ClientToken",
                .num_tapes_to_create = "NumTapesToCreate",
                .tape_barcode_prefix = "TapeBarcodePrefix",
                .kms_encrypted = "KMSEncrypted",
                .kms_key = "KMSKey",
                .pool_id = "PoolId",
                .worm = "Worm",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tapes) } {
            return .{ .service_metadata = service_metadata, .action = create_tapes };
        }
    },
    Response: type = struct {
        tape_ar_ns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_ar_ns = "TapeARNs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const create_tape_with_barcode: struct {
    action_name: []const u8 = "CreateTapeWithBarcode",
    Request: type = struct {
        gateway_arn: []const u8,
        tape_size_in_bytes: i64,
        tape_barcode: []const u8,
        kms_encrypted: ?bool = null,
        kms_key: ?[]const u8 = null,
        pool_id: ?[]const u8 = null,
        worm: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .tape_size_in_bytes = "TapeSizeInBytes",
                .tape_barcode = "TapeBarcode",
                .kms_encrypted = "KMSEncrypted",
                .kms_key = "KMSKey",
                .pool_id = "PoolId",
                .worm = "Worm",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tape_with_barcode) } {
            return .{ .service_metadata = service_metadata, .action = create_tape_with_barcode };
        }
    },
    Response: type = struct {
        tape_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const delete_automatic_tape_creation_policy: struct {
    action_name: []const u8 = "DeleteAutomaticTapeCreationPolicy",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_automatic_tape_creation_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_automatic_tape_creation_policy };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const delete_bandwidth_rate_limit: struct {
    action_name: []const u8 = "DeleteBandwidthRateLimit",
    Request: type = struct {
        gateway_arn: []const u8,
        bandwidth_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .bandwidth_type = "BandwidthType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bandwidth_rate_limit) } {
            return .{ .service_metadata = service_metadata, .action = delete_bandwidth_rate_limit };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const delete_chap_credentials: struct {
    action_name: []const u8 = "DeleteChapCredentials",
    Request: type = struct {
        target_arn: []const u8,
        initiator_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "TargetARN",
                .initiator_name = "InitiatorName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_chap_credentials) } {
            return .{ .service_metadata = service_metadata, .action = delete_chap_credentials };
        }
    },
    Response: type = struct {
        target_arn: ?[]const u8 = null,
        initiator_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "TargetARN",
                .initiator_name = "InitiatorName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const delete_file_share: struct {
    action_name: []const u8 = "DeleteFileShare",
    Request: type = struct {
        file_share_arn: []const u8,
        force_delete: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
                .force_delete = "ForceDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_file_share) } {
            return .{ .service_metadata = service_metadata, .action = delete_file_share };
        }
    },
    Response: type = struct {
        file_share_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const delete_gateway: struct {
    action_name: []const u8 = "DeleteGateway",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_gateway };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const delete_snapshot_schedule: struct {
    action_name: []const u8 = "DeleteSnapshotSchedule",
    Request: type = struct {
        volume_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_snapshot_schedule) } {
            return .{ .service_metadata = service_metadata, .action = delete_snapshot_schedule };
        }
    },
    Response: type = struct {
        volume_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const delete_tape: struct {
    action_name: []const u8 = "DeleteTape",
    Request: type = struct {
        gateway_arn: []const u8,
        tape_arn: []const u8,
        bypass_governance_retention: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .tape_arn = "TapeARN",
                .bypass_governance_retention = "BypassGovernanceRetention",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tape) } {
            return .{ .service_metadata = service_metadata, .action = delete_tape };
        }
    },
    Response: type = struct {
        tape_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const delete_tape_archive: struct {
    action_name: []const u8 = "DeleteTapeArchive",
    Request: type = struct {
        tape_arn: []const u8,
        bypass_governance_retention: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
                .bypass_governance_retention = "BypassGovernanceRetention",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tape_archive) } {
            return .{ .service_metadata = service_metadata, .action = delete_tape_archive };
        }
    },
    Response: type = struct {
        tape_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const delete_tape_pool: struct {
    action_name: []const u8 = "DeleteTapePool",
    Request: type = struct {
        pool_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_arn = "PoolARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tape_pool) } {
            return .{ .service_metadata = service_metadata, .action = delete_tape_pool };
        }
    },
    Response: type = struct {
        pool_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_arn = "PoolARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const delete_volume: struct {
    action_name: []const u8 = "DeleteVolume",
    Request: type = struct {
        volume_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_volume) } {
            return .{ .service_metadata = service_metadata, .action = delete_volume };
        }
    },
    Response: type = struct {
        volume_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_availability_monitor_test: struct {
    action_name: []const u8 = "DescribeAvailabilityMonitorTest",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_availability_monitor_test) } {
            return .{ .service_metadata = service_metadata, .action = describe_availability_monitor_test };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        start_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .status = "Status",
                .start_time = "StartTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_bandwidth_rate_limit: struct {
    action_name: []const u8 = "DescribeBandwidthRateLimit",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bandwidth_rate_limit) } {
            return .{ .service_metadata = service_metadata, .action = describe_bandwidth_rate_limit };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        average_upload_rate_limit_in_bits_per_sec: ?i64 = null,
        average_download_rate_limit_in_bits_per_sec: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .average_upload_rate_limit_in_bits_per_sec = "AverageUploadRateLimitInBitsPerSec",
                .average_download_rate_limit_in_bits_per_sec = "AverageDownloadRateLimitInBitsPerSec",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_bandwidth_rate_limit_schedule: struct {
    action_name: []const u8 = "DescribeBandwidthRateLimitSchedule",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bandwidth_rate_limit_schedule) } {
            return .{ .service_metadata = service_metadata, .action = describe_bandwidth_rate_limit_schedule };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        bandwidth_rate_limit_intervals: ?[]BandwidthRateLimitInterval = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .bandwidth_rate_limit_intervals = "BandwidthRateLimitIntervals",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_cache: struct {
    action_name: []const u8 = "DescribeCache",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cache) } {
            return .{ .service_metadata = service_metadata, .action = describe_cache };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        disk_ids: ?[][]const u8 = null,
        cache_allocated_in_bytes: ?i64 = null,
        cache_used_percentage: ?f64 = null,
        cache_dirty_percentage: ?f64 = null,
        cache_hit_percentage: ?f64 = null,
        cache_miss_percentage: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .disk_ids = "DiskIds",
                .cache_allocated_in_bytes = "CacheAllocatedInBytes",
                .cache_used_percentage = "CacheUsedPercentage",
                .cache_dirty_percentage = "CacheDirtyPercentage",
                .cache_hit_percentage = "CacheHitPercentage",
                .cache_miss_percentage = "CacheMissPercentage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_cachedi_scsi_volumes: struct {
    action_name: []const u8 = "DescribeCachediSCSIVolumes",
    Request: type = struct {
        volume_ar_ns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_ar_ns = "VolumeARNs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cachedi_scsi_volumes) } {
            return .{ .service_metadata = service_metadata, .action = describe_cachedi_scsi_volumes };
        }
    },
    Response: type = struct {
        cachedi_scsi_volumes: ?[]struct {
            volume_arn: ?[]const u8 = null,
            volume_id: ?[]const u8 = null,
            volume_type: ?[]const u8 = null,
            volume_status: ?[]const u8 = null,
            volume_attachment_status: ?[]const u8 = null,
            volume_size_in_bytes: ?i64 = null,
            volume_progress: ?f64 = null,
            source_snapshot_id: ?[]const u8 = null,
            volumei_scsi_attributes: ?VolumeiSCSIAttributes = null,
            created_date: ?i64 = null,
            volume_used_in_bytes: ?i64 = null,
            kms_key: ?[]const u8 = null,
            target_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .volume_arn = "VolumeARN",
                    .volume_id = "VolumeId",
                    .volume_type = "VolumeType",
                    .volume_status = "VolumeStatus",
                    .volume_attachment_status = "VolumeAttachmentStatus",
                    .volume_size_in_bytes = "VolumeSizeInBytes",
                    .volume_progress = "VolumeProgress",
                    .source_snapshot_id = "SourceSnapshotId",
                    .volumei_scsi_attributes = "VolumeiSCSIAttributes",
                    .created_date = "CreatedDate",
                    .volume_used_in_bytes = "VolumeUsedInBytes",
                    .kms_key = "KMSKey",
                    .target_name = "TargetName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cachedi_scsi_volumes = "CachediSCSIVolumes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_chap_credentials: struct {
    action_name: []const u8 = "DescribeChapCredentials",
    Request: type = struct {
        target_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "TargetARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_chap_credentials) } {
            return .{ .service_metadata = service_metadata, .action = describe_chap_credentials };
        }
    },
    Response: type = struct {
        chap_credentials: ?[]struct {
            target_arn: ?[]const u8 = null,
            secret_to_authenticate_initiator: ?[]const u8 = null,
            initiator_name: ?[]const u8 = null,
            secret_to_authenticate_target: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .target_arn = "TargetARN",
                    .secret_to_authenticate_initiator = "SecretToAuthenticateInitiator",
                    .initiator_name = "InitiatorName",
                    .secret_to_authenticate_target = "SecretToAuthenticateTarget",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .chap_credentials = "ChapCredentials",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_file_system_associations: struct {
    action_name: []const u8 = "DescribeFileSystemAssociations",
    Request: type = struct {
        file_system_association_arn_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_association_arn_list = "FileSystemAssociationARNList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_file_system_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_file_system_associations };
        }
    },
    Response: type = struct {
        file_system_association_info_list: ?[]struct {
            file_system_association_arn: ?[]const u8 = null,
            location_arn: ?[]const u8 = null,
            file_system_association_status: ?[]const u8 = null,
            audit_destination_arn: ?[]const u8 = null,
            gateway_arn: ?[]const u8 = null,
            tags: ?[]Tag = null,
            cache_attributes: ?CacheAttributes = null,
            endpoint_network_configuration: ?EndpointNetworkConfiguration = null,
            file_system_association_status_details: ?[]struct {
                error_code: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "ErrorCode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .file_system_association_arn = "FileSystemAssociationARN",
                    .location_arn = "LocationARN",
                    .file_system_association_status = "FileSystemAssociationStatus",
                    .audit_destination_arn = "AuditDestinationARN",
                    .gateway_arn = "GatewayARN",
                    .tags = "Tags",
                    .cache_attributes = "CacheAttributes",
                    .endpoint_network_configuration = "EndpointNetworkConfiguration",
                    .file_system_association_status_details = "FileSystemAssociationStatusDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_association_info_list = "FileSystemAssociationInfoList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_gateway_information: struct {
    action_name: []const u8 = "DescribeGatewayInformation",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_gateway_information) } {
            return .{ .service_metadata = service_metadata, .action = describe_gateway_information };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        gateway_id: ?[]const u8 = null,
        gateway_name: ?[]const u8 = null,
        gateway_timezone: ?[]const u8 = null,
        gateway_state: ?[]const u8 = null,
        gateway_network_interfaces: ?[]struct {
            ipv4_address: ?[]const u8 = null,
            mac_address: ?[]const u8 = null,
            ipv6_address: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ipv4_address = "Ipv4Address",
                    .mac_address = "MacAddress",
                    .ipv6_address = "Ipv6Address",
                };
                return @field(mappings, field_name);
            }
        } = null,
        gateway_type: ?[]const u8 = null,
        next_update_availability_date: ?[]const u8 = null,
        last_software_update: ?[]const u8 = null,
        ec2_instance_id: ?[]const u8 = null,
        ec2_instance_region: ?[]const u8 = null,
        tags: ?[]Tag = null,
        vpc_endpoint: ?[]const u8 = null,
        cloud_watch_log_group_arn: ?[]const u8 = null,
        host_environment: ?[]const u8 = null,
        endpoint_type: ?[]const u8 = null,
        software_updates_end_date: ?[]const u8 = null,
        deprecation_date: ?[]const u8 = null,
        gateway_capacity: ?[]const u8 = null,
        supported_gateway_capacities: ?[][]const u8 = null,
        host_environment_id: ?[]const u8 = null,
        software_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .gateway_id = "GatewayId",
                .gateway_name = "GatewayName",
                .gateway_timezone = "GatewayTimezone",
                .gateway_state = "GatewayState",
                .gateway_network_interfaces = "GatewayNetworkInterfaces",
                .gateway_type = "GatewayType",
                .next_update_availability_date = "NextUpdateAvailabilityDate",
                .last_software_update = "LastSoftwareUpdate",
                .ec2_instance_id = "Ec2InstanceId",
                .ec2_instance_region = "Ec2InstanceRegion",
                .tags = "Tags",
                .vpc_endpoint = "VPCEndpoint",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupARN",
                .host_environment = "HostEnvironment",
                .endpoint_type = "EndpointType",
                .software_updates_end_date = "SoftwareUpdatesEndDate",
                .deprecation_date = "DeprecationDate",
                .gateway_capacity = "GatewayCapacity",
                .supported_gateway_capacities = "SupportedGatewayCapacities",
                .host_environment_id = "HostEnvironmentId",
                .software_version = "SoftwareVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_maintenance_start_time: struct {
    action_name: []const u8 = "DescribeMaintenanceStartTime",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_maintenance_start_time) } {
            return .{ .service_metadata = service_metadata, .action = describe_maintenance_start_time };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        hour_of_day: ?i64 = null,
        minute_of_hour: ?i64 = null,
        day_of_week: ?i64 = null,
        day_of_month: ?i64 = null,
        timezone: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .hour_of_day = "HourOfDay",
                .minute_of_hour = "MinuteOfHour",
                .day_of_week = "DayOfWeek",
                .day_of_month = "DayOfMonth",
                .timezone = "Timezone",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_nfs_file_shares: struct {
    action_name: []const u8 = "DescribeNFSFileShares",
    Request: type = struct {
        file_share_arn_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn_list = "FileShareARNList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_nfs_file_shares) } {
            return .{ .service_metadata = service_metadata, .action = describe_nfs_file_shares };
        }
    },
    Response: type = struct {
        nfs_file_share_info_list: ?[]struct {
            nfs_file_share_defaults: ?NFSFileShareDefaults = null,
            file_share_arn: ?[]const u8 = null,
            file_share_id: ?[]const u8 = null,
            file_share_status: ?[]const u8 = null,
            gateway_arn: ?[]const u8 = null,
            kms_encrypted: ?bool = null,
            kms_key: ?[]const u8 = null,
            path: ?[]const u8 = null,
            role: ?[]const u8 = null,
            location_arn: ?[]const u8 = null,
            default_storage_class: ?[]const u8 = null,
            object_acl: ?[]const u8 = null,
            client_list: ?[][]const u8 = null,
            squash: ?[]const u8 = null,
            read_only: ?bool = null,
            guess_mime_type_enabled: ?bool = null,
            requester_pays: ?bool = null,
            tags: ?[]Tag = null,
            file_share_name: ?[]const u8 = null,
            cache_attributes: ?CacheAttributes = null,
            notification_policy: ?[]const u8 = null,
            vpc_endpoint_dns_name: ?[]const u8 = null,
            bucket_region: ?[]const u8 = null,
            audit_destination_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .nfs_file_share_defaults = "NFSFileShareDefaults",
                    .file_share_arn = "FileShareARN",
                    .file_share_id = "FileShareId",
                    .file_share_status = "FileShareStatus",
                    .gateway_arn = "GatewayARN",
                    .kms_encrypted = "KMSEncrypted",
                    .kms_key = "KMSKey",
                    .path = "Path",
                    .role = "Role",
                    .location_arn = "LocationARN",
                    .default_storage_class = "DefaultStorageClass",
                    .object_acl = "ObjectACL",
                    .client_list = "ClientList",
                    .squash = "Squash",
                    .read_only = "ReadOnly",
                    .guess_mime_type_enabled = "GuessMIMETypeEnabled",
                    .requester_pays = "RequesterPays",
                    .tags = "Tags",
                    .file_share_name = "FileShareName",
                    .cache_attributes = "CacheAttributes",
                    .notification_policy = "NotificationPolicy",
                    .vpc_endpoint_dns_name = "VPCEndpointDNSName",
                    .bucket_region = "BucketRegion",
                    .audit_destination_arn = "AuditDestinationARN",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nfs_file_share_info_list = "NFSFileShareInfoList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_smb_file_shares: struct {
    action_name: []const u8 = "DescribeSMBFileShares",
    Request: type = struct {
        file_share_arn_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn_list = "FileShareARNList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_smb_file_shares) } {
            return .{ .service_metadata = service_metadata, .action = describe_smb_file_shares };
        }
    },
    Response: type = struct {
        smb_file_share_info_list: ?[]struct {
            file_share_arn: ?[]const u8 = null,
            file_share_id: ?[]const u8 = null,
            file_share_status: ?[]const u8 = null,
            gateway_arn: ?[]const u8 = null,
            kms_encrypted: ?bool = null,
            kms_key: ?[]const u8 = null,
            path: ?[]const u8 = null,
            role: ?[]const u8 = null,
            location_arn: ?[]const u8 = null,
            default_storage_class: ?[]const u8 = null,
            object_acl: ?[]const u8 = null,
            read_only: ?bool = null,
            guess_mime_type_enabled: ?bool = null,
            requester_pays: ?bool = null,
            smbacl_enabled: ?bool = null,
            access_based_enumeration: ?bool = null,
            admin_user_list: ?[][]const u8 = null,
            valid_user_list: ?[][]const u8 = null,
            invalid_user_list: ?[][]const u8 = null,
            audit_destination_arn: ?[]const u8 = null,
            authentication: ?[]const u8 = null,
            case_sensitivity: ?[]const u8 = null,
            tags: ?[]Tag = null,
            file_share_name: ?[]const u8 = null,
            cache_attributes: ?CacheAttributes = null,
            notification_policy: ?[]const u8 = null,
            vpc_endpoint_dns_name: ?[]const u8 = null,
            bucket_region: ?[]const u8 = null,
            oplocks_enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .file_share_arn = "FileShareARN",
                    .file_share_id = "FileShareId",
                    .file_share_status = "FileShareStatus",
                    .gateway_arn = "GatewayARN",
                    .kms_encrypted = "KMSEncrypted",
                    .kms_key = "KMSKey",
                    .path = "Path",
                    .role = "Role",
                    .location_arn = "LocationARN",
                    .default_storage_class = "DefaultStorageClass",
                    .object_acl = "ObjectACL",
                    .read_only = "ReadOnly",
                    .guess_mime_type_enabled = "GuessMIMETypeEnabled",
                    .requester_pays = "RequesterPays",
                    .smbacl_enabled = "SMBACLEnabled",
                    .access_based_enumeration = "AccessBasedEnumeration",
                    .admin_user_list = "AdminUserList",
                    .valid_user_list = "ValidUserList",
                    .invalid_user_list = "InvalidUserList",
                    .audit_destination_arn = "AuditDestinationARN",
                    .authentication = "Authentication",
                    .case_sensitivity = "CaseSensitivity",
                    .tags = "Tags",
                    .file_share_name = "FileShareName",
                    .cache_attributes = "CacheAttributes",
                    .notification_policy = "NotificationPolicy",
                    .vpc_endpoint_dns_name = "VPCEndpointDNSName",
                    .bucket_region = "BucketRegion",
                    .oplocks_enabled = "OplocksEnabled",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .smb_file_share_info_list = "SMBFileShareInfoList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_smb_settings: struct {
    action_name: []const u8 = "DescribeSMBSettings",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_smb_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_smb_settings };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        active_directory_status: ?[]const u8 = null,
        smb_guest_password_set: ?bool = null,
        smb_security_strategy: ?[]const u8 = null,
        file_shares_visible: ?bool = null,
        smb_local_groups: ?SMBLocalGroups = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .domain_name = "DomainName",
                .active_directory_status = "ActiveDirectoryStatus",
                .smb_guest_password_set = "SMBGuestPasswordSet",
                .smb_security_strategy = "SMBSecurityStrategy",
                .file_shares_visible = "FileSharesVisible",
                .smb_local_groups = "SMBLocalGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_snapshot_schedule: struct {
    action_name: []const u8 = "DescribeSnapshotSchedule",
    Request: type = struct {
        volume_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_snapshot_schedule) } {
            return .{ .service_metadata = service_metadata, .action = describe_snapshot_schedule };
        }
    },
    Response: type = struct {
        volume_arn: ?[]const u8 = null,
        start_at: ?i64 = null,
        recurrence_in_hours: ?i64 = null,
        description: ?[]const u8 = null,
        timezone: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
                .start_at = "StartAt",
                .recurrence_in_hours = "RecurrenceInHours",
                .description = "Description",
                .timezone = "Timezone",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_storedi_scsi_volumes: struct {
    action_name: []const u8 = "DescribeStorediSCSIVolumes",
    Request: type = struct {
        volume_ar_ns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_ar_ns = "VolumeARNs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_storedi_scsi_volumes) } {
            return .{ .service_metadata = service_metadata, .action = describe_storedi_scsi_volumes };
        }
    },
    Response: type = struct {
        storedi_scsi_volumes: ?[]struct {
            volume_arn: ?[]const u8 = null,
            volume_id: ?[]const u8 = null,
            volume_type: ?[]const u8 = null,
            volume_status: ?[]const u8 = null,
            volume_attachment_status: ?[]const u8 = null,
            volume_size_in_bytes: ?i64 = null,
            volume_progress: ?f64 = null,
            volume_disk_id: ?[]const u8 = null,
            source_snapshot_id: ?[]const u8 = null,
            preserved_existing_data: ?bool = null,
            volumei_scsi_attributes: ?VolumeiSCSIAttributes = null,
            created_date: ?i64 = null,
            volume_used_in_bytes: ?i64 = null,
            kms_key: ?[]const u8 = null,
            target_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .volume_arn = "VolumeARN",
                    .volume_id = "VolumeId",
                    .volume_type = "VolumeType",
                    .volume_status = "VolumeStatus",
                    .volume_attachment_status = "VolumeAttachmentStatus",
                    .volume_size_in_bytes = "VolumeSizeInBytes",
                    .volume_progress = "VolumeProgress",
                    .volume_disk_id = "VolumeDiskId",
                    .source_snapshot_id = "SourceSnapshotId",
                    .preserved_existing_data = "PreservedExistingData",
                    .volumei_scsi_attributes = "VolumeiSCSIAttributes",
                    .created_date = "CreatedDate",
                    .volume_used_in_bytes = "VolumeUsedInBytes",
                    .kms_key = "KMSKey",
                    .target_name = "TargetName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storedi_scsi_volumes = "StorediSCSIVolumes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_tape_archives: struct {
    action_name: []const u8 = "DescribeTapeArchives",
    Request: type = struct {
        tape_ar_ns: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_ar_ns = "TapeARNs",
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tape_archives) } {
            return .{ .service_metadata = service_metadata, .action = describe_tape_archives };
        }
    },
    Response: type = struct {
        tape_archives: ?[]struct {
            tape_arn: ?[]const u8 = null,
            tape_barcode: ?[]const u8 = null,
            tape_created_date: ?i64 = null,
            tape_size_in_bytes: ?i64 = null,
            completion_time: ?i64 = null,
            retrieved_to: ?[]const u8 = null,
            tape_status: ?[]const u8 = null,
            tape_used_in_bytes: ?i64 = null,
            kms_key: ?[]const u8 = null,
            pool_id: ?[]const u8 = null,
            worm: ?bool = null,
            retention_start_date: ?i64 = null,
            pool_entry_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tape_arn = "TapeARN",
                    .tape_barcode = "TapeBarcode",
                    .tape_created_date = "TapeCreatedDate",
                    .tape_size_in_bytes = "TapeSizeInBytes",
                    .completion_time = "CompletionTime",
                    .retrieved_to = "RetrievedTo",
                    .tape_status = "TapeStatus",
                    .tape_used_in_bytes = "TapeUsedInBytes",
                    .kms_key = "KMSKey",
                    .pool_id = "PoolId",
                    .worm = "Worm",
                    .retention_start_date = "RetentionStartDate",
                    .pool_entry_date = "PoolEntryDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_archives = "TapeArchives",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_tape_recovery_points: struct {
    action_name: []const u8 = "DescribeTapeRecoveryPoints",
    Request: type = struct {
        gateway_arn: []const u8,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tape_recovery_points) } {
            return .{ .service_metadata = service_metadata, .action = describe_tape_recovery_points };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        tape_recovery_point_infos: ?[]struct {
            tape_arn: ?[]const u8 = null,
            tape_recovery_point_time: ?i64 = null,
            tape_size_in_bytes: ?i64 = null,
            tape_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tape_arn = "TapeARN",
                    .tape_recovery_point_time = "TapeRecoveryPointTime",
                    .tape_size_in_bytes = "TapeSizeInBytes",
                    .tape_status = "TapeStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .tape_recovery_point_infos = "TapeRecoveryPointInfos",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_tapes: struct {
    action_name: []const u8 = "DescribeTapes",
    Request: type = struct {
        gateway_arn: []const u8,
        tape_ar_ns: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .tape_ar_ns = "TapeARNs",
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tapes) } {
            return .{ .service_metadata = service_metadata, .action = describe_tapes };
        }
    },
    Response: type = struct {
        tapes: ?[]struct {
            tape_arn: ?[]const u8 = null,
            tape_barcode: ?[]const u8 = null,
            tape_created_date: ?i64 = null,
            tape_size_in_bytes: ?i64 = null,
            tape_status: ?[]const u8 = null,
            vtl_device: ?[]const u8 = null,
            progress: ?f64 = null,
            tape_used_in_bytes: ?i64 = null,
            kms_key: ?[]const u8 = null,
            pool_id: ?[]const u8 = null,
            worm: ?bool = null,
            retention_start_date: ?i64 = null,
            pool_entry_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tape_arn = "TapeARN",
                    .tape_barcode = "TapeBarcode",
                    .tape_created_date = "TapeCreatedDate",
                    .tape_size_in_bytes = "TapeSizeInBytes",
                    .tape_status = "TapeStatus",
                    .vtl_device = "VTLDevice",
                    .progress = "Progress",
                    .tape_used_in_bytes = "TapeUsedInBytes",
                    .kms_key = "KMSKey",
                    .pool_id = "PoolId",
                    .worm = "Worm",
                    .retention_start_date = "RetentionStartDate",
                    .pool_entry_date = "PoolEntryDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tapes = "Tapes",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_upload_buffer: struct {
    action_name: []const u8 = "DescribeUploadBuffer",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_upload_buffer) } {
            return .{ .service_metadata = service_metadata, .action = describe_upload_buffer };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        disk_ids: ?[][]const u8 = null,
        upload_buffer_used_in_bytes: ?i64 = null,
        upload_buffer_allocated_in_bytes: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .disk_ids = "DiskIds",
                .upload_buffer_used_in_bytes = "UploadBufferUsedInBytes",
                .upload_buffer_allocated_in_bytes = "UploadBufferAllocatedInBytes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_vtl_devices: struct {
    action_name: []const u8 = "DescribeVTLDevices",
    Request: type = struct {
        gateway_arn: []const u8,
        vtl_device_ar_ns: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .vtl_device_ar_ns = "VTLDeviceARNs",
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vtl_devices) } {
            return .{ .service_metadata = service_metadata, .action = describe_vtl_devices };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        vtl_devices: ?[]struct {
            vtl_device_arn: ?[]const u8 = null,
            vtl_device_type: ?[]const u8 = null,
            vtl_device_vendor: ?[]const u8 = null,
            vtl_device_product_identifier: ?[]const u8 = null,
            devicei_scsi_attributes: ?struct {
                target_arn: ?[]const u8 = null,
                network_interface_id: ?[]const u8 = null,
                network_interface_port: ?i64 = null,
                chap_enabled: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .target_arn = "TargetARN",
                        .network_interface_id = "NetworkInterfaceId",
                        .network_interface_port = "NetworkInterfacePort",
                        .chap_enabled = "ChapEnabled",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vtl_device_arn = "VTLDeviceARN",
                    .vtl_device_type = "VTLDeviceType",
                    .vtl_device_vendor = "VTLDeviceVendor",
                    .vtl_device_product_identifier = "VTLDeviceProductIdentifier",
                    .devicei_scsi_attributes = "DeviceiSCSIAttributes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .vtl_devices = "VTLDevices",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const describe_working_storage: struct {
    action_name: []const u8 = "DescribeWorkingStorage",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_working_storage) } {
            return .{ .service_metadata = service_metadata, .action = describe_working_storage };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        disk_ids: ?[][]const u8 = null,
        working_storage_used_in_bytes: ?i64 = null,
        working_storage_allocated_in_bytes: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .disk_ids = "DiskIds",
                .working_storage_used_in_bytes = "WorkingStorageUsedInBytes",
                .working_storage_allocated_in_bytes = "WorkingStorageAllocatedInBytes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const detach_volume: struct {
    action_name: []const u8 = "DetachVolume",
    Request: type = struct {
        volume_arn: []const u8,
        force_detach: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
                .force_detach = "ForceDetach",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detach_volume) } {
            return .{ .service_metadata = service_metadata, .action = detach_volume };
        }
    },
    Response: type = struct {
        volume_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const disable_gateway: struct {
    action_name: []const u8 = "DisableGateway",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_gateway) } {
            return .{ .service_metadata = service_metadata, .action = disable_gateway };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const disassociate_file_system: struct {
    action_name: []const u8 = "DisassociateFileSystem",
    Request: type = struct {
        file_system_association_arn: []const u8,
        force_delete: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_association_arn = "FileSystemAssociationARN",
                .force_delete = "ForceDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_file_system) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_file_system };
        }
    },
    Response: type = struct {
        file_system_association_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_association_arn = "FileSystemAssociationARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const join_domain: struct {
    action_name: []const u8 = "JoinDomain",
    Request: type = struct {
        gateway_arn: []const u8,
        domain_name: []const u8,
        organizational_unit: ?[]const u8 = null,
        domain_controllers: ?[][]const u8 = null,
        timeout_in_seconds: ?i64 = null,
        user_name: []const u8,
        password: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .domain_name = "DomainName",
                .organizational_unit = "OrganizationalUnit",
                .domain_controllers = "DomainControllers",
                .timeout_in_seconds = "TimeoutInSeconds",
                .user_name = "UserName",
                .password = "Password",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(join_domain) } {
            return .{ .service_metadata = service_metadata, .action = join_domain };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        active_directory_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .active_directory_status = "ActiveDirectoryStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_automatic_tape_creation_policies: struct {
    action_name: []const u8 = "ListAutomaticTapeCreationPolicies",
    Request: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_automatic_tape_creation_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_automatic_tape_creation_policies };
        }
    },
    Response: type = struct {
        automatic_tape_creation_policy_infos: ?[]struct {
            automatic_tape_creation_rules: ?[]AutomaticTapeCreationRule = null,
            gateway_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .automatic_tape_creation_rules = "AutomaticTapeCreationRules",
                    .gateway_arn = "GatewayARN",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automatic_tape_creation_policy_infos = "AutomaticTapeCreationPolicyInfos",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_file_shares: struct {
    action_name: []const u8 = "ListFileShares",
    Request: type = struct {
        gateway_arn: ?[]const u8 = null,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_file_shares) } {
            return .{ .service_metadata = service_metadata, .action = list_file_shares };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        next_marker: ?[]const u8 = null,
        file_share_info_list: ?[]struct {
            file_share_type: ?[]const u8 = null,
            file_share_arn: ?[]const u8 = null,
            file_share_id: ?[]const u8 = null,
            file_share_status: ?[]const u8 = null,
            gateway_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .file_share_type = "FileShareType",
                    .file_share_arn = "FileShareARN",
                    .file_share_id = "FileShareId",
                    .file_share_status = "FileShareStatus",
                    .gateway_arn = "GatewayARN",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .next_marker = "NextMarker",
                .file_share_info_list = "FileShareInfoList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_file_system_associations: struct {
    action_name: []const u8 = "ListFileSystemAssociations",
    Request: type = struct {
        gateway_arn: ?[]const u8 = null,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_file_system_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_file_system_associations };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        next_marker: ?[]const u8 = null,
        file_system_association_summary_list: ?[]struct {
            file_system_association_id: ?[]const u8 = null,
            file_system_association_arn: ?[]const u8 = null,
            file_system_association_status: ?[]const u8 = null,
            gateway_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .file_system_association_id = "FileSystemAssociationId",
                    .file_system_association_arn = "FileSystemAssociationARN",
                    .file_system_association_status = "FileSystemAssociationStatus",
                    .gateway_arn = "GatewayARN",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .next_marker = "NextMarker",
                .file_system_association_summary_list = "FileSystemAssociationSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_gateways: struct {
    action_name: []const u8 = "ListGateways",
    Request: type = struct {
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_gateways) } {
            return .{ .service_metadata = service_metadata, .action = list_gateways };
        }
    },
    Response: type = struct {
        gateways: ?[]struct {
            gateway_id: ?[]const u8 = null,
            gateway_arn: ?[]const u8 = null,
            gateway_type: ?[]const u8 = null,
            gateway_operational_state: ?[]const u8 = null,
            gateway_name: ?[]const u8 = null,
            ec2_instance_id: ?[]const u8 = null,
            ec2_instance_region: ?[]const u8 = null,
            host_environment: ?[]const u8 = null,
            host_environment_id: ?[]const u8 = null,
            deprecation_date: ?[]const u8 = null,
            software_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .gateway_id = "GatewayId",
                    .gateway_arn = "GatewayARN",
                    .gateway_type = "GatewayType",
                    .gateway_operational_state = "GatewayOperationalState",
                    .gateway_name = "GatewayName",
                    .ec2_instance_id = "Ec2InstanceId",
                    .ec2_instance_region = "Ec2InstanceRegion",
                    .host_environment = "HostEnvironment",
                    .host_environment_id = "HostEnvironmentId",
                    .deprecation_date = "DeprecationDate",
                    .software_version = "SoftwareVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateways = "Gateways",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_local_disks: struct {
    action_name: []const u8 = "ListLocalDisks",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_local_disks) } {
            return .{ .service_metadata = service_metadata, .action = list_local_disks };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        disks: ?[]struct {
            disk_id: ?[]const u8 = null,
            disk_path: ?[]const u8 = null,
            disk_node: ?[]const u8 = null,
            disk_status: ?[]const u8 = null,
            disk_size_in_bytes: ?i64 = null,
            disk_allocation_type: ?[]const u8 = null,
            disk_allocation_resource: ?[]const u8 = null,
            disk_attribute_list: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .disk_id = "DiskId",
                    .disk_path = "DiskPath",
                    .disk_node = "DiskNode",
                    .disk_status = "DiskStatus",
                    .disk_size_in_bytes = "DiskSizeInBytes",
                    .disk_allocation_type = "DiskAllocationType",
                    .disk_allocation_resource = "DiskAllocationResource",
                    .disk_attribute_list = "DiskAttributeList",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .disks = "Disks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .marker = "Marker",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_tape_pools: struct {
    action_name: []const u8 = "ListTapePools",
    Request: type = struct {
        pool_ar_ns: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_ar_ns = "PoolARNs",
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tape_pools) } {
            return .{ .service_metadata = service_metadata, .action = list_tape_pools };
        }
    },
    Response: type = struct {
        pool_infos: ?[]struct {
            pool_arn: ?[]const u8 = null,
            pool_name: ?[]const u8 = null,
            storage_class: ?[]const u8 = null,
            retention_lock_type: ?[]const u8 = null,
            retention_lock_time_in_days: ?i64 = null,
            pool_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pool_arn = "PoolARN",
                    .pool_name = "PoolName",
                    .storage_class = "StorageClass",
                    .retention_lock_type = "RetentionLockType",
                    .retention_lock_time_in_days = "RetentionLockTimeInDays",
                    .pool_status = "PoolStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pool_infos = "PoolInfos",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_tapes: struct {
    action_name: []const u8 = "ListTapes",
    Request: type = struct {
        tape_ar_ns: ?[][]const u8 = null,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_ar_ns = "TapeARNs",
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tapes) } {
            return .{ .service_metadata = service_metadata, .action = list_tapes };
        }
    },
    Response: type = struct {
        tape_infos: ?[]struct {
            tape_arn: ?[]const u8 = null,
            tape_barcode: ?[]const u8 = null,
            tape_size_in_bytes: ?i64 = null,
            tape_status: ?[]const u8 = null,
            gateway_arn: ?[]const u8 = null,
            pool_id: ?[]const u8 = null,
            retention_start_date: ?i64 = null,
            pool_entry_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tape_arn = "TapeARN",
                    .tape_barcode = "TapeBarcode",
                    .tape_size_in_bytes = "TapeSizeInBytes",
                    .tape_status = "TapeStatus",
                    .gateway_arn = "GatewayARN",
                    .pool_id = "PoolId",
                    .retention_start_date = "RetentionStartDate",
                    .pool_entry_date = "PoolEntryDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_infos = "TapeInfos",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_volume_initiators: struct {
    action_name: []const u8 = "ListVolumeInitiators",
    Request: type = struct {
        volume_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_volume_initiators) } {
            return .{ .service_metadata = service_metadata, .action = list_volume_initiators };
        }
    },
    Response: type = struct {
        initiators: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .initiators = "Initiators",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_volume_recovery_points: struct {
    action_name: []const u8 = "ListVolumeRecoveryPoints",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_volume_recovery_points) } {
            return .{ .service_metadata = service_metadata, .action = list_volume_recovery_points };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        volume_recovery_point_infos: ?[]struct {
            volume_arn: ?[]const u8 = null,
            volume_size_in_bytes: ?i64 = null,
            volume_usage_in_bytes: ?i64 = null,
            volume_recovery_point_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .volume_arn = "VolumeARN",
                    .volume_size_in_bytes = "VolumeSizeInBytes",
                    .volume_usage_in_bytes = "VolumeUsageInBytes",
                    .volume_recovery_point_time = "VolumeRecoveryPointTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .volume_recovery_point_infos = "VolumeRecoveryPointInfos",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const list_volumes: struct {
    action_name: []const u8 = "ListVolumes",
    Request: type = struct {
        gateway_arn: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_volumes) } {
            return .{ .service_metadata = service_metadata, .action = list_volumes };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        volume_infos: ?[]struct {
            volume_arn: ?[]const u8 = null,
            volume_id: ?[]const u8 = null,
            gateway_arn: ?[]const u8 = null,
            gateway_id: ?[]const u8 = null,
            volume_type: ?[]const u8 = null,
            volume_size_in_bytes: ?i64 = null,
            volume_attachment_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .volume_arn = "VolumeARN",
                    .volume_id = "VolumeId",
                    .gateway_arn = "GatewayARN",
                    .gateway_id = "GatewayId",
                    .volume_type = "VolumeType",
                    .volume_size_in_bytes = "VolumeSizeInBytes",
                    .volume_attachment_status = "VolumeAttachmentStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .marker = "Marker",
                .volume_infos = "VolumeInfos",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const notify_when_uploaded: struct {
    action_name: []const u8 = "NotifyWhenUploaded",
    Request: type = struct {
        file_share_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(notify_when_uploaded) } {
            return .{ .service_metadata = service_metadata, .action = notify_when_uploaded };
        }
    },
    Response: type = struct {
        file_share_arn: ?[]const u8 = null,
        notification_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
                .notification_id = "NotificationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const refresh_cache: struct {
    action_name: []const u8 = "RefreshCache",
    Request: type = struct {
        file_share_arn: []const u8,
        folder_list: ?[][]const u8 = null,
        recursive: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
                .folder_list = "FolderList",
                .recursive = "Recursive",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(refresh_cache) } {
            return .{ .service_metadata = service_metadata, .action = refresh_cache };
        }
    },
    Response: type = struct {
        file_share_arn: ?[]const u8 = null,
        notification_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
                .notification_id = "NotificationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const remove_tags_from_resource: struct {
    action_name: []const u8 = "RemoveTagsFromResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_resource };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const reset_cache: struct {
    action_name: []const u8 = "ResetCache",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_cache) } {
            return .{ .service_metadata = service_metadata, .action = reset_cache };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const retrieve_tape_archive: struct {
    action_name: []const u8 = "RetrieveTapeArchive",
    Request: type = struct {
        tape_arn: []const u8,
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(retrieve_tape_archive) } {
            return .{ .service_metadata = service_metadata, .action = retrieve_tape_archive };
        }
    },
    Response: type = struct {
        tape_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const retrieve_tape_recovery_point: struct {
    action_name: []const u8 = "RetrieveTapeRecoveryPoint",
    Request: type = struct {
        tape_arn: []const u8,
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(retrieve_tape_recovery_point) } {
            return .{ .service_metadata = service_metadata, .action = retrieve_tape_recovery_point };
        }
    },
    Response: type = struct {
        tape_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tape_arn = "TapeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const set_local_console_password: struct {
    action_name: []const u8 = "SetLocalConsolePassword",
    Request: type = struct {
        gateway_arn: []const u8,
        local_console_password: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .local_console_password = "LocalConsolePassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_local_console_password) } {
            return .{ .service_metadata = service_metadata, .action = set_local_console_password };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const set_smb_guest_password: struct {
    action_name: []const u8 = "SetSMBGuestPassword",
    Request: type = struct {
        gateway_arn: []const u8,
        password: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .password = "Password",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_smb_guest_password) } {
            return .{ .service_metadata = service_metadata, .action = set_smb_guest_password };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const shutdown_gateway: struct {
    action_name: []const u8 = "ShutdownGateway",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(shutdown_gateway) } {
            return .{ .service_metadata = service_metadata, .action = shutdown_gateway };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const start_availability_monitor_test: struct {
    action_name: []const u8 = "StartAvailabilityMonitorTest",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_availability_monitor_test) } {
            return .{ .service_metadata = service_metadata, .action = start_availability_monitor_test };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const start_gateway: struct {
    action_name: []const u8 = "StartGateway",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_gateway) } {
            return .{ .service_metadata = service_metadata, .action = start_gateway };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_automatic_tape_creation_policy: struct {
    action_name: []const u8 = "UpdateAutomaticTapeCreationPolicy",
    Request: type = struct {
        automatic_tape_creation_rules: []AutomaticTapeCreationRule,
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .automatic_tape_creation_rules = "AutomaticTapeCreationRules",
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_automatic_tape_creation_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_automatic_tape_creation_policy };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_bandwidth_rate_limit: struct {
    action_name: []const u8 = "UpdateBandwidthRateLimit",
    Request: type = struct {
        gateway_arn: []const u8,
        average_upload_rate_limit_in_bits_per_sec: ?i64 = null,
        average_download_rate_limit_in_bits_per_sec: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .average_upload_rate_limit_in_bits_per_sec = "AverageUploadRateLimitInBitsPerSec",
                .average_download_rate_limit_in_bits_per_sec = "AverageDownloadRateLimitInBitsPerSec",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bandwidth_rate_limit) } {
            return .{ .service_metadata = service_metadata, .action = update_bandwidth_rate_limit };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_bandwidth_rate_limit_schedule: struct {
    action_name: []const u8 = "UpdateBandwidthRateLimitSchedule",
    Request: type = struct {
        gateway_arn: []const u8,
        bandwidth_rate_limit_intervals: []BandwidthRateLimitInterval,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .bandwidth_rate_limit_intervals = "BandwidthRateLimitIntervals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bandwidth_rate_limit_schedule) } {
            return .{ .service_metadata = service_metadata, .action = update_bandwidth_rate_limit_schedule };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_chap_credentials: struct {
    action_name: []const u8 = "UpdateChapCredentials",
    Request: type = struct {
        target_arn: []const u8,
        secret_to_authenticate_initiator: []const u8,
        initiator_name: []const u8,
        secret_to_authenticate_target: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "TargetARN",
                .secret_to_authenticate_initiator = "SecretToAuthenticateInitiator",
                .initiator_name = "InitiatorName",
                .secret_to_authenticate_target = "SecretToAuthenticateTarget",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_chap_credentials) } {
            return .{ .service_metadata = service_metadata, .action = update_chap_credentials };
        }
    },
    Response: type = struct {
        target_arn: ?[]const u8 = null,
        initiator_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "TargetARN",
                .initiator_name = "InitiatorName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_file_system_association: struct {
    action_name: []const u8 = "UpdateFileSystemAssociation",
    Request: type = struct {
        file_system_association_arn: []const u8,
        user_name: ?[]const u8 = null,
        password: ?[]const u8 = null,
        audit_destination_arn: ?[]const u8 = null,
        cache_attributes: ?CacheAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_association_arn = "FileSystemAssociationARN",
                .user_name = "UserName",
                .password = "Password",
                .audit_destination_arn = "AuditDestinationARN",
                .cache_attributes = "CacheAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_file_system_association) } {
            return .{ .service_metadata = service_metadata, .action = update_file_system_association };
        }
    },
    Response: type = struct {
        file_system_association_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_association_arn = "FileSystemAssociationARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_gateway_information: struct {
    action_name: []const u8 = "UpdateGatewayInformation",
    Request: type = struct {
        gateway_arn: []const u8,
        gateway_name: ?[]const u8 = null,
        gateway_timezone: ?[]const u8 = null,
        cloud_watch_log_group_arn: ?[]const u8 = null,
        gateway_capacity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .gateway_name = "GatewayName",
                .gateway_timezone = "GatewayTimezone",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupARN",
                .gateway_capacity = "GatewayCapacity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_gateway_information) } {
            return .{ .service_metadata = service_metadata, .action = update_gateway_information };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,
        gateway_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .gateway_name = "GatewayName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_gateway_software_now: struct {
    action_name: []const u8 = "UpdateGatewaySoftwareNow",
    Request: type = struct {
        gateway_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_gateway_software_now) } {
            return .{ .service_metadata = service_metadata, .action = update_gateway_software_now };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_maintenance_start_time: struct {
    action_name: []const u8 = "UpdateMaintenanceStartTime",
    Request: type = struct {
        gateway_arn: []const u8,
        hour_of_day: i64,
        minute_of_hour: i64,
        day_of_week: ?i64 = null,
        day_of_month: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .hour_of_day = "HourOfDay",
                .minute_of_hour = "MinuteOfHour",
                .day_of_week = "DayOfWeek",
                .day_of_month = "DayOfMonth",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_maintenance_start_time) } {
            return .{ .service_metadata = service_metadata, .action = update_maintenance_start_time };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_nfs_file_share: struct {
    action_name: []const u8 = "UpdateNFSFileShare",
    Request: type = struct {
        file_share_arn: []const u8,
        kms_encrypted: ?bool = null,
        kms_key: ?[]const u8 = null,
        nfs_file_share_defaults: ?NFSFileShareDefaults = null,
        default_storage_class: ?[]const u8 = null,
        object_acl: ?[]const u8 = null,
        client_list: ?[][]const u8 = null,
        squash: ?[]const u8 = null,
        read_only: ?bool = null,
        guess_mime_type_enabled: ?bool = null,
        requester_pays: ?bool = null,
        file_share_name: ?[]const u8 = null,
        cache_attributes: ?CacheAttributes = null,
        notification_policy: ?[]const u8 = null,
        audit_destination_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
                .kms_encrypted = "KMSEncrypted",
                .kms_key = "KMSKey",
                .nfs_file_share_defaults = "NFSFileShareDefaults",
                .default_storage_class = "DefaultStorageClass",
                .object_acl = "ObjectACL",
                .client_list = "ClientList",
                .squash = "Squash",
                .read_only = "ReadOnly",
                .guess_mime_type_enabled = "GuessMIMETypeEnabled",
                .requester_pays = "RequesterPays",
                .file_share_name = "FileShareName",
                .cache_attributes = "CacheAttributes",
                .notification_policy = "NotificationPolicy",
                .audit_destination_arn = "AuditDestinationARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_nfs_file_share) } {
            return .{ .service_metadata = service_metadata, .action = update_nfs_file_share };
        }
    },
    Response: type = struct {
        file_share_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_smb_file_share: struct {
    action_name: []const u8 = "UpdateSMBFileShare",
    Request: type = struct {
        file_share_arn: []const u8,
        kms_encrypted: ?bool = null,
        kms_key: ?[]const u8 = null,
        default_storage_class: ?[]const u8 = null,
        object_acl: ?[]const u8 = null,
        read_only: ?bool = null,
        guess_mime_type_enabled: ?bool = null,
        requester_pays: ?bool = null,
        smbacl_enabled: ?bool = null,
        access_based_enumeration: ?bool = null,
        admin_user_list: ?[][]const u8 = null,
        valid_user_list: ?[][]const u8 = null,
        invalid_user_list: ?[][]const u8 = null,
        audit_destination_arn: ?[]const u8 = null,
        case_sensitivity: ?[]const u8 = null,
        file_share_name: ?[]const u8 = null,
        cache_attributes: ?CacheAttributes = null,
        notification_policy: ?[]const u8 = null,
        oplocks_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
                .kms_encrypted = "KMSEncrypted",
                .kms_key = "KMSKey",
                .default_storage_class = "DefaultStorageClass",
                .object_acl = "ObjectACL",
                .read_only = "ReadOnly",
                .guess_mime_type_enabled = "GuessMIMETypeEnabled",
                .requester_pays = "RequesterPays",
                .smbacl_enabled = "SMBACLEnabled",
                .access_based_enumeration = "AccessBasedEnumeration",
                .admin_user_list = "AdminUserList",
                .valid_user_list = "ValidUserList",
                .invalid_user_list = "InvalidUserList",
                .audit_destination_arn = "AuditDestinationARN",
                .case_sensitivity = "CaseSensitivity",
                .file_share_name = "FileShareName",
                .cache_attributes = "CacheAttributes",
                .notification_policy = "NotificationPolicy",
                .oplocks_enabled = "OplocksEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_smb_file_share) } {
            return .{ .service_metadata = service_metadata, .action = update_smb_file_share };
        }
    },
    Response: type = struct {
        file_share_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_share_arn = "FileShareARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_smb_file_share_visibility: struct {
    action_name: []const u8 = "UpdateSMBFileShareVisibility",
    Request: type = struct {
        gateway_arn: []const u8,
        file_shares_visible: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .file_shares_visible = "FileSharesVisible",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_smb_file_share_visibility) } {
            return .{ .service_metadata = service_metadata, .action = update_smb_file_share_visibility };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_smb_local_groups: struct {
    action_name: []const u8 = "UpdateSMBLocalGroups",
    Request: type = struct {
        gateway_arn: []const u8,
        smb_local_groups: SMBLocalGroups,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .smb_local_groups = "SMBLocalGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_smb_local_groups) } {
            return .{ .service_metadata = service_metadata, .action = update_smb_local_groups };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_smb_security_strategy: struct {
    action_name: []const u8 = "UpdateSMBSecurityStrategy",
    Request: type = struct {
        gateway_arn: []const u8,
        smb_security_strategy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
                .smb_security_strategy = "SMBSecurityStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_smb_security_strategy) } {
            return .{ .service_metadata = service_metadata, .action = update_smb_security_strategy };
        }
    },
    Response: type = struct {
        gateway_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .gateway_arn = "GatewayARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_snapshot_schedule: struct {
    action_name: []const u8 = "UpdateSnapshotSchedule",
    Request: type = struct {
        volume_arn: []const u8,
        start_at: i64,
        recurrence_in_hours: i64,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
                .start_at = "StartAt",
                .recurrence_in_hours = "RecurrenceInHours",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_snapshot_schedule) } {
            return .{ .service_metadata = service_metadata, .action = update_snapshot_schedule };
        }
    },
    Response: type = struct {
        volume_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arn = "VolumeARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};
pub const update_vtl_device_type: struct {
    action_name: []const u8 = "UpdateVTLDeviceType",
    Request: type = struct {
        vtl_device_arn: []const u8,
        device_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vtl_device_arn = "VTLDeviceARN",
                .device_type = "DeviceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vtl_device_type) } {
            return .{ .service_metadata = service_metadata, .action = update_vtl_device_type };
        }
    },
    Response: type = struct {
        vtl_device_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vtl_device_arn = "VTLDeviceARN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidGatewayRequest,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const SMBLocalGroups = struct {
    gateway_admins: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gateway_admins = "GatewayAdmins",
        };
        return @field(mappings, field_name);
    }
};

pub const CacheAttributes = struct {
    cache_stale_timeout_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_stale_timeout_in_seconds = "CacheStaleTimeoutInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const NFSFileShareDefaults = struct {
    file_mode: ?[]const u8 = null,
    directory_mode: ?[]const u8 = null,
    group_id: ?i64 = null,
    owner_id: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_mode = "FileMode",
            .directory_mode = "DirectoryMode",
            .group_id = "GroupId",
            .owner_id = "OwnerId",
        };
        return @field(mappings, field_name);
    }
};

pub const BandwidthRateLimitInterval = struct {
    start_hour_of_day: i64,
    start_minute_of_hour: i64,
    end_hour_of_day: i64,
    end_minute_of_hour: i64,
    days_of_week: []i64,
    average_upload_rate_limit_in_bits_per_sec: ?i64 = null,
    average_download_rate_limit_in_bits_per_sec: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_hour_of_day = "StartHourOfDay",
            .start_minute_of_hour = "StartMinuteOfHour",
            .end_hour_of_day = "EndHourOfDay",
            .end_minute_of_hour = "EndMinuteOfHour",
            .days_of_week = "DaysOfWeek",
            .average_upload_rate_limit_in_bits_per_sec = "AverageUploadRateLimitInBitsPerSec",
            .average_download_rate_limit_in_bits_per_sec = "AverageDownloadRateLimitInBitsPerSec",
        };
        return @field(mappings, field_name);
    }
};

pub const AutomaticTapeCreationRule = struct {
    tape_barcode_prefix: []const u8,
    pool_id: []const u8,
    tape_size_in_bytes: i64,
    minimum_num_tapes: i64,
    worm: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tape_barcode_prefix = "TapeBarcodePrefix",
            .pool_id = "PoolId",
            .tape_size_in_bytes = "TapeSizeInBytes",
            .minimum_num_tapes = "MinimumNumTapes",
            .worm = "Worm",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeiSCSIAttributes = struct {
    target_arn: ?[]const u8 = null,
    network_interface_id: ?[]const u8 = null,
    network_interface_port: ?i64 = null,
    lun_number: ?i64 = null,
    chap_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_arn = "TargetARN",
            .network_interface_id = "NetworkInterfaceId",
            .network_interface_port = "NetworkInterfacePort",
            .lun_number = "LunNumber",
            .chap_enabled = "ChapEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointNetworkConfiguration = struct {
    ip_addresses: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_addresses = "IpAddresses",
        };
        return @field(mappings, field_name);
    }
};
