const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2011-06-15";
pub const sdk_id: []const u8 = "STS";
pub const arn_namespace: ?[]const u8 = "sts";
pub const endpoint_prefix: []const u8 = "sts";
pub const sigv4_name: []const u8 = "sts";
pub const name: []const u8 = "AWSSecurityTokenServiceV20110615";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query;

pub const service_metadata: struct {
    version: []const u8 = "2011-06-15",
    sdk_id: []const u8 = "STS",
    arn_namespace: ?[]const u8 = "sts",
    endpoint_prefix: []const u8 = "sts",
    sigv4_name: []const u8 = "sts",
    name: []const u8 = "AWSSecurityTokenServiceV20110615",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.query,
} = .{};
pub const assume_role: struct {
    action_name: []const u8 = "AssumeRole",
    Request: type = struct {
        role_arn: []const u8,
        role_session_name: []const u8,
        policy_arns: ?[]PolicyDescriptorType = null,
        policy: ?[]const u8 = null,
        duration_seconds: ?i64 = null,
        tags: ?[]Tag = null,
        transitive_tag_keys: ?[][]const u8 = null,
        external_id: ?[]const u8 = null,
        serial_number: ?[]const u8 = null,
        token_code: ?[]const u8 = null,
        source_identity: ?[]const u8 = null,
        provided_contexts: ?[]struct {
            provider_arn: ?[]const u8 = null,
            context_assertion: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .provider_arn = "ProviderArn",
                    .context_assertion = "ContextAssertion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "RoleArn",
                .role_session_name = "RoleSessionName",
                .policy_arns = "PolicyArns",
                .policy = "Policy",
                .duration_seconds = "DurationSeconds",
                .tags = "Tags",
                .transitive_tag_keys = "TransitiveTagKeys",
                .external_id = "ExternalId",
                .serial_number = "SerialNumber",
                .token_code = "TokenCode",
                .source_identity = "SourceIdentity",
                .provided_contexts = "ProvidedContexts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(assume_role) } {
            return .{ .service_metadata = service_metadata, .action = assume_role };
        }
    },
    Response: type = struct {
        credentials: ?Credentials = null,
        assumed_role_user: ?AssumedRoleUser = null,
        packed_policy_size: ?i64 = null,
        source_identity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "Credentials",
                .assumed_role_user = "AssumedRoleUser",
                .packed_policy_size = "PackedPolicySize",
                .source_identity = "SourceIdentity",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExpiredToken,
        MalformedPolicyDocument,
        PackedPolicyTooLarge,
        RegionDisabled,
    },
} = .{};
pub const assume_role_with_saml: struct {
    action_name: []const u8 = "AssumeRoleWithSAML",
    Request: type = struct {
        role_arn: []const u8,
        principal_arn: []const u8,
        saml_assertion: []const u8,
        policy_arns: ?[]PolicyDescriptorType = null,
        policy: ?[]const u8 = null,
        duration_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "RoleArn",
                .principal_arn = "PrincipalArn",
                .saml_assertion = "SAMLAssertion",
                .policy_arns = "PolicyArns",
                .policy = "Policy",
                .duration_seconds = "DurationSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(assume_role_with_saml) } {
            return .{ .service_metadata = service_metadata, .action = assume_role_with_saml };
        }
    },
    Response: type = struct {
        credentials: ?Credentials = null,
        assumed_role_user: ?AssumedRoleUser = null,
        packed_policy_size: ?i64 = null,
        subject: ?[]const u8 = null,
        subject_type: ?[]const u8 = null,
        issuer: ?[]const u8 = null,
        audience: ?[]const u8 = null,
        name_qualifier: ?[]const u8 = null,
        source_identity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "Credentials",
                .assumed_role_user = "AssumedRoleUser",
                .packed_policy_size = "PackedPolicySize",
                .subject = "Subject",
                .subject_type = "SubjectType",
                .issuer = "Issuer",
                .audience = "Audience",
                .name_qualifier = "NameQualifier",
                .source_identity = "SourceIdentity",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExpiredToken,
        IDPRejectedClaim,
        InvalidIdentityToken,
        MalformedPolicyDocument,
        PackedPolicyTooLarge,
        RegionDisabled,
    },
} = .{};
pub const assume_role_with_web_identity: struct {
    action_name: []const u8 = "AssumeRoleWithWebIdentity",
    Request: type = struct {
        role_arn: []const u8,
        role_session_name: []const u8,
        web_identity_token: []const u8,
        provider_id: ?[]const u8 = null,
        policy_arns: ?[]PolicyDescriptorType = null,
        policy: ?[]const u8 = null,
        duration_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "RoleArn",
                .role_session_name = "RoleSessionName",
                .web_identity_token = "WebIdentityToken",
                .provider_id = "ProviderId",
                .policy_arns = "PolicyArns",
                .policy = "Policy",
                .duration_seconds = "DurationSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(assume_role_with_web_identity) } {
            return .{ .service_metadata = service_metadata, .action = assume_role_with_web_identity };
        }
    },
    Response: type = struct {
        credentials: ?Credentials = null,
        subject_from_web_identity_token: ?[]const u8 = null,
        assumed_role_user: ?AssumedRoleUser = null,
        packed_policy_size: ?i64 = null,
        provider: ?[]const u8 = null,
        audience: ?[]const u8 = null,
        source_identity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "Credentials",
                .subject_from_web_identity_token = "SubjectFromWebIdentityToken",
                .assumed_role_user = "AssumedRoleUser",
                .packed_policy_size = "PackedPolicySize",
                .provider = "Provider",
                .audience = "Audience",
                .source_identity = "SourceIdentity",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExpiredToken,
        IDPCommunicationError,
        IDPRejectedClaim,
        InvalidIdentityToken,
        MalformedPolicyDocument,
        PackedPolicyTooLarge,
        RegionDisabled,
    },
} = .{};
pub const decode_authorization_message: struct {
    action_name: []const u8 = "DecodeAuthorizationMessage",
    Request: type = struct {
        encoded_message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encoded_message = "EncodedMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(decode_authorization_message) } {
            return .{ .service_metadata = service_metadata, .action = decode_authorization_message };
        }
    },
    Response: type = struct {
        decoded_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .decoded_message = "DecodedMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidAuthorizationMessage,
    },
} = .{};
pub const get_access_key_info: struct {
    action_name: []const u8 = "GetAccessKeyInfo",
    Request: type = struct {
        access_key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_key_id = "AccessKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_key_info) } {
            return .{ .service_metadata = service_metadata, .action = get_access_key_info };
        }
    },
    Response: type = struct {
        account: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account = "Account",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_caller_identity: struct {
    action_name: []const u8 = "GetCallerIdentity",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_caller_identity) } {
            return .{ .service_metadata = service_metadata, .action = get_caller_identity };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        account: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .account = "Account",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_federation_token: struct {
    action_name: []const u8 = "GetFederationToken",
    Request: type = struct {
        name: []const u8,
        policy: ?[]const u8 = null,
        policy_arns: ?[]PolicyDescriptorType = null,
        duration_seconds: ?i64 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .policy = "Policy",
                .policy_arns = "PolicyArns",
                .duration_seconds = "DurationSeconds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_federation_token) } {
            return .{ .service_metadata = service_metadata, .action = get_federation_token };
        }
    },
    Response: type = struct {
        credentials: ?Credentials = null,
        federated_user: ?struct {
            federated_user_id: []const u8,
            arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .federated_user_id = "FederatedUserId",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        packed_policy_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "Credentials",
                .federated_user = "FederatedUser",
                .packed_policy_size = "PackedPolicySize",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        MalformedPolicyDocument,
        PackedPolicyTooLarge,
        RegionDisabled,
    },
} = .{};
pub const get_session_token: struct {
    action_name: []const u8 = "GetSessionToken",
    Request: type = struct {
        duration_seconds: ?i64 = null,
        serial_number: ?[]const u8 = null,
        token_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .duration_seconds = "DurationSeconds",
                .serial_number = "SerialNumber",
                .token_code = "TokenCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_session_token) } {
            return .{ .service_metadata = service_metadata, .action = get_session_token };
        }
    },
    Response: type = struct {
        credentials: ?Credentials = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "Credentials",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        RegionDisabled,
    },
} = .{};

pub const Credentials = struct {
    access_key_id: []const u8,
    secret_access_key: []const u8,
    session_token: []const u8,
    expiration: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_key_id = "AccessKeyId",
            .secret_access_key = "SecretAccessKey",
            .session_token = "SessionToken",
            .expiration = "Expiration",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const PolicyDescriptorType = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const AssumedRoleUser = struct {
    assumed_role_id: []const u8,
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assumed_role_id = "AssumedRoleId",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};
