const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2013-04-15";
pub const sdk_id: []const u8 = "Support";
pub const arn_namespace: ?[]const u8 = "support";
pub const endpoint_prefix: []const u8 = "support";
pub const sigv4_name: []const u8 = "support";
pub const name: []const u8 = "AWSSupport_20130415";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2013-04-15",
    sdk_id: []const u8 = "Support",
    arn_namespace: ?[]const u8 = "support",
    endpoint_prefix: []const u8 = "support",
    sigv4_name: []const u8 = "support",
    name: []const u8 = "AWSSupport_20130415",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_attachments_to_set: struct {
    action_name: []const u8 = "AddAttachmentsToSet",
    Request: type = struct {
        attachment_set_id: ?[]const u8 = null,
        attachments: []Attachment,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_set_id = "attachmentSetId",
                .attachments = "attachments",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_attachments_to_set) } {
            return .{ .service_metadata = service_metadata, .action = add_attachments_to_set };
        }
    },
    Response: type = struct {
        attachment_set_id: ?[]const u8 = null,
        expiry_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_set_id = "attachmentSetId",
                .expiry_time = "expiryTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AttachmentLimitExceeded,
        AttachmentSetExpired,
        AttachmentSetIdNotFound,
        AttachmentSetSizeLimitExceeded,
        InternalServerError,
    },
} = .{};
pub const add_communication_to_case: struct {
    action_name: []const u8 = "AddCommunicationToCase",
    Request: type = struct {
        case_id: ?[]const u8 = null,
        communication_body: []const u8,
        cc_email_addresses: ?[][]const u8 = null,
        attachment_set_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .case_id = "caseId",
                .communication_body = "communicationBody",
                .cc_email_addresses = "ccEmailAddresses",
                .attachment_set_id = "attachmentSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_communication_to_case) } {
            return .{ .service_metadata = service_metadata, .action = add_communication_to_case };
        }
    },
    Response: type = struct {
        result: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "result",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AttachmentSetExpired,
        AttachmentSetIdNotFound,
        CaseIdNotFound,
        InternalServerError,
    },
} = .{};
pub const create_case: struct {
    action_name: []const u8 = "CreateCase",
    Request: type = struct {
        subject: []const u8,
        service_code: ?[]const u8 = null,
        severity_code: ?[]const u8 = null,
        category_code: ?[]const u8 = null,
        communication_body: []const u8,
        cc_email_addresses: ?[][]const u8 = null,
        language: ?[]const u8 = null,
        issue_type: ?[]const u8 = null,
        attachment_set_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subject = "subject",
                .service_code = "serviceCode",
                .severity_code = "severityCode",
                .category_code = "categoryCode",
                .communication_body = "communicationBody",
                .cc_email_addresses = "ccEmailAddresses",
                .language = "language",
                .issue_type = "issueType",
                .attachment_set_id = "attachmentSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_case) } {
            return .{ .service_metadata = service_metadata, .action = create_case };
        }
    },
    Response: type = struct {
        case_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .case_id = "caseId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AttachmentSetExpired,
        AttachmentSetIdNotFound,
        CaseCreationLimitExceeded,
        InternalServerError,
    },
} = .{};
pub const describe_attachment: struct {
    action_name: []const u8 = "DescribeAttachment",
    Request: type = struct {
        attachment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment_id = "attachmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_attachment) } {
            return .{ .service_metadata = service_metadata, .action = describe_attachment };
        }
    },
    Response: type = struct {
        attachment: ?Attachment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attachment = "attachment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AttachmentIdNotFound,
        DescribeAttachmentLimitExceeded,
        InternalServerError,
    },
} = .{};
pub const describe_cases: struct {
    action_name: []const u8 = "DescribeCases",
    Request: type = struct {
        case_id_list: ?[][]const u8 = null,
        display_id: ?[]const u8 = null,
        after_time: ?[]const u8 = null,
        before_time: ?[]const u8 = null,
        include_resolved_cases: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        language: ?[]const u8 = null,
        include_communications: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .case_id_list = "caseIdList",
                .display_id = "displayId",
                .after_time = "afterTime",
                .before_time = "beforeTime",
                .include_resolved_cases = "includeResolvedCases",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .language = "language",
                .include_communications = "includeCommunications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cases) } {
            return .{ .service_metadata = service_metadata, .action = describe_cases };
        }
    },
    Response: type = struct {
        cases: ?[]struct {
            case_id: ?[]const u8 = null,
            display_id: ?[]const u8 = null,
            subject: ?[]const u8 = null,
            status: ?[]const u8 = null,
            service_code: ?[]const u8 = null,
            category_code: ?[]const u8 = null,
            severity_code: ?[]const u8 = null,
            submitted_by: ?[]const u8 = null,
            time_created: ?[]const u8 = null,
            recent_communications: ?struct {
                communications: ?[]Communication = null,
                next_token: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .communications = "communications",
                        .next_token = "nextToken",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            cc_email_addresses: ?[][]const u8 = null,
            language: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .case_id = "caseId",
                    .display_id = "displayId",
                    .subject = "subject",
                    .status = "status",
                    .service_code = "serviceCode",
                    .category_code = "categoryCode",
                    .severity_code = "severityCode",
                    .submitted_by = "submittedBy",
                    .time_created = "timeCreated",
                    .recent_communications = "recentCommunications",
                    .cc_email_addresses = "ccEmailAddresses",
                    .language = "language",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cases = "cases",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CaseIdNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_communications: struct {
    action_name: []const u8 = "DescribeCommunications",
    Request: type = struct {
        case_id: []const u8,
        before_time: ?[]const u8 = null,
        after_time: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .case_id = "caseId",
                .before_time = "beforeTime",
                .after_time = "afterTime",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_communications) } {
            return .{ .service_metadata = service_metadata, .action = describe_communications };
        }
    },
    Response: type = struct {
        communications: ?[]Communication = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .communications = "communications",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CaseIdNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_create_case_options: struct {
    action_name: []const u8 = "DescribeCreateCaseOptions",
    Request: type = struct {
        issue_type: []const u8,
        service_code: []const u8,
        language: []const u8,
        category_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .issue_type = "issueType",
                .service_code = "serviceCode",
                .language = "language",
                .category_code = "categoryCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_create_case_options) } {
            return .{ .service_metadata = service_metadata, .action = describe_create_case_options };
        }
    },
    Response: type = struct {
        language_availability: ?[]const u8 = null,
        communication_types: ?[]struct {
            type: ?[]const u8 = null,
            supported_hours: ?[]struct {
                start_time: ?[]const u8 = null,
                end_time: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_time = "startTime",
                        .end_time = "endTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            dates_without_support: ?[]struct {
                start_date_time: ?[]const u8 = null,
                end_date_time: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_date_time = "startDateTime",
                        .end_date_time = "endDateTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "type",
                    .supported_hours = "supportedHours",
                    .dates_without_support = "datesWithoutSupport",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language_availability = "languageAvailability",
                .communication_types = "communicationTypes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        Throttling,
    },
} = .{};
pub const describe_services: struct {
    action_name: []const u8 = "DescribeServices",
    Request: type = struct {
        service_code_list: ?[][]const u8 = null,
        language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_code_list = "serviceCodeList",
                .language = "language",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_services) } {
            return .{ .service_metadata = service_metadata, .action = describe_services };
        }
    },
    Response: type = struct {
        services: ?[]struct {
            code: ?[]const u8 = null,
            name: ?[]const u8 = null,
            categories: ?[]struct {
                code: ?[]const u8 = null,
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "code",
                        .name = "name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code = "code",
                    .name = "name",
                    .categories = "categories",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .services = "services",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_severity_levels: struct {
    action_name: []const u8 = "DescribeSeverityLevels",
    Request: type = struct {
        language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language = "language",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_severity_levels) } {
            return .{ .service_metadata = service_metadata, .action = describe_severity_levels };
        }
    },
    Response: type = struct {
        severity_levels: ?[]struct {
            code: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code = "code",
                    .name = "name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .severity_levels = "severityLevels",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const describe_supported_languages: struct {
    action_name: []const u8 = "DescribeSupportedLanguages",
    Request: type = struct {
        issue_type: []const u8,
        service_code: []const u8,
        category_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .issue_type = "issueType",
                .service_code = "serviceCode",
                .category_code = "categoryCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_supported_languages) } {
            return .{ .service_metadata = service_metadata, .action = describe_supported_languages };
        }
    },
    Response: type = struct {
        supported_languages: ?[]struct {
            code: ?[]const u8 = null,
            language: ?[]const u8 = null,
            display: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code = "code",
                    .language = "language",
                    .display = "display",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .supported_languages = "supportedLanguages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        Throttling,
    },
} = .{};
pub const describe_trusted_advisor_check_refresh_statuses: struct {
    action_name: []const u8 = "DescribeTrustedAdvisorCheckRefreshStatuses",
    Request: type = struct {
        check_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_ids = "checkIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trusted_advisor_check_refresh_statuses) } {
            return .{ .service_metadata = service_metadata, .action = describe_trusted_advisor_check_refresh_statuses };
        }
    },
    Response: type = struct {
        statuses: []TrustedAdvisorCheckRefreshStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statuses = "statuses",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        Throttling,
    },
} = .{};
pub const describe_trusted_advisor_check_result: struct {
    action_name: []const u8 = "DescribeTrustedAdvisorCheckResult",
    Request: type = struct {
        check_id: []const u8,
        language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_id = "checkId",
                .language = "language",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trusted_advisor_check_result) } {
            return .{ .service_metadata = service_metadata, .action = describe_trusted_advisor_check_result };
        }
    },
    Response: type = struct {
        result: ?struct {
            check_id: []const u8,
            timestamp: []const u8,
            status: []const u8,
            resources_summary: TrustedAdvisorResourcesSummary,
            category_specific_summary: TrustedAdvisorCategorySpecificSummary,
            flagged_resources: []struct {
                status: []const u8,
                region: ?[]const u8 = null,
                resource_id: []const u8,
                is_suppressed: ?bool = null,
                metadata: [][]const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "status",
                        .region = "region",
                        .resource_id = "resourceId",
                        .is_suppressed = "isSuppressed",
                        .metadata = "metadata",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .check_id = "checkId",
                    .timestamp = "timestamp",
                    .status = "status",
                    .resources_summary = "resourcesSummary",
                    .category_specific_summary = "categorySpecificSummary",
                    .flagged_resources = "flaggedResources",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "result",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        Throttling,
    },
} = .{};
pub const describe_trusted_advisor_checks: struct {
    action_name: []const u8 = "DescribeTrustedAdvisorChecks",
    Request: type = struct {
        language: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language = "language",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trusted_advisor_checks) } {
            return .{ .service_metadata = service_metadata, .action = describe_trusted_advisor_checks };
        }
    },
    Response: type = struct {
        checks: []struct {
            id: []const u8,
            name: []const u8,
            description: []const u8,
            category: []const u8,
            metadata: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .description = "description",
                    .category = "category",
                    .metadata = "metadata",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .checks = "checks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        Throttling,
    },
} = .{};
pub const describe_trusted_advisor_check_summaries: struct {
    action_name: []const u8 = "DescribeTrustedAdvisorCheckSummaries",
    Request: type = struct {
        check_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_ids = "checkIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trusted_advisor_check_summaries) } {
            return .{ .service_metadata = service_metadata, .action = describe_trusted_advisor_check_summaries };
        }
    },
    Response: type = struct {
        summaries: []struct {
            check_id: []const u8,
            timestamp: []const u8,
            status: []const u8,
            has_flagged_resources: ?bool = null,
            resources_summary: TrustedAdvisorResourcesSummary,
            category_specific_summary: TrustedAdvisorCategorySpecificSummary,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .check_id = "checkId",
                    .timestamp = "timestamp",
                    .status = "status",
                    .has_flagged_resources = "hasFlaggedResources",
                    .resources_summary = "resourcesSummary",
                    .category_specific_summary = "categorySpecificSummary",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summaries = "summaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        Throttling,
    },
} = .{};
pub const refresh_trusted_advisor_check: struct {
    action_name: []const u8 = "RefreshTrustedAdvisorCheck",
    Request: type = struct {
        check_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_id = "checkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(refresh_trusted_advisor_check) } {
            return .{ .service_metadata = service_metadata, .action = refresh_trusted_advisor_check };
        }
    },
    Response: type = struct {
        status: TrustedAdvisorCheckRefreshStatus,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
    },
} = .{};
pub const resolve_case: struct {
    action_name: []const u8 = "ResolveCase",
    Request: type = struct {
        case_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .case_id = "caseId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resolve_case) } {
            return .{ .service_metadata = service_metadata, .action = resolve_case };
        }
    },
    Response: type = struct {
        initial_case_status: ?[]const u8 = null,
        final_case_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .initial_case_status = "initialCaseStatus",
                .final_case_status = "finalCaseStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CaseIdNotFound,
        InternalServerError,
    },
} = .{};

pub const TrustedAdvisorCheckRefreshStatus = struct {
    check_id: []const u8,
    status: []const u8,
    millis_until_next_refreshable: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .check_id = "checkId",
            .status = "status",
            .millis_until_next_refreshable = "millisUntilNextRefreshable",
        };
        return @field(mappings, field_name);
    }
};

pub const TrustedAdvisorCategorySpecificSummary = struct {
    cost_optimizing: ?TrustedAdvisorCostOptimizingSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cost_optimizing = "costOptimizing",
        };
        return @field(mappings, field_name);
    }
};

pub const TrustedAdvisorCostOptimizingSummary = struct {
    estimated_monthly_savings: f64,
    estimated_percent_monthly_savings: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .estimated_monthly_savings = "estimatedMonthlySavings",
            .estimated_percent_monthly_savings = "estimatedPercentMonthlySavings",
        };
        return @field(mappings, field_name);
    }
};

pub const TrustedAdvisorResourcesSummary = struct {
    resources_processed: i64,
    resources_flagged: i64,
    resources_ignored: i64,
    resources_suppressed: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resources_processed = "resourcesProcessed",
            .resources_flagged = "resourcesFlagged",
            .resources_ignored = "resourcesIgnored",
            .resources_suppressed = "resourcesSuppressed",
        };
        return @field(mappings, field_name);
    }
};

pub const Communication = struct {
    case_id: ?[]const u8 = null,
    body: ?[]const u8 = null,
    submitted_by: ?[]const u8 = null,
    time_created: ?[]const u8 = null,
    attachment_set: ?[]AttachmentDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .case_id = "caseId",
            .body = "body",
            .submitted_by = "submittedBy",
            .time_created = "timeCreated",
            .attachment_set = "attachmentSet",
        };
        return @field(mappings, field_name);
    }
};

pub const AttachmentDetails = struct {
    attachment_id: ?[]const u8 = null,
    file_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment_id = "attachmentId",
            .file_name = "fileName",
        };
        return @field(mappings, field_name);
    }
};

pub const Attachment = struct {
    file_name: ?[]const u8 = null,
    data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_name = "fileName",
            .data = "data",
        };
        return @field(mappings, field_name);
    }
};
