const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2012-01-25";
pub const sdk_id: []const u8 = "SWF";
pub const arn_namespace: ?[]const u8 = "swf";
pub const endpoint_prefix: []const u8 = "swf";
pub const sigv4_name: []const u8 = "swf";
pub const name: []const u8 = "SimpleWorkflowService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2012-01-25",
    sdk_id: []const u8 = "SWF",
    arn_namespace: ?[]const u8 = "swf",
    endpoint_prefix: []const u8 = "swf",
    sigv4_name: []const u8 = "swf",
    name: []const u8 = "SimpleWorkflowService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const count_closed_workflow_executions: struct {
    action_name: []const u8 = "CountClosedWorkflowExecutions",
    Request: type = struct {
        domain: []const u8,
        start_time_filter: ?ExecutionTimeFilter = null,
        close_time_filter: ?ExecutionTimeFilter = null,
        execution_filter: ?WorkflowExecutionFilter = null,
        type_filter: ?WorkflowTypeFilter = null,
        tag_filter: ?TagFilter = null,
        close_status_filter: ?CloseStatusFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .start_time_filter = "startTimeFilter",
                .close_time_filter = "closeTimeFilter",
                .execution_filter = "executionFilter",
                .type_filter = "typeFilter",
                .tag_filter = "tagFilter",
                .close_status_filter = "closeStatusFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(count_closed_workflow_executions) } {
            return .{ .service_metadata = service_metadata, .action = count_closed_workflow_executions };
        }
    },
    Response: type = struct {
        count: i64,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .count = "count",
                .truncated = "truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const count_open_workflow_executions: struct {
    action_name: []const u8 = "CountOpenWorkflowExecutions",
    Request: type = struct {
        domain: []const u8,
        start_time_filter: ExecutionTimeFilter,
        type_filter: ?WorkflowTypeFilter = null,
        tag_filter: ?TagFilter = null,
        execution_filter: ?WorkflowExecutionFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .start_time_filter = "startTimeFilter",
                .type_filter = "typeFilter",
                .tag_filter = "tagFilter",
                .execution_filter = "executionFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(count_open_workflow_executions) } {
            return .{ .service_metadata = service_metadata, .action = count_open_workflow_executions };
        }
    },
    Response: type = struct {
        count: i64,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .count = "count",
                .truncated = "truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const count_pending_activity_tasks: struct {
    action_name: []const u8 = "CountPendingActivityTasks",
    Request: type = struct {
        domain: []const u8,
        task_list: TaskList,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .task_list = "taskList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(count_pending_activity_tasks) } {
            return .{ .service_metadata = service_metadata, .action = count_pending_activity_tasks };
        }
    },
    Response: type = struct {
        count: i64,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .count = "count",
                .truncated = "truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const count_pending_decision_tasks: struct {
    action_name: []const u8 = "CountPendingDecisionTasks",
    Request: type = struct {
        domain: []const u8,
        task_list: TaskList,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .task_list = "taskList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(count_pending_decision_tasks) } {
            return .{ .service_metadata = service_metadata, .action = count_pending_decision_tasks };
        }
    },
    Response: type = struct {
        count: i64,
        truncated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .count = "count",
                .truncated = "truncated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const deprecate_activity_type: struct {
    action_name: []const u8 = "DeprecateActivityType",
    Request: type = struct {
        domain: []const u8,
        activity_type: ActivityType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .activity_type = "activityType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprecate_activity_type) } {
            return .{ .service_metadata = service_metadata, .action = deprecate_activity_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        TypeDeprecated,
        UnknownResource,
    },
} = .{};
pub const deprecate_domain: struct {
    action_name: []const u8 = "DeprecateDomain",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprecate_domain) } {
            return .{ .service_metadata = service_metadata, .action = deprecate_domain };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DomainDeprecated,
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const deprecate_workflow_type: struct {
    action_name: []const u8 = "DeprecateWorkflowType",
    Request: type = struct {
        domain: []const u8,
        workflow_type: WorkflowType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .workflow_type = "workflowType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deprecate_workflow_type) } {
            return .{ .service_metadata = service_metadata, .action = deprecate_workflow_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        TypeDeprecated,
        UnknownResource,
    },
} = .{};
pub const describe_activity_type: struct {
    action_name: []const u8 = "DescribeActivityType",
    Request: type = struct {
        domain: []const u8,
        activity_type: ActivityType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .activity_type = "activityType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_activity_type) } {
            return .{ .service_metadata = service_metadata, .action = describe_activity_type };
        }
    },
    Response: type = struct {
        type_info: ActivityTypeInfo,
        configuration: struct {
            default_task_start_to_close_timeout: ?[]const u8 = null,
            default_task_heartbeat_timeout: ?[]const u8 = null,
            default_task_list: ?TaskList = null,
            default_task_priority: ?[]const u8 = null,
            default_task_schedule_to_start_timeout: ?[]const u8 = null,
            default_task_schedule_to_close_timeout: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .default_task_start_to_close_timeout = "defaultTaskStartToCloseTimeout",
                    .default_task_heartbeat_timeout = "defaultTaskHeartbeatTimeout",
                    .default_task_list = "defaultTaskList",
                    .default_task_priority = "defaultTaskPriority",
                    .default_task_schedule_to_start_timeout = "defaultTaskScheduleToStartTimeout",
                    .default_task_schedule_to_close_timeout = "defaultTaskScheduleToCloseTimeout",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_info = "typeInfo",
                .configuration = "configuration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const describe_domain: struct {
    action_name: []const u8 = "DescribeDomain",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain };
        }
    },
    Response: type = struct {
        domain_info: DomainInfo,
        configuration: struct {
            workflow_execution_retention_period_in_days: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workflow_execution_retention_period_in_days = "workflowExecutionRetentionPeriodInDays",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_info = "domainInfo",
                .configuration = "configuration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const describe_workflow_execution: struct {
    action_name: []const u8 = "DescribeWorkflowExecution",
    Request: type = struct {
        domain: []const u8,
        execution: WorkflowExecution,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .execution = "execution",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workflow_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_workflow_execution };
        }
    },
    Response: type = struct {
        execution_info: WorkflowExecutionInfo,
        execution_configuration: struct {
            task_start_to_close_timeout: []const u8,
            execution_start_to_close_timeout: []const u8,
            task_list: TaskList,
            task_priority: ?[]const u8 = null,
            child_policy: []const u8,
            lambda_role: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_start_to_close_timeout = "taskStartToCloseTimeout",
                    .execution_start_to_close_timeout = "executionStartToCloseTimeout",
                    .task_list = "taskList",
                    .task_priority = "taskPriority",
                    .child_policy = "childPolicy",
                    .lambda_role = "lambdaRole",
                };
                return @field(mappings, field_name);
            }
        },
        open_counts: struct {
            open_activity_tasks: i64,
            open_decision_tasks: i64,
            open_timers: i64,
            open_child_workflow_executions: i64,
            open_lambda_functions: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .open_activity_tasks = "openActivityTasks",
                    .open_decision_tasks = "openDecisionTasks",
                    .open_timers = "openTimers",
                    .open_child_workflow_executions = "openChildWorkflowExecutions",
                    .open_lambda_functions = "openLambdaFunctions",
                };
                return @field(mappings, field_name);
            }
        },
        latest_activity_task_timestamp: ?i64 = null,
        latest_execution_context: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_info = "executionInfo",
                .execution_configuration = "executionConfiguration",
                .open_counts = "openCounts",
                .latest_activity_task_timestamp = "latestActivityTaskTimestamp",
                .latest_execution_context = "latestExecutionContext",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const describe_workflow_type: struct {
    action_name: []const u8 = "DescribeWorkflowType",
    Request: type = struct {
        domain: []const u8,
        workflow_type: WorkflowType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .workflow_type = "workflowType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workflow_type) } {
            return .{ .service_metadata = service_metadata, .action = describe_workflow_type };
        }
    },
    Response: type = struct {
        type_info: WorkflowTypeInfo,
        configuration: struct {
            default_task_start_to_close_timeout: ?[]const u8 = null,
            default_execution_start_to_close_timeout: ?[]const u8 = null,
            default_task_list: ?TaskList = null,
            default_task_priority: ?[]const u8 = null,
            default_child_policy: ?[]const u8 = null,
            default_lambda_role: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .default_task_start_to_close_timeout = "defaultTaskStartToCloseTimeout",
                    .default_execution_start_to_close_timeout = "defaultExecutionStartToCloseTimeout",
                    .default_task_list = "defaultTaskList",
                    .default_task_priority = "defaultTaskPriority",
                    .default_child_policy = "defaultChildPolicy",
                    .default_lambda_role = "defaultLambdaRole",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_info = "typeInfo",
                .configuration = "configuration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const get_workflow_execution_history: struct {
    action_name: []const u8 = "GetWorkflowExecutionHistory",
    Request: type = struct {
        domain: []const u8,
        execution: WorkflowExecution,
        next_page_token: ?[]const u8 = null,
        maximum_page_size: ?i64 = null,
        reverse_order: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .execution = "execution",
                .next_page_token = "nextPageToken",
                .maximum_page_size = "maximumPageSize",
                .reverse_order = "reverseOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow_execution_history) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow_execution_history };
        }
    },
    Response: type = struct {
        events: []HistoryEvent,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "events",
                .next_page_token = "nextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const list_activity_types: struct {
    action_name: []const u8 = "ListActivityTypes",
    Request: type = struct {
        domain: []const u8,
        name: ?[]const u8 = null,
        registration_status: []const u8,
        next_page_token: ?[]const u8 = null,
        maximum_page_size: ?i64 = null,
        reverse_order: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .name = "name",
                .registration_status = "registrationStatus",
                .next_page_token = "nextPageToken",
                .maximum_page_size = "maximumPageSize",
                .reverse_order = "reverseOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_activity_types) } {
            return .{ .service_metadata = service_metadata, .action = list_activity_types };
        }
    },
    Response: type = struct {
        type_infos: []ActivityTypeInfo,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_infos = "typeInfos",
                .next_page_token = "nextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const list_closed_workflow_executions: struct {
    action_name: []const u8 = "ListClosedWorkflowExecutions",
    Request: type = struct {
        domain: []const u8,
        start_time_filter: ?ExecutionTimeFilter = null,
        close_time_filter: ?ExecutionTimeFilter = null,
        execution_filter: ?WorkflowExecutionFilter = null,
        close_status_filter: ?CloseStatusFilter = null,
        type_filter: ?WorkflowTypeFilter = null,
        tag_filter: ?TagFilter = null,
        next_page_token: ?[]const u8 = null,
        maximum_page_size: ?i64 = null,
        reverse_order: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .start_time_filter = "startTimeFilter",
                .close_time_filter = "closeTimeFilter",
                .execution_filter = "executionFilter",
                .close_status_filter = "closeStatusFilter",
                .type_filter = "typeFilter",
                .tag_filter = "tagFilter",
                .next_page_token = "nextPageToken",
                .maximum_page_size = "maximumPageSize",
                .reverse_order = "reverseOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_closed_workflow_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_closed_workflow_executions };
        }
    },
    Response: type = struct {
        execution_infos: []WorkflowExecutionInfo,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_infos = "executionInfos",
                .next_page_token = "nextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const list_domains: struct {
    action_name: []const u8 = "ListDomains",
    Request: type = struct {
        next_page_token: ?[]const u8 = null,
        registration_status: []const u8,
        maximum_page_size: ?i64 = null,
        reverse_order: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_page_token = "nextPageToken",
                .registration_status = "registrationStatus",
                .maximum_page_size = "maximumPageSize",
                .reverse_order = "reverseOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domains) } {
            return .{ .service_metadata = service_metadata, .action = list_domains };
        }
    },
    Response: type = struct {
        domain_infos: []DomainInfo,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_infos = "domainInfos",
                .next_page_token = "nextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
    },
} = .{};
pub const list_open_workflow_executions: struct {
    action_name: []const u8 = "ListOpenWorkflowExecutions",
    Request: type = struct {
        domain: []const u8,
        start_time_filter: ExecutionTimeFilter,
        type_filter: ?WorkflowTypeFilter = null,
        tag_filter: ?TagFilter = null,
        next_page_token: ?[]const u8 = null,
        maximum_page_size: ?i64 = null,
        reverse_order: ?bool = null,
        execution_filter: ?WorkflowExecutionFilter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .start_time_filter = "startTimeFilter",
                .type_filter = "typeFilter",
                .tag_filter = "tagFilter",
                .next_page_token = "nextPageToken",
                .maximum_page_size = "maximumPageSize",
                .reverse_order = "reverseOrder",
                .execution_filter = "executionFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_open_workflow_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_open_workflow_executions };
        }
    },
    Response: type = struct {
        execution_infos: []WorkflowExecutionInfo,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_infos = "executionInfos",
                .next_page_token = "nextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]ResourceTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const list_workflow_types: struct {
    action_name: []const u8 = "ListWorkflowTypes",
    Request: type = struct {
        domain: []const u8,
        name: ?[]const u8 = null,
        registration_status: []const u8,
        next_page_token: ?[]const u8 = null,
        maximum_page_size: ?i64 = null,
        reverse_order: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .name = "name",
                .registration_status = "registrationStatus",
                .next_page_token = "nextPageToken",
                .maximum_page_size = "maximumPageSize",
                .reverse_order = "reverseOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workflow_types) } {
            return .{ .service_metadata = service_metadata, .action = list_workflow_types };
        }
    },
    Response: type = struct {
        type_infos: []WorkflowTypeInfo,
        next_page_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type_infos = "typeInfos",
                .next_page_token = "nextPageToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const poll_for_activity_task: struct {
    action_name: []const u8 = "PollForActivityTask",
    Request: type = struct {
        domain: []const u8,
        task_list: TaskList,
        identity: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .task_list = "taskList",
                .identity = "identity",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(poll_for_activity_task) } {
            return .{ .service_metadata = service_metadata, .action = poll_for_activity_task };
        }
    },
    Response: type = struct {
        task_token: []const u8,
        activity_id: []const u8,
        started_event_id: i64,
        workflow_execution: WorkflowExecution,
        activity_type: ActivityType,
        input: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
                .activity_id = "activityId",
                .started_event_id = "startedEventId",
                .workflow_execution = "workflowExecution",
                .activity_type = "activityType",
                .input = "input",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const poll_for_decision_task: struct {
    action_name: []const u8 = "PollForDecisionTask",
    Request: type = struct {
        domain: []const u8,
        task_list: TaskList,
        identity: ?[]const u8 = null,
        next_page_token: ?[]const u8 = null,
        maximum_page_size: ?i64 = null,
        reverse_order: ?bool = null,
        start_at_previous_started_event: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .task_list = "taskList",
                .identity = "identity",
                .next_page_token = "nextPageToken",
                .maximum_page_size = "maximumPageSize",
                .reverse_order = "reverseOrder",
                .start_at_previous_started_event = "startAtPreviousStartedEvent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(poll_for_decision_task) } {
            return .{ .service_metadata = service_metadata, .action = poll_for_decision_task };
        }
    },
    Response: type = struct {
        task_token: []const u8,
        started_event_id: i64,
        workflow_execution: WorkflowExecution,
        workflow_type: WorkflowType,
        events: []HistoryEvent,
        next_page_token: ?[]const u8 = null,
        previous_started_event_id: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
                .started_event_id = "startedEventId",
                .workflow_execution = "workflowExecution",
                .workflow_type = "workflowType",
                .events = "events",
                .next_page_token = "nextPageToken",
                .previous_started_event_id = "previousStartedEventId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const record_activity_task_heartbeat: struct {
    action_name: []const u8 = "RecordActivityTaskHeartbeat",
    Request: type = struct {
        task_token: []const u8,
        details: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
                .details = "details",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(record_activity_task_heartbeat) } {
            return .{ .service_metadata = service_metadata, .action = record_activity_task_heartbeat };
        }
    },
    Response: type = struct {
        cancel_requested: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cancel_requested = "cancelRequested",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const register_activity_type: struct {
    action_name: []const u8 = "RegisterActivityType",
    Request: type = struct {
        domain: []const u8,
        name: []const u8,
        version: []const u8,
        description: ?[]const u8 = null,
        default_task_start_to_close_timeout: ?[]const u8 = null,
        default_task_heartbeat_timeout: ?[]const u8 = null,
        default_task_list: ?TaskList = null,
        default_task_priority: ?[]const u8 = null,
        default_task_schedule_to_start_timeout: ?[]const u8 = null,
        default_task_schedule_to_close_timeout: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .name = "name",
                .version = "version",
                .description = "description",
                .default_task_start_to_close_timeout = "defaultTaskStartToCloseTimeout",
                .default_task_heartbeat_timeout = "defaultTaskHeartbeatTimeout",
                .default_task_list = "defaultTaskList",
                .default_task_priority = "defaultTaskPriority",
                .default_task_schedule_to_start_timeout = "defaultTaskScheduleToStartTimeout",
                .default_task_schedule_to_close_timeout = "defaultTaskScheduleToCloseTimeout",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_activity_type) } {
            return .{ .service_metadata = service_metadata, .action = register_activity_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        LimitExceeded,
        OperationNotPermitted,
        TypeAlreadyExists,
        UnknownResource,
    },
} = .{};
pub const register_domain: struct {
    action_name: []const u8 = "RegisterDomain",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        workflow_execution_retention_period_in_days: []const u8,
        tags: ?[]ResourceTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .workflow_execution_retention_period_in_days = "workflowExecutionRetentionPeriodInDays",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_domain) } {
            return .{ .service_metadata = service_metadata, .action = register_domain };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DomainAlreadyExists,
        LimitExceeded,
        OperationNotPermitted,
        TooManyTags,
    },
} = .{};
pub const register_workflow_type: struct {
    action_name: []const u8 = "RegisterWorkflowType",
    Request: type = struct {
        domain: []const u8,
        name: []const u8,
        version: []const u8,
        description: ?[]const u8 = null,
        default_task_start_to_close_timeout: ?[]const u8 = null,
        default_execution_start_to_close_timeout: ?[]const u8 = null,
        default_task_list: ?TaskList = null,
        default_task_priority: ?[]const u8 = null,
        default_child_policy: ?[]const u8 = null,
        default_lambda_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .name = "name",
                .version = "version",
                .description = "description",
                .default_task_start_to_close_timeout = "defaultTaskStartToCloseTimeout",
                .default_execution_start_to_close_timeout = "defaultExecutionStartToCloseTimeout",
                .default_task_list = "defaultTaskList",
                .default_task_priority = "defaultTaskPriority",
                .default_child_policy = "defaultChildPolicy",
                .default_lambda_role = "defaultLambdaRole",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_workflow_type) } {
            return .{ .service_metadata = service_metadata, .action = register_workflow_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        LimitExceeded,
        OperationNotPermitted,
        TypeAlreadyExists,
        UnknownResource,
    },
} = .{};
pub const request_cancel_workflow_execution: struct {
    action_name: []const u8 = "RequestCancelWorkflowExecution",
    Request: type = struct {
        domain: []const u8,
        workflow_id: []const u8,
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .workflow_id = "workflowId",
                .run_id = "runId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(request_cancel_workflow_execution) } {
            return .{ .service_metadata = service_metadata, .action = request_cancel_workflow_execution };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const respond_activity_task_canceled: struct {
    action_name: []const u8 = "RespondActivityTaskCanceled",
    Request: type = struct {
        task_token: []const u8,
        details: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
                .details = "details",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(respond_activity_task_canceled) } {
            return .{ .service_metadata = service_metadata, .action = respond_activity_task_canceled };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const respond_activity_task_completed: struct {
    action_name: []const u8 = "RespondActivityTaskCompleted",
    Request: type = struct {
        task_token: []const u8,
        result: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
                .result = "result",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(respond_activity_task_completed) } {
            return .{ .service_metadata = service_metadata, .action = respond_activity_task_completed };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const respond_activity_task_failed: struct {
    action_name: []const u8 = "RespondActivityTaskFailed",
    Request: type = struct {
        task_token: []const u8,
        reason: ?[]const u8 = null,
        details: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
                .reason = "reason",
                .details = "details",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(respond_activity_task_failed) } {
            return .{ .service_metadata = service_metadata, .action = respond_activity_task_failed };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const respond_decision_task_completed: struct {
    action_name: []const u8 = "RespondDecisionTaskCompleted",
    Request: type = struct {
        task_token: []const u8,
        decisions: ?[]struct {
            decision_type: []const u8,
            schedule_activity_task_decision_attributes: ?struct {
                activity_type: ActivityType,
                activity_id: []const u8,
                control: ?[]const u8 = null,
                input: ?[]const u8 = null,
                schedule_to_close_timeout: ?[]const u8 = null,
                task_list: ?TaskList = null,
                task_priority: ?[]const u8 = null,
                schedule_to_start_timeout: ?[]const u8 = null,
                start_to_close_timeout: ?[]const u8 = null,
                heartbeat_timeout: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .activity_type = "activityType",
                        .activity_id = "activityId",
                        .control = "control",
                        .input = "input",
                        .schedule_to_close_timeout = "scheduleToCloseTimeout",
                        .task_list = "taskList",
                        .task_priority = "taskPriority",
                        .schedule_to_start_timeout = "scheduleToStartTimeout",
                        .start_to_close_timeout = "startToCloseTimeout",
                        .heartbeat_timeout = "heartbeatTimeout",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            request_cancel_activity_task_decision_attributes: ?struct {
                activity_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .activity_id = "activityId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            complete_workflow_execution_decision_attributes: ?struct {
                result: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .result = "result",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            fail_workflow_execution_decision_attributes: ?struct {
                reason: ?[]const u8 = null,
                details: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .reason = "reason",
                        .details = "details",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            cancel_workflow_execution_decision_attributes: ?struct {
                details: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .details = "details",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            continue_as_new_workflow_execution_decision_attributes: ?struct {
                input: ?[]const u8 = null,
                execution_start_to_close_timeout: ?[]const u8 = null,
                task_list: ?TaskList = null,
                task_priority: ?[]const u8 = null,
                task_start_to_close_timeout: ?[]const u8 = null,
                child_policy: ?[]const u8 = null,
                tag_list: ?[][]const u8 = null,
                workflow_type_version: ?[]const u8 = null,
                lambda_role: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input = "input",
                        .execution_start_to_close_timeout = "executionStartToCloseTimeout",
                        .task_list = "taskList",
                        .task_priority = "taskPriority",
                        .task_start_to_close_timeout = "taskStartToCloseTimeout",
                        .child_policy = "childPolicy",
                        .tag_list = "tagList",
                        .workflow_type_version = "workflowTypeVersion",
                        .lambda_role = "lambdaRole",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            record_marker_decision_attributes: ?struct {
                marker_name: []const u8,
                details: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .marker_name = "markerName",
                        .details = "details",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            start_timer_decision_attributes: ?struct {
                timer_id: []const u8,
                control: ?[]const u8 = null,
                start_to_fire_timeout: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .timer_id = "timerId",
                        .control = "control",
                        .start_to_fire_timeout = "startToFireTimeout",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            cancel_timer_decision_attributes: ?struct {
                timer_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .timer_id = "timerId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            signal_external_workflow_execution_decision_attributes: ?struct {
                workflow_id: []const u8,
                run_id: ?[]const u8 = null,
                signal_name: []const u8,
                input: ?[]const u8 = null,
                control: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .workflow_id = "workflowId",
                        .run_id = "runId",
                        .signal_name = "signalName",
                        .input = "input",
                        .control = "control",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            request_cancel_external_workflow_execution_decision_attributes: ?struct {
                workflow_id: []const u8,
                run_id: ?[]const u8 = null,
                control: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .workflow_id = "workflowId",
                        .run_id = "runId",
                        .control = "control",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            start_child_workflow_execution_decision_attributes: ?struct {
                workflow_type: WorkflowType,
                workflow_id: []const u8,
                control: ?[]const u8 = null,
                input: ?[]const u8 = null,
                execution_start_to_close_timeout: ?[]const u8 = null,
                task_list: ?TaskList = null,
                task_priority: ?[]const u8 = null,
                task_start_to_close_timeout: ?[]const u8 = null,
                child_policy: ?[]const u8 = null,
                tag_list: ?[][]const u8 = null,
                lambda_role: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .workflow_type = "workflowType",
                        .workflow_id = "workflowId",
                        .control = "control",
                        .input = "input",
                        .execution_start_to_close_timeout = "executionStartToCloseTimeout",
                        .task_list = "taskList",
                        .task_priority = "taskPriority",
                        .task_start_to_close_timeout = "taskStartToCloseTimeout",
                        .child_policy = "childPolicy",
                        .tag_list = "tagList",
                        .lambda_role = "lambdaRole",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            schedule_lambda_function_decision_attributes: ?struct {
                id: []const u8,
                name: []const u8,
                control: ?[]const u8 = null,
                input: ?[]const u8 = null,
                start_to_close_timeout: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "id",
                        .name = "name",
                        .control = "control",
                        .input = "input",
                        .start_to_close_timeout = "startToCloseTimeout",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .decision_type = "decisionType",
                    .schedule_activity_task_decision_attributes = "scheduleActivityTaskDecisionAttributes",
                    .request_cancel_activity_task_decision_attributes = "requestCancelActivityTaskDecisionAttributes",
                    .complete_workflow_execution_decision_attributes = "completeWorkflowExecutionDecisionAttributes",
                    .fail_workflow_execution_decision_attributes = "failWorkflowExecutionDecisionAttributes",
                    .cancel_workflow_execution_decision_attributes = "cancelWorkflowExecutionDecisionAttributes",
                    .continue_as_new_workflow_execution_decision_attributes = "continueAsNewWorkflowExecutionDecisionAttributes",
                    .record_marker_decision_attributes = "recordMarkerDecisionAttributes",
                    .start_timer_decision_attributes = "startTimerDecisionAttributes",
                    .cancel_timer_decision_attributes = "cancelTimerDecisionAttributes",
                    .signal_external_workflow_execution_decision_attributes = "signalExternalWorkflowExecutionDecisionAttributes",
                    .request_cancel_external_workflow_execution_decision_attributes = "requestCancelExternalWorkflowExecutionDecisionAttributes",
                    .start_child_workflow_execution_decision_attributes = "startChildWorkflowExecutionDecisionAttributes",
                    .schedule_lambda_function_decision_attributes = "scheduleLambdaFunctionDecisionAttributes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        execution_context: ?[]const u8 = null,
        task_list: ?TaskList = null,
        task_list_schedule_to_start_timeout: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
                .decisions = "decisions",
                .execution_context = "executionContext",
                .task_list = "taskList",
                .task_list_schedule_to_start_timeout = "taskListScheduleToStartTimeout",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(respond_decision_task_completed) } {
            return .{ .service_metadata = service_metadata, .action = respond_decision_task_completed };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const signal_workflow_execution: struct {
    action_name: []const u8 = "SignalWorkflowExecution",
    Request: type = struct {
        domain: []const u8,
        workflow_id: []const u8,
        run_id: ?[]const u8 = null,
        signal_name: []const u8,
        input: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .workflow_id = "workflowId",
                .run_id = "runId",
                .signal_name = "signalName",
                .input = "input",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(signal_workflow_execution) } {
            return .{ .service_metadata = service_metadata, .action = signal_workflow_execution };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const start_workflow_execution: struct {
    action_name: []const u8 = "StartWorkflowExecution",
    Request: type = struct {
        domain: []const u8,
        workflow_id: []const u8,
        workflow_type: WorkflowType,
        task_list: ?TaskList = null,
        task_priority: ?[]const u8 = null,
        input: ?[]const u8 = null,
        execution_start_to_close_timeout: ?[]const u8 = null,
        tag_list: ?[][]const u8 = null,
        task_start_to_close_timeout: ?[]const u8 = null,
        child_policy: ?[]const u8 = null,
        lambda_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .workflow_id = "workflowId",
                .workflow_type = "workflowType",
                .task_list = "taskList",
                .task_priority = "taskPriority",
                .input = "input",
                .execution_start_to_close_timeout = "executionStartToCloseTimeout",
                .tag_list = "tagList",
                .task_start_to_close_timeout = "taskStartToCloseTimeout",
                .child_policy = "childPolicy",
                .lambda_role = "lambdaRole",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_workflow_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_workflow_execution };
        }
    },
    Response: type = struct {
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "runId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DefaultUndefined,
        LimitExceeded,
        OperationNotPermitted,
        TypeDeprecated,
        UnknownResource,
        WorkflowExecutionAlreadyStarted,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []ResourceTag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        LimitExceeded,
        OperationNotPermitted,
        TooManyTags,
        UnknownResource,
    },
} = .{};
pub const terminate_workflow_execution: struct {
    action_name: []const u8 = "TerminateWorkflowExecution",
    Request: type = struct {
        domain: []const u8,
        workflow_id: []const u8,
        run_id: ?[]const u8 = null,
        reason: ?[]const u8 = null,
        details: ?[]const u8 = null,
        child_policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .workflow_id = "workflowId",
                .run_id = "runId",
                .reason = "reason",
                .details = "details",
                .child_policy = "childPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_workflow_execution) } {
            return .{ .service_metadata = service_metadata, .action = terminate_workflow_execution };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const undeprecate_activity_type: struct {
    action_name: []const u8 = "UndeprecateActivityType",
    Request: type = struct {
        domain: []const u8,
        activity_type: ActivityType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .activity_type = "activityType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(undeprecate_activity_type) } {
            return .{ .service_metadata = service_metadata, .action = undeprecate_activity_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        TypeAlreadyExists,
        UnknownResource,
    },
} = .{};
pub const undeprecate_domain: struct {
    action_name: []const u8 = "UndeprecateDomain",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(undeprecate_domain) } {
            return .{ .service_metadata = service_metadata, .action = undeprecate_domain };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DomainAlreadyExists,
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};
pub const undeprecate_workflow_type: struct {
    action_name: []const u8 = "UndeprecateWorkflowType",
    Request: type = struct {
        domain: []const u8,
        workflow_type: WorkflowType,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain = "domain",
                .workflow_type = "workflowType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(undeprecate_workflow_type) } {
            return .{ .service_metadata = service_metadata, .action = undeprecate_workflow_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        OperationNotPermitted,
        TypeAlreadyExists,
        UnknownResource,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        LimitExceeded,
        OperationNotPermitted,
        UnknownResource,
    },
} = .{};

pub const WorkflowType = struct {
    name: []const u8,
    version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityType = struct {
    name: []const u8,
    version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceTag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskList = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const HistoryEvent = struct {
    event_timestamp: i64,
    event_type: []const u8,
    event_id: i64,
    workflow_execution_started_event_attributes: ?WorkflowExecutionStartedEventAttributes = null,
    workflow_execution_completed_event_attributes: ?WorkflowExecutionCompletedEventAttributes = null,
    complete_workflow_execution_failed_event_attributes: ?CompleteWorkflowExecutionFailedEventAttributes = null,
    workflow_execution_failed_event_attributes: ?WorkflowExecutionFailedEventAttributes = null,
    fail_workflow_execution_failed_event_attributes: ?FailWorkflowExecutionFailedEventAttributes = null,
    workflow_execution_timed_out_event_attributes: ?WorkflowExecutionTimedOutEventAttributes = null,
    workflow_execution_canceled_event_attributes: ?WorkflowExecutionCanceledEventAttributes = null,
    cancel_workflow_execution_failed_event_attributes: ?CancelWorkflowExecutionFailedEventAttributes = null,
    workflow_execution_continued_as_new_event_attributes: ?WorkflowExecutionContinuedAsNewEventAttributes = null,
    continue_as_new_workflow_execution_failed_event_attributes: ?ContinueAsNewWorkflowExecutionFailedEventAttributes = null,
    workflow_execution_terminated_event_attributes: ?WorkflowExecutionTerminatedEventAttributes = null,
    workflow_execution_cancel_requested_event_attributes: ?WorkflowExecutionCancelRequestedEventAttributes = null,
    decision_task_scheduled_event_attributes: ?DecisionTaskScheduledEventAttributes = null,
    decision_task_started_event_attributes: ?DecisionTaskStartedEventAttributes = null,
    decision_task_completed_event_attributes: ?DecisionTaskCompletedEventAttributes = null,
    decision_task_timed_out_event_attributes: ?DecisionTaskTimedOutEventAttributes = null,
    activity_task_scheduled_event_attributes: ?ActivityTaskScheduledEventAttributes = null,
    activity_task_started_event_attributes: ?ActivityTaskStartedEventAttributes = null,
    activity_task_completed_event_attributes: ?ActivityTaskCompletedEventAttributes = null,
    activity_task_failed_event_attributes: ?ActivityTaskFailedEventAttributes = null,
    activity_task_timed_out_event_attributes: ?ActivityTaskTimedOutEventAttributes = null,
    activity_task_canceled_event_attributes: ?ActivityTaskCanceledEventAttributes = null,
    activity_task_cancel_requested_event_attributes: ?ActivityTaskCancelRequestedEventAttributes = null,
    workflow_execution_signaled_event_attributes: ?WorkflowExecutionSignaledEventAttributes = null,
    marker_recorded_event_attributes: ?MarkerRecordedEventAttributes = null,
    record_marker_failed_event_attributes: ?RecordMarkerFailedEventAttributes = null,
    timer_started_event_attributes: ?TimerStartedEventAttributes = null,
    timer_fired_event_attributes: ?TimerFiredEventAttributes = null,
    timer_canceled_event_attributes: ?TimerCanceledEventAttributes = null,
    start_child_workflow_execution_initiated_event_attributes: ?StartChildWorkflowExecutionInitiatedEventAttributes = null,
    child_workflow_execution_started_event_attributes: ?ChildWorkflowExecutionStartedEventAttributes = null,
    child_workflow_execution_completed_event_attributes: ?ChildWorkflowExecutionCompletedEventAttributes = null,
    child_workflow_execution_failed_event_attributes: ?ChildWorkflowExecutionFailedEventAttributes = null,
    child_workflow_execution_timed_out_event_attributes: ?ChildWorkflowExecutionTimedOutEventAttributes = null,
    child_workflow_execution_canceled_event_attributes: ?ChildWorkflowExecutionCanceledEventAttributes = null,
    child_workflow_execution_terminated_event_attributes: ?ChildWorkflowExecutionTerminatedEventAttributes = null,
    signal_external_workflow_execution_initiated_event_attributes: ?SignalExternalWorkflowExecutionInitiatedEventAttributes = null,
    external_workflow_execution_signaled_event_attributes: ?ExternalWorkflowExecutionSignaledEventAttributes = null,
    signal_external_workflow_execution_failed_event_attributes: ?SignalExternalWorkflowExecutionFailedEventAttributes = null,
    external_workflow_execution_cancel_requested_event_attributes: ?ExternalWorkflowExecutionCancelRequestedEventAttributes = null,
    request_cancel_external_workflow_execution_initiated_event_attributes: ?RequestCancelExternalWorkflowExecutionInitiatedEventAttributes = null,
    request_cancel_external_workflow_execution_failed_event_attributes: ?RequestCancelExternalWorkflowExecutionFailedEventAttributes = null,
    schedule_activity_task_failed_event_attributes: ?ScheduleActivityTaskFailedEventAttributes = null,
    request_cancel_activity_task_failed_event_attributes: ?RequestCancelActivityTaskFailedEventAttributes = null,
    start_timer_failed_event_attributes: ?StartTimerFailedEventAttributes = null,
    cancel_timer_failed_event_attributes: ?CancelTimerFailedEventAttributes = null,
    start_child_workflow_execution_failed_event_attributes: ?StartChildWorkflowExecutionFailedEventAttributes = null,
    lambda_function_scheduled_event_attributes: ?LambdaFunctionScheduledEventAttributes = null,
    lambda_function_started_event_attributes: ?LambdaFunctionStartedEventAttributes = null,
    lambda_function_completed_event_attributes: ?LambdaFunctionCompletedEventAttributes = null,
    lambda_function_failed_event_attributes: ?LambdaFunctionFailedEventAttributes = null,
    lambda_function_timed_out_event_attributes: ?LambdaFunctionTimedOutEventAttributes = null,
    schedule_lambda_function_failed_event_attributes: ?ScheduleLambdaFunctionFailedEventAttributes = null,
    start_lambda_function_failed_event_attributes: ?StartLambdaFunctionFailedEventAttributes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_timestamp = "eventTimestamp",
            .event_type = "eventType",
            .event_id = "eventId",
            .workflow_execution_started_event_attributes = "workflowExecutionStartedEventAttributes",
            .workflow_execution_completed_event_attributes = "workflowExecutionCompletedEventAttributes",
            .complete_workflow_execution_failed_event_attributes = "completeWorkflowExecutionFailedEventAttributes",
            .workflow_execution_failed_event_attributes = "workflowExecutionFailedEventAttributes",
            .fail_workflow_execution_failed_event_attributes = "failWorkflowExecutionFailedEventAttributes",
            .workflow_execution_timed_out_event_attributes = "workflowExecutionTimedOutEventAttributes",
            .workflow_execution_canceled_event_attributes = "workflowExecutionCanceledEventAttributes",
            .cancel_workflow_execution_failed_event_attributes = "cancelWorkflowExecutionFailedEventAttributes",
            .workflow_execution_continued_as_new_event_attributes = "workflowExecutionContinuedAsNewEventAttributes",
            .continue_as_new_workflow_execution_failed_event_attributes = "continueAsNewWorkflowExecutionFailedEventAttributes",
            .workflow_execution_terminated_event_attributes = "workflowExecutionTerminatedEventAttributes",
            .workflow_execution_cancel_requested_event_attributes = "workflowExecutionCancelRequestedEventAttributes",
            .decision_task_scheduled_event_attributes = "decisionTaskScheduledEventAttributes",
            .decision_task_started_event_attributes = "decisionTaskStartedEventAttributes",
            .decision_task_completed_event_attributes = "decisionTaskCompletedEventAttributes",
            .decision_task_timed_out_event_attributes = "decisionTaskTimedOutEventAttributes",
            .activity_task_scheduled_event_attributes = "activityTaskScheduledEventAttributes",
            .activity_task_started_event_attributes = "activityTaskStartedEventAttributes",
            .activity_task_completed_event_attributes = "activityTaskCompletedEventAttributes",
            .activity_task_failed_event_attributes = "activityTaskFailedEventAttributes",
            .activity_task_timed_out_event_attributes = "activityTaskTimedOutEventAttributes",
            .activity_task_canceled_event_attributes = "activityTaskCanceledEventAttributes",
            .activity_task_cancel_requested_event_attributes = "activityTaskCancelRequestedEventAttributes",
            .workflow_execution_signaled_event_attributes = "workflowExecutionSignaledEventAttributes",
            .marker_recorded_event_attributes = "markerRecordedEventAttributes",
            .record_marker_failed_event_attributes = "recordMarkerFailedEventAttributes",
            .timer_started_event_attributes = "timerStartedEventAttributes",
            .timer_fired_event_attributes = "timerFiredEventAttributes",
            .timer_canceled_event_attributes = "timerCanceledEventAttributes",
            .start_child_workflow_execution_initiated_event_attributes = "startChildWorkflowExecutionInitiatedEventAttributes",
            .child_workflow_execution_started_event_attributes = "childWorkflowExecutionStartedEventAttributes",
            .child_workflow_execution_completed_event_attributes = "childWorkflowExecutionCompletedEventAttributes",
            .child_workflow_execution_failed_event_attributes = "childWorkflowExecutionFailedEventAttributes",
            .child_workflow_execution_timed_out_event_attributes = "childWorkflowExecutionTimedOutEventAttributes",
            .child_workflow_execution_canceled_event_attributes = "childWorkflowExecutionCanceledEventAttributes",
            .child_workflow_execution_terminated_event_attributes = "childWorkflowExecutionTerminatedEventAttributes",
            .signal_external_workflow_execution_initiated_event_attributes = "signalExternalWorkflowExecutionInitiatedEventAttributes",
            .external_workflow_execution_signaled_event_attributes = "externalWorkflowExecutionSignaledEventAttributes",
            .signal_external_workflow_execution_failed_event_attributes = "signalExternalWorkflowExecutionFailedEventAttributes",
            .external_workflow_execution_cancel_requested_event_attributes = "externalWorkflowExecutionCancelRequestedEventAttributes",
            .request_cancel_external_workflow_execution_initiated_event_attributes = "requestCancelExternalWorkflowExecutionInitiatedEventAttributes",
            .request_cancel_external_workflow_execution_failed_event_attributes = "requestCancelExternalWorkflowExecutionFailedEventAttributes",
            .schedule_activity_task_failed_event_attributes = "scheduleActivityTaskFailedEventAttributes",
            .request_cancel_activity_task_failed_event_attributes = "requestCancelActivityTaskFailedEventAttributes",
            .start_timer_failed_event_attributes = "startTimerFailedEventAttributes",
            .cancel_timer_failed_event_attributes = "cancelTimerFailedEventAttributes",
            .start_child_workflow_execution_failed_event_attributes = "startChildWorkflowExecutionFailedEventAttributes",
            .lambda_function_scheduled_event_attributes = "lambdaFunctionScheduledEventAttributes",
            .lambda_function_started_event_attributes = "lambdaFunctionStartedEventAttributes",
            .lambda_function_completed_event_attributes = "lambdaFunctionCompletedEventAttributes",
            .lambda_function_failed_event_attributes = "lambdaFunctionFailedEventAttributes",
            .lambda_function_timed_out_event_attributes = "lambdaFunctionTimedOutEventAttributes",
            .schedule_lambda_function_failed_event_attributes = "scheduleLambdaFunctionFailedEventAttributes",
            .start_lambda_function_failed_event_attributes = "startLambdaFunctionFailedEventAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const StartLambdaFunctionFailedEventAttributes = struct {
    scheduled_event_id: ?i64 = null,
    cause: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scheduled_event_id = "scheduledEventId",
            .cause = "cause",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduleLambdaFunctionFailedEventAttributes = struct {
    id: []const u8,
    name: []const u8,
    cause: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .cause = "cause",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionTimedOutEventAttributes = struct {
    scheduled_event_id: i64,
    started_event_id: i64,
    timeout_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scheduled_event_id = "scheduledEventId",
            .started_event_id = "startedEventId",
            .timeout_type = "timeoutType",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionFailedEventAttributes = struct {
    scheduled_event_id: i64,
    started_event_id: i64,
    reason: ?[]const u8 = null,
    details: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scheduled_event_id = "scheduledEventId",
            .started_event_id = "startedEventId",
            .reason = "reason",
            .details = "details",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionCompletedEventAttributes = struct {
    scheduled_event_id: i64,
    started_event_id: i64,
    result: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scheduled_event_id = "scheduledEventId",
            .started_event_id = "startedEventId",
            .result = "result",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionStartedEventAttributes = struct {
    scheduled_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scheduled_event_id = "scheduledEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaFunctionScheduledEventAttributes = struct {
    id: []const u8,
    name: []const u8,
    control: ?[]const u8 = null,
    input: ?[]const u8 = null,
    start_to_close_timeout: ?[]const u8 = null,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .control = "control",
            .input = "input",
            .start_to_close_timeout = "startToCloseTimeout",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const StartChildWorkflowExecutionFailedEventAttributes = struct {
    workflow_type: WorkflowType,
    cause: []const u8,
    workflow_id: []const u8,
    initiated_event_id: i64,
    decision_task_completed_event_id: i64,
    control: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_type = "workflowType",
            .cause = "cause",
            .workflow_id = "workflowId",
            .initiated_event_id = "initiatedEventId",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
            .control = "control",
        };
        return @field(mappings, field_name);
    }
};

pub const CancelTimerFailedEventAttributes = struct {
    timer_id: []const u8,
    cause: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timer_id = "timerId",
            .cause = "cause",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const StartTimerFailedEventAttributes = struct {
    timer_id: []const u8,
    cause: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timer_id = "timerId",
            .cause = "cause",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestCancelActivityTaskFailedEventAttributes = struct {
    activity_id: []const u8,
    cause: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activity_id = "activityId",
            .cause = "cause",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduleActivityTaskFailedEventAttributes = struct {
    activity_type: ActivityType,
    activity_id: []const u8,
    cause: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activity_type = "activityType",
            .activity_id = "activityId",
            .cause = "cause",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestCancelExternalWorkflowExecutionFailedEventAttributes = struct {
    workflow_id: []const u8,
    run_id: ?[]const u8 = null,
    cause: []const u8,
    initiated_event_id: i64,
    decision_task_completed_event_id: i64,
    control: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_id = "workflowId",
            .run_id = "runId",
            .cause = "cause",
            .initiated_event_id = "initiatedEventId",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
            .control = "control",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestCancelExternalWorkflowExecutionInitiatedEventAttributes = struct {
    workflow_id: []const u8,
    run_id: ?[]const u8 = null,
    decision_task_completed_event_id: i64,
    control: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_id = "workflowId",
            .run_id = "runId",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
            .control = "control",
        };
        return @field(mappings, field_name);
    }
};

pub const ExternalWorkflowExecutionCancelRequestedEventAttributes = struct {
    workflow_execution: WorkflowExecution,
    initiated_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_execution = "workflowExecution",
            .initiated_event_id = "initiatedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecution = struct {
    workflow_id: []const u8,
    run_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_id = "workflowId",
            .run_id = "runId",
        };
        return @field(mappings, field_name);
    }
};

pub const SignalExternalWorkflowExecutionFailedEventAttributes = struct {
    workflow_id: []const u8,
    run_id: ?[]const u8 = null,
    cause: []const u8,
    initiated_event_id: i64,
    decision_task_completed_event_id: i64,
    control: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_id = "workflowId",
            .run_id = "runId",
            .cause = "cause",
            .initiated_event_id = "initiatedEventId",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
            .control = "control",
        };
        return @field(mappings, field_name);
    }
};

pub const ExternalWorkflowExecutionSignaledEventAttributes = struct {
    workflow_execution: WorkflowExecution,
    initiated_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_execution = "workflowExecution",
            .initiated_event_id = "initiatedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const SignalExternalWorkflowExecutionInitiatedEventAttributes = struct {
    workflow_id: []const u8,
    run_id: ?[]const u8 = null,
    signal_name: []const u8,
    input: ?[]const u8 = null,
    decision_task_completed_event_id: i64,
    control: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_id = "workflowId",
            .run_id = "runId",
            .signal_name = "signalName",
            .input = "input",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
            .control = "control",
        };
        return @field(mappings, field_name);
    }
};

pub const ChildWorkflowExecutionTerminatedEventAttributes = struct {
    workflow_execution: WorkflowExecution,
    workflow_type: WorkflowType,
    initiated_event_id: i64,
    started_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_execution = "workflowExecution",
            .workflow_type = "workflowType",
            .initiated_event_id = "initiatedEventId",
            .started_event_id = "startedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ChildWorkflowExecutionCanceledEventAttributes = struct {
    workflow_execution: WorkflowExecution,
    workflow_type: WorkflowType,
    details: ?[]const u8 = null,
    initiated_event_id: i64,
    started_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_execution = "workflowExecution",
            .workflow_type = "workflowType",
            .details = "details",
            .initiated_event_id = "initiatedEventId",
            .started_event_id = "startedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ChildWorkflowExecutionTimedOutEventAttributes = struct {
    workflow_execution: WorkflowExecution,
    workflow_type: WorkflowType,
    timeout_type: []const u8,
    initiated_event_id: i64,
    started_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_execution = "workflowExecution",
            .workflow_type = "workflowType",
            .timeout_type = "timeoutType",
            .initiated_event_id = "initiatedEventId",
            .started_event_id = "startedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ChildWorkflowExecutionFailedEventAttributes = struct {
    workflow_execution: WorkflowExecution,
    workflow_type: WorkflowType,
    reason: ?[]const u8 = null,
    details: ?[]const u8 = null,
    initiated_event_id: i64,
    started_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_execution = "workflowExecution",
            .workflow_type = "workflowType",
            .reason = "reason",
            .details = "details",
            .initiated_event_id = "initiatedEventId",
            .started_event_id = "startedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ChildWorkflowExecutionCompletedEventAttributes = struct {
    workflow_execution: WorkflowExecution,
    workflow_type: WorkflowType,
    result: ?[]const u8 = null,
    initiated_event_id: i64,
    started_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_execution = "workflowExecution",
            .workflow_type = "workflowType",
            .result = "result",
            .initiated_event_id = "initiatedEventId",
            .started_event_id = "startedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ChildWorkflowExecutionStartedEventAttributes = struct {
    workflow_execution: WorkflowExecution,
    workflow_type: WorkflowType,
    initiated_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_execution = "workflowExecution",
            .workflow_type = "workflowType",
            .initiated_event_id = "initiatedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const StartChildWorkflowExecutionInitiatedEventAttributes = struct {
    workflow_id: []const u8,
    workflow_type: WorkflowType,
    control: ?[]const u8 = null,
    input: ?[]const u8 = null,
    execution_start_to_close_timeout: ?[]const u8 = null,
    task_list: TaskList,
    task_priority: ?[]const u8 = null,
    decision_task_completed_event_id: i64,
    child_policy: []const u8,
    task_start_to_close_timeout: ?[]const u8 = null,
    tag_list: ?[][]const u8 = null,
    lambda_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_id = "workflowId",
            .workflow_type = "workflowType",
            .control = "control",
            .input = "input",
            .execution_start_to_close_timeout = "executionStartToCloseTimeout",
            .task_list = "taskList",
            .task_priority = "taskPriority",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
            .child_policy = "childPolicy",
            .task_start_to_close_timeout = "taskStartToCloseTimeout",
            .tag_list = "tagList",
            .lambda_role = "lambdaRole",
        };
        return @field(mappings, field_name);
    }
};

pub const TimerCanceledEventAttributes = struct {
    timer_id: []const u8,
    started_event_id: i64,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timer_id = "timerId",
            .started_event_id = "startedEventId",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const TimerFiredEventAttributes = struct {
    timer_id: []const u8,
    started_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timer_id = "timerId",
            .started_event_id = "startedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const TimerStartedEventAttributes = struct {
    timer_id: []const u8,
    control: ?[]const u8 = null,
    start_to_fire_timeout: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timer_id = "timerId",
            .control = "control",
            .start_to_fire_timeout = "startToFireTimeout",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const RecordMarkerFailedEventAttributes = struct {
    marker_name: []const u8,
    cause: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .marker_name = "markerName",
            .cause = "cause",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const MarkerRecordedEventAttributes = struct {
    marker_name: []const u8,
    details: ?[]const u8 = null,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .marker_name = "markerName",
            .details = "details",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionSignaledEventAttributes = struct {
    signal_name: []const u8,
    input: ?[]const u8 = null,
    external_workflow_execution: ?WorkflowExecution = null,
    external_initiated_event_id: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signal_name = "signalName",
            .input = "input",
            .external_workflow_execution = "externalWorkflowExecution",
            .external_initiated_event_id = "externalInitiatedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityTaskCancelRequestedEventAttributes = struct {
    decision_task_completed_event_id: i64,
    activity_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
            .activity_id = "activityId",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityTaskCanceledEventAttributes = struct {
    details: ?[]const u8 = null,
    scheduled_event_id: i64,
    started_event_id: i64,
    latest_cancel_requested_event_id: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .details = "details",
            .scheduled_event_id = "scheduledEventId",
            .started_event_id = "startedEventId",
            .latest_cancel_requested_event_id = "latestCancelRequestedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityTaskTimedOutEventAttributes = struct {
    timeout_type: []const u8,
    scheduled_event_id: i64,
    started_event_id: i64,
    details: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_type = "timeoutType",
            .scheduled_event_id = "scheduledEventId",
            .started_event_id = "startedEventId",
            .details = "details",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityTaskFailedEventAttributes = struct {
    reason: ?[]const u8 = null,
    details: ?[]const u8 = null,
    scheduled_event_id: i64,
    started_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reason = "reason",
            .details = "details",
            .scheduled_event_id = "scheduledEventId",
            .started_event_id = "startedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityTaskCompletedEventAttributes = struct {
    result: ?[]const u8 = null,
    scheduled_event_id: i64,
    started_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .result = "result",
            .scheduled_event_id = "scheduledEventId",
            .started_event_id = "startedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityTaskStartedEventAttributes = struct {
    identity: ?[]const u8 = null,
    scheduled_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity = "identity",
            .scheduled_event_id = "scheduledEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityTaskScheduledEventAttributes = struct {
    activity_type: ActivityType,
    activity_id: []const u8,
    input: ?[]const u8 = null,
    control: ?[]const u8 = null,
    schedule_to_start_timeout: ?[]const u8 = null,
    schedule_to_close_timeout: ?[]const u8 = null,
    start_to_close_timeout: ?[]const u8 = null,
    task_list: TaskList,
    task_priority: ?[]const u8 = null,
    decision_task_completed_event_id: i64,
    heartbeat_timeout: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activity_type = "activityType",
            .activity_id = "activityId",
            .input = "input",
            .control = "control",
            .schedule_to_start_timeout = "scheduleToStartTimeout",
            .schedule_to_close_timeout = "scheduleToCloseTimeout",
            .start_to_close_timeout = "startToCloseTimeout",
            .task_list = "taskList",
            .task_priority = "taskPriority",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
            .heartbeat_timeout = "heartbeatTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const DecisionTaskTimedOutEventAttributes = struct {
    timeout_type: []const u8,
    scheduled_event_id: i64,
    started_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_type = "timeoutType",
            .scheduled_event_id = "scheduledEventId",
            .started_event_id = "startedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const DecisionTaskCompletedEventAttributes = struct {
    execution_context: ?[]const u8 = null,
    scheduled_event_id: i64,
    started_event_id: i64,
    task_list: ?TaskList = null,
    task_list_schedule_to_start_timeout: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .execution_context = "executionContext",
            .scheduled_event_id = "scheduledEventId",
            .started_event_id = "startedEventId",
            .task_list = "taskList",
            .task_list_schedule_to_start_timeout = "taskListScheduleToStartTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const DecisionTaskStartedEventAttributes = struct {
    identity: ?[]const u8 = null,
    scheduled_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity = "identity",
            .scheduled_event_id = "scheduledEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const DecisionTaskScheduledEventAttributes = struct {
    task_list: TaskList,
    task_priority: ?[]const u8 = null,
    start_to_close_timeout: ?[]const u8 = null,
    schedule_to_start_timeout: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_list = "taskList",
            .task_priority = "taskPriority",
            .start_to_close_timeout = "startToCloseTimeout",
            .schedule_to_start_timeout = "scheduleToStartTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionCancelRequestedEventAttributes = struct {
    external_workflow_execution: ?WorkflowExecution = null,
    external_initiated_event_id: ?i64 = null,
    cause: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_workflow_execution = "externalWorkflowExecution",
            .external_initiated_event_id = "externalInitiatedEventId",
            .cause = "cause",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionTerminatedEventAttributes = struct {
    reason: ?[]const u8 = null,
    details: ?[]const u8 = null,
    child_policy: []const u8,
    cause: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reason = "reason",
            .details = "details",
            .child_policy = "childPolicy",
            .cause = "cause",
        };
        return @field(mappings, field_name);
    }
};

pub const ContinueAsNewWorkflowExecutionFailedEventAttributes = struct {
    cause: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cause = "cause",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionContinuedAsNewEventAttributes = struct {
    input: ?[]const u8 = null,
    decision_task_completed_event_id: i64,
    new_execution_run_id: []const u8,
    execution_start_to_close_timeout: ?[]const u8 = null,
    task_list: TaskList,
    task_priority: ?[]const u8 = null,
    task_start_to_close_timeout: ?[]const u8 = null,
    child_policy: []const u8,
    tag_list: ?[][]const u8 = null,
    workflow_type: WorkflowType,
    lambda_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input = "input",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
            .new_execution_run_id = "newExecutionRunId",
            .execution_start_to_close_timeout = "executionStartToCloseTimeout",
            .task_list = "taskList",
            .task_priority = "taskPriority",
            .task_start_to_close_timeout = "taskStartToCloseTimeout",
            .child_policy = "childPolicy",
            .tag_list = "tagList",
            .workflow_type = "workflowType",
            .lambda_role = "lambdaRole",
        };
        return @field(mappings, field_name);
    }
};

pub const CancelWorkflowExecutionFailedEventAttributes = struct {
    cause: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cause = "cause",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionCanceledEventAttributes = struct {
    details: ?[]const u8 = null,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .details = "details",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionTimedOutEventAttributes = struct {
    timeout_type: []const u8,
    child_policy: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timeout_type = "timeoutType",
            .child_policy = "childPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const FailWorkflowExecutionFailedEventAttributes = struct {
    cause: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cause = "cause",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionFailedEventAttributes = struct {
    reason: ?[]const u8 = null,
    details: ?[]const u8 = null,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reason = "reason",
            .details = "details",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const CompleteWorkflowExecutionFailedEventAttributes = struct {
    cause: []const u8,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cause = "cause",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionCompletedEventAttributes = struct {
    result: ?[]const u8 = null,
    decision_task_completed_event_id: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .result = "result",
            .decision_task_completed_event_id = "decisionTaskCompletedEventId",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionStartedEventAttributes = struct {
    input: ?[]const u8 = null,
    execution_start_to_close_timeout: ?[]const u8 = null,
    task_start_to_close_timeout: ?[]const u8 = null,
    child_policy: []const u8,
    task_list: TaskList,
    task_priority: ?[]const u8 = null,
    workflow_type: WorkflowType,
    tag_list: ?[][]const u8 = null,
    continued_execution_run_id: ?[]const u8 = null,
    parent_workflow_execution: ?WorkflowExecution = null,
    parent_initiated_event_id: ?i64 = null,
    lambda_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input = "input",
            .execution_start_to_close_timeout = "executionStartToCloseTimeout",
            .task_start_to_close_timeout = "taskStartToCloseTimeout",
            .child_policy = "childPolicy",
            .task_list = "taskList",
            .task_priority = "taskPriority",
            .workflow_type = "workflowType",
            .tag_list = "tagList",
            .continued_execution_run_id = "continuedExecutionRunId",
            .parent_workflow_execution = "parentWorkflowExecution",
            .parent_initiated_event_id = "parentInitiatedEventId",
            .lambda_role = "lambdaRole",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowTypeInfo = struct {
    workflow_type: WorkflowType,
    status: []const u8,
    description: ?[]const u8 = null,
    creation_date: i64,
    deprecation_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_type = "workflowType",
            .status = "status",
            .description = "description",
            .creation_date = "creationDate",
            .deprecation_date = "deprecationDate",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionInfo = struct {
    execution: WorkflowExecution,
    workflow_type: WorkflowType,
    start_timestamp: i64,
    close_timestamp: ?i64 = null,
    execution_status: []const u8,
    close_status: ?[]const u8 = null,
    parent: ?WorkflowExecution = null,
    tag_list: ?[][]const u8 = null,
    cancel_requested: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .execution = "execution",
            .workflow_type = "workflowType",
            .start_timestamp = "startTimestamp",
            .close_timestamp = "closeTimestamp",
            .execution_status = "executionStatus",
            .close_status = "closeStatus",
            .parent = "parent",
            .tag_list = "tagList",
            .cancel_requested = "cancelRequested",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowExecutionFilter = struct {
    workflow_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_id = "workflowId",
        };
        return @field(mappings, field_name);
    }
};

pub const TagFilter = struct {
    tag: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag = "tag",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowTypeFilter = struct {
    name: []const u8,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutionTimeFilter = struct {
    oldest_date: i64,
    latest_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .oldest_date = "oldestDate",
            .latest_date = "latestDate",
        };
        return @field(mappings, field_name);
    }
};

pub const DomainInfo = struct {
    name: []const u8,
    status: []const u8,
    description: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .status = "status",
            .description = "description",
            .arn = "arn",
        };
        return @field(mappings, field_name);
    }
};

pub const CloseStatusFilter = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityTypeInfo = struct {
    activity_type: ActivityType,
    status: []const u8,
    description: ?[]const u8 = null,
    creation_date: i64,
    deprecation_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activity_type = "activityType",
            .status = "status",
            .description = "description",
            .creation_date = "creationDate",
            .deprecation_date = "deprecationDate",
        };
        return @field(mappings, field_name);
    }
};
