const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-06-27";
pub const sdk_id: []const u8 = "Textract";
pub const arn_namespace: ?[]const u8 = "textract";
pub const endpoint_prefix: []const u8 = "textract";
pub const sigv4_name: []const u8 = "textract";
pub const name: []const u8 = "Textract";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-06-27",
    sdk_id: []const u8 = "Textract",
    arn_namespace: ?[]const u8 = "textract",
    endpoint_prefix: []const u8 = "textract",
    sigv4_name: []const u8 = "textract",
    name: []const u8 = "Textract",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const analyze_document: struct {
    action_name: []const u8 = "AnalyzeDocument",
    Request: type = struct {
        document: Document,
        feature_types: [][]const u8,
        human_loop_config: ?struct {
            human_loop_name: []const u8,
            flow_definition_arn: []const u8,
            data_attributes: ?struct {
                content_classifiers: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .content_classifiers = "ContentClassifiers",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .human_loop_name = "HumanLoopName",
                    .flow_definition_arn = "FlowDefinitionArn",
                    .data_attributes = "DataAttributes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        queries_config: ?QueriesConfig = null,
        adapters_config: ?AdaptersConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document = "Document",
                .feature_types = "FeatureTypes",
                .human_loop_config = "HumanLoopConfig",
                .queries_config = "QueriesConfig",
                .adapters_config = "AdaptersConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(analyze_document) } {
            return .{ .service_metadata = service_metadata, .action = analyze_document };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        blocks: ?[]Block = null,
        human_loop_activation_output: ?struct {
            human_loop_arn: ?[]const u8 = null,
            human_loop_activation_reasons: ?[][]const u8 = null,
            human_loop_activation_conditions_evaluation_results: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .human_loop_arn = "HumanLoopArn",
                    .human_loop_activation_reasons = "HumanLoopActivationReasons",
                    .human_loop_activation_conditions_evaluation_results = "HumanLoopActivationConditionsEvaluationResults",
                };
                return @field(mappings, field_name);
            }
        } = null,
        analyze_document_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .blocks = "Blocks",
                .human_loop_activation_output = "HumanLoopActivationOutput",
                .analyze_document_model_version = "AnalyzeDocumentModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        HumanLoopQuotaExceeded,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const analyze_expense: struct {
    action_name: []const u8 = "AnalyzeExpense",
    Request: type = struct {
        document: Document,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document = "Document",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(analyze_expense) } {
            return .{ .service_metadata = service_metadata, .action = analyze_expense };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        expense_documents: ?[]ExpenseDocument = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .expense_documents = "ExpenseDocuments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const analyze_id: struct {
    action_name: []const u8 = "AnalyzeID",
    Request: type = struct {
        document_pages: []Document,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_pages = "DocumentPages",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(analyze_id) } {
            return .{ .service_metadata = service_metadata, .action = analyze_id };
        }
    },
    Response: type = struct {
        identity_documents: ?[]IdentityDocument = null,
        document_metadata: ?DocumentMetadata = null,
        analyze_id_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_documents = "IdentityDocuments",
                .document_metadata = "DocumentMetadata",
                .analyze_id_model_version = "AnalyzeIDModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const create_adapter: struct {
    action_name: []const u8 = "CreateAdapter",
    Request: type = struct {
        adapter_name: []const u8,
        client_request_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        feature_types: [][]const u8,
        auto_update: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_name = "AdapterName",
                .client_request_token = "ClientRequestToken",
                .description = "Description",
                .feature_types = "FeatureTypes",
                .auto_update = "AutoUpdate",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_adapter) } {
            return .{ .service_metadata = service_metadata, .action = create_adapter };
        }
    },
    Response: type = struct {
        adapter_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_adapter_version: struct {
    action_name: []const u8 = "CreateAdapterVersion",
    Request: type = struct {
        adapter_id: []const u8,
        client_request_token: ?[]const u8 = null,
        dataset_config: AdapterVersionDatasetConfig,
        kms_key_id: ?[]const u8 = null,
        output_config: OutputConfig,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
                .client_request_token = "ClientRequestToken",
                .dataset_config = "DatasetConfig",
                .kms_key_id = "KMSKeyId",
                .output_config = "OutputConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_adapter_version) } {
            return .{ .service_metadata = service_metadata, .action = create_adapter_version };
        }
    },
    Response: type = struct {
        adapter_id: ?[]const u8 = null,
        adapter_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
                .adapter_version = "AdapterVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_adapter: struct {
    action_name: []const u8 = "DeleteAdapter",
    Request: type = struct {
        adapter_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_adapter) } {
            return .{ .service_metadata = service_metadata, .action = delete_adapter };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_adapter_version: struct {
    action_name: []const u8 = "DeleteAdapterVersion",
    Request: type = struct {
        adapter_id: []const u8,
        adapter_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
                .adapter_version = "AdapterVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_adapter_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_adapter_version };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const detect_document_text: struct {
    action_name: []const u8 = "DetectDocumentText",
    Request: type = struct {
        document: Document,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document = "Document",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_document_text) } {
            return .{ .service_metadata = service_metadata, .action = detect_document_text };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        blocks: ?[]Block = null,
        detect_document_text_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .blocks = "Blocks",
                .detect_document_text_model_version = "DetectDocumentTextModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const get_adapter: struct {
    action_name: []const u8 = "GetAdapter",
    Request: type = struct {
        adapter_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_adapter) } {
            return .{ .service_metadata = service_metadata, .action = get_adapter };
        }
    },
    Response: type = struct {
        adapter_id: ?[]const u8 = null,
        adapter_name: ?[]const u8 = null,
        creation_time: ?i64 = null,
        description: ?[]const u8 = null,
        feature_types: ?[][]const u8 = null,
        auto_update: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
                .adapter_name = "AdapterName",
                .creation_time = "CreationTime",
                .description = "Description",
                .feature_types = "FeatureTypes",
                .auto_update = "AutoUpdate",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_adapter_version: struct {
    action_name: []const u8 = "GetAdapterVersion",
    Request: type = struct {
        adapter_id: []const u8,
        adapter_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
                .adapter_version = "AdapterVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_adapter_version) } {
            return .{ .service_metadata = service_metadata, .action = get_adapter_version };
        }
    },
    Response: type = struct {
        adapter_id: ?[]const u8 = null,
        adapter_version: ?[]const u8 = null,
        creation_time: ?i64 = null,
        feature_types: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        dataset_config: ?AdapterVersionDatasetConfig = null,
        kms_key_id: ?[]const u8 = null,
        output_config: ?OutputConfig = null,
        evaluation_metrics: ?[]struct {
            baseline: ?EvaluationMetric = null,
            adapter_version: ?EvaluationMetric = null,
            feature_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .baseline = "Baseline",
                    .adapter_version = "AdapterVersion",
                    .feature_type = "FeatureType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
                .adapter_version = "AdapterVersion",
                .creation_time = "CreationTime",
                .feature_types = "FeatureTypes",
                .status = "Status",
                .status_message = "StatusMessage",
                .dataset_config = "DatasetConfig",
                .kms_key_id = "KMSKeyId",
                .output_config = "OutputConfig",
                .evaluation_metrics = "EvaluationMetrics",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_document_analysis: struct {
    action_name: []const u8 = "GetDocumentAnalysis",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_document_analysis) } {
            return .{ .service_metadata = service_metadata, .action = get_document_analysis };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        job_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        blocks: ?[]Block = null,
        warnings: ?[]Warning = null,
        status_message: ?[]const u8 = null,
        analyze_document_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .job_status = "JobStatus",
                .next_token = "NextToken",
                .blocks = "Blocks",
                .warnings = "Warnings",
                .status_message = "StatusMessage",
                .analyze_document_model_version = "AnalyzeDocumentModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidJobId,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const get_document_text_detection: struct {
    action_name: []const u8 = "GetDocumentTextDetection",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_document_text_detection) } {
            return .{ .service_metadata = service_metadata, .action = get_document_text_detection };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        job_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        blocks: ?[]Block = null,
        warnings: ?[]Warning = null,
        status_message: ?[]const u8 = null,
        detect_document_text_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .job_status = "JobStatus",
                .next_token = "NextToken",
                .blocks = "Blocks",
                .warnings = "Warnings",
                .status_message = "StatusMessage",
                .detect_document_text_model_version = "DetectDocumentTextModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidJobId,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const get_expense_analysis: struct {
    action_name: []const u8 = "GetExpenseAnalysis",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_expense_analysis) } {
            return .{ .service_metadata = service_metadata, .action = get_expense_analysis };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        job_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        expense_documents: ?[]ExpenseDocument = null,
        warnings: ?[]Warning = null,
        status_message: ?[]const u8 = null,
        analyze_expense_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .job_status = "JobStatus",
                .next_token = "NextToken",
                .expense_documents = "ExpenseDocuments",
                .warnings = "Warnings",
                .status_message = "StatusMessage",
                .analyze_expense_model_version = "AnalyzeExpenseModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidJobId,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const get_lending_analysis: struct {
    action_name: []const u8 = "GetLendingAnalysis",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lending_analysis) } {
            return .{ .service_metadata = service_metadata, .action = get_lending_analysis };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        job_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        results: ?[]struct {
            page: ?i64 = null,
            page_classification: ?struct {
                page_type: []Prediction,
                page_number: []Prediction,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .page_type = "PageType",
                        .page_number = "PageNumber",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            extractions: ?[]struct {
                lending_document: ?struct {
                    lending_fields: ?[]struct {
                        type: ?[]const u8 = null,
                        key_detection: ?LendingDetection = null,
                        value_detections: ?[]LendingDetection = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .type = "Type",
                                .key_detection = "KeyDetection",
                                .value_detections = "ValueDetections",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    signature_detections: ?[]struct {
                        confidence: ?f32 = null,
                        geometry: ?Geometry = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .confidence = "Confidence",
                                .geometry = "Geometry",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .lending_fields = "LendingFields",
                            .signature_detections = "SignatureDetections",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                expense_document: ?ExpenseDocument = null,
                identity_document: ?IdentityDocument = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .lending_document = "LendingDocument",
                        .expense_document = "ExpenseDocument",
                        .identity_document = "IdentityDocument",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .page = "Page",
                    .page_classification = "PageClassification",
                    .extractions = "Extractions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        warnings: ?[]Warning = null,
        status_message: ?[]const u8 = null,
        analyze_lending_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .job_status = "JobStatus",
                .next_token = "NextToken",
                .results = "Results",
                .warnings = "Warnings",
                .status_message = "StatusMessage",
                .analyze_lending_model_version = "AnalyzeLendingModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidJobId,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const get_lending_analysis_summary: struct {
    action_name: []const u8 = "GetLendingAnalysisSummary",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lending_analysis_summary) } {
            return .{ .service_metadata = service_metadata, .action = get_lending_analysis_summary };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        job_status: ?[]const u8 = null,
        summary: ?struct {
            document_groups: ?[]struct {
                type: ?[]const u8 = null,
                split_documents: ?[]struct {
                    index: ?i64 = null,
                    pages: ?[]i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .index = "Index",
                            .pages = "Pages",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                detected_signatures: ?[]struct {
                    page: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .page = "Page",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                undetected_signatures: ?[]struct {
                    page: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .page = "Page",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .split_documents = "SplitDocuments",
                        .detected_signatures = "DetectedSignatures",
                        .undetected_signatures = "UndetectedSignatures",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            undetected_document_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .document_groups = "DocumentGroups",
                    .undetected_document_types = "UndetectedDocumentTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        warnings: ?[]Warning = null,
        status_message: ?[]const u8 = null,
        analyze_lending_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .job_status = "JobStatus",
                .summary = "Summary",
                .warnings = "Warnings",
                .status_message = "StatusMessage",
                .analyze_lending_model_version = "AnalyzeLendingModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidJobId,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const list_adapters: struct {
    action_name: []const u8 = "ListAdapters",
    Request: type = struct {
        after_creation_time: ?i64 = null,
        before_creation_time: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .after_creation_time = "AfterCreationTime",
                .before_creation_time = "BeforeCreationTime",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_adapters) } {
            return .{ .service_metadata = service_metadata, .action = list_adapters };
        }
    },
    Response: type = struct {
        adapters: ?[]struct {
            adapter_id: ?[]const u8 = null,
            adapter_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            feature_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .adapter_id = "AdapterId",
                    .adapter_name = "AdapterName",
                    .creation_time = "CreationTime",
                    .feature_types = "FeatureTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapters = "Adapters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_adapter_versions: struct {
    action_name: []const u8 = "ListAdapterVersions",
    Request: type = struct {
        adapter_id: ?[]const u8 = null,
        after_creation_time: ?i64 = null,
        before_creation_time: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
                .after_creation_time = "AfterCreationTime",
                .before_creation_time = "BeforeCreationTime",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_adapter_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_adapter_versions };
        }
    },
    Response: type = struct {
        adapter_versions: ?[]struct {
            adapter_id: ?[]const u8 = null,
            adapter_version: ?[]const u8 = null,
            creation_time: ?i64 = null,
            feature_types: ?[][]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .adapter_id = "AdapterId",
                    .adapter_version = "AdapterVersion",
                    .creation_time = "CreationTime",
                    .feature_types = "FeatureTypes",
                    .status = "Status",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_versions = "AdapterVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_document_analysis: struct {
    action_name: []const u8 = "StartDocumentAnalysis",
    Request: type = struct {
        document_location: DocumentLocation,
        feature_types: [][]const u8,
        client_request_token: ?[]const u8 = null,
        job_tag: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        output_config: ?OutputConfig = null,
        kms_key_id: ?[]const u8 = null,
        queries_config: ?QueriesConfig = null,
        adapters_config: ?AdaptersConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_location = "DocumentLocation",
                .feature_types = "FeatureTypes",
                .client_request_token = "ClientRequestToken",
                .job_tag = "JobTag",
                .notification_channel = "NotificationChannel",
                .output_config = "OutputConfig",
                .kms_key_id = "KMSKeyId",
                .queries_config = "QueriesConfig",
                .adapters_config = "AdaptersConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_document_analysis) } {
            return .{ .service_metadata = service_metadata, .action = start_document_analysis };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const start_document_text_detection: struct {
    action_name: []const u8 = "StartDocumentTextDetection",
    Request: type = struct {
        document_location: DocumentLocation,
        client_request_token: ?[]const u8 = null,
        job_tag: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        output_config: ?OutputConfig = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_location = "DocumentLocation",
                .client_request_token = "ClientRequestToken",
                .job_tag = "JobTag",
                .notification_channel = "NotificationChannel",
                .output_config = "OutputConfig",
                .kms_key_id = "KMSKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_document_text_detection) } {
            return .{ .service_metadata = service_metadata, .action = start_document_text_detection };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const start_expense_analysis: struct {
    action_name: []const u8 = "StartExpenseAnalysis",
    Request: type = struct {
        document_location: DocumentLocation,
        client_request_token: ?[]const u8 = null,
        job_tag: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        output_config: ?OutputConfig = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_location = "DocumentLocation",
                .client_request_token = "ClientRequestToken",
                .job_tag = "JobTag",
                .notification_channel = "NotificationChannel",
                .output_config = "OutputConfig",
                .kms_key_id = "KMSKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_expense_analysis) } {
            return .{ .service_metadata = service_metadata, .action = start_expense_analysis };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const start_lending_analysis: struct {
    action_name: []const u8 = "StartLendingAnalysis",
    Request: type = struct {
        document_location: DocumentLocation,
        client_request_token: ?[]const u8 = null,
        job_tag: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        output_config: ?OutputConfig = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_location = "DocumentLocation",
                .client_request_token = "ClientRequestToken",
                .job_tag = "JobTag",
                .notification_channel = "NotificationChannel",
                .output_config = "OutputConfig",
                .kms_key_id = "KMSKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_lending_analysis) } {
            return .{ .service_metadata = service_metadata, .action = start_lending_analysis };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_adapter: struct {
    action_name: []const u8 = "UpdateAdapter",
    Request: type = struct {
        adapter_id: []const u8,
        description: ?[]const u8 = null,
        adapter_name: ?[]const u8 = null,
        auto_update: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
                .description = "Description",
                .adapter_name = "AdapterName",
                .auto_update = "AutoUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_adapter) } {
            return .{ .service_metadata = service_metadata, .action = update_adapter };
        }
    },
    Response: type = struct {
        adapter_id: ?[]const u8 = null,
        adapter_name: ?[]const u8 = null,
        creation_time: ?i64 = null,
        description: ?[]const u8 = null,
        feature_types: ?[][]const u8 = null,
        auto_update: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .adapter_id = "AdapterId",
                .adapter_name = "AdapterName",
                .creation_time = "CreationTime",
                .description = "Description",
                .feature_types = "FeatureTypes",
                .auto_update = "AutoUpdate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const OutputConfig = struct {
    s3_bucket: []const u8,
    s3_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_prefix = "S3Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationChannel = struct {
    sns_topic_arn: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_topic_arn = "SNSTopicArn",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentLocation = struct {
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Object = struct {
    bucket: ?[]const u8 = null,
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .name = "Name",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const AdaptersConfig = struct {
    adapters: []Adapter,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adapters = "Adapters",
        };
        return @field(mappings, field_name);
    }
};

pub const Adapter = struct {
    adapter_id: []const u8,
    pages: ?[][]const u8 = null,
    version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .adapter_id = "AdapterId",
            .pages = "Pages",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const QueriesConfig = struct {
    queries: []Query,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queries = "Queries",
        };
        return @field(mappings, field_name);
    }
};

pub const Query = struct {
    text: []const u8,
    alias: ?[]const u8 = null,
    pages: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .alias = "Alias",
            .pages = "Pages",
        };
        return @field(mappings, field_name);
    }
};

pub const Warning = struct {
    error_code: ?[]const u8 = null,
    pages: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .pages = "Pages",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentMetadata = struct {
    pages: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pages = "Pages",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityDocument = struct {
    document_index: ?i64 = null,
    identity_document_fields: ?[]IdentityDocumentField = null,
    blocks: ?[]Block = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .document_index = "DocumentIndex",
            .identity_document_fields = "IdentityDocumentFields",
            .blocks = "Blocks",
        };
        return @field(mappings, field_name);
    }
};

pub const Block = struct {
    block_type: ?[]const u8 = null,
    confidence: ?f32 = null,
    text: ?[]const u8 = null,
    text_type: ?[]const u8 = null,
    row_index: ?i64 = null,
    column_index: ?i64 = null,
    row_span: ?i64 = null,
    column_span: ?i64 = null,
    geometry: ?Geometry = null,
    id: ?[]const u8 = null,
    relationships: ?[]Relationship = null,
    entity_types: ?[][]const u8 = null,
    selection_status: ?[]const u8 = null,
    page: ?i64 = null,
    query: ?Query = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_type = "BlockType",
            .confidence = "Confidence",
            .text = "Text",
            .text_type = "TextType",
            .row_index = "RowIndex",
            .column_index = "ColumnIndex",
            .row_span = "RowSpan",
            .column_span = "ColumnSpan",
            .geometry = "Geometry",
            .id = "Id",
            .relationships = "Relationships",
            .entity_types = "EntityTypes",
            .selection_status = "SelectionStatus",
            .page = "Page",
            .query = "Query",
        };
        return @field(mappings, field_name);
    }
};

pub const Relationship = struct {
    type: ?[]const u8 = null,
    ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .ids = "Ids",
        };
        return @field(mappings, field_name);
    }
};

pub const Geometry = struct {
    bounding_box: ?BoundingBox = null,
    polygon: ?[]Point = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .polygon = "Polygon",
        };
        return @field(mappings, field_name);
    }
};

pub const Point = struct {
    x: ?f32 = null,
    y: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .x = "X",
            .y = "Y",
        };
        return @field(mappings, field_name);
    }
};

pub const BoundingBox = struct {
    width: ?f32 = null,
    height: ?f32 = null,
    left: ?f32 = null,
    top: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .width = "Width",
            .height = "Height",
            .left = "Left",
            .top = "Top",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityDocumentField = struct {
    type: ?AnalyzeIDDetections = null,
    value_detection: ?AnalyzeIDDetections = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value_detection = "ValueDetection",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyzeIDDetections = struct {
    text: []const u8,
    normalized_value: ?NormalizedValue = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .normalized_value = "NormalizedValue",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const NormalizedValue = struct {
    value: ?[]const u8 = null,
    value_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .value_type = "ValueType",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpenseDocument = struct {
    expense_index: ?i64 = null,
    summary_fields: ?[]ExpenseField = null,
    line_item_groups: ?[]LineItemGroup = null,
    blocks: ?[]Block = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expense_index = "ExpenseIndex",
            .summary_fields = "SummaryFields",
            .line_item_groups = "LineItemGroups",
            .blocks = "Blocks",
        };
        return @field(mappings, field_name);
    }
};

pub const LineItemGroup = struct {
    line_item_group_index: ?i64 = null,
    line_items: ?[]LineItemFields = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .line_item_group_index = "LineItemGroupIndex",
            .line_items = "LineItems",
        };
        return @field(mappings, field_name);
    }
};

pub const LineItemFields = struct {
    line_item_expense_fields: ?[]ExpenseField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .line_item_expense_fields = "LineItemExpenseFields",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpenseField = struct {
    type: ?ExpenseType = null,
    label_detection: ?ExpenseDetection = null,
    value_detection: ?ExpenseDetection = null,
    page_number: ?i64 = null,
    currency: ?ExpenseCurrency = null,
    group_properties: ?[]ExpenseGroupProperty = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .label_detection = "LabelDetection",
            .value_detection = "ValueDetection",
            .page_number = "PageNumber",
            .currency = "Currency",
            .group_properties = "GroupProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpenseGroupProperty = struct {
    types: ?[][]const u8 = null,
    id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .types = "Types",
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpenseCurrency = struct {
    code: ?[]const u8 = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "Code",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpenseDetection = struct {
    text: ?[]const u8 = null,
    geometry: ?Geometry = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .geometry = "Geometry",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const ExpenseType = struct {
    text: ?[]const u8 = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const LendingDetection = struct {
    text: ?[]const u8 = null,
    selection_status: ?[]const u8 = null,
    geometry: ?Geometry = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
            .selection_status = "SelectionStatus",
            .geometry = "Geometry",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Prediction = struct {
    value: ?[]const u8 = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationMetric = struct {
    f1_score: ?f32 = null,
    precision: ?f32 = null,
    recall: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .f1_score = "F1Score",
            .precision = "Precision",
            .recall = "Recall",
        };
        return @field(mappings, field_name);
    }
};

pub const AdapterVersionDatasetConfig = struct {
    manifest_s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_s3_object = "ManifestS3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const Document = struct {
    bytes: ?[]const u8 = null,
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bytes = "Bytes",
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};
