const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-01";
pub const sdk_id: []const u8 = "Timestream Query";
pub const arn_namespace: ?[]const u8 = "timestream";
pub const endpoint_prefix: []const u8 = "query.timestream";
pub const sigv4_name: []const u8 = "timestream";
pub const name: []const u8 = "Timestream_20181101";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-01",
    sdk_id: []const u8 = "Timestream Query",
    arn_namespace: ?[]const u8 = "timestream",
    endpoint_prefix: []const u8 = "query.timestream",
    sigv4_name: []const u8 = "timestream",
    name: []const u8 = "Timestream_20181101",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const cancel_query: struct {
    action_name: []const u8 = "CancelQuery",
    Request: type = struct {
        query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_query) } {
            return .{ .service_metadata = service_metadata, .action = cancel_query };
        }
    },
    Response: type = struct {
        cancellation_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cancellation_message = "CancellationMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        Throttling,
        Validation,
    },
} = .{};
pub const create_scheduled_query: struct {
    action_name: []const u8 = "CreateScheduledQuery",
    Request: type = struct {
        name: []const u8,
        query_string: []const u8,
        schedule_configuration: ScheduleConfiguration,
        notification_configuration: NotificationConfiguration,
        target_configuration: ?TargetConfiguration = null,
        client_token: ?[]const u8 = null,
        scheduled_query_execution_role_arn: []const u8,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        error_report_configuration: ErrorReportConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .query_string = "QueryString",
                .schedule_configuration = "ScheduleConfiguration",
                .notification_configuration = "NotificationConfiguration",
                .target_configuration = "TargetConfiguration",
                .client_token = "ClientToken",
                .scheduled_query_execution_role_arn = "ScheduledQueryExecutionRoleArn",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .error_report_configuration = "ErrorReportConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_scheduled_query) } {
            return .{ .service_metadata = service_metadata, .action = create_scheduled_query };
        }
    },
    Response: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidEndpoint,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_scheduled_query: struct {
    action_name: []const u8 = "DeleteScheduledQuery",
    Request: type = struct {
        scheduled_query_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_query_arn = "ScheduledQueryArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_scheduled_query) } {
            return .{ .service_metadata = service_metadata, .action = delete_scheduled_query };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_endpoints: struct {
    action_name: []const u8 = "DescribeEndpoints",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoints };
        }
    },
    Response: type = struct {
        endpoints: []struct {
            address: []const u8,
            cache_period_in_minutes: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .address = "Address",
                    .cache_period_in_minutes = "CachePeriodInMinutes",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "Endpoints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_scheduled_query: struct {
    action_name: []const u8 = "DescribeScheduledQuery",
    Request: type = struct {
        scheduled_query_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_query_arn = "ScheduledQueryArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_scheduled_query) } {
            return .{ .service_metadata = service_metadata, .action = describe_scheduled_query };
        }
    },
    Response: type = struct {
        scheduled_query: struct {
            arn: []const u8,
            name: []const u8,
            query_string: []const u8,
            creation_time: ?i64 = null,
            state: []const u8,
            previous_invocation_time: ?i64 = null,
            next_invocation_time: ?i64 = null,
            schedule_configuration: ScheduleConfiguration,
            notification_configuration: NotificationConfiguration,
            target_configuration: ?TargetConfiguration = null,
            scheduled_query_execution_role_arn: ?[]const u8 = null,
            kms_key_id: ?[]const u8 = null,
            error_report_configuration: ?ErrorReportConfiguration = null,
            last_run_summary: ?ScheduledQueryRunSummary = null,
            recently_failed_runs: ?[]ScheduledQueryRunSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .query_string = "QueryString",
                    .creation_time = "CreationTime",
                    .state = "State",
                    .previous_invocation_time = "PreviousInvocationTime",
                    .next_invocation_time = "NextInvocationTime",
                    .schedule_configuration = "ScheduleConfiguration",
                    .notification_configuration = "NotificationConfiguration",
                    .target_configuration = "TargetConfiguration",
                    .scheduled_query_execution_role_arn = "ScheduledQueryExecutionRoleArn",
                    .kms_key_id = "KmsKeyId",
                    .error_report_configuration = "ErrorReportConfiguration",
                    .last_run_summary = "LastRunSummary",
                    .recently_failed_runs = "RecentlyFailedRuns",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_query = "ScheduledQuery",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const execute_scheduled_query: struct {
    action_name: []const u8 = "ExecuteScheduledQuery",
    Request: type = struct {
        scheduled_query_arn: []const u8,
        invocation_time: i64,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_query_arn = "ScheduledQueryArn",
                .invocation_time = "InvocationTime",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(execute_scheduled_query) } {
            return .{ .service_metadata = service_metadata, .action = execute_scheduled_query };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_scheduled_queries: struct {
    action_name: []const u8 = "ListScheduledQueries",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_scheduled_queries) } {
            return .{ .service_metadata = service_metadata, .action = list_scheduled_queries };
        }
    },
    Response: type = struct {
        scheduled_queries: []struct {
            arn: []const u8,
            name: []const u8,
            creation_time: ?i64 = null,
            state: []const u8,
            previous_invocation_time: ?i64 = null,
            next_invocation_time: ?i64 = null,
            error_report_configuration: ?ErrorReportConfiguration = null,
            target_destination: ?struct {
                timestream_destination: ?struct {
                    database_name: ?[]const u8 = null,
                    table_name: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .database_name = "DatabaseName",
                            .table_name = "TableName",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .timestream_destination = "TimestreamDestination",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_run_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .creation_time = "CreationTime",
                    .state = "State",
                    .previous_invocation_time = "PreviousInvocationTime",
                    .next_invocation_time = "NextInvocationTime",
                    .error_report_configuration = "ErrorReportConfiguration",
                    .target_destination = "TargetDestination",
                    .last_run_status = "LastRunStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_queries = "ScheduledQueries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []Tag,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const prepare_query: struct {
    action_name: []const u8 = "PrepareQuery",
    Request: type = struct {
        query_string: []const u8,
        validate_only: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_string = "QueryString",
                .validate_only = "ValidateOnly",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(prepare_query) } {
            return .{ .service_metadata = service_metadata, .action = prepare_query };
        }
    },
    Response: type = struct {
        query_string: []const u8,
        columns: []struct {
            name: ?[]const u8 = null,
            type: ?Type = null,
            database_name: ?[]const u8 = null,
            table_name: ?[]const u8 = null,
            aliased: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .type = "Type",
                    .database_name = "DatabaseName",
                    .table_name = "TableName",
                    .aliased = "Aliased",
                };
                return @field(mappings, field_name);
            }
        },
        parameters: []struct {
            name: []const u8,
            type: Type,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_string = "QueryString",
                .columns = "Columns",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        Throttling,
        Validation,
    },
} = .{};
pub const query: struct {
    action_name: []const u8 = "Query",
    Request: type = struct {
        query_string: []const u8,
        client_token: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_rows: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_string = "QueryString",
                .client_token = "ClientToken",
                .next_token = "NextToken",
                .max_rows = "MaxRows",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query) } {
            return .{ .service_metadata = service_metadata, .action = query };
        }
    },
    Response: type = struct {
        query_id: []const u8,
        next_token: ?[]const u8 = null,
        rows: []Row,
        column_info: []ColumnInfo,
        query_status: ?struct {
            progress_percentage: ?f64 = null,
            cumulative_bytes_scanned: ?i64 = null,
            cumulative_bytes_metered: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .progress_percentage = "ProgressPercentage",
                    .cumulative_bytes_scanned = "CumulativeBytesScanned",
                    .cumulative_bytes_metered = "CumulativeBytesMetered",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_id = "QueryId",
                .next_token = "NextToken",
                .rows = "Rows",
                .column_info = "ColumnInfo",
                .query_status = "QueryStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidEndpoint,
        QueryExecution,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidEndpoint,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_scheduled_query: struct {
    action_name: []const u8 = "UpdateScheduledQuery",
    Request: type = struct {
        scheduled_query_arn: []const u8,
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scheduled_query_arn = "ScheduledQueryArn",
                .state = "State",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_scheduled_query) } {
            return .{ .service_metadata = service_metadata, .action = update_scheduled_query };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnInfo = struct {
    name: ?[]const u8 = null,
    type: Type,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const Type = struct {
    scalar_type: ?[]const u8 = null,
    array_column_info: ?ColumnInfo = null,
    time_series_measure_value_column_info: ?ColumnInfo = null,
    row_column_info: ?[]ColumnInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scalar_type = "ScalarType",
            .array_column_info = "ArrayColumnInfo",
            .time_series_measure_value_column_info = "TimeSeriesMeasureValueColumnInfo",
            .row_column_info = "RowColumnInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const Row = struct {
    data: []Datum,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data = "Data",
        };
        return @field(mappings, field_name);
    }
};

pub const Datum = struct {
    scalar_value: ?[]const u8 = null,
    time_series_value: ?[]struct {
        time: []const u8,
        value: Datum,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time = "Time",
                .value = "Value",
            };
            return @field(mappings, field_name);
        }
    } = null,
    array_value: ?[]Datum = null,
    row_value: ?Row = null,
    null_value: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scalar_value = "ScalarValue",
            .time_series_value = "TimeSeriesValue",
            .array_value = "ArrayValue",
            .row_value = "RowValue",
            .null_value = "NullValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorReportConfiguration = struct {
    s3_configuration: S3Configuration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_configuration = "S3Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Configuration = struct {
    bucket_name: []const u8,
    object_key_prefix: ?[]const u8 = null,
    encryption_option: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .object_key_prefix = "ObjectKeyPrefix",
            .encryption_option = "EncryptionOption",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduledQueryRunSummary = struct {
    invocation_time: ?i64 = null,
    trigger_time: ?i64 = null,
    run_status: ?[]const u8 = null,
    execution_stats: ?ExecutionStats = null,
    error_report_location: ?ErrorReportLocation = null,
    failure_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .invocation_time = "InvocationTime",
            .trigger_time = "TriggerTime",
            .run_status = "RunStatus",
            .execution_stats = "ExecutionStats",
            .error_report_location = "ErrorReportLocation",
            .failure_reason = "FailureReason",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorReportLocation = struct {
    s3_report_location: ?S3ReportLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_report_location = "S3ReportLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ReportLocation = struct {
    bucket_name: ?[]const u8 = null,
    object_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .object_key = "ObjectKey",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutionStats = struct {
    execution_time_in_millis: ?i64 = null,
    data_writes: ?i64 = null,
    bytes_metered: ?i64 = null,
    records_ingested: ?i64 = null,
    query_result_rows: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .execution_time_in_millis = "ExecutionTimeInMillis",
            .data_writes = "DataWrites",
            .bytes_metered = "BytesMetered",
            .records_ingested = "RecordsIngested",
            .query_result_rows = "QueryResultRows",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetConfiguration = struct {
    timestream_configuration: TimestreamConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestream_configuration = "TimestreamConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestreamConfiguration = struct {
    database_name: []const u8,
    table_name: []const u8,
    time_column: []const u8,
    dimension_mappings: []DimensionMapping,
    multi_measure_mappings: ?MultiMeasureMappings = null,
    mixed_measure_mappings: ?[]MixedMeasureMapping = null,
    measure_name_column: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .time_column = "TimeColumn",
            .dimension_mappings = "DimensionMappings",
            .multi_measure_mappings = "MultiMeasureMappings",
            .mixed_measure_mappings = "MixedMeasureMappings",
            .measure_name_column = "MeasureNameColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const MixedMeasureMapping = struct {
    measure_name: ?[]const u8 = null,
    source_column: ?[]const u8 = null,
    target_measure_name: ?[]const u8 = null,
    measure_value_type: []const u8,
    multi_measure_attribute_mappings: ?[]MultiMeasureAttributeMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .measure_name = "MeasureName",
            .source_column = "SourceColumn",
            .target_measure_name = "TargetMeasureName",
            .measure_value_type = "MeasureValueType",
            .multi_measure_attribute_mappings = "MultiMeasureAttributeMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiMeasureAttributeMapping = struct {
    source_column: []const u8,
    target_multi_measure_attribute_name: ?[]const u8 = null,
    measure_value_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_column = "SourceColumn",
            .target_multi_measure_attribute_name = "TargetMultiMeasureAttributeName",
            .measure_value_type = "MeasureValueType",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiMeasureMappings = struct {
    target_multi_measure_name: ?[]const u8 = null,
    multi_measure_attribute_mappings: []MultiMeasureAttributeMapping,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_multi_measure_name = "TargetMultiMeasureName",
            .multi_measure_attribute_mappings = "MultiMeasureAttributeMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const DimensionMapping = struct {
    name: []const u8,
    dimension_value_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .dimension_value_type = "DimensionValueType",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationConfiguration = struct {
    sns_configuration: SnsConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_configuration = "SnsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SnsConfiguration = struct {
    topic_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduleConfiguration = struct {
    schedule_expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_expression = "ScheduleExpression",
        };
        return @field(mappings, field_name);
    }
};
