const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-01";
pub const sdk_id: []const u8 = "Timestream Write";
pub const arn_namespace: ?[]const u8 = "timestream";
pub const endpoint_prefix: []const u8 = "ingest.timestream";
pub const sigv4_name: []const u8 = "timestream";
pub const name: []const u8 = "Timestream_20181101";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-01",
    sdk_id: []const u8 = "Timestream Write",
    arn_namespace: ?[]const u8 = "timestream",
    endpoint_prefix: []const u8 = "ingest.timestream",
    sigv4_name: []const u8 = "timestream",
    name: []const u8 = "Timestream_20181101",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const create_batch_load_task: struct {
    action_name: []const u8 = "CreateBatchLoadTask",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        data_model_configuration: ?DataModelConfiguration = null,
        data_source_configuration: DataSourceConfiguration,
        report_configuration: ReportConfiguration,
        target_database_name: []const u8,
        target_table_name: []const u8,
        record_version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .data_model_configuration = "DataModelConfiguration",
                .data_source_configuration = "DataSourceConfiguration",
                .report_configuration = "ReportConfiguration",
                .target_database_name = "TargetDatabaseName",
                .target_table_name = "TargetTableName",
                .record_version = "RecordVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_batch_load_task) } {
            return .{ .service_metadata = service_metadata, .action = create_batch_load_task };
        }
    },
    Response: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "TaskId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_database: struct {
    action_name: []const u8 = "CreateDatabase",
    Request: type = struct {
        database_name: []const u8,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_database) } {
            return .{ .service_metadata = service_metadata, .action = create_database };
        }
    },
    Response: type = struct {
        database: ?Database = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database = "Database",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidEndpoint,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_table: struct {
    action_name: []const u8 = "CreateTable",
    Request: type = struct {
        database_name: []const u8,
        table_name: []const u8,
        retention_properties: ?RetentionProperties = null,
        tags: ?[]Tag = null,
        magnetic_store_write_properties: ?MagneticStoreWriteProperties = null,
        schema: ?Schema = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .retention_properties = "RetentionProperties",
                .tags = "Tags",
                .magnetic_store_write_properties = "MagneticStoreWriteProperties",
                .schema = "Schema",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_table) } {
            return .{ .service_metadata = service_metadata, .action = create_table };
        }
    },
    Response: type = struct {
        table: ?Table = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table = "Table",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_database: struct {
    action_name: []const u8 = "DeleteDatabase",
    Request: type = struct {
        database_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_database) } {
            return .{ .service_metadata = service_metadata, .action = delete_database };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_table: struct {
    action_name: []const u8 = "DeleteTable",
    Request: type = struct {
        database_name: []const u8,
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .table_name = "TableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_table };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_batch_load_task: struct {
    action_name: []const u8 = "DescribeBatchLoadTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "TaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_batch_load_task) } {
            return .{ .service_metadata = service_metadata, .action = describe_batch_load_task };
        }
    },
    Response: type = struct {
        batch_load_task_description: struct {
            task_id: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            data_source_configuration: ?DataSourceConfiguration = null,
            progress_report: ?struct {
                records_processed: ?i64 = null,
                records_ingested: ?i64 = null,
                parse_failures: ?i64 = null,
                record_ingestion_failures: ?i64 = null,
                file_failures: ?i64 = null,
                bytes_metered: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .records_processed = "RecordsProcessed",
                        .records_ingested = "RecordsIngested",
                        .parse_failures = "ParseFailures",
                        .record_ingestion_failures = "RecordIngestionFailures",
                        .file_failures = "FileFailures",
                        .bytes_metered = "BytesMetered",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            report_configuration: ?ReportConfiguration = null,
            data_model_configuration: ?DataModelConfiguration = null,
            target_database_name: ?[]const u8 = null,
            target_table_name: ?[]const u8 = null,
            task_status: ?[]const u8 = null,
            record_version: ?i64 = null,
            creation_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            resumable_until: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_id = "TaskId",
                    .error_message = "ErrorMessage",
                    .data_source_configuration = "DataSourceConfiguration",
                    .progress_report = "ProgressReport",
                    .report_configuration = "ReportConfiguration",
                    .data_model_configuration = "DataModelConfiguration",
                    .target_database_name = "TargetDatabaseName",
                    .target_table_name = "TargetTableName",
                    .task_status = "TaskStatus",
                    .record_version = "RecordVersion",
                    .creation_time = "CreationTime",
                    .last_updated_time = "LastUpdatedTime",
                    .resumable_until = "ResumableUntil",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_load_task_description = "BatchLoadTaskDescription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_database: struct {
    action_name: []const u8 = "DescribeDatabase",
    Request: type = struct {
        database_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_database) } {
            return .{ .service_metadata = service_metadata, .action = describe_database };
        }
    },
    Response: type = struct {
        database: ?Database = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database = "Database",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_endpoints: struct {
    action_name: []const u8 = "DescribeEndpoints",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoints };
        }
    },
    Response: type = struct {
        endpoints: []struct {
            address: []const u8,
            cache_period_in_minutes: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .address = "Address",
                    .cache_period_in_minutes = "CachePeriodInMinutes",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "Endpoints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_table: struct {
    action_name: []const u8 = "DescribeTable",
    Request: type = struct {
        database_name: []const u8,
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .table_name = "TableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_table) } {
            return .{ .service_metadata = service_metadata, .action = describe_table };
        }
    },
    Response: type = struct {
        table: ?Table = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table = "Table",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_batch_load_tasks: struct {
    action_name: []const u8 = "ListBatchLoadTasks",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        task_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .task_status = "TaskStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_batch_load_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_batch_load_tasks };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        batch_load_tasks: ?[]struct {
            task_id: ?[]const u8 = null,
            task_status: ?[]const u8 = null,
            database_name: ?[]const u8 = null,
            table_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            resumable_until: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_id = "TaskId",
                    .task_status = "TaskStatus",
                    .database_name = "DatabaseName",
                    .table_name = "TableName",
                    .creation_time = "CreationTime",
                    .last_updated_time = "LastUpdatedTime",
                    .resumable_until = "ResumableUntil",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .batch_load_tasks = "BatchLoadTasks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        Throttling,
        Validation,
    },
} = .{};
pub const list_databases: struct {
    action_name: []const u8 = "ListDatabases",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_databases) } {
            return .{ .service_metadata = service_metadata, .action = list_databases };
        }
    },
    Response: type = struct {
        databases: ?[]Database = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .databases = "Databases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tables: struct {
    action_name: []const u8 = "ListTables",
    Request: type = struct {
        database_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tables) } {
            return .{ .service_metadata = service_metadata, .action = list_tables };
        }
    },
    Response: type = struct {
        tables: ?[]Table = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tables = "Tables",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const resume_batch_load_task: struct {
    action_name: []const u8 = "ResumeBatchLoadTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "TaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_batch_load_task) } {
            return .{ .service_metadata = service_metadata, .action = resume_batch_load_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidEndpoint,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidEndpoint,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_database: struct {
    action_name: []const u8 = "UpdateDatabase",
    Request: type = struct {
        database_name: []const u8,
        kms_key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .kms_key_id = "KmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_database) } {
            return .{ .service_metadata = service_metadata, .action = update_database };
        }
    },
    Response: type = struct {
        database: ?Database = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database = "Database",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_table: struct {
    action_name: []const u8 = "UpdateTable",
    Request: type = struct {
        database_name: []const u8,
        table_name: []const u8,
        retention_properties: ?RetentionProperties = null,
        magnetic_store_write_properties: ?MagneticStoreWriteProperties = null,
        schema: ?Schema = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .retention_properties = "RetentionProperties",
                .magnetic_store_write_properties = "MagneticStoreWriteProperties",
                .schema = "Schema",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_table) } {
            return .{ .service_metadata = service_metadata, .action = update_table };
        }
    },
    Response: type = struct {
        table: ?Table = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table = "Table",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const write_records: struct {
    action_name: []const u8 = "WriteRecords",
    Request: type = struct {
        database_name: []const u8,
        table_name: []const u8,
        common_attributes: ?Record = null,
        records: []Record,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .common_attributes = "CommonAttributes",
                .records = "Records",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(write_records) } {
            return .{ .service_metadata = service_metadata, .action = write_records };
        }
    },
    Response: type = struct {
        records_ingested: ?struct {
            total: ?i64 = null,
            memory_store: ?i64 = null,
            magnetic_store: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .total = "Total",
                    .memory_store = "MemoryStore",
                    .magnetic_store = "MagneticStore",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records_ingested = "RecordsIngested",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidEndpoint,
        RejectedRecords,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Record = struct {
    dimensions: ?[]Dimension = null,
    measure_name: ?[]const u8 = null,
    measure_value: ?[]const u8 = null,
    measure_value_type: ?[]const u8 = null,
    time: ?[]const u8 = null,
    time_unit: ?[]const u8 = null,
    version: ?i64 = null,
    measure_values: ?[]MeasureValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dimensions = "Dimensions",
            .measure_name = "MeasureName",
            .measure_value = "MeasureValue",
            .measure_value_type = "MeasureValueType",
            .time = "Time",
            .time_unit = "TimeUnit",
            .version = "Version",
            .measure_values = "MeasureValues",
        };
        return @field(mappings, field_name);
    }
};

pub const MeasureValue = struct {
    name: []const u8,
    value: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const Dimension = struct {
    name: []const u8,
    value: []const u8,
    dimension_value_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
            .dimension_value_type = "DimensionValueType",
        };
        return @field(mappings, field_name);
    }
};

pub const Table = struct {
    arn: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    table_status: ?[]const u8 = null,
    retention_properties: ?RetentionProperties = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    magnetic_store_write_properties: ?MagneticStoreWriteProperties = null,
    schema: ?Schema = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .table_name = "TableName",
            .database_name = "DatabaseName",
            .table_status = "TableStatus",
            .retention_properties = "RetentionProperties",
            .creation_time = "CreationTime",
            .last_updated_time = "LastUpdatedTime",
            .magnetic_store_write_properties = "MagneticStoreWriteProperties",
            .schema = "Schema",
        };
        return @field(mappings, field_name);
    }
};

pub const Schema = struct {
    composite_partition_key: ?[]PartitionKey = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .composite_partition_key = "CompositePartitionKey",
        };
        return @field(mappings, field_name);
    }
};

pub const PartitionKey = struct {
    type: []const u8,
    name: ?[]const u8 = null,
    enforcement_in_record: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .name = "Name",
            .enforcement_in_record = "EnforcementInRecord",
        };
        return @field(mappings, field_name);
    }
};

pub const MagneticStoreWriteProperties = struct {
    enable_magnetic_store_writes: bool,
    magnetic_store_rejected_data_location: ?MagneticStoreRejectedDataLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_magnetic_store_writes = "EnableMagneticStoreWrites",
            .magnetic_store_rejected_data_location = "MagneticStoreRejectedDataLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const MagneticStoreRejectedDataLocation = struct {
    s3_configuration: ?S3Configuration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_configuration = "S3Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Configuration = struct {
    bucket_name: ?[]const u8 = null,
    object_key_prefix: ?[]const u8 = null,
    encryption_option: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .object_key_prefix = "ObjectKeyPrefix",
            .encryption_option = "EncryptionOption",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const RetentionProperties = struct {
    memory_store_retention_period_in_hours: i64,
    magnetic_store_retention_period_in_days: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .memory_store_retention_period_in_hours = "MemoryStoreRetentionPeriodInHours",
            .magnetic_store_retention_period_in_days = "MagneticStoreRetentionPeriodInDays",
        };
        return @field(mappings, field_name);
    }
};

pub const Database = struct {
    arn: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    table_count: ?i64 = null,
    kms_key_id: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .database_name = "DatabaseName",
            .table_count = "TableCount",
            .kms_key_id = "KmsKeyId",
            .creation_time = "CreationTime",
            .last_updated_time = "LastUpdatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DataModelConfiguration = struct {
    data_model: ?DataModel = null,
    data_model_s3_configuration: ?DataModelS3Configuration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_model = "DataModel",
            .data_model_s3_configuration = "DataModelS3Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const DataModelS3Configuration = struct {
    bucket_name: ?[]const u8 = null,
    object_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .object_key = "ObjectKey",
        };
        return @field(mappings, field_name);
    }
};

pub const DataModel = struct {
    time_column: ?[]const u8 = null,
    time_unit: ?[]const u8 = null,
    dimension_mappings: []DimensionMapping,
    multi_measure_mappings: ?MultiMeasureMappings = null,
    mixed_measure_mappings: ?[]MixedMeasureMapping = null,
    measure_name_column: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .time_column = "TimeColumn",
            .time_unit = "TimeUnit",
            .dimension_mappings = "DimensionMappings",
            .multi_measure_mappings = "MultiMeasureMappings",
            .mixed_measure_mappings = "MixedMeasureMappings",
            .measure_name_column = "MeasureNameColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const MixedMeasureMapping = struct {
    measure_name: ?[]const u8 = null,
    source_column: ?[]const u8 = null,
    target_measure_name: ?[]const u8 = null,
    measure_value_type: []const u8,
    multi_measure_attribute_mappings: ?[]MultiMeasureAttributeMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .measure_name = "MeasureName",
            .source_column = "SourceColumn",
            .target_measure_name = "TargetMeasureName",
            .measure_value_type = "MeasureValueType",
            .multi_measure_attribute_mappings = "MultiMeasureAttributeMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiMeasureAttributeMapping = struct {
    source_column: []const u8,
    target_multi_measure_attribute_name: ?[]const u8 = null,
    measure_value_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_column = "SourceColumn",
            .target_multi_measure_attribute_name = "TargetMultiMeasureAttributeName",
            .measure_value_type = "MeasureValueType",
        };
        return @field(mappings, field_name);
    }
};

pub const MultiMeasureMappings = struct {
    target_multi_measure_name: ?[]const u8 = null,
    multi_measure_attribute_mappings: []MultiMeasureAttributeMapping,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_multi_measure_name = "TargetMultiMeasureName",
            .multi_measure_attribute_mappings = "MultiMeasureAttributeMappings",
        };
        return @field(mappings, field_name);
    }
};

pub const DimensionMapping = struct {
    source_column: ?[]const u8 = null,
    destination_column: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_column = "SourceColumn",
            .destination_column = "DestinationColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportConfiguration = struct {
    report_s3_configuration: ?ReportS3Configuration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report_s3_configuration = "ReportS3Configuration",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportS3Configuration = struct {
    bucket_name: []const u8,
    object_key_prefix: ?[]const u8 = null,
    encryption_option: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .object_key_prefix = "ObjectKeyPrefix",
            .encryption_option = "EncryptionOption",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceConfiguration = struct {
    data_source_s3_configuration: DataSourceS3Configuration,
    csv_configuration: ?CsvConfiguration = null,
    data_format: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_s3_configuration = "DataSourceS3Configuration",
            .csv_configuration = "CsvConfiguration",
            .data_format = "DataFormat",
        };
        return @field(mappings, field_name);
    }
};

pub const CsvConfiguration = struct {
    column_separator: ?[]const u8 = null,
    escape_char: ?[]const u8 = null,
    quote_char: ?[]const u8 = null,
    null_value: ?[]const u8 = null,
    trim_white_space: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_separator = "ColumnSeparator",
            .escape_char = "EscapeChar",
            .quote_char = "QuoteChar",
            .null_value = "NullValue",
            .trim_white_space = "TrimWhiteSpace",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceS3Configuration = struct {
    bucket_name: []const u8,
    object_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .object_key_prefix = "ObjectKeyPrefix",
        };
        return @field(mappings, field_name);
    }
};
