const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2008-10-21";
pub const sdk_id: []const u8 = "tnb";
pub const arn_namespace: ?[]const u8 = "tnb";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "tnb";
pub const name: []const u8 = "TNB";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2008-10-21",
    sdk_id: []const u8 = "tnb",
    arn_namespace: ?[]const u8 = "tnb",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "tnb",
    name: []const u8 = "TNB",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_sol_network_operation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sol/nslcm/v1/ns_lcm_op_occs/{nsLcmOpOccId}/cancel",
        .success_code = 202,
    };

    action_name: []const u8 = "CancelSolNetworkOperation",
    Request: type = struct {
        ns_lcm_op_occ_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ns_lcm_op_occ_id = "nsLcmOpOccId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_sol_network_operation) } {
            return .{ .service_metadata = service_metadata, .action = cancel_sol_network_operation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_sol_function_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sol/vnfpkgm/v1/vnf_packages",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSolFunctionPackage",
    Request: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sol_function_package) } {
            return .{ .service_metadata = service_metadata, .action = create_sol_function_package };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        onboarding_state: []const u8,
        operational_state: []const u8,
        usage_state: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .onboarding_state = "onboardingState",
                .operational_state = "operationalState",
                .usage_state = "usageState",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_sol_network_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sol/nslcm/v1/ns_instances",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSolNetworkInstance",
    Request: type = struct {
        nsd_info_id: []const u8,
        ns_name: []const u8,
        ns_description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nsd_info_id = "nsdInfoId",
                .ns_name = "nsName",
                .ns_description = "nsDescription",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sol_network_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_sol_network_instance };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        nsd_info_id: []const u8,
        ns_instance_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .nsd_info_id = "nsdInfoId",
                .ns_instance_name = "nsInstanceName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_sol_network_package: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sol/nsd/v1/ns_descriptors",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSolNetworkPackage",
    Request: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sol_network_package) } {
            return .{ .service_metadata = service_metadata, .action = create_sol_network_package };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        nsd_onboarding_state: []const u8,
        nsd_operational_state: []const u8,
        nsd_usage_state: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .nsd_onboarding_state = "nsdOnboardingState",
                .nsd_operational_state = "nsdOperationalState",
                .nsd_usage_state = "nsdUsageState",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_sol_function_package: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sol/vnfpkgm/v1/vnf_packages/{vnfPkgId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSolFunctionPackage",
    Request: type = struct {
        vnf_pkg_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vnf_pkg_id = "vnfPkgId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sol_function_package) } {
            return .{ .service_metadata = service_metadata, .action = delete_sol_function_package };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_sol_network_instance: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sol/nslcm/v1/ns_instances/{nsInstanceId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSolNetworkInstance",
    Request: type = struct {
        ns_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ns_instance_id = "nsInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sol_network_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_sol_network_instance };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_sol_network_package: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sol/nsd/v1/ns_descriptors/{nsdInfoId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSolNetworkPackage",
    Request: type = struct {
        nsd_info_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nsd_info_id = "nsdInfoId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sol_network_package) } {
            return .{ .service_metadata = service_metadata, .action = delete_sol_network_package };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sol_function_instance: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/vnflcm/v1/vnf_instances/{vnfInstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSolFunctionInstance",
    Request: type = struct {
        vnf_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vnf_instance_id = "vnfInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sol_function_instance) } {
            return .{ .service_metadata = service_metadata, .action = get_sol_function_instance };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        ns_instance_id: []const u8,
        vnf_pkg_id: []const u8,
        vnfd_id: []const u8,
        vnf_provider: ?[]const u8 = null,
        vnf_product_name: ?[]const u8 = null,
        vnfd_version: ?[]const u8 = null,
        instantiation_state: []const u8,
        instantiated_vnf_info: ?struct {
            vnf_state: ?[]const u8 = null,
            vnfc_resource_info: ?[]struct {
                metadata: ?struct {
                    node_group: ?[]const u8 = null,
                    cluster: ?[]const u8 = null,
                    helm_chart: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .node_group = "nodeGroup",
                            .cluster = "cluster",
                            .helm_chart = "helmChart",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metadata = "metadata",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vnf_state = "vnfState",
                    .vnfc_resource_info = "vnfcResourceInfo",
                };
                return @field(mappings, field_name);
            }
        } = null,
        metadata: struct {
            created_at: i64,
            last_modified: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_at = "createdAt",
                    .last_modified = "lastModified",
                };
                return @field(mappings, field_name);
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .ns_instance_id = "nsInstanceId",
                .vnf_pkg_id = "vnfPkgId",
                .vnfd_id = "vnfdId",
                .vnf_provider = "vnfProvider",
                .vnf_product_name = "vnfProductName",
                .vnfd_version = "vnfdVersion",
                .instantiation_state = "instantiationState",
                .instantiated_vnf_info = "instantiatedVnfInfo",
                .metadata = "metadata",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sol_function_package: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/vnfpkgm/v1/vnf_packages/{vnfPkgId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSolFunctionPackage",
    Request: type = struct {
        vnf_pkg_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vnf_pkg_id = "vnfPkgId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sol_function_package) } {
            return .{ .service_metadata = service_metadata, .action = get_sol_function_package };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        onboarding_state: []const u8,
        operational_state: []const u8,
        usage_state: []const u8,
        vnfd_id: ?[]const u8 = null,
        vnf_provider: ?[]const u8 = null,
        vnf_product_name: ?[]const u8 = null,
        vnfd_version: ?[]const u8 = null,
        metadata: ?struct {
            vnfd: ?FunctionArtifactMeta = null,
            created_at: i64,
            last_modified: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vnfd = "vnfd",
                    .created_at = "createdAt",
                    .last_modified = "lastModified",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .onboarding_state = "onboardingState",
                .operational_state = "operationalState",
                .usage_state = "usageState",
                .vnfd_id = "vnfdId",
                .vnf_provider = "vnfProvider",
                .vnf_product_name = "vnfProductName",
                .vnfd_version = "vnfdVersion",
                .metadata = "metadata",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sol_function_package_content: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/vnfpkgm/v1/vnf_packages/{vnfPkgId}/package_content",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSolFunctionPackageContent",
    Request: type = struct {
        vnf_pkg_id: []const u8,
        accept: []const u8,
        pub const http_header = .{
            .accept = "Accept",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vnf_pkg_id = "vnfPkgId",
                .accept = "accept",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sol_function_package_content) } {
            return .{ .service_metadata = service_metadata, .action = get_sol_function_package_content };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        package_content: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "package_content";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .package_content = "packageContent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sol_function_package_descriptor: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/vnfpkgm/v1/vnf_packages/{vnfPkgId}/vnfd",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSolFunctionPackageDescriptor",
    Request: type = struct {
        vnf_pkg_id: []const u8,
        accept: []const u8,
        pub const http_header = .{
            .accept = "Accept",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vnf_pkg_id = "vnfPkgId",
                .accept = "accept",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sol_function_package_descriptor) } {
            return .{ .service_metadata = service_metadata, .action = get_sol_function_package_descriptor };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        vnfd: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "vnfd";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .vnfd = "vnfd",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sol_network_instance: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/nslcm/v1/ns_instances/{nsInstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSolNetworkInstance",
    Request: type = struct {
        ns_instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ns_instance_id = "nsInstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sol_network_instance) } {
            return .{ .service_metadata = service_metadata, .action = get_sol_network_instance };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        ns_instance_name: []const u8,
        ns_instance_description: []const u8,
        nsd_id: []const u8,
        nsd_info_id: []const u8,
        ns_state: ?[]const u8 = null,
        lcm_op_info: ?struct {
            ns_lcm_op_occ_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ns_lcm_op_occ_id = "nsLcmOpOccId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        metadata: struct {
            created_at: i64,
            last_modified: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_at = "createdAt",
                    .last_modified = "lastModified",
                };
                return @field(mappings, field_name);
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .ns_instance_name = "nsInstanceName",
                .ns_instance_description = "nsInstanceDescription",
                .nsd_id = "nsdId",
                .nsd_info_id = "nsdInfoId",
                .ns_state = "nsState",
                .lcm_op_info = "lcmOpInfo",
                .metadata = "metadata",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sol_network_operation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/nslcm/v1/ns_lcm_op_occs/{nsLcmOpOccId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSolNetworkOperation",
    Request: type = struct {
        ns_lcm_op_occ_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ns_lcm_op_occ_id = "nsLcmOpOccId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sol_network_operation) } {
            return .{ .service_metadata = service_metadata, .action = get_sol_network_operation };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: []const u8,
        operation_state: ?[]const u8 = null,
        ns_instance_id: ?[]const u8 = null,
        lcm_operation_type: ?[]const u8 = null,
        @"error": ?ProblemDetails = null,
        metadata: ?struct {
            created_at: i64,
            last_modified: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_at = "createdAt",
                    .last_modified = "lastModified",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tasks: ?[]struct {
            task_name: ?[]const u8 = null,
            task_context: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            task_error_details: ?struct {
                cause: ?[]const u8 = null,
                details: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .cause = "cause",
                        .details = "details",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            task_status: ?[]const u8 = null,
            task_start_time: ?i64 = null,
            task_end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_name = "taskName",
                    .task_context = "taskContext",
                    .task_error_details = "taskErrorDetails",
                    .task_status = "taskStatus",
                    .task_start_time = "taskStartTime",
                    .task_end_time = "taskEndTime",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "task_context", field_name))
                    return try serializeMap(self.task_context, self.fieldNameFor("task_context"), options, out_stream);
                return false;
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .operation_state = "operationState",
                .ns_instance_id = "nsInstanceId",
                .lcm_operation_type = "lcmOperationType",
                .@"error" = "error",
                .metadata = "metadata",
                .tasks = "tasks",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sol_network_package: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/nsd/v1/ns_descriptors/{nsdInfoId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSolNetworkPackage",
    Request: type = struct {
        nsd_info_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nsd_info_id = "nsdInfoId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sol_network_package) } {
            return .{ .service_metadata = service_metadata, .action = get_sol_network_package };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        nsd_onboarding_state: []const u8,
        nsd_operational_state: []const u8,
        nsd_usage_state: []const u8,
        nsd_id: []const u8,
        nsd_name: []const u8,
        nsd_version: []const u8,
        vnf_pkg_ids: [][]const u8,
        metadata: struct {
            nsd: ?NetworkArtifactMeta = null,
            created_at: i64,
            last_modified: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .nsd = "nsd",
                    .created_at = "createdAt",
                    .last_modified = "lastModified",
                };
                return @field(mappings, field_name);
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .nsd_onboarding_state = "nsdOnboardingState",
                .nsd_operational_state = "nsdOperationalState",
                .nsd_usage_state = "nsdUsageState",
                .nsd_id = "nsdId",
                .nsd_name = "nsdName",
                .nsd_version = "nsdVersion",
                .vnf_pkg_ids = "vnfPkgIds",
                .metadata = "metadata",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sol_network_package_content: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/nsd/v1/ns_descriptors/{nsdInfoId}/nsd_content",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSolNetworkPackageContent",
    Request: type = struct {
        nsd_info_id: []const u8,
        accept: []const u8,
        pub const http_header = .{
            .accept = "Accept",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nsd_info_id = "nsdInfoId",
                .accept = "accept",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sol_network_package_content) } {
            return .{ .service_metadata = service_metadata, .action = get_sol_network_package_content };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        nsd_content: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "nsd_content";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .nsd_content = "nsdContent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_sol_network_package_descriptor: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/nsd/v1/ns_descriptors/{nsdInfoId}/nsd",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSolNetworkPackageDescriptor",
    Request: type = struct {
        nsd_info_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nsd_info_id = "nsdInfoId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sol_network_package_descriptor) } {
            return .{ .service_metadata = service_metadata, .action = get_sol_network_package_descriptor };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        nsd: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "nsd";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .nsd = "nsd",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const instantiate_sol_network_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sol/nslcm/v1/ns_instances/{nsInstanceId}/instantiate",
        .success_code = 201,
    };

    action_name: []const u8 = "InstantiateSolNetworkInstance",
    Request: type = struct {
        ns_instance_id: []const u8,
        dry_run: ?bool = null,
        additional_params_for_ns: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub const http_query = .{
            .dry_run = "dry_run",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ns_instance_id = "nsInstanceId",
                .dry_run = "dryRun",
                .additional_params_for_ns = "additionalParamsForNs",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(instantiate_sol_network_instance) } {
            return .{ .service_metadata = service_metadata, .action = instantiate_sol_network_instance };
        }
    },
    Response: type = struct {
        ns_lcm_op_occ_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ns_lcm_op_occ_id = "nsLcmOpOccId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_sol_function_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/vnflcm/v1/vnf_instances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSolFunctionInstances",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "nextpage_opaque_marker",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sol_function_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_sol_function_instances };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        function_instances: ?[]struct {
            id: []const u8,
            arn: []const u8,
            ns_instance_id: []const u8,
            vnf_pkg_id: []const u8,
            vnf_pkg_name: ?[]const u8 = null,
            instantiation_state: []const u8,
            instantiated_vnf_info: ?struct {
                vnf_state: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .vnf_state = "vnfState",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            metadata: struct {
                created_at: i64,
                last_modified: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .created_at = "createdAt",
                        .last_modified = "lastModified",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .ns_instance_id = "nsInstanceId",
                    .vnf_pkg_id = "vnfPkgId",
                    .vnf_pkg_name = "vnfPkgName",
                    .instantiation_state = "instantiationState",
                    .instantiated_vnf_info = "instantiatedVnfInfo",
                    .metadata = "metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .function_instances = "functionInstances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_sol_function_packages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/vnfpkgm/v1/vnf_packages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSolFunctionPackages",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "nextpage_opaque_marker",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sol_function_packages) } {
            return .{ .service_metadata = service_metadata, .action = list_sol_function_packages };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        function_packages: []struct {
            id: []const u8,
            arn: []const u8,
            onboarding_state: []const u8,
            operational_state: []const u8,
            usage_state: []const u8,
            vnfd_id: ?[]const u8 = null,
            vnf_provider: ?[]const u8 = null,
            vnf_product_name: ?[]const u8 = null,
            vnfd_version: ?[]const u8 = null,
            metadata: ?struct {
                created_at: i64,
                last_modified: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .created_at = "createdAt",
                        .last_modified = "lastModified",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .onboarding_state = "onboardingState",
                    .operational_state = "operationalState",
                    .usage_state = "usageState",
                    .vnfd_id = "vnfdId",
                    .vnf_provider = "vnfProvider",
                    .vnf_product_name = "vnfProductName",
                    .vnfd_version = "vnfdVersion",
                    .metadata = "metadata",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .function_packages = "functionPackages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_sol_network_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/nslcm/v1/ns_instances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSolNetworkInstances",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "nextpage_opaque_marker",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sol_network_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_sol_network_instances };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        network_instances: ?[]struct {
            id: []const u8,
            arn: []const u8,
            ns_instance_name: []const u8,
            ns_instance_description: []const u8,
            nsd_id: []const u8,
            nsd_info_id: []const u8,
            ns_state: []const u8,
            metadata: struct {
                created_at: i64,
                last_modified: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .created_at = "createdAt",
                        .last_modified = "lastModified",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .ns_instance_name = "nsInstanceName",
                    .ns_instance_description = "nsInstanceDescription",
                    .nsd_id = "nsdId",
                    .nsd_info_id = "nsdInfoId",
                    .ns_state = "nsState",
                    .metadata = "metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .network_instances = "networkInstances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_sol_network_operations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/nslcm/v1/ns_lcm_op_occs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSolNetworkOperations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "nextpage_opaque_marker",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sol_network_operations) } {
            return .{ .service_metadata = service_metadata, .action = list_sol_network_operations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        network_operations: ?[]struct {
            id: []const u8,
            arn: []const u8,
            operation_state: []const u8,
            ns_instance_id: []const u8,
            lcm_operation_type: []const u8,
            @"error": ?ProblemDetails = null,
            metadata: ?struct {
                created_at: i64,
                last_modified: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .created_at = "createdAt",
                        .last_modified = "lastModified",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .operation_state = "operationState",
                    .ns_instance_id = "nsInstanceId",
                    .lcm_operation_type = "lcmOperationType",
                    .@"error" = "error",
                    .metadata = "metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .network_operations = "networkOperations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_sol_network_packages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sol/nsd/v1/ns_descriptors",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSolNetworkPackages",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max_results",
            .next_token = "nextpage_opaque_marker",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sol_network_packages) } {
            return .{ .service_metadata = service_metadata, .action = list_sol_network_packages };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        network_packages: []struct {
            id: []const u8,
            arn: []const u8,
            nsd_onboarding_state: []const u8,
            nsd_operational_state: []const u8,
            nsd_usage_state: []const u8,
            nsd_id: ?[]const u8 = null,
            nsd_name: ?[]const u8 = null,
            nsd_version: ?[]const u8 = null,
            nsd_designer: ?[]const u8 = null,
            nsd_invariant_id: ?[]const u8 = null,
            vnf_pkg_ids: ?[][]const u8 = null,
            metadata: struct {
                created_at: i64,
                last_modified: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .created_at = "createdAt",
                        .last_modified = "lastModified",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .nsd_onboarding_state = "nsdOnboardingState",
                    .nsd_operational_state = "nsdOperationalState",
                    .nsd_usage_state = "nsdUsageState",
                    .nsd_id = "nsdId",
                    .nsd_name = "nsdName",
                    .nsd_version = "nsdVersion",
                    .nsd_designer = "nsdDesigner",
                    .nsd_invariant_id = "nsdInvariantId",
                    .vnf_pkg_ids = "vnfPkgIds",
                    .metadata = "metadata",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .network_packages = "networkPackages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_sol_function_package_content: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sol/vnfpkgm/v1/vnf_packages/{vnfPkgId}/package_content",
        .success_code = 202,
    };

    action_name: []const u8 = "PutSolFunctionPackageContent",
    Request: type = struct {
        vnf_pkg_id: []const u8,
        content_type: ?[]const u8 = null,
        file: []const u8,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "file";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vnf_pkg_id = "vnfPkgId",
                .content_type = "contentType",
                .file = "file",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_sol_function_package_content) } {
            return .{ .service_metadata = service_metadata, .action = put_sol_function_package_content };
        }
    },
    Response: type = struct {
        id: []const u8,
        vnfd_id: []const u8,
        vnf_product_name: []const u8,
        vnf_provider: []const u8,
        vnfd_version: []const u8,
        metadata: struct {
            vnfd: ?FunctionArtifactMeta = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vnfd = "vnfd",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .vnfd_id = "vnfdId",
                .vnf_product_name = "vnfProductName",
                .vnf_provider = "vnfProvider",
                .vnfd_version = "vnfdVersion",
                .metadata = "metadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_sol_network_package_content: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sol/nsd/v1/ns_descriptors/{nsdInfoId}/nsd_content",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSolNetworkPackageContent",
    Request: type = struct {
        nsd_info_id: []const u8,
        content_type: ?[]const u8 = null,
        file: []const u8,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "file";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nsd_info_id = "nsdInfoId",
                .content_type = "contentType",
                .file = "file",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_sol_network_package_content) } {
            return .{ .service_metadata = service_metadata, .action = put_sol_network_package_content };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        nsd_id: []const u8,
        nsd_name: []const u8,
        nsd_version: []const u8,
        vnf_pkg_ids: [][]const u8,
        metadata: struct {
            nsd: ?NetworkArtifactMeta = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .nsd = "nsd",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .nsd_id = "nsdId",
                .nsd_name = "nsdName",
                .nsd_version = "nsdVersion",
                .vnf_pkg_ids = "vnfPkgIds",
                .metadata = "metadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const terminate_sol_network_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sol/nslcm/v1/ns_instances/{nsInstanceId}/terminate",
        .success_code = 201,
    };

    action_name: []const u8 = "TerminateSolNetworkInstance",
    Request: type = struct {
        ns_instance_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ns_instance_id = "nsInstanceId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_sol_network_instance) } {
            return .{ .service_metadata = service_metadata, .action = terminate_sol_network_instance };
        }
    },
    Response: type = struct {
        ns_lcm_op_occ_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ns_lcm_op_occ_id = "nsLcmOpOccId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_sol_function_package: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/sol/vnfpkgm/v1/vnf_packages/{vnfPkgId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSolFunctionPackage",
    Request: type = struct {
        vnf_pkg_id: []const u8,
        operational_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vnf_pkg_id = "vnfPkgId",
                .operational_state = "operationalState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sol_function_package) } {
            return .{ .service_metadata = service_metadata, .action = update_sol_function_package };
        }
    },
    Response: type = struct {
        operational_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .operational_state = "operationalState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_sol_network_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sol/nslcm/v1/ns_instances/{nsInstanceId}/update",
        .success_code = 201,
    };

    action_name: []const u8 = "UpdateSolNetworkInstance",
    Request: type = struct {
        ns_instance_id: []const u8,
        update_type: []const u8,
        modify_vnf_info_data: ?struct {
            vnf_instance_id: []const u8,
            vnf_configurable_properties: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vnf_instance_id = "vnfInstanceId",
                    .vnf_configurable_properties = "vnfConfigurableProperties",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ns_instance_id = "nsInstanceId",
                .update_type = "updateType",
                .modify_vnf_info_data = "modifyVnfInfoData",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sol_network_instance) } {
            return .{ .service_metadata = service_metadata, .action = update_sol_network_instance };
        }
    },
    Response: type = struct {
        ns_lcm_op_occ_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ns_lcm_op_occ_id = "nsLcmOpOccId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_sol_network_package: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/sol/nsd/v1/ns_descriptors/{nsdInfoId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSolNetworkPackage",
    Request: type = struct {
        nsd_info_id: []const u8,
        nsd_operational_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nsd_info_id = "nsdInfoId",
                .nsd_operational_state = "nsdOperationalState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sol_network_package) } {
            return .{ .service_metadata = service_metadata, .action = update_sol_network_package };
        }
    },
    Response: type = struct {
        nsd_operational_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nsd_operational_state = "nsdOperationalState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const validate_sol_function_package_content: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sol/vnfpkgm/v1/vnf_packages/{vnfPkgId}/package_content/validate",
        .success_code = 202,
    };

    action_name: []const u8 = "ValidateSolFunctionPackageContent",
    Request: type = struct {
        vnf_pkg_id: []const u8,
        content_type: ?[]const u8 = null,
        file: []const u8,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "file";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vnf_pkg_id = "vnfPkgId",
                .content_type = "contentType",
                .file = "file",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_sol_function_package_content) } {
            return .{ .service_metadata = service_metadata, .action = validate_sol_function_package_content };
        }
    },
    Response: type = struct {
        id: []const u8,
        vnfd_id: []const u8,
        vnf_product_name: []const u8,
        vnf_provider: []const u8,
        vnfd_version: []const u8,
        metadata: struct {
            vnfd: ?FunctionArtifactMeta = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vnfd = "vnfd",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .vnfd_id = "vnfdId",
                .vnf_product_name = "vnfProductName",
                .vnf_provider = "vnfProvider",
                .vnfd_version = "vnfdVersion",
                .metadata = "metadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const validate_sol_network_package_content: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sol/nsd/v1/ns_descriptors/{nsdInfoId}/nsd_content/validate",
        .success_code = 200,
    };

    action_name: []const u8 = "ValidateSolNetworkPackageContent",
    Request: type = struct {
        nsd_info_id: []const u8,
        content_type: ?[]const u8 = null,
        file: []const u8,
        pub const http_header = .{
            .content_type = "Content-Type",
        };

        pub const http_payload: []const u8 = "file";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nsd_info_id = "nsdInfoId",
                .content_type = "contentType",
                .file = "file",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_sol_network_package_content) } {
            return .{ .service_metadata = service_metadata, .action = validate_sol_network_package_content };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,
        nsd_id: []const u8,
        nsd_name: []const u8,
        nsd_version: []const u8,
        vnf_pkg_ids: [][]const u8,
        metadata: struct {
            nsd: ?NetworkArtifactMeta = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .nsd = "nsd",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .arn = "arn",
                .nsd_id = "nsdId",
                .nsd_name = "nsdName",
                .nsd_version = "nsdVersion",
                .vnf_pkg_ids = "vnfPkgIds",
                .metadata = "metadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const NetworkArtifactMeta = struct {
    overrides: ?[]ToscaOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .overrides = "overrides",
        };
        return @field(mappings, field_name);
    }
};

pub const ToscaOverride = struct {
    name: ?[]const u8 = null,
    default_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .default_value = "defaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionArtifactMeta = struct {
    overrides: ?[]ToscaOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .overrides = "overrides",
        };
        return @field(mappings, field_name);
    }
};

pub const ProblemDetails = struct {
    detail: []const u8,
    title: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detail = "detail",
            .title = "title",
        };
        return @field(mappings, field_name);
    }
};
