const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-10-26";
pub const sdk_id: []const u8 = "Transcribe";
pub const arn_namespace: ?[]const u8 = "transcribe";
pub const endpoint_prefix: []const u8 = "transcribe";
pub const sigv4_name: []const u8 = "transcribe";
pub const name: []const u8 = "Transcribe";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-10-26",
    sdk_id: []const u8 = "Transcribe",
    arn_namespace: ?[]const u8 = "transcribe",
    endpoint_prefix: []const u8 = "transcribe",
    sigv4_name: []const u8 = "transcribe",
    name: []const u8 = "Transcribe",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_call_analytics_category: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/callanalyticscategories/{CategoryName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCallAnalyticsCategory",
    Request: type = struct {
        category_name: []const u8,
        rules: []Rule,
        input_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category_name = "CategoryName",
                .rules = "Rules",
                .input_type = "InputType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_call_analytics_category) } {
            return .{ .service_metadata = service_metadata, .action = create_call_analytics_category };
        }
    },
    Response: type = struct {
        category_properties: ?CategoryProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category_properties = "CategoryProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const create_language_model: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/languagemodels/{ModelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLanguageModel",
    Request: type = struct {
        language_code: []const u8,
        base_model_name: []const u8,
        model_name: []const u8,
        input_data_config: InputDataConfig,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language_code = "LanguageCode",
                .base_model_name = "BaseModelName",
                .model_name = "ModelName",
                .input_data_config = "InputDataConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_language_model) } {
            return .{ .service_metadata = service_metadata, .action = create_language_model };
        }
    },
    Response: type = struct {
        language_code: ?[]const u8 = null,
        base_model_name: ?[]const u8 = null,
        model_name: ?[]const u8 = null,
        input_data_config: ?InputDataConfig = null,
        model_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language_code = "LanguageCode",
                .base_model_name = "BaseModelName",
                .model_name = "ModelName",
                .input_data_config = "InputDataConfig",
                .model_status = "ModelStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const create_medical_vocabulary: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/medicalvocabularies/{VocabularyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMedicalVocabulary",
    Request: type = struct {
        vocabulary_name: []const u8,
        language_code: []const u8,
        vocabulary_file_uri: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .vocabulary_file_uri = "VocabularyFileUri",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_medical_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = create_medical_vocabulary };
        }
    },
    Response: type = struct {
        vocabulary_name: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        vocabulary_state: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        failure_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .vocabulary_state = "VocabularyState",
                .last_modified_time = "LastModifiedTime",
                .failure_reason = "FailureReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const create_vocabulary: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/vocabularies/{VocabularyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateVocabulary",
    Request: type = struct {
        vocabulary_name: []const u8,
        language_code: []const u8,
        phrases: ?[][]const u8 = null,
        vocabulary_file_uri: ?[]const u8 = null,
        tags: ?[]Tag = null,
        data_access_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .phrases = "Phrases",
                .vocabulary_file_uri = "VocabularyFileUri",
                .tags = "Tags",
                .data_access_role_arn = "DataAccessRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = create_vocabulary };
        }
    },
    Response: type = struct {
        vocabulary_name: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        vocabulary_state: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        failure_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .vocabulary_state = "VocabularyState",
                .last_modified_time = "LastModifiedTime",
                .failure_reason = "FailureReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const create_vocabulary_filter: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/vocabularyFilters/{VocabularyFilterName}",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateVocabularyFilter",
    Request: type = struct {
        vocabulary_filter_name: []const u8,
        language_code: []const u8,
        words: ?[][]const u8 = null,
        vocabulary_filter_file_uri: ?[]const u8 = null,
        tags: ?[]Tag = null,
        data_access_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_filter_name = "VocabularyFilterName",
                .language_code = "LanguageCode",
                .words = "Words",
                .vocabulary_filter_file_uri = "VocabularyFilterFileUri",
                .tags = "Tags",
                .data_access_role_arn = "DataAccessRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vocabulary_filter) } {
            return .{ .service_metadata = service_metadata, .action = create_vocabulary_filter };
        }
    },
    Response: type = struct {
        vocabulary_filter_name: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        last_modified_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_filter_name = "VocabularyFilterName",
                .language_code = "LanguageCode",
                .last_modified_time = "LastModifiedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const delete_call_analytics_category: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/callanalyticscategories/{CategoryName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteCallAnalyticsCategory",
    Request: type = struct {
        category_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category_name = "CategoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_call_analytics_category) } {
            return .{ .service_metadata = service_metadata, .action = delete_call_analytics_category };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const delete_call_analytics_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/callanalyticsjobs/{CallAnalyticsJobName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteCallAnalyticsJob",
    Request: type = struct {
        call_analytics_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .call_analytics_job_name = "CallAnalyticsJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_call_analytics_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_call_analytics_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const delete_language_model: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/languagemodels/{ModelName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteLanguageModel",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_language_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_language_model };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const delete_medical_scribe_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/medicalscribejobs/{MedicalScribeJobName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMedicalScribeJob",
    Request: type = struct {
        medical_scribe_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .medical_scribe_job_name = "MedicalScribeJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_medical_scribe_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_medical_scribe_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const delete_medical_transcription_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/medicaltranscriptionjobs/{MedicalTranscriptionJobName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMedicalTranscriptionJob",
    Request: type = struct {
        medical_transcription_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .medical_transcription_job_name = "MedicalTranscriptionJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_medical_transcription_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_medical_transcription_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const delete_medical_vocabulary: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/medicalvocabularies/{VocabularyName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMedicalVocabulary",
    Request: type = struct {
        vocabulary_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_medical_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = delete_medical_vocabulary };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const delete_transcription_job: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/transcriptionjobs/{TranscriptionJobName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteTranscriptionJob",
    Request: type = struct {
        transcription_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transcription_job_name = "TranscriptionJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_transcription_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_transcription_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const delete_vocabulary: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/vocabularies/{VocabularyName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVocabulary",
    Request: type = struct {
        vocabulary_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = delete_vocabulary };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const delete_vocabulary_filter: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/vocabularyFilters/{VocabularyFilterName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVocabularyFilter",
    Request: type = struct {
        vocabulary_filter_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_filter_name = "VocabularyFilterName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vocabulary_filter) } {
            return .{ .service_metadata = service_metadata, .action = delete_vocabulary_filter };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const describe_language_model: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/languagemodels/{ModelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeLanguageModel",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_language_model) } {
            return .{ .service_metadata = service_metadata, .action = describe_language_model };
        }
    },
    Response: type = struct {
        language_model: ?LanguageModel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language_model = "LanguageModel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_call_analytics_category: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/callanalyticscategories/{CategoryName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCallAnalyticsCategory",
    Request: type = struct {
        category_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category_name = "CategoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_call_analytics_category) } {
            return .{ .service_metadata = service_metadata, .action = get_call_analytics_category };
        }
    },
    Response: type = struct {
        category_properties: ?CategoryProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category_properties = "CategoryProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_call_analytics_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/callanalyticsjobs/{CallAnalyticsJobName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCallAnalyticsJob",
    Request: type = struct {
        call_analytics_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .call_analytics_job_name = "CallAnalyticsJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_call_analytics_job) } {
            return .{ .service_metadata = service_metadata, .action = get_call_analytics_job };
        }
    },
    Response: type = struct {
        call_analytics_job: ?CallAnalyticsJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .call_analytics_job = "CallAnalyticsJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_medical_scribe_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/medicalscribejobs/{MedicalScribeJobName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMedicalScribeJob",
    Request: type = struct {
        medical_scribe_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .medical_scribe_job_name = "MedicalScribeJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_medical_scribe_job) } {
            return .{ .service_metadata = service_metadata, .action = get_medical_scribe_job };
        }
    },
    Response: type = struct {
        medical_scribe_job: ?MedicalScribeJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .medical_scribe_job = "MedicalScribeJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_medical_transcription_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/medicaltranscriptionjobs/{MedicalTranscriptionJobName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMedicalTranscriptionJob",
    Request: type = struct {
        medical_transcription_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .medical_transcription_job_name = "MedicalTranscriptionJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_medical_transcription_job) } {
            return .{ .service_metadata = service_metadata, .action = get_medical_transcription_job };
        }
    },
    Response: type = struct {
        medical_transcription_job: ?MedicalTranscriptionJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .medical_transcription_job = "MedicalTranscriptionJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_medical_vocabulary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/medicalvocabularies/{VocabularyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMedicalVocabulary",
    Request: type = struct {
        vocabulary_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_medical_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = get_medical_vocabulary };
        }
    },
    Response: type = struct {
        vocabulary_name: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        vocabulary_state: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        failure_reason: ?[]const u8 = null,
        download_uri: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .vocabulary_state = "VocabularyState",
                .last_modified_time = "LastModifiedTime",
                .failure_reason = "FailureReason",
                .download_uri = "DownloadUri",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_transcription_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/transcriptionjobs/{TranscriptionJobName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTranscriptionJob",
    Request: type = struct {
        transcription_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transcription_job_name = "TranscriptionJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_transcription_job) } {
            return .{ .service_metadata = service_metadata, .action = get_transcription_job };
        }
    },
    Response: type = struct {
        transcription_job: ?TranscriptionJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transcription_job = "TranscriptionJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_vocabulary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/vocabularies/{VocabularyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVocabulary",
    Request: type = struct {
        vocabulary_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = get_vocabulary };
        }
    },
    Response: type = struct {
        vocabulary_name: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        vocabulary_state: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        failure_reason: ?[]const u8 = null,
        download_uri: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .vocabulary_state = "VocabularyState",
                .last_modified_time = "LastModifiedTime",
                .failure_reason = "FailureReason",
                .download_uri = "DownloadUri",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const get_vocabulary_filter: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/vocabularyFilters/{VocabularyFilterName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVocabularyFilter",
    Request: type = struct {
        vocabulary_filter_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_filter_name = "VocabularyFilterName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vocabulary_filter) } {
            return .{ .service_metadata = service_metadata, .action = get_vocabulary_filter };
        }
    },
    Response: type = struct {
        vocabulary_filter_name: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        download_uri: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_filter_name = "VocabularyFilterName",
                .language_code = "LanguageCode",
                .last_modified_time = "LastModifiedTime",
                .download_uri = "DownloadUri",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const list_call_analytics_categories: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/callanalyticscategories",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCallAnalyticsCategories",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_call_analytics_categories) } {
            return .{ .service_metadata = service_metadata, .action = list_call_analytics_categories };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        categories: ?[]CategoryProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .categories = "Categories",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const list_call_analytics_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/callanalyticsjobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCallAnalyticsJobs",
    Request: type = struct {
        status: ?[]const u8 = null,
        job_name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .status = "Status",
            .job_name_contains = "JobNameContains",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .job_name_contains = "JobNameContains",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_call_analytics_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_call_analytics_jobs };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        call_analytics_job_summaries: ?[]struct {
            call_analytics_job_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            start_time: ?i64 = null,
            completion_time: ?i64 = null,
            language_code: ?[]const u8 = null,
            call_analytics_job_status: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .call_analytics_job_name = "CallAnalyticsJobName",
                    .creation_time = "CreationTime",
                    .start_time = "StartTime",
                    .completion_time = "CompletionTime",
                    .language_code = "LanguageCode",
                    .call_analytics_job_status = "CallAnalyticsJobStatus",
                    .failure_reason = "FailureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .next_token = "NextToken",
                .call_analytics_job_summaries = "CallAnalyticsJobSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const list_language_models: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/languagemodels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLanguageModels",
    Request: type = struct {
        status_equals: ?[]const u8 = null,
        name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .status_equals = "         StatusEquals",
            .name_contains = "NameContains",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_equals = "StatusEquals",
                .name_contains = "NameContains",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_language_models) } {
            return .{ .service_metadata = service_metadata, .action = list_language_models };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        models: ?[]LanguageModel = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .models = "Models",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const list_medical_scribe_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/medicalscribejobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMedicalScribeJobs",
    Request: type = struct {
        status: ?[]const u8 = null,
        job_name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .status = "Status",
            .job_name_contains = "JobNameContains",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .job_name_contains = "JobNameContains",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_medical_scribe_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_medical_scribe_jobs };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        medical_scribe_job_summaries: ?[]struct {
            medical_scribe_job_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            start_time: ?i64 = null,
            completion_time: ?i64 = null,
            language_code: ?[]const u8 = null,
            medical_scribe_job_status: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .medical_scribe_job_name = "MedicalScribeJobName",
                    .creation_time = "CreationTime",
                    .start_time = "StartTime",
                    .completion_time = "CompletionTime",
                    .language_code = "LanguageCode",
                    .medical_scribe_job_status = "MedicalScribeJobStatus",
                    .failure_reason = "FailureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .next_token = "NextToken",
                .medical_scribe_job_summaries = "MedicalScribeJobSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const list_medical_transcription_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/medicaltranscriptionjobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMedicalTranscriptionJobs",
    Request: type = struct {
        status: ?[]const u8 = null,
        job_name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .status = "Status",
            .job_name_contains = "JobNameContains",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .job_name_contains = "JobNameContains",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_medical_transcription_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_medical_transcription_jobs };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        medical_transcription_job_summaries: ?[]struct {
            medical_transcription_job_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            start_time: ?i64 = null,
            completion_time: ?i64 = null,
            language_code: ?[]const u8 = null,
            transcription_job_status: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            output_location_type: ?[]const u8 = null,
            specialty: ?[]const u8 = null,
            content_identification_type: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .medical_transcription_job_name = "MedicalTranscriptionJobName",
                    .creation_time = "CreationTime",
                    .start_time = "StartTime",
                    .completion_time = "CompletionTime",
                    .language_code = "LanguageCode",
                    .transcription_job_status = "TranscriptionJobStatus",
                    .failure_reason = "FailureReason",
                    .output_location_type = "OutputLocationType",
                    .specialty = "Specialty",
                    .content_identification_type = "ContentIdentificationType",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .next_token = "NextToken",
                .medical_transcription_job_summaries = "MedicalTranscriptionJobSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const list_medical_vocabularies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/medicalvocabularies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMedicalVocabularies",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        state_equals: ?[]const u8 = null,
        name_contains: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .state_equals = "StateEquals",
            .name_contains = "NameContains",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .state_equals = "StateEquals",
                .name_contains = "NameContains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_medical_vocabularies) } {
            return .{ .service_metadata = service_metadata, .action = list_medical_vocabularies };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        vocabularies: ?[]VocabularyInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .next_token = "NextToken",
                .vocabularies = "Vocabularies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const list_transcription_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/transcriptionjobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTranscriptionJobs",
    Request: type = struct {
        status: ?[]const u8 = null,
        job_name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .status = "Status",
            .job_name_contains = "JobNameContains",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .job_name_contains = "JobNameContains",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_transcription_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_transcription_jobs };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        transcription_job_summaries: ?[]struct {
            transcription_job_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            start_time: ?i64 = null,
            completion_time: ?i64 = null,
            language_code: ?[]const u8 = null,
            transcription_job_status: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            output_location_type: ?[]const u8 = null,
            content_redaction: ?ContentRedaction = null,
            model_settings: ?ModelSettings = null,
            identify_language: ?bool = null,
            identify_multiple_languages: ?bool = null,
            identified_language_score: ?f32 = null,
            language_codes: ?[]LanguageCodeItem = null,
            toxicity_detection: ?[]ToxicityDetectionSettings = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transcription_job_name = "TranscriptionJobName",
                    .creation_time = "CreationTime",
                    .start_time = "StartTime",
                    .completion_time = "CompletionTime",
                    .language_code = "LanguageCode",
                    .transcription_job_status = "TranscriptionJobStatus",
                    .failure_reason = "FailureReason",
                    .output_location_type = "OutputLocationType",
                    .content_redaction = "ContentRedaction",
                    .model_settings = "ModelSettings",
                    .identify_language = "IdentifyLanguage",
                    .identify_multiple_languages = "IdentifyMultipleLanguages",
                    .identified_language_score = "IdentifiedLanguageScore",
                    .language_codes = "LanguageCodes",
                    .toxicity_detection = "ToxicityDetection",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .next_token = "NextToken",
                .transcription_job_summaries = "TranscriptionJobSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const list_vocabularies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/vocabularies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVocabularies",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        state_equals: ?[]const u8 = null,
        name_contains: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .state_equals = "StateEquals",
            .name_contains = "NameContains",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .state_equals = "StateEquals",
                .name_contains = "NameContains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vocabularies) } {
            return .{ .service_metadata = service_metadata, .action = list_vocabularies };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        vocabularies: ?[]VocabularyInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .next_token = "NextToken",
                .vocabularies = "Vocabularies",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const list_vocabulary_filters: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/vocabularyFilters",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVocabularyFilters",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .name_contains = "NameContains",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vocabulary_filters) } {
            return .{ .service_metadata = service_metadata, .action = list_vocabulary_filters };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        vocabulary_filters: ?[]struct {
            vocabulary_filter_name: ?[]const u8 = null,
            language_code: ?[]const u8 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vocabulary_filter_name = "VocabularyFilterName",
                    .language_code = "LanguageCode",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .vocabulary_filters = "VocabularyFilters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const start_call_analytics_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/callanalyticsjobs/{CallAnalyticsJobName}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartCallAnalyticsJob",
    Request: type = struct {
        call_analytics_job_name: []const u8,
        media: Media,
        output_location: ?[]const u8 = null,
        output_encryption_kms_key_id: ?[]const u8 = null,
        data_access_role_arn: ?[]const u8 = null,
        settings: ?CallAnalyticsJobSettings = null,
        channel_definitions: ?[]ChannelDefinition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .call_analytics_job_name = "CallAnalyticsJobName",
                .media = "Media",
                .output_location = "OutputLocation",
                .output_encryption_kms_key_id = "OutputEncryptionKMSKeyId",
                .data_access_role_arn = "DataAccessRoleArn",
                .settings = "Settings",
                .channel_definitions = "ChannelDefinitions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_call_analytics_job) } {
            return .{ .service_metadata = service_metadata, .action = start_call_analytics_job };
        }
    },
    Response: type = struct {
        call_analytics_job: ?CallAnalyticsJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .call_analytics_job = "CallAnalyticsJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const start_medical_scribe_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/medicalscribejobs/{MedicalScribeJobName}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMedicalScribeJob",
    Request: type = struct {
        medical_scribe_job_name: []const u8,
        media: Media,
        output_bucket_name: []const u8,
        output_encryption_kms_key_id: ?[]const u8 = null,
        kms_encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        data_access_role_arn: []const u8,
        settings: MedicalScribeSettings,
        channel_definitions: ?[]MedicalScribeChannelDefinition = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .medical_scribe_job_name = "MedicalScribeJobName",
                .media = "Media",
                .output_bucket_name = "OutputBucketName",
                .output_encryption_kms_key_id = "OutputEncryptionKMSKeyId",
                .kms_encryption_context = "KMSEncryptionContext",
                .data_access_role_arn = "DataAccessRoleArn",
                .settings = "Settings",
                .channel_definitions = "ChannelDefinitions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "kms_encryption_context", field_name))
                return try serializeMap(self.kms_encryption_context, self.fieldNameFor("kms_encryption_context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_medical_scribe_job) } {
            return .{ .service_metadata = service_metadata, .action = start_medical_scribe_job };
        }
    },
    Response: type = struct {
        medical_scribe_job: ?MedicalScribeJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .medical_scribe_job = "MedicalScribeJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const start_medical_transcription_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/medicaltranscriptionjobs/{MedicalTranscriptionJobName}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMedicalTranscriptionJob",
    Request: type = struct {
        medical_transcription_job_name: []const u8,
        language_code: []const u8,
        media_sample_rate_hertz: ?i64 = null,
        media_format: ?[]const u8 = null,
        media: Media,
        output_bucket_name: []const u8,
        output_key: ?[]const u8 = null,
        output_encryption_kms_key_id: ?[]const u8 = null,
        kms_encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        settings: ?MedicalTranscriptionSetting = null,
        content_identification_type: ?[]const u8 = null,
        specialty: []const u8,
        type: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .medical_transcription_job_name = "MedicalTranscriptionJobName",
                .language_code = "LanguageCode",
                .media_sample_rate_hertz = "MediaSampleRateHertz",
                .media_format = "MediaFormat",
                .media = "Media",
                .output_bucket_name = "OutputBucketName",
                .output_key = "OutputKey",
                .output_encryption_kms_key_id = "OutputEncryptionKMSKeyId",
                .kms_encryption_context = "KMSEncryptionContext",
                .settings = "Settings",
                .content_identification_type = "ContentIdentificationType",
                .specialty = "Specialty",
                .type = "Type",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "kms_encryption_context", field_name))
                return try serializeMap(self.kms_encryption_context, self.fieldNameFor("kms_encryption_context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_medical_transcription_job) } {
            return .{ .service_metadata = service_metadata, .action = start_medical_transcription_job };
        }
    },
    Response: type = struct {
        medical_transcription_job: ?MedicalTranscriptionJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .medical_transcription_job = "MedicalTranscriptionJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const start_transcription_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/transcriptionjobs/{TranscriptionJobName}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartTranscriptionJob",
    Request: type = struct {
        transcription_job_name: []const u8,
        language_code: ?[]const u8 = null,
        media_sample_rate_hertz: ?i64 = null,
        media_format: ?[]const u8 = null,
        media: Media,
        output_bucket_name: ?[]const u8 = null,
        output_key: ?[]const u8 = null,
        output_encryption_kms_key_id: ?[]const u8 = null,
        kms_encryption_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        settings: ?Settings = null,
        model_settings: ?ModelSettings = null,
        job_execution_settings: ?JobExecutionSettings = null,
        content_redaction: ?ContentRedaction = null,
        identify_language: ?bool = null,
        identify_multiple_languages: ?bool = null,
        language_options: ?[][]const u8 = null,
        subtitles: ?struct {
            formats: ?[][]const u8 = null,
            output_start_index: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .formats = "Formats",
                    .output_start_index = "OutputStartIndex",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]Tag = null,
        language_id_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LanguageIdSettings = null,
        } = null,
        toxicity_detection: ?[]ToxicityDetectionSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transcription_job_name = "TranscriptionJobName",
                .language_code = "LanguageCode",
                .media_sample_rate_hertz = "MediaSampleRateHertz",
                .media_format = "MediaFormat",
                .media = "Media",
                .output_bucket_name = "OutputBucketName",
                .output_key = "OutputKey",
                .output_encryption_kms_key_id = "OutputEncryptionKMSKeyId",
                .kms_encryption_context = "KMSEncryptionContext",
                .settings = "Settings",
                .model_settings = "ModelSettings",
                .job_execution_settings = "JobExecutionSettings",
                .content_redaction = "ContentRedaction",
                .identify_language = "IdentifyLanguage",
                .identify_multiple_languages = "IdentifyMultipleLanguages",
                .language_options = "LanguageOptions",
                .subtitles = "Subtitles",
                .tags = "Tags",
                .language_id_settings = "LanguageIdSettings",
                .toxicity_detection = "ToxicityDetection",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "kms_encryption_context", field_name))
                return try serializeMap(self.kms_encryption_context, self.fieldNameFor("kms_encryption_context"), options, out_stream);
            if (std.mem.eql(u8, "language_id_settings", field_name))
                return try serializeMap(self.language_id_settings, self.fieldNameFor("language_id_settings"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_transcription_job) } {
            return .{ .service_metadata = service_metadata, .action = start_transcription_job };
        }
    },
    Response: type = struct {
        transcription_job: ?TranscriptionJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transcription_job = "TranscriptionJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const update_call_analytics_category: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/callanalyticscategories/{CategoryName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCallAnalyticsCategory",
    Request: type = struct {
        category_name: []const u8,
        rules: []Rule,
        input_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category_name = "CategoryName",
                .rules = "Rules",
                .input_type = "InputType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_call_analytics_category) } {
            return .{ .service_metadata = service_metadata, .action = update_call_analytics_category };
        }
    },
    Response: type = struct {
        category_properties: ?CategoryProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .category_properties = "CategoryProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const update_medical_vocabulary: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/medicalvocabularies/{VocabularyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMedicalVocabulary",
    Request: type = struct {
        vocabulary_name: []const u8,
        language_code: []const u8,
        vocabulary_file_uri: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .vocabulary_file_uri = "VocabularyFileUri",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_medical_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = update_medical_vocabulary };
        }
    },
    Response: type = struct {
        vocabulary_name: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        vocabulary_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .last_modified_time = "LastModifiedTime",
                .vocabulary_state = "VocabularyState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const update_vocabulary: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/vocabularies/{VocabularyName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVocabulary",
    Request: type = struct {
        vocabulary_name: []const u8,
        language_code: []const u8,
        phrases: ?[][]const u8 = null,
        vocabulary_file_uri: ?[]const u8 = null,
        data_access_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .phrases = "Phrases",
                .vocabulary_file_uri = "VocabularyFileUri",
                .data_access_role_arn = "DataAccessRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = update_vocabulary };
        }
    },
    Response: type = struct {
        vocabulary_name: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        vocabulary_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .last_modified_time = "LastModifiedTime",
                .vocabulary_state = "VocabularyState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};
pub const update_vocabulary_filter: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/vocabularyFilters/{VocabularyFilterName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVocabularyFilter",
    Request: type = struct {
        vocabulary_filter_name: []const u8,
        words: ?[][]const u8 = null,
        vocabulary_filter_file_uri: ?[]const u8 = null,
        data_access_role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_filter_name = "VocabularyFilterName",
                .words = "Words",
                .vocabulary_filter_file_uri = "VocabularyFilterFileUri",
                .data_access_role_arn = "DataAccessRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vocabulary_filter) } {
            return .{ .service_metadata = service_metadata, .action = update_vocabulary_filter };
        }
    },
    Response: type = struct {
        vocabulary_filter_name: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        last_modified_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_filter_name = "VocabularyFilterName",
                .language_code = "LanguageCode",
                .last_modified_time = "LastModifiedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
    },
} = .{};

pub const CategoryProperties = struct {
    category_name: ?[]const u8 = null,
    rules: ?[]Rule = null,
    create_time: ?i64 = null,
    last_update_time: ?i64 = null,
    input_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category_name = "CategoryName",
            .rules = "Rules",
            .create_time = "CreateTime",
            .last_update_time = "LastUpdateTime",
            .input_type = "InputType",
        };
        return @field(mappings, field_name);
    }
};

pub const Rule = union {
    non_talk_time_filter: ?NonTalkTimeFilter,
    interruption_filter: ?InterruptionFilter,
    transcript_filter: ?TranscriptFilter,
    sentiment_filter: ?SentimentFilter,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .non_talk_time_filter = "NonTalkTimeFilter",
            .interruption_filter = "InterruptionFilter",
            .transcript_filter = "TranscriptFilter",
            .sentiment_filter = "SentimentFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const SentimentFilter = struct {
    sentiments: [][]const u8,
    absolute_time_range: ?AbsoluteTimeRange = null,
    relative_time_range: ?RelativeTimeRange = null,
    participant_role: ?[]const u8 = null,
    negate: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sentiments = "Sentiments",
            .absolute_time_range = "AbsoluteTimeRange",
            .relative_time_range = "RelativeTimeRange",
            .participant_role = "ParticipantRole",
            .negate = "Negate",
        };
        return @field(mappings, field_name);
    }
};

pub const RelativeTimeRange = struct {
    start_percentage: ?i64 = null,
    end_percentage: ?i64 = null,
    first: ?i64 = null,
    last: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_percentage = "StartPercentage",
            .end_percentage = "EndPercentage",
            .first = "First",
            .last = "Last",
        };
        return @field(mappings, field_name);
    }
};

pub const AbsoluteTimeRange = struct {
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    first: ?i64 = null,
    last: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
            .first = "First",
            .last = "Last",
        };
        return @field(mappings, field_name);
    }
};

pub const TranscriptFilter = struct {
    transcript_filter_type: []const u8,
    absolute_time_range: ?AbsoluteTimeRange = null,
    relative_time_range: ?RelativeTimeRange = null,
    participant_role: ?[]const u8 = null,
    negate: ?bool = null,
    targets: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transcript_filter_type = "TranscriptFilterType",
            .absolute_time_range = "AbsoluteTimeRange",
            .relative_time_range = "RelativeTimeRange",
            .participant_role = "ParticipantRole",
            .negate = "Negate",
            .targets = "Targets",
        };
        return @field(mappings, field_name);
    }
};

pub const InterruptionFilter = struct {
    threshold: ?i64 = null,
    participant_role: ?[]const u8 = null,
    absolute_time_range: ?AbsoluteTimeRange = null,
    relative_time_range: ?RelativeTimeRange = null,
    negate: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .threshold = "Threshold",
            .participant_role = "ParticipantRole",
            .absolute_time_range = "AbsoluteTimeRange",
            .relative_time_range = "RelativeTimeRange",
            .negate = "Negate",
        };
        return @field(mappings, field_name);
    }
};

pub const NonTalkTimeFilter = struct {
    threshold: ?i64 = null,
    absolute_time_range: ?AbsoluteTimeRange = null,
    relative_time_range: ?RelativeTimeRange = null,
    negate: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .threshold = "Threshold",
            .absolute_time_range = "AbsoluteTimeRange",
            .relative_time_range = "RelativeTimeRange",
            .negate = "Negate",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TranscriptionJob = struct {
    transcription_job_name: ?[]const u8 = null,
    transcription_job_status: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    media_sample_rate_hertz: ?i64 = null,
    media_format: ?[]const u8 = null,
    media: ?Media = null,
    transcript: ?Transcript = null,
    start_time: ?i64 = null,
    creation_time: ?i64 = null,
    completion_time: ?i64 = null,
    failure_reason: ?[]const u8 = null,
    settings: ?Settings = null,
    model_settings: ?ModelSettings = null,
    job_execution_settings: ?JobExecutionSettings = null,
    content_redaction: ?ContentRedaction = null,
    identify_language: ?bool = null,
    identify_multiple_languages: ?bool = null,
    language_options: ?[][]const u8 = null,
    identified_language_score: ?f32 = null,
    language_codes: ?[]LanguageCodeItem = null,
    tags: ?[]Tag = null,
    subtitles: ?SubtitlesOutput = null,
    language_id_settings: ?[]struct {
        key: ?[]const u8 = null,
        value: ?LanguageIdSettings = null,
    } = null,
    toxicity_detection: ?[]ToxicityDetectionSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transcription_job_name = "TranscriptionJobName",
            .transcription_job_status = "TranscriptionJobStatus",
            .language_code = "LanguageCode",
            .media_sample_rate_hertz = "MediaSampleRateHertz",
            .media_format = "MediaFormat",
            .media = "Media",
            .transcript = "Transcript",
            .start_time = "StartTime",
            .creation_time = "CreationTime",
            .completion_time = "CompletionTime",
            .failure_reason = "FailureReason",
            .settings = "Settings",
            .model_settings = "ModelSettings",
            .job_execution_settings = "JobExecutionSettings",
            .content_redaction = "ContentRedaction",
            .identify_language = "IdentifyLanguage",
            .identify_multiple_languages = "IdentifyMultipleLanguages",
            .language_options = "LanguageOptions",
            .identified_language_score = "IdentifiedLanguageScore",
            .language_codes = "LanguageCodes",
            .tags = "Tags",
            .subtitles = "Subtitles",
            .language_id_settings = "LanguageIdSettings",
            .toxicity_detection = "ToxicityDetection",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "language_id_settings", field_name))
            return try serializeMap(self.language_id_settings, self.fieldNameFor("language_id_settings"), options, out_stream);
        return false;
    }
};

pub const ToxicityDetectionSettings = struct {
    toxicity_categories: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .toxicity_categories = "ToxicityCategories",
        };
        return @field(mappings, field_name);
    }
};

pub const LanguageIdSettings = struct {
    vocabulary_name: ?[]const u8 = null,
    vocabulary_filter_name: ?[]const u8 = null,
    language_model_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vocabulary_name = "VocabularyName",
            .vocabulary_filter_name = "VocabularyFilterName",
            .language_model_name = "LanguageModelName",
        };
        return @field(mappings, field_name);
    }
};

pub const SubtitlesOutput = struct {
    formats: ?[][]const u8 = null,
    subtitle_file_uris: ?[][]const u8 = null,
    output_start_index: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .formats = "Formats",
            .subtitle_file_uris = "SubtitleFileUris",
            .output_start_index = "OutputStartIndex",
        };
        return @field(mappings, field_name);
    }
};

pub const LanguageCodeItem = struct {
    language_code: ?[]const u8 = null,
    duration_in_seconds: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .language_code = "LanguageCode",
            .duration_in_seconds = "DurationInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentRedaction = struct {
    redaction_type: []const u8,
    redaction_output: []const u8,
    pii_entity_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .redaction_type = "RedactionType",
            .redaction_output = "RedactionOutput",
            .pii_entity_types = "PiiEntityTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const JobExecutionSettings = struct {
    allow_deferred_execution: ?bool = null,
    data_access_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .allow_deferred_execution = "AllowDeferredExecution",
            .data_access_role_arn = "DataAccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelSettings = struct {
    language_model_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .language_model_name = "LanguageModelName",
        };
        return @field(mappings, field_name);
    }
};

pub const Settings = struct {
    vocabulary_name: ?[]const u8 = null,
    show_speaker_labels: ?bool = null,
    max_speaker_labels: ?i64 = null,
    channel_identification: ?bool = null,
    show_alternatives: ?bool = null,
    max_alternatives: ?i64 = null,
    vocabulary_filter_name: ?[]const u8 = null,
    vocabulary_filter_method: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vocabulary_name = "VocabularyName",
            .show_speaker_labels = "ShowSpeakerLabels",
            .max_speaker_labels = "MaxSpeakerLabels",
            .channel_identification = "ChannelIdentification",
            .show_alternatives = "ShowAlternatives",
            .max_alternatives = "MaxAlternatives",
            .vocabulary_filter_name = "VocabularyFilterName",
            .vocabulary_filter_method = "VocabularyFilterMethod",
        };
        return @field(mappings, field_name);
    }
};

pub const Transcript = struct {
    transcript_file_uri: ?[]const u8 = null,
    redacted_transcript_file_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transcript_file_uri = "TranscriptFileUri",
            .redacted_transcript_file_uri = "RedactedTranscriptFileUri",
        };
        return @field(mappings, field_name);
    }
};

pub const Media = struct {
    media_file_uri: ?[]const u8 = null,
    redacted_media_file_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .media_file_uri = "MediaFileUri",
            .redacted_media_file_uri = "RedactedMediaFileUri",
        };
        return @field(mappings, field_name);
    }
};

pub const MedicalTranscriptionJob = struct {
    medical_transcription_job_name: ?[]const u8 = null,
    transcription_job_status: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    media_sample_rate_hertz: ?i64 = null,
    media_format: ?[]const u8 = null,
    media: ?Media = null,
    transcript: ?MedicalTranscript = null,
    start_time: ?i64 = null,
    creation_time: ?i64 = null,
    completion_time: ?i64 = null,
    failure_reason: ?[]const u8 = null,
    settings: ?MedicalTranscriptionSetting = null,
    content_identification_type: ?[]const u8 = null,
    specialty: ?[]const u8 = null,
    type: ?[]const u8 = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .medical_transcription_job_name = "MedicalTranscriptionJobName",
            .transcription_job_status = "TranscriptionJobStatus",
            .language_code = "LanguageCode",
            .media_sample_rate_hertz = "MediaSampleRateHertz",
            .media_format = "MediaFormat",
            .media = "Media",
            .transcript = "Transcript",
            .start_time = "StartTime",
            .creation_time = "CreationTime",
            .completion_time = "CompletionTime",
            .failure_reason = "FailureReason",
            .settings = "Settings",
            .content_identification_type = "ContentIdentificationType",
            .specialty = "Specialty",
            .type = "Type",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const MedicalTranscriptionSetting = struct {
    show_speaker_labels: ?bool = null,
    max_speaker_labels: ?i64 = null,
    channel_identification: ?bool = null,
    show_alternatives: ?bool = null,
    max_alternatives: ?i64 = null,
    vocabulary_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .show_speaker_labels = "ShowSpeakerLabels",
            .max_speaker_labels = "MaxSpeakerLabels",
            .channel_identification = "ChannelIdentification",
            .show_alternatives = "ShowAlternatives",
            .max_alternatives = "MaxAlternatives",
            .vocabulary_name = "VocabularyName",
        };
        return @field(mappings, field_name);
    }
};

pub const MedicalTranscript = struct {
    transcript_file_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transcript_file_uri = "TranscriptFileUri",
        };
        return @field(mappings, field_name);
    }
};

pub const MedicalScribeJob = struct {
    medical_scribe_job_name: ?[]const u8 = null,
    medical_scribe_job_status: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    media: ?Media = null,
    medical_scribe_output: ?MedicalScribeOutput = null,
    start_time: ?i64 = null,
    creation_time: ?i64 = null,
    completion_time: ?i64 = null,
    failure_reason: ?[]const u8 = null,
    settings: ?MedicalScribeSettings = null,
    data_access_role_arn: ?[]const u8 = null,
    channel_definitions: ?[]MedicalScribeChannelDefinition = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .medical_scribe_job_name = "MedicalScribeJobName",
            .medical_scribe_job_status = "MedicalScribeJobStatus",
            .language_code = "LanguageCode",
            .media = "Media",
            .medical_scribe_output = "MedicalScribeOutput",
            .start_time = "StartTime",
            .creation_time = "CreationTime",
            .completion_time = "CompletionTime",
            .failure_reason = "FailureReason",
            .settings = "Settings",
            .data_access_role_arn = "DataAccessRoleArn",
            .channel_definitions = "ChannelDefinitions",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const MedicalScribeChannelDefinition = struct {
    channel_id: i64,
    participant_role: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_id = "ChannelId",
            .participant_role = "ParticipantRole",
        };
        return @field(mappings, field_name);
    }
};

pub const MedicalScribeSettings = struct {
    show_speaker_labels: ?bool = null,
    max_speaker_labels: ?i64 = null,
    channel_identification: ?bool = null,
    vocabulary_name: ?[]const u8 = null,
    vocabulary_filter_name: ?[]const u8 = null,
    vocabulary_filter_method: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .show_speaker_labels = "ShowSpeakerLabels",
            .max_speaker_labels = "MaxSpeakerLabels",
            .channel_identification = "ChannelIdentification",
            .vocabulary_name = "VocabularyName",
            .vocabulary_filter_name = "VocabularyFilterName",
            .vocabulary_filter_method = "VocabularyFilterMethod",
        };
        return @field(mappings, field_name);
    }
};

pub const MedicalScribeOutput = struct {
    transcript_file_uri: []const u8,
    clinical_document_uri: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transcript_file_uri = "TranscriptFileUri",
            .clinical_document_uri = "ClinicalDocumentUri",
        };
        return @field(mappings, field_name);
    }
};

pub const CallAnalyticsJob = struct {
    call_analytics_job_name: ?[]const u8 = null,
    call_analytics_job_status: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    media_sample_rate_hertz: ?i64 = null,
    media_format: ?[]const u8 = null,
    media: ?Media = null,
    transcript: ?Transcript = null,
    start_time: ?i64 = null,
    creation_time: ?i64 = null,
    completion_time: ?i64 = null,
    failure_reason: ?[]const u8 = null,
    data_access_role_arn: ?[]const u8 = null,
    identified_language_score: ?f32 = null,
    settings: ?CallAnalyticsJobSettings = null,
    channel_definitions: ?[]ChannelDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .call_analytics_job_name = "CallAnalyticsJobName",
            .call_analytics_job_status = "CallAnalyticsJobStatus",
            .language_code = "LanguageCode",
            .media_sample_rate_hertz = "MediaSampleRateHertz",
            .media_format = "MediaFormat",
            .media = "Media",
            .transcript = "Transcript",
            .start_time = "StartTime",
            .creation_time = "CreationTime",
            .completion_time = "CompletionTime",
            .failure_reason = "FailureReason",
            .data_access_role_arn = "DataAccessRoleArn",
            .identified_language_score = "IdentifiedLanguageScore",
            .settings = "Settings",
            .channel_definitions = "ChannelDefinitions",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelDefinition = struct {
    channel_id: ?i64 = null,
    participant_role: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_id = "ChannelId",
            .participant_role = "ParticipantRole",
        };
        return @field(mappings, field_name);
    }
};

pub const CallAnalyticsJobSettings = struct {
    vocabulary_name: ?[]const u8 = null,
    vocabulary_filter_name: ?[]const u8 = null,
    vocabulary_filter_method: ?[]const u8 = null,
    language_model_name: ?[]const u8 = null,
    content_redaction: ?ContentRedaction = null,
    language_options: ?[][]const u8 = null,
    language_id_settings: ?[]struct {
        key: ?[]const u8 = null,
        value: ?LanguageIdSettings = null,
    } = null,
    summarization: ?Summarization = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vocabulary_name = "VocabularyName",
            .vocabulary_filter_name = "VocabularyFilterName",
            .vocabulary_filter_method = "VocabularyFilterMethod",
            .language_model_name = "LanguageModelName",
            .content_redaction = "ContentRedaction",
            .language_options = "LanguageOptions",
            .language_id_settings = "LanguageIdSettings",
            .summarization = "Summarization",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "language_id_settings", field_name))
            return try serializeMap(self.language_id_settings, self.fieldNameFor("language_id_settings"), options, out_stream);
        return false;
    }
};

pub const Summarization = struct {
    generate_abstractive_summary: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .generate_abstractive_summary = "GenerateAbstractiveSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const VocabularyInfo = struct {
    vocabulary_name: ?[]const u8 = null,
    language_code: ?[]const u8 = null,
    last_modified_time: ?i64 = null,
    vocabulary_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vocabulary_name = "VocabularyName",
            .language_code = "LanguageCode",
            .last_modified_time = "LastModifiedTime",
            .vocabulary_state = "VocabularyState",
        };
        return @field(mappings, field_name);
    }
};

pub const LanguageModel = struct {
    model_name: ?[]const u8 = null,
    create_time: ?i64 = null,
    last_modified_time: ?i64 = null,
    language_code: ?[]const u8 = null,
    base_model_name: ?[]const u8 = null,
    model_status: ?[]const u8 = null,
    upgrade_availability: ?bool = null,
    failure_reason: ?[]const u8 = null,
    input_data_config: ?InputDataConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .model_name = "ModelName",
            .create_time = "CreateTime",
            .last_modified_time = "LastModifiedTime",
            .language_code = "LanguageCode",
            .base_model_name = "BaseModelName",
            .model_status = "ModelStatus",
            .upgrade_availability = "UpgradeAvailability",
            .failure_reason = "FailureReason",
            .input_data_config = "InputDataConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDataConfig = struct {
    s3_uri: []const u8,
    tuning_data_s3_uri: ?[]const u8 = null,
    data_access_role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
            .tuning_data_s3_uri = "TuningDataS3Uri",
            .data_access_role_arn = "DataAccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};
