const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-10-26";
pub const sdk_id: []const u8 = "Transcribe Streaming";
pub const arn_namespace: ?[]const u8 = "transcribe";
pub const endpoint_prefix: []const u8 = "transcribestreaming";
pub const sigv4_name: []const u8 = "transcribe";
pub const name: []const u8 = "Transcribe";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-10-26",
    sdk_id: []const u8 = "Transcribe Streaming",
    arn_namespace: ?[]const u8 = "transcribe",
    endpoint_prefix: []const u8 = "transcribestreaming",
    sigv4_name: []const u8 = "transcribe",
    name: []const u8 = "Transcribe",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const start_call_analytics_stream_transcription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/call-analytics-stream-transcription",
        .success_code = 200,
    };

    action_name: []const u8 = "StartCallAnalyticsStreamTranscription",
    Request: type = struct {
        language_code: []const u8,
        media_sample_rate_hertz: i64,
        media_encoding: []const u8,
        vocabulary_name: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        audio_stream: AudioStream,
        vocabulary_filter_name: ?[]const u8 = null,
        vocabulary_filter_method: ?[]const u8 = null,
        language_model_name: ?[]const u8 = null,
        enable_partial_results_stabilization: ?bool = null,
        partial_results_stability: ?[]const u8 = null,
        content_identification_type: ?[]const u8 = null,
        content_redaction_type: ?[]const u8 = null,
        pii_entity_types: ?[]const u8 = null,
        pub const http_header = .{
            .language_code = "x-amzn-transcribe-language-code",
            .media_sample_rate_hertz = "x-amzn-transcribe-sample-rate",
            .media_encoding = "x-amzn-transcribe-media-encoding",
            .vocabulary_name = "x-amzn-transcribe-vocabulary-name",
            .session_id = "x-amzn-transcribe-session-id",
            .vocabulary_filter_name = "x-amzn-transcribe-vocabulary-filter-name",
            .vocabulary_filter_method = "x-amzn-transcribe-vocabulary-filter-method",
            .language_model_name = "x-amzn-transcribe-language-model-name",
            .enable_partial_results_stabilization = "x-amzn-transcribe-enable-partial-results-stabilization",
            .partial_results_stability = "x-amzn-transcribe-partial-results-stability",
            .content_identification_type = "x-amzn-transcribe-content-identification-type",
            .content_redaction_type = "x-amzn-transcribe-content-redaction-type",
            .pii_entity_types = "x-amzn-transcribe-pii-entity-types",
        };

        pub const http_payload: []const u8 = "audio_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language_code = "LanguageCode",
                .media_sample_rate_hertz = "MediaSampleRateHertz",
                .media_encoding = "MediaEncoding",
                .vocabulary_name = "VocabularyName",
                .session_id = "SessionId",
                .audio_stream = "AudioStream",
                .vocabulary_filter_name = "VocabularyFilterName",
                .vocabulary_filter_method = "VocabularyFilterMethod",
                .language_model_name = "LanguageModelName",
                .enable_partial_results_stabilization = "EnablePartialResultsStabilization",
                .partial_results_stability = "PartialResultsStability",
                .content_identification_type = "ContentIdentificationType",
                .content_redaction_type = "ContentRedactionType",
                .pii_entity_types = "PiiEntityTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_call_analytics_stream_transcription) } {
            return .{ .service_metadata = service_metadata, .action = start_call_analytics_stream_transcription };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        media_sample_rate_hertz: ?i64 = null,
        media_encoding: ?[]const u8 = null,
        vocabulary_name: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        call_analytics_transcript_result_stream: ?union {
            utterance_event: ?struct {
                utterance_id: ?[]const u8 = null,
                is_partial: ?bool = null,
                participant_role: ?[]const u8 = null,
                begin_offset_millis: ?i64 = null,
                end_offset_millis: ?i64 = null,
                transcript: ?[]const u8 = null,
                items: ?[]struct {
                    begin_offset_millis: ?i64 = null,
                    end_offset_millis: ?i64 = null,
                    type: ?[]const u8 = null,
                    content: ?[]const u8 = null,
                    confidence: ?f64 = null,
                    vocabulary_filter_match: ?bool = null,
                    stable: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .begin_offset_millis = "BeginOffsetMillis",
                            .end_offset_millis = "EndOffsetMillis",
                            .type = "Type",
                            .content = "Content",
                            .confidence = "Confidence",
                            .vocabulary_filter_match = "VocabularyFilterMatch",
                            .stable = "Stable",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                entities: ?[]struct {
                    begin_offset_millis: ?i64 = null,
                    end_offset_millis: ?i64 = null,
                    category: ?[]const u8 = null,
                    type: ?[]const u8 = null,
                    content: ?[]const u8 = null,
                    confidence: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .begin_offset_millis = "BeginOffsetMillis",
                            .end_offset_millis = "EndOffsetMillis",
                            .category = "Category",
                            .type = "Type",
                            .content = "Content",
                            .confidence = "Confidence",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                sentiment: ?[]const u8 = null,
                issues_detected: ?[]struct {
                    character_offsets: ?struct {
                        begin: ?i64 = null,
                        end: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .begin = "Begin",
                                .end = "End",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .character_offsets = "CharacterOffsets",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .utterance_id = "UtteranceId",
                        .is_partial = "IsPartial",
                        .participant_role = "ParticipantRole",
                        .begin_offset_millis = "BeginOffsetMillis",
                        .end_offset_millis = "EndOffsetMillis",
                        .transcript = "Transcript",
                        .items = "Items",
                        .entities = "Entities",
                        .sentiment = "Sentiment",
                        .issues_detected = "IssuesDetected",
                    };
                    return @field(mappings, field_name);
                }
            },
            category_event: ?struct {
                matched_categories: ?[][]const u8 = null,
                matched_details: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?struct {
                        timestamp_ranges: ?[]struct {
                            begin_offset_millis: ?i64 = null,
                            end_offset_millis: ?i64 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .begin_offset_millis = "BeginOffsetMillis",
                                    .end_offset_millis = "EndOffsetMillis",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .timestamp_ranges = "TimestampRanges",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .matched_categories = "MatchedCategories",
                        .matched_details = "MatchedDetails",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "matched_details", field_name))
                        return try serializeMap(self.matched_details, self.fieldNameFor("matched_details"), options, out_stream);
                    return false;
                }
            },
            bad_request_exception: ?BadRequestException,
            limit_exceeded_exception: ?LimitExceededException,
            internal_failure_exception: ?InternalFailureException,
            conflict_exception: ?ConflictException,
            service_unavailable_exception: ?ServiceUnavailableException,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .utterance_event = "UtteranceEvent",
                    .category_event = "CategoryEvent",
                    .bad_request_exception = "BadRequestException",
                    .limit_exceeded_exception = "LimitExceededException",
                    .internal_failure_exception = "InternalFailureException",
                    .conflict_exception = "ConflictException",
                    .service_unavailable_exception = "ServiceUnavailableException",
                };
                return @field(mappings, field_name);
            }
        } = null,
        vocabulary_filter_name: ?[]const u8 = null,
        vocabulary_filter_method: ?[]const u8 = null,
        language_model_name: ?[]const u8 = null,
        enable_partial_results_stabilization: ?bool = null,
        partial_results_stability: ?[]const u8 = null,
        content_identification_type: ?[]const u8 = null,
        content_redaction_type: ?[]const u8 = null,
        pii_entity_types: ?[]const u8 = null,
        pub const http_header = .{
            .request_id = "x-amzn-request-id",
            .language_code = "x-amzn-transcribe-language-code",
            .media_sample_rate_hertz = "x-amzn-transcribe-sample-rate",
            .media_encoding = "x-amzn-transcribe-media-encoding",
            .vocabulary_name = "x-amzn-transcribe-vocabulary-name",
            .session_id = "x-amzn-transcribe-session-id",
            .vocabulary_filter_name = "x-amzn-transcribe-vocabulary-filter-name",
            .vocabulary_filter_method = "x-amzn-transcribe-vocabulary-filter-method",
            .language_model_name = "x-amzn-transcribe-language-model-name",
            .enable_partial_results_stabilization = "x-amzn-transcribe-enable-partial-results-stabilization",
            .partial_results_stability = "x-amzn-transcribe-partial-results-stability",
            .content_identification_type = "x-amzn-transcribe-content-identification-type",
            .content_redaction_type = "x-amzn-transcribe-content-redaction-type",
            .pii_entity_types = "x-amzn-transcribe-pii-entity-types",
        };

        pub const http_payload: []const u8 = "call_analytics_transcript_result_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .language_code = "LanguageCode",
                .media_sample_rate_hertz = "MediaSampleRateHertz",
                .media_encoding = "MediaEncoding",
                .vocabulary_name = "VocabularyName",
                .session_id = "SessionId",
                .call_analytics_transcript_result_stream = "CallAnalyticsTranscriptResultStream",
                .vocabulary_filter_name = "VocabularyFilterName",
                .vocabulary_filter_method = "VocabularyFilterMethod",
                .language_model_name = "LanguageModelName",
                .enable_partial_results_stabilization = "EnablePartialResultsStabilization",
                .partial_results_stability = "PartialResultsStability",
                .content_identification_type = "ContentIdentificationType",
                .content_redaction_type = "ContentRedactionType",
                .pii_entity_types = "PiiEntityTypes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const start_medical_stream_transcription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/medical-stream-transcription",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMedicalStreamTranscription",
    Request: type = struct {
        language_code: []const u8,
        media_sample_rate_hertz: i64,
        media_encoding: []const u8,
        vocabulary_name: ?[]const u8 = null,
        specialty: []const u8,
        type: []const u8,
        show_speaker_label: ?bool = null,
        session_id: ?[]const u8 = null,
        audio_stream: AudioStream,
        enable_channel_identification: ?bool = null,
        number_of_channels: ?i64 = null,
        content_identification_type: ?[]const u8 = null,
        pub const http_header = .{
            .language_code = "x-amzn-transcribe-language-code",
            .media_sample_rate_hertz = "x-amzn-transcribe-sample-rate",
            .media_encoding = "x-amzn-transcribe-media-encoding",
            .vocabulary_name = "x-amzn-transcribe-vocabulary-name",
            .specialty = "x-amzn-transcribe-specialty",
            .type = "x-amzn-transcribe-type",
            .show_speaker_label = "x-amzn-transcribe-show-speaker-label",
            .session_id = "x-amzn-transcribe-session-id",
            .enable_channel_identification = "x-amzn-transcribe-enable-channel-identification",
            .number_of_channels = "x-amzn-transcribe-number-of-channels",
            .content_identification_type = "x-amzn-transcribe-content-identification-type",
        };

        pub const http_payload: []const u8 = "audio_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language_code = "LanguageCode",
                .media_sample_rate_hertz = "MediaSampleRateHertz",
                .media_encoding = "MediaEncoding",
                .vocabulary_name = "VocabularyName",
                .specialty = "Specialty",
                .type = "Type",
                .show_speaker_label = "ShowSpeakerLabel",
                .session_id = "SessionId",
                .audio_stream = "AudioStream",
                .enable_channel_identification = "EnableChannelIdentification",
                .number_of_channels = "NumberOfChannels",
                .content_identification_type = "ContentIdentificationType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_medical_stream_transcription) } {
            return .{ .service_metadata = service_metadata, .action = start_medical_stream_transcription };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        media_sample_rate_hertz: ?i64 = null,
        media_encoding: ?[]const u8 = null,
        vocabulary_name: ?[]const u8 = null,
        specialty: ?[]const u8 = null,
        type: ?[]const u8 = null,
        show_speaker_label: ?bool = null,
        session_id: ?[]const u8 = null,
        transcript_result_stream: ?union {
            transcript_event: ?struct {
                transcript: ?struct {
                    results: ?[]struct {
                        result_id: ?[]const u8 = null,
                        start_time: ?f64 = null,
                        end_time: ?f64 = null,
                        is_partial: ?bool = null,
                        alternatives: ?[]struct {
                            transcript: ?[]const u8 = null,
                            items: ?[]struct {
                                start_time: ?f64 = null,
                                end_time: ?f64 = null,
                                type: ?[]const u8 = null,
                                content: ?[]const u8 = null,
                                confidence: ?f64 = null,
                                speaker: ?[]const u8 = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .start_time = "StartTime",
                                        .end_time = "EndTime",
                                        .type = "Type",
                                        .content = "Content",
                                        .confidence = "Confidence",
                                        .speaker = "Speaker",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,
                            entities: ?[]struct {
                                start_time: ?f64 = null,
                                end_time: ?f64 = null,
                                category: ?[]const u8 = null,
                                content: ?[]const u8 = null,
                                confidence: ?f64 = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .start_time = "StartTime",
                                        .end_time = "EndTime",
                                        .category = "Category",
                                        .content = "Content",
                                        .confidence = "Confidence",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .transcript = "Transcript",
                                    .items = "Items",
                                    .entities = "Entities",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        channel_id: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .result_id = "ResultId",
                                .start_time = "StartTime",
                                .end_time = "EndTime",
                                .is_partial = "IsPartial",
                                .alternatives = "Alternatives",
                                .channel_id = "ChannelId",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .results = "Results",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .transcript = "Transcript",
                    };
                    return @field(mappings, field_name);
                }
            },
            bad_request_exception: ?BadRequestException,
            limit_exceeded_exception: ?LimitExceededException,
            internal_failure_exception: ?InternalFailureException,
            conflict_exception: ?ConflictException,
            service_unavailable_exception: ?ServiceUnavailableException,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transcript_event = "TranscriptEvent",
                    .bad_request_exception = "BadRequestException",
                    .limit_exceeded_exception = "LimitExceededException",
                    .internal_failure_exception = "InternalFailureException",
                    .conflict_exception = "ConflictException",
                    .service_unavailable_exception = "ServiceUnavailableException",
                };
                return @field(mappings, field_name);
            }
        } = null,
        enable_channel_identification: ?bool = null,
        number_of_channels: ?i64 = null,
        content_identification_type: ?[]const u8 = null,
        pub const http_header = .{
            .request_id = "x-amzn-request-id",
            .language_code = "x-amzn-transcribe-language-code",
            .media_sample_rate_hertz = "x-amzn-transcribe-sample-rate",
            .media_encoding = "x-amzn-transcribe-media-encoding",
            .vocabulary_name = "x-amzn-transcribe-vocabulary-name",
            .specialty = "x-amzn-transcribe-specialty",
            .type = "x-amzn-transcribe-type",
            .show_speaker_label = "x-amzn-transcribe-show-speaker-label",
            .session_id = "x-amzn-transcribe-session-id",
            .enable_channel_identification = "x-amzn-transcribe-enable-channel-identification",
            .number_of_channels = "x-amzn-transcribe-number-of-channels",
            .content_identification_type = "x-amzn-transcribe-content-identification-type",
        };

        pub const http_payload: []const u8 = "transcript_result_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .language_code = "LanguageCode",
                .media_sample_rate_hertz = "MediaSampleRateHertz",
                .media_encoding = "MediaEncoding",
                .vocabulary_name = "VocabularyName",
                .specialty = "Specialty",
                .type = "Type",
                .show_speaker_label = "ShowSpeakerLabel",
                .session_id = "SessionId",
                .transcript_result_stream = "TranscriptResultStream",
                .enable_channel_identification = "EnableChannelIdentification",
                .number_of_channels = "NumberOfChannels",
                .content_identification_type = "ContentIdentificationType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const start_stream_transcription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/stream-transcription",
        .success_code = 200,
    };

    action_name: []const u8 = "StartStreamTranscription",
    Request: type = struct {
        language_code: ?[]const u8 = null,
        media_sample_rate_hertz: i64,
        media_encoding: []const u8,
        vocabulary_name: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        audio_stream: AudioStream,
        vocabulary_filter_name: ?[]const u8 = null,
        vocabulary_filter_method: ?[]const u8 = null,
        show_speaker_label: ?bool = null,
        enable_channel_identification: ?bool = null,
        number_of_channels: ?i64 = null,
        enable_partial_results_stabilization: ?bool = null,
        partial_results_stability: ?[]const u8 = null,
        content_identification_type: ?[]const u8 = null,
        content_redaction_type: ?[]const u8 = null,
        pii_entity_types: ?[]const u8 = null,
        language_model_name: ?[]const u8 = null,
        identify_language: ?bool = null,
        language_options: ?[]const u8 = null,
        preferred_language: ?[]const u8 = null,
        identify_multiple_languages: ?bool = null,
        vocabulary_names: ?[]const u8 = null,
        vocabulary_filter_names: ?[]const u8 = null,
        pub const http_header = .{
            .language_code = "x-amzn-transcribe-language-code",
            .media_sample_rate_hertz = "x-amzn-transcribe-sample-rate",
            .media_encoding = "x-amzn-transcribe-media-encoding",
            .vocabulary_name = "x-amzn-transcribe-vocabulary-name",
            .session_id = "x-amzn-transcribe-session-id",
            .vocabulary_filter_name = "x-amzn-transcribe-vocabulary-filter-name",
            .vocabulary_filter_method = "x-amzn-transcribe-vocabulary-filter-method",
            .show_speaker_label = "x-amzn-transcribe-show-speaker-label",
            .enable_channel_identification = "x-amzn-transcribe-enable-channel-identification",
            .number_of_channels = "x-amzn-transcribe-number-of-channels",
            .enable_partial_results_stabilization = "x-amzn-transcribe-enable-partial-results-stabilization",
            .partial_results_stability = "x-amzn-transcribe-partial-results-stability",
            .content_identification_type = "x-amzn-transcribe-content-identification-type",
            .content_redaction_type = "x-amzn-transcribe-content-redaction-type",
            .pii_entity_types = "x-amzn-transcribe-pii-entity-types",
            .language_model_name = "x-amzn-transcribe-language-model-name",
            .identify_language = "x-amzn-transcribe-identify-language",
            .language_options = "x-amzn-transcribe-language-options",
            .preferred_language = "x-amzn-transcribe-preferred-language",
            .identify_multiple_languages = "x-amzn-transcribe-identify-multiple-languages",
            .vocabulary_names = "x-amzn-transcribe-vocabulary-names",
            .vocabulary_filter_names = "x-amzn-transcribe-vocabulary-filter-names",
        };

        pub const http_payload: []const u8 = "audio_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .language_code = "LanguageCode",
                .media_sample_rate_hertz = "MediaSampleRateHertz",
                .media_encoding = "MediaEncoding",
                .vocabulary_name = "VocabularyName",
                .session_id = "SessionId",
                .audio_stream = "AudioStream",
                .vocabulary_filter_name = "VocabularyFilterName",
                .vocabulary_filter_method = "VocabularyFilterMethod",
                .show_speaker_label = "ShowSpeakerLabel",
                .enable_channel_identification = "EnableChannelIdentification",
                .number_of_channels = "NumberOfChannels",
                .enable_partial_results_stabilization = "EnablePartialResultsStabilization",
                .partial_results_stability = "PartialResultsStability",
                .content_identification_type = "ContentIdentificationType",
                .content_redaction_type = "ContentRedactionType",
                .pii_entity_types = "PiiEntityTypes",
                .language_model_name = "LanguageModelName",
                .identify_language = "IdentifyLanguage",
                .language_options = "LanguageOptions",
                .preferred_language = "PreferredLanguage",
                .identify_multiple_languages = "IdentifyMultipleLanguages",
                .vocabulary_names = "VocabularyNames",
                .vocabulary_filter_names = "VocabularyFilterNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_stream_transcription) } {
            return .{ .service_metadata = service_metadata, .action = start_stream_transcription };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        language_code: ?[]const u8 = null,
        media_sample_rate_hertz: ?i64 = null,
        media_encoding: ?[]const u8 = null,
        vocabulary_name: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        transcript_result_stream: ?union {
            transcript_event: ?struct {
                transcript: ?struct {
                    results: ?[]struct {
                        result_id: ?[]const u8 = null,
                        start_time: ?f64 = null,
                        end_time: ?f64 = null,
                        is_partial: ?bool = null,
                        alternatives: ?[]struct {
                            transcript: ?[]const u8 = null,
                            items: ?[]struct {
                                start_time: ?f64 = null,
                                end_time: ?f64 = null,
                                type: ?[]const u8 = null,
                                content: ?[]const u8 = null,
                                vocabulary_filter_match: ?bool = null,
                                speaker: ?[]const u8 = null,
                                confidence: ?f64 = null,
                                stable: ?bool = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .start_time = "StartTime",
                                        .end_time = "EndTime",
                                        .type = "Type",
                                        .content = "Content",
                                        .vocabulary_filter_match = "VocabularyFilterMatch",
                                        .speaker = "Speaker",
                                        .confidence = "Confidence",
                                        .stable = "Stable",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,
                            entities: ?[]struct {
                                start_time: ?f64 = null,
                                end_time: ?f64 = null,
                                category: ?[]const u8 = null,
                                type: ?[]const u8 = null,
                                content: ?[]const u8 = null,
                                confidence: ?f64 = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .start_time = "StartTime",
                                        .end_time = "EndTime",
                                        .category = "Category",
                                        .type = "Type",
                                        .content = "Content",
                                        .confidence = "Confidence",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .transcript = "Transcript",
                                    .items = "Items",
                                    .entities = "Entities",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,
                        channel_id: ?[]const u8 = null,
                        language_code: ?[]const u8 = null,
                        language_identification: ?[]struct {
                            language_code: ?[]const u8 = null,
                            score: ?f64 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .language_code = "LanguageCode",
                                    .score = "Score",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .result_id = "ResultId",
                                .start_time = "StartTime",
                                .end_time = "EndTime",
                                .is_partial = "IsPartial",
                                .alternatives = "Alternatives",
                                .channel_id = "ChannelId",
                                .language_code = "LanguageCode",
                                .language_identification = "LanguageIdentification",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .results = "Results",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .transcript = "Transcript",
                    };
                    return @field(mappings, field_name);
                }
            },
            bad_request_exception: ?BadRequestException,
            limit_exceeded_exception: ?LimitExceededException,
            internal_failure_exception: ?InternalFailureException,
            conflict_exception: ?ConflictException,
            service_unavailable_exception: ?ServiceUnavailableException,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transcript_event = "TranscriptEvent",
                    .bad_request_exception = "BadRequestException",
                    .limit_exceeded_exception = "LimitExceededException",
                    .internal_failure_exception = "InternalFailureException",
                    .conflict_exception = "ConflictException",
                    .service_unavailable_exception = "ServiceUnavailableException",
                };
                return @field(mappings, field_name);
            }
        } = null,
        vocabulary_filter_name: ?[]const u8 = null,
        vocabulary_filter_method: ?[]const u8 = null,
        show_speaker_label: ?bool = null,
        enable_channel_identification: ?bool = null,
        number_of_channels: ?i64 = null,
        enable_partial_results_stabilization: ?bool = null,
        partial_results_stability: ?[]const u8 = null,
        content_identification_type: ?[]const u8 = null,
        content_redaction_type: ?[]const u8 = null,
        pii_entity_types: ?[]const u8 = null,
        language_model_name: ?[]const u8 = null,
        identify_language: ?bool = null,
        language_options: ?[]const u8 = null,
        preferred_language: ?[]const u8 = null,
        identify_multiple_languages: ?bool = null,
        vocabulary_names: ?[]const u8 = null,
        vocabulary_filter_names: ?[]const u8 = null,
        pub const http_header = .{
            .request_id = "x-amzn-request-id",
            .language_code = "x-amzn-transcribe-language-code",
            .media_sample_rate_hertz = "x-amzn-transcribe-sample-rate",
            .media_encoding = "x-amzn-transcribe-media-encoding",
            .vocabulary_name = "x-amzn-transcribe-vocabulary-name",
            .session_id = "x-amzn-transcribe-session-id",
            .vocabulary_filter_name = "x-amzn-transcribe-vocabulary-filter-name",
            .vocabulary_filter_method = "x-amzn-transcribe-vocabulary-filter-method",
            .show_speaker_label = "x-amzn-transcribe-show-speaker-label",
            .enable_channel_identification = "x-amzn-transcribe-enable-channel-identification",
            .number_of_channels = "x-amzn-transcribe-number-of-channels",
            .enable_partial_results_stabilization = "x-amzn-transcribe-enable-partial-results-stabilization",
            .partial_results_stability = "x-amzn-transcribe-partial-results-stability",
            .content_identification_type = "x-amzn-transcribe-content-identification-type",
            .content_redaction_type = "x-amzn-transcribe-content-redaction-type",
            .pii_entity_types = "x-amzn-transcribe-pii-entity-types",
            .language_model_name = "x-amzn-transcribe-language-model-name",
            .identify_language = "x-amzn-transcribe-identify-language",
            .language_options = "x-amzn-transcribe-language-options",
            .preferred_language = "x-amzn-transcribe-preferred-language",
            .identify_multiple_languages = "x-amzn-transcribe-identify-multiple-languages",
            .vocabulary_names = "x-amzn-transcribe-vocabulary-names",
            .vocabulary_filter_names = "x-amzn-transcribe-vocabulary-filter-names",
        };

        pub const http_payload: []const u8 = "transcript_result_stream";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .language_code = "LanguageCode",
                .media_sample_rate_hertz = "MediaSampleRateHertz",
                .media_encoding = "MediaEncoding",
                .vocabulary_name = "VocabularyName",
                .session_id = "SessionId",
                .transcript_result_stream = "TranscriptResultStream",
                .vocabulary_filter_name = "VocabularyFilterName",
                .vocabulary_filter_method = "VocabularyFilterMethod",
                .show_speaker_label = "ShowSpeakerLabel",
                .enable_channel_identification = "EnableChannelIdentification",
                .number_of_channels = "NumberOfChannels",
                .enable_partial_results_stabilization = "EnablePartialResultsStabilization",
                .partial_results_stability = "PartialResultsStability",
                .content_identification_type = "ContentIdentificationType",
                .content_redaction_type = "ContentRedactionType",
                .pii_entity_types = "PiiEntityTypes",
                .language_model_name = "LanguageModelName",
                .identify_language = "IdentifyLanguage",
                .language_options = "LanguageOptions",
                .preferred_language = "PreferredLanguage",
                .identify_multiple_languages = "IdentifyMultipleLanguages",
                .vocabulary_names = "VocabularyNames",
                .vocabulary_filter_names = "VocabularyFilterNames",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        InternalFailure,
        LimitExceeded,
        ServiceUnavailable,
    },
} = .{};

pub const ServiceUnavailableException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const ConflictException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const InternalFailureException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const LimitExceededException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const BadRequestException = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioStream = union {
    audio_event: ?AudioEvent,
    configuration_event: ?ConfigurationEvent,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_event = "AudioEvent",
            .configuration_event = "ConfigurationEvent",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationEvent = struct {
    channel_definitions: ?[]ChannelDefinition = null,
    post_call_analytics_settings: ?PostCallAnalyticsSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_definitions = "ChannelDefinitions",
            .post_call_analytics_settings = "PostCallAnalyticsSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const PostCallAnalyticsSettings = struct {
    output_location: []const u8,
    data_access_role_arn: []const u8,
    content_redaction_output: ?[]const u8 = null,
    output_encryption_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_location = "OutputLocation",
            .data_access_role_arn = "DataAccessRoleArn",
            .content_redaction_output = "ContentRedactionOutput",
            .output_encryption_kms_key_id = "OutputEncryptionKMSKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelDefinition = struct {
    channel_id: i64,
    participant_role: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_id = "ChannelId",
            .participant_role = "ParticipantRole",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioEvent = struct {
    audio_chunk: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_chunk = "AudioChunk",
        };
        return @field(mappings, field_name);
    }
};
