const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-05";
pub const sdk_id: []const u8 = "Transfer";
pub const arn_namespace: ?[]const u8 = "transfer";
pub const endpoint_prefix: []const u8 = "transfer";
pub const sigv4_name: []const u8 = "transfer";
pub const name: []const u8 = "TransferService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-05",
    sdk_id: []const u8 = "Transfer",
    arn_namespace: ?[]const u8 = "transfer",
    endpoint_prefix: []const u8 = "transfer",
    sigv4_name: []const u8 = "transfer",
    name: []const u8 = "TransferService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_access: struct {
    action_name: []const u8 = "CreateAccess",
    Request: type = struct {
        home_directory: ?[]const u8 = null,
        home_directory_type: ?[]const u8 = null,
        home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
        policy: ?[]const u8 = null,
        posix_profile: ?PosixProfile = null,
        role: []const u8,
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_directory = "HomeDirectory",
                .home_directory_type = "HomeDirectoryType",
                .home_directory_mappings = "HomeDirectoryMappings",
                .policy = "Policy",
                .posix_profile = "PosixProfile",
                .role = "Role",
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access) } {
            return .{ .service_metadata = service_metadata, .action = create_access };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const create_agreement: struct {
    action_name: []const u8 = "CreateAgreement",
    Request: type = struct {
        description: ?[]const u8 = null,
        server_id: []const u8,
        local_profile_id: []const u8,
        partner_profile_id: []const u8,
        base_directory: []const u8,
        access_role: []const u8,
        status: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .server_id = "ServerId",
                .local_profile_id = "LocalProfileId",
                .partner_profile_id = "PartnerProfileId",
                .base_directory = "BaseDirectory",
                .access_role = "AccessRole",
                .status = "Status",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_agreement) } {
            return .{ .service_metadata = service_metadata, .action = create_agreement };
        }
    },
    Response: type = struct {
        agreement_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement_id = "AgreementId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_connector: struct {
    action_name: []const u8 = "CreateConnector",
    Request: type = struct {
        url: []const u8,
        as2_config: ?As2ConnectorConfig = null,
        access_role: []const u8,
        logging_role: ?[]const u8 = null,
        tags: ?[]Tag = null,
        sftp_config: ?SftpConnectorConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .url = "Url",
                .as2_config = "As2Config",
                .access_role = "AccessRole",
                .logging_role = "LoggingRole",
                .tags = "Tags",
                .sftp_config = "SftpConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connector) } {
            return .{ .service_metadata = service_metadata, .action = create_connector };
        }
    },
    Response: type = struct {
        connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_id = "ConnectorId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_profile: struct {
    action_name: []const u8 = "CreateProfile",
    Request: type = struct {
        as2_id: []const u8,
        profile_type: []const u8,
        certificate_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .as2_id = "As2Id",
                .profile_type = "ProfileType",
                .certificate_ids = "CertificateIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_profile };
        }
    },
    Response: type = struct {
        profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_server: struct {
    action_name: []const u8 = "CreateServer",
    Request: type = struct {
        certificate: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        endpoint_details: ?EndpointDetails = null,
        endpoint_type: ?[]const u8 = null,
        host_key: ?[]const u8 = null,
        identity_provider_details: ?IdentityProviderDetails = null,
        identity_provider_type: ?[]const u8 = null,
        logging_role: ?[]const u8 = null,
        post_authentication_login_banner: ?[]const u8 = null,
        pre_authentication_login_banner: ?[]const u8 = null,
        protocols: ?[][]const u8 = null,
        protocol_details: ?ProtocolDetails = null,
        security_policy_name: ?[]const u8 = null,
        tags: ?[]Tag = null,
        workflow_details: ?WorkflowDetails = null,
        structured_log_destinations: ?[][]const u8 = null,
        s3_storage_options: ?S3StorageOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
                .domain = "Domain",
                .endpoint_details = "EndpointDetails",
                .endpoint_type = "EndpointType",
                .host_key = "HostKey",
                .identity_provider_details = "IdentityProviderDetails",
                .identity_provider_type = "IdentityProviderType",
                .logging_role = "LoggingRole",
                .post_authentication_login_banner = "PostAuthenticationLoginBanner",
                .pre_authentication_login_banner = "PreAuthenticationLoginBanner",
                .protocols = "Protocols",
                .protocol_details = "ProtocolDetails",
                .security_policy_name = "SecurityPolicyName",
                .tags = "Tags",
                .workflow_details = "WorkflowDetails",
                .structured_log_destinations = "StructuredLogDestinations",
                .s3_storage_options = "S3StorageOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_server) } {
            return .{ .service_metadata = service_metadata, .action = create_server };
        }
    },
    Response: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_user: struct {
    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        home_directory: ?[]const u8 = null,
        home_directory_type: ?[]const u8 = null,
        home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
        policy: ?[]const u8 = null,
        posix_profile: ?PosixProfile = null,
        role: []const u8,
        server_id: []const u8,
        ssh_public_key_body: ?[]const u8 = null,
        tags: ?[]Tag = null,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_directory = "HomeDirectory",
                .home_directory_type = "HomeDirectoryType",
                .home_directory_mappings = "HomeDirectoryMappings",
                .policy = "Policy",
                .posix_profile = "PosixProfile",
                .role = "Role",
                .server_id = "ServerId",
                .ssh_public_key_body = "SshPublicKeyBody",
                .tags = "Tags",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const create_workflow: struct {
    action_name: []const u8 = "CreateWorkflow",
    Request: type = struct {
        description: ?[]const u8 = null,
        steps: []WorkflowStep,
        on_exception_steps: ?[]WorkflowStep = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .steps = "Steps",
                .on_exception_steps = "OnExceptionSteps",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workflow) } {
            return .{ .service_metadata = service_metadata, .action = create_workflow };
        }
    },
    Response: type = struct {
        workflow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_id = "WorkflowId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_access: struct {
    action_name: []const u8 = "DeleteAccess",
    Request: type = struct {
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access) } {
            return .{ .service_metadata = service_metadata, .action = delete_access };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_agreement: struct {
    action_name: []const u8 = "DeleteAgreement",
    Request: type = struct {
        agreement_id: []const u8,
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement_id = "AgreementId",
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_agreement) } {
            return .{ .service_metadata = service_metadata, .action = delete_agreement };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_certificate: struct {
    action_name: []const u8 = "DeleteCertificate",
    Request: type = struct {
        certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "CertificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_certificate) } {
            return .{ .service_metadata = service_metadata, .action = delete_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_connector: struct {
    action_name: []const u8 = "DeleteConnector",
    Request: type = struct {
        connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_id = "ConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connector) } {
            return .{ .service_metadata = service_metadata, .action = delete_connector };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_host_key: struct {
    action_name: []const u8 = "DeleteHostKey",
    Request: type = struct {
        server_id: []const u8,
        host_key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .host_key_id = "HostKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_host_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_host_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_profile: struct {
    action_name: []const u8 = "DeleteProfile",
    Request: type = struct {
        profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_server: struct {
    action_name: []const u8 = "DeleteServer",
    Request: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_server) } {
            return .{ .service_metadata = service_metadata, .action = delete_server };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_ssh_public_key: struct {
    action_name: []const u8 = "DeleteSshPublicKey",
    Request: type = struct {
        server_id: []const u8,
        ssh_public_key_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .ssh_public_key_id = "SshPublicKeyId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ssh_public_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_ssh_public_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_user: struct {
    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        server_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_workflow: struct {
    action_name: []const u8 = "DeleteWorkflow",
    Request: type = struct {
        workflow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_id = "WorkflowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workflow) } {
            return .{ .service_metadata = service_metadata, .action = delete_workflow };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_access: struct {
    action_name: []const u8 = "DescribeAccess",
    Request: type = struct {
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_access) } {
            return .{ .service_metadata = service_metadata, .action = describe_access };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        access: struct {
            home_directory: ?[]const u8 = null,
            home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
            home_directory_type: ?[]const u8 = null,
            policy: ?[]const u8 = null,
            posix_profile: ?PosixProfile = null,
            role: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .home_directory = "HomeDirectory",
                    .home_directory_mappings = "HomeDirectoryMappings",
                    .home_directory_type = "HomeDirectoryType",
                    .policy = "Policy",
                    .posix_profile = "PosixProfile",
                    .role = "Role",
                    .external_id = "ExternalId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .access = "Access",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_agreement: struct {
    action_name: []const u8 = "DescribeAgreement",
    Request: type = struct {
        agreement_id: []const u8,
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement_id = "AgreementId",
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_agreement) } {
            return .{ .service_metadata = service_metadata, .action = describe_agreement };
        }
    },
    Response: type = struct {
        agreement: struct {
            arn: []const u8,
            agreement_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            server_id: ?[]const u8 = null,
            local_profile_id: ?[]const u8 = null,
            partner_profile_id: ?[]const u8 = null,
            base_directory: ?[]const u8 = null,
            access_role: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .agreement_id = "AgreementId",
                    .description = "Description",
                    .status = "Status",
                    .server_id = "ServerId",
                    .local_profile_id = "LocalProfileId",
                    .partner_profile_id = "PartnerProfileId",
                    .base_directory = "BaseDirectory",
                    .access_role = "AccessRole",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement = "Agreement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_certificate: struct {
    action_name: []const u8 = "DescribeCertificate",
    Request: type = struct {
        certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "CertificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificate) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificate };
        }
    },
    Response: type = struct {
        certificate: struct {
            arn: []const u8,
            certificate_id: ?[]const u8 = null,
            usage: ?[]const u8 = null,
            status: ?[]const u8 = null,
            certificate: ?[]const u8 = null,
            certificate_chain: ?[]const u8 = null,
            active_date: ?i64 = null,
            inactive_date: ?i64 = null,
            serial: ?[]const u8 = null,
            not_before_date: ?i64 = null,
            not_after_date: ?i64 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .certificate_id = "CertificateId",
                    .usage = "Usage",
                    .status = "Status",
                    .certificate = "Certificate",
                    .certificate_chain = "CertificateChain",
                    .active_date = "ActiveDate",
                    .inactive_date = "InactiveDate",
                    .serial = "Serial",
                    .not_before_date = "NotBeforeDate",
                    .not_after_date = "NotAfterDate",
                    .type = "Type",
                    .description = "Description",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_connector: struct {
    action_name: []const u8 = "DescribeConnector",
    Request: type = struct {
        connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_id = "ConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connector) } {
            return .{ .service_metadata = service_metadata, .action = describe_connector };
        }
    },
    Response: type = struct {
        connector: struct {
            arn: []const u8,
            connector_id: ?[]const u8 = null,
            url: ?[]const u8 = null,
            as2_config: ?As2ConnectorConfig = null,
            access_role: ?[]const u8 = null,
            logging_role: ?[]const u8 = null,
            tags: ?[]Tag = null,
            sftp_config: ?SftpConnectorConfig = null,
            service_managed_egress_ip_addresses: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .connector_id = "ConnectorId",
                    .url = "Url",
                    .as2_config = "As2Config",
                    .access_role = "AccessRole",
                    .logging_role = "LoggingRole",
                    .tags = "Tags",
                    .sftp_config = "SftpConfig",
                    .service_managed_egress_ip_addresses = "ServiceManagedEgressIpAddresses",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector = "Connector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_execution: struct {
    action_name: []const u8 = "DescribeExecution",
    Request: type = struct {
        execution_id: []const u8,
        workflow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_id = "ExecutionId",
                .workflow_id = "WorkflowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_execution };
        }
    },
    Response: type = struct {
        workflow_id: []const u8,
        execution: struct {
            execution_id: ?[]const u8 = null,
            initial_file_location: ?FileLocation = null,
            service_metadata: ?ServiceMetadata = null,
            execution_role: ?[]const u8 = null,
            logging_configuration: ?struct {
                logging_role: ?[]const u8 = null,
                log_group_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .logging_role = "LoggingRole",
                        .log_group_name = "LogGroupName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            posix_profile: ?PosixProfile = null,
            status: ?[]const u8 = null,
            results: ?struct {
                steps: ?[]ExecutionStepResult = null,
                on_exception_steps: ?[]ExecutionStepResult = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .steps = "Steps",
                        .on_exception_steps = "OnExceptionSteps",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .execution_id = "ExecutionId",
                    .initial_file_location = "InitialFileLocation",
                    .service_metadata = "ServiceMetadata",
                    .execution_role = "ExecutionRole",
                    .logging_configuration = "LoggingConfiguration",
                    .posix_profile = "PosixProfile",
                    .status = "Status",
                    .results = "Results",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_id = "WorkflowId",
                .execution = "Execution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_host_key: struct {
    action_name: []const u8 = "DescribeHostKey",
    Request: type = struct {
        server_id: []const u8,
        host_key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .host_key_id = "HostKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_host_key) } {
            return .{ .service_metadata = service_metadata, .action = describe_host_key };
        }
    },
    Response: type = struct {
        host_key: struct {
            arn: []const u8,
            host_key_id: ?[]const u8 = null,
            host_key_fingerprint: ?[]const u8 = null,
            description: ?[]const u8 = null,
            type: ?[]const u8 = null,
            date_imported: ?i64 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .host_key_id = "HostKeyId",
                    .host_key_fingerprint = "HostKeyFingerprint",
                    .description = "Description",
                    .type = "Type",
                    .date_imported = "DateImported",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_key = "HostKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_profile: struct {
    action_name: []const u8 = "DescribeProfile",
    Request: type = struct {
        profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_profile) } {
            return .{ .service_metadata = service_metadata, .action = describe_profile };
        }
    },
    Response: type = struct {
        profile: struct {
            arn: []const u8,
            profile_id: ?[]const u8 = null,
            profile_type: ?[]const u8 = null,
            as2_id: ?[]const u8 = null,
            certificate_ids: ?[][]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .profile_id = "ProfileId",
                    .profile_type = "ProfileType",
                    .as2_id = "As2Id",
                    .certificate_ids = "CertificateIds",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile = "Profile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_security_policy: struct {
    action_name: []const u8 = "DescribeSecurityPolicy",
    Request: type = struct {
        security_policy_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_policy_name = "SecurityPolicyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_security_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_security_policy };
        }
    },
    Response: type = struct {
        security_policy: struct {
            fips: ?bool = null,
            security_policy_name: []const u8,
            ssh_ciphers: ?[][]const u8 = null,
            ssh_kexs: ?[][]const u8 = null,
            ssh_macs: ?[][]const u8 = null,
            tls_ciphers: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fips = "Fips",
                    .security_policy_name = "SecurityPolicyName",
                    .ssh_ciphers = "SshCiphers",
                    .ssh_kexs = "SshKexs",
                    .ssh_macs = "SshMacs",
                    .tls_ciphers = "TlsCiphers",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_policy = "SecurityPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_server: struct {
    action_name: []const u8 = "DescribeServer",
    Request: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_server) } {
            return .{ .service_metadata = service_metadata, .action = describe_server };
        }
    },
    Response: type = struct {
        server: struct {
            arn: []const u8,
            certificate: ?[]const u8 = null,
            protocol_details: ?ProtocolDetails = null,
            domain: ?[]const u8 = null,
            endpoint_details: ?EndpointDetails = null,
            endpoint_type: ?[]const u8 = null,
            host_key_fingerprint: ?[]const u8 = null,
            identity_provider_details: ?IdentityProviderDetails = null,
            identity_provider_type: ?[]const u8 = null,
            logging_role: ?[]const u8 = null,
            post_authentication_login_banner: ?[]const u8 = null,
            pre_authentication_login_banner: ?[]const u8 = null,
            protocols: ?[][]const u8 = null,
            security_policy_name: ?[]const u8 = null,
            server_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            tags: ?[]Tag = null,
            user_count: ?i64 = null,
            workflow_details: ?WorkflowDetails = null,
            structured_log_destinations: ?[][]const u8 = null,
            s3_storage_options: ?S3StorageOptions = null,
            as2_service_managed_egress_ip_addresses: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .certificate = "Certificate",
                    .protocol_details = "ProtocolDetails",
                    .domain = "Domain",
                    .endpoint_details = "EndpointDetails",
                    .endpoint_type = "EndpointType",
                    .host_key_fingerprint = "HostKeyFingerprint",
                    .identity_provider_details = "IdentityProviderDetails",
                    .identity_provider_type = "IdentityProviderType",
                    .logging_role = "LoggingRole",
                    .post_authentication_login_banner = "PostAuthenticationLoginBanner",
                    .pre_authentication_login_banner = "PreAuthenticationLoginBanner",
                    .protocols = "Protocols",
                    .security_policy_name = "SecurityPolicyName",
                    .server_id = "ServerId",
                    .state = "State",
                    .tags = "Tags",
                    .user_count = "UserCount",
                    .workflow_details = "WorkflowDetails",
                    .structured_log_destinations = "StructuredLogDestinations",
                    .s3_storage_options = "S3StorageOptions",
                    .as2_service_managed_egress_ip_addresses = "As2ServiceManagedEgressIpAddresses",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server = "Server",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_user: struct {
    action_name: []const u8 = "DescribeUser",
    Request: type = struct {
        server_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_user };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        user: struct {
            arn: []const u8,
            home_directory: ?[]const u8 = null,
            home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
            home_directory_type: ?[]const u8 = null,
            policy: ?[]const u8 = null,
            posix_profile: ?PosixProfile = null,
            role: ?[]const u8 = null,
            ssh_public_keys: ?[]struct {
                date_imported: i64,
                ssh_public_key_body: []const u8,
                ssh_public_key_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .date_imported = "DateImported",
                        .ssh_public_key_body = "SshPublicKeyBody",
                        .ssh_public_key_id = "SshPublicKeyId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]Tag = null,
            user_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .home_directory = "HomeDirectory",
                    .home_directory_mappings = "HomeDirectoryMappings",
                    .home_directory_type = "HomeDirectoryType",
                    .policy = "Policy",
                    .posix_profile = "PosixProfile",
                    .role = "Role",
                    .ssh_public_keys = "SshPublicKeys",
                    .tags = "Tags",
                    .user_name = "UserName",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_workflow: struct {
    action_name: []const u8 = "DescribeWorkflow",
    Request: type = struct {
        workflow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_id = "WorkflowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workflow) } {
            return .{ .service_metadata = service_metadata, .action = describe_workflow };
        }
    },
    Response: type = struct {
        workflow: struct {
            arn: []const u8,
            description: ?[]const u8 = null,
            steps: ?[]WorkflowStep = null,
            on_exception_steps: ?[]WorkflowStep = null,
            workflow_id: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .description = "Description",
                    .steps = "Steps",
                    .on_exception_steps = "OnExceptionSteps",
                    .workflow_id = "WorkflowId",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow = "Workflow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const import_certificate: struct {
    action_name: []const u8 = "ImportCertificate",
    Request: type = struct {
        usage: []const u8,
        certificate: []const u8,
        certificate_chain: ?[]const u8 = null,
        private_key: ?[]const u8 = null,
        active_date: ?i64 = null,
        inactive_date: ?i64 = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage = "Usage",
                .certificate = "Certificate",
                .certificate_chain = "CertificateChain",
                .private_key = "PrivateKey",
                .active_date = "ActiveDate",
                .inactive_date = "InactiveDate",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_certificate) } {
            return .{ .service_metadata = service_metadata, .action = import_certificate };
        }
    },
    Response: type = struct {
        certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "CertificateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const import_host_key: struct {
    action_name: []const u8 = "ImportHostKey",
    Request: type = struct {
        server_id: []const u8,
        host_key_body: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .host_key_body = "HostKeyBody",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_host_key) } {
            return .{ .service_metadata = service_metadata, .action = import_host_key };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        host_key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .host_key_id = "HostKeyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const import_ssh_public_key: struct {
    action_name: []const u8 = "ImportSshPublicKey",
    Request: type = struct {
        server_id: []const u8,
        ssh_public_key_body: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .ssh_public_key_body = "SshPublicKeyBody",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_ssh_public_key) } {
            return .{ .service_metadata = service_metadata, .action = import_ssh_public_key };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        ssh_public_key_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .ssh_public_key_id = "SshPublicKeyId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_accesses: struct {
    action_name: []const u8 = "ListAccesses",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accesses) } {
            return .{ .service_metadata = service_metadata, .action = list_accesses };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        server_id: []const u8,
        accesses: []struct {
            home_directory: ?[]const u8 = null,
            home_directory_type: ?[]const u8 = null,
            role: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .home_directory = "HomeDirectory",
                    .home_directory_type = "HomeDirectoryType",
                    .role = "Role",
                    .external_id = "ExternalId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .server_id = "ServerId",
                .accesses = "Accesses",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_agreements: struct {
    action_name: []const u8 = "ListAgreements",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_agreements) } {
            return .{ .service_metadata = service_metadata, .action = list_agreements };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        agreements: []struct {
            arn: ?[]const u8 = null,
            agreement_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            server_id: ?[]const u8 = null,
            local_profile_id: ?[]const u8 = null,
            partner_profile_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .agreement_id = "AgreementId",
                    .description = "Description",
                    .status = "Status",
                    .server_id = "ServerId",
                    .local_profile_id = "LocalProfileId",
                    .partner_profile_id = "PartnerProfileId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .agreements = "Agreements",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_certificates: struct {
    action_name: []const u8 = "ListCertificates",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_certificates) } {
            return .{ .service_metadata = service_metadata, .action = list_certificates };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        certificates: []struct {
            arn: ?[]const u8 = null,
            certificate_id: ?[]const u8 = null,
            usage: ?[]const u8 = null,
            status: ?[]const u8 = null,
            active_date: ?i64 = null,
            inactive_date: ?i64 = null,
            type: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .certificate_id = "CertificateId",
                    .usage = "Usage",
                    .status = "Status",
                    .active_date = "ActiveDate",
                    .inactive_date = "InactiveDate",
                    .type = "Type",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .certificates = "Certificates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_connectors: struct {
    action_name: []const u8 = "ListConnectors",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connectors) } {
            return .{ .service_metadata = service_metadata, .action = list_connectors };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        connectors: []struct {
            arn: ?[]const u8 = null,
            connector_id: ?[]const u8 = null,
            url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .connector_id = "ConnectorId",
                    .url = "Url",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .connectors = "Connectors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_executions: struct {
    action_name: []const u8 = "ListExecutions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        workflow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .workflow_id = "WorkflowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_executions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        workflow_id: []const u8,
        executions: []struct {
            execution_id: ?[]const u8 = null,
            initial_file_location: ?FileLocation = null,
            service_metadata: ?ServiceMetadata = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .execution_id = "ExecutionId",
                    .initial_file_location = "InitialFileLocation",
                    .service_metadata = "ServiceMetadata",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .workflow_id = "WorkflowId",
                .executions = "Executions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_host_keys: struct {
    action_name: []const u8 = "ListHostKeys",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_host_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_host_keys };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        server_id: []const u8,
        host_keys: []struct {
            arn: []const u8,
            host_key_id: ?[]const u8 = null,
            fingerprint: ?[]const u8 = null,
            description: ?[]const u8 = null,
            type: ?[]const u8 = null,
            date_imported: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .host_key_id = "HostKeyId",
                    .fingerprint = "Fingerprint",
                    .description = "Description",
                    .type = "Type",
                    .date_imported = "DateImported",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .server_id = "ServerId",
                .host_keys = "HostKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_profiles: struct {
    action_name: []const u8 = "ListProfiles",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        profile_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .profile_type = "ProfileType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_profiles };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        profiles: []struct {
            arn: ?[]const u8 = null,
            profile_id: ?[]const u8 = null,
            as2_id: ?[]const u8 = null,
            profile_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .profile_id = "ProfileId",
                    .as2_id = "As2Id",
                    .profile_type = "ProfileType",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .profiles = "Profiles",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_security_policies: struct {
    action_name: []const u8 = "ListSecurityPolicies",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_security_policies };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        security_policy_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .security_policy_names = "SecurityPolicyNames",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const list_servers: struct {
    action_name: []const u8 = "ListServers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_servers) } {
            return .{ .service_metadata = service_metadata, .action = list_servers };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        servers: []struct {
            arn: []const u8,
            domain: ?[]const u8 = null,
            identity_provider_type: ?[]const u8 = null,
            endpoint_type: ?[]const u8 = null,
            logging_role: ?[]const u8 = null,
            server_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            user_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .domain = "Domain",
                    .identity_provider_type = "IdentityProviderType",
                    .endpoint_type = "EndpointType",
                    .logging_role = "LoggingRole",
                    .server_id = "ServerId",
                    .state = "State",
                    .user_count = "UserCount",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .servers = "Servers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .next_token = "NextToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const list_users: struct {
    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        server_id: []const u8,
        users: []struct {
            arn: []const u8,
            home_directory: ?[]const u8 = null,
            home_directory_type: ?[]const u8 = null,
            role: ?[]const u8 = null,
            ssh_public_key_count: ?i64 = null,
            user_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .home_directory = "HomeDirectory",
                    .home_directory_type = "HomeDirectoryType",
                    .role = "Role",
                    .ssh_public_key_count = "SshPublicKeyCount",
                    .user_name = "UserName",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .server_id = "ServerId",
                .users = "Users",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_workflows: struct {
    action_name: []const u8 = "ListWorkflows",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workflows) } {
            return .{ .service_metadata = service_metadata, .action = list_workflows };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        workflows: []struct {
            workflow_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workflow_id = "WorkflowId",
                    .description = "Description",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .workflows = "Workflows",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const send_workflow_step_state: struct {
    action_name: []const u8 = "SendWorkflowStepState",
    Request: type = struct {
        workflow_id: []const u8,
        execution_id: []const u8,
        token: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow_id = "WorkflowId",
                .execution_id = "ExecutionId",
                .token = "Token",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_workflow_step_state) } {
            return .{ .service_metadata = service_metadata, .action = send_workflow_step_state };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const start_file_transfer: struct {
    action_name: []const u8 = "StartFileTransfer",
    Request: type = struct {
        connector_id: []const u8,
        send_file_paths: ?[][]const u8 = null,
        retrieve_file_paths: ?[][]const u8 = null,
        local_directory_path: ?[]const u8 = null,
        remote_directory_path: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_id = "ConnectorId",
                .send_file_paths = "SendFilePaths",
                .retrieve_file_paths = "RetrieveFilePaths",
                .local_directory_path = "LocalDirectoryPath",
                .remote_directory_path = "RemoteDirectoryPath",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_file_transfer) } {
            return .{ .service_metadata = service_metadata, .action = start_file_transfer };
        }
    },
    Response: type = struct {
        transfer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transfer_id = "TransferId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const start_server: struct {
    action_name: []const u8 = "StartServer",
    Request: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_server) } {
            return .{ .service_metadata = service_metadata, .action = start_server };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const stop_server: struct {
    action_name: []const u8 = "StopServer",
    Request: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_server) } {
            return .{ .service_metadata = service_metadata, .action = stop_server };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const test_connection: struct {
    action_name: []const u8 = "TestConnection",
    Request: type = struct {
        connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_id = "ConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_connection) } {
            return .{ .service_metadata = service_metadata, .action = test_connection };
        }
    },
    Response: type = struct {
        connector_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_id = "ConnectorId",
                .status = "Status",
                .status_message = "StatusMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const test_identity_provider: struct {
    action_name: []const u8 = "TestIdentityProvider",
    Request: type = struct {
        server_id: []const u8,
        server_protocol: ?[]const u8 = null,
        source_ip: ?[]const u8 = null,
        user_name: []const u8,
        user_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .server_protocol = "ServerProtocol",
                .source_ip = "SourceIp",
                .user_name = "UserName",
                .user_password = "UserPassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_identity_provider) } {
            return .{ .service_metadata = service_metadata, .action = test_identity_provider };
        }
    },
    Response: type = struct {
        response: ?[]const u8 = null,
        status_code: i64,
        message: ?[]const u8 = null,
        url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .response = "Response",
                .status_code = "StatusCode",
                .message = "Message",
                .url = "Url",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const update_access: struct {
    action_name: []const u8 = "UpdateAccess",
    Request: type = struct {
        home_directory: ?[]const u8 = null,
        home_directory_type: ?[]const u8 = null,
        home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
        policy: ?[]const u8 = null,
        posix_profile: ?PosixProfile = null,
        role: ?[]const u8 = null,
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_directory = "HomeDirectory",
                .home_directory_type = "HomeDirectoryType",
                .home_directory_mappings = "HomeDirectoryMappings",
                .policy = "Policy",
                .posix_profile = "PosixProfile",
                .role = "Role",
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_access) } {
            return .{ .service_metadata = service_metadata, .action = update_access };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_agreement: struct {
    action_name: []const u8 = "UpdateAgreement",
    Request: type = struct {
        agreement_id: []const u8,
        server_id: []const u8,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        local_profile_id: ?[]const u8 = null,
        partner_profile_id: ?[]const u8 = null,
        base_directory: ?[]const u8 = null,
        access_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement_id = "AgreementId",
                .server_id = "ServerId",
                .description = "Description",
                .status = "Status",
                .local_profile_id = "LocalProfileId",
                .partner_profile_id = "PartnerProfileId",
                .base_directory = "BaseDirectory",
                .access_role = "AccessRole",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_agreement) } {
            return .{ .service_metadata = service_metadata, .action = update_agreement };
        }
    },
    Response: type = struct {
        agreement_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agreement_id = "AgreementId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_certificate: struct {
    action_name: []const u8 = "UpdateCertificate",
    Request: type = struct {
        certificate_id: []const u8,
        active_date: ?i64 = null,
        inactive_date: ?i64 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "CertificateId",
                .active_date = "ActiveDate",
                .inactive_date = "InactiveDate",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_certificate) } {
            return .{ .service_metadata = service_metadata, .action = update_certificate };
        }
    },
    Response: type = struct {
        certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_id = "CertificateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_connector: struct {
    action_name: []const u8 = "UpdateConnector",
    Request: type = struct {
        connector_id: []const u8,
        url: ?[]const u8 = null,
        as2_config: ?As2ConnectorConfig = null,
        access_role: ?[]const u8 = null,
        logging_role: ?[]const u8 = null,
        sftp_config: ?SftpConnectorConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_id = "ConnectorId",
                .url = "Url",
                .as2_config = "As2Config",
                .access_role = "AccessRole",
                .logging_role = "LoggingRole",
                .sftp_config = "SftpConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connector) } {
            return .{ .service_metadata = service_metadata, .action = update_connector };
        }
    },
    Response: type = struct {
        connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connector_id = "ConnectorId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_host_key: struct {
    action_name: []const u8 = "UpdateHostKey",
    Request: type = struct {
        server_id: []const u8,
        host_key_id: []const u8,
        description: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .host_key_id = "HostKeyId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_host_key) } {
            return .{ .service_metadata = service_metadata, .action = update_host_key };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        host_key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .host_key_id = "HostKeyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_profile: struct {
    action_name: []const u8 = "UpdateProfile",
    Request: type = struct {
        profile_id: []const u8,
        certificate_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
                .certificate_ids = "CertificateIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_profile };
        }
    },
    Response: type = struct {
        profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_server: struct {
    action_name: []const u8 = "UpdateServer",
    Request: type = struct {
        certificate: ?[]const u8 = null,
        protocol_details: ?ProtocolDetails = null,
        endpoint_details: ?EndpointDetails = null,
        endpoint_type: ?[]const u8 = null,
        host_key: ?[]const u8 = null,
        identity_provider_details: ?IdentityProviderDetails = null,
        logging_role: ?[]const u8 = null,
        post_authentication_login_banner: ?[]const u8 = null,
        pre_authentication_login_banner: ?[]const u8 = null,
        protocols: ?[][]const u8 = null,
        security_policy_name: ?[]const u8 = null,
        server_id: []const u8,
        workflow_details: ?WorkflowDetails = null,
        structured_log_destinations: ?[][]const u8 = null,
        s3_storage_options: ?S3StorageOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
                .protocol_details = "ProtocolDetails",
                .endpoint_details = "EndpointDetails",
                .endpoint_type = "EndpointType",
                .host_key = "HostKey",
                .identity_provider_details = "IdentityProviderDetails",
                .logging_role = "LoggingRole",
                .post_authentication_login_banner = "PostAuthenticationLoginBanner",
                .pre_authentication_login_banner = "PreAuthenticationLoginBanner",
                .protocols = "Protocols",
                .security_policy_name = "SecurityPolicyName",
                .server_id = "ServerId",
                .workflow_details = "WorkflowDetails",
                .structured_log_destinations = "StructuredLogDestinations",
                .s3_storage_options = "S3StorageOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_server) } {
            return .{ .service_metadata = service_metadata, .action = update_server };
        }
    },
    Response: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_user: struct {
    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        home_directory: ?[]const u8 = null,
        home_directory_type: ?[]const u8 = null,
        home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
        policy: ?[]const u8 = null,
        posix_profile: ?PosixProfile = null,
        role: ?[]const u8 = null,
        server_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_directory = "HomeDirectory",
                .home_directory_type = "HomeDirectoryType",
                .home_directory_mappings = "HomeDirectoryMappings",
                .policy = "Policy",
                .posix_profile = "PosixProfile",
                .role = "Role",
                .server_id = "ServerId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};

pub const PosixProfile = struct {
    uid: i64,
    gid: i64,
    secondary_gids: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .uid = "Uid",
            .gid = "Gid",
            .secondary_gids = "SecondaryGids",
        };
        return @field(mappings, field_name);
    }
};

pub const HomeDirectoryMapEntry = struct {
    entry: []const u8,
    target: []const u8,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entry = "Entry",
            .target = "Target",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const S3StorageOptions = struct {
    directory_listing_optimization: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .directory_listing_optimization = "DirectoryListingOptimization",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowDetails = struct {
    on_upload: ?[]WorkflowDetail = null,
    on_partial_upload: ?[]WorkflowDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .on_upload = "OnUpload",
            .on_partial_upload = "OnPartialUpload",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowDetail = struct {
    workflow_id: []const u8,
    execution_role: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workflow_id = "WorkflowId",
            .execution_role = "ExecutionRole",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityProviderDetails = struct {
    url: ?[]const u8 = null,
    invocation_role: ?[]const u8 = null,
    directory_id: ?[]const u8 = null,
    function: ?[]const u8 = null,
    sftp_authentication_methods: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .url = "Url",
            .invocation_role = "InvocationRole",
            .directory_id = "DirectoryId",
            .function = "Function",
            .sftp_authentication_methods = "SftpAuthenticationMethods",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointDetails = struct {
    address_allocation_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    vpc_endpoint_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address_allocation_ids = "AddressAllocationIds",
            .subnet_ids = "SubnetIds",
            .vpc_endpoint_id = "VpcEndpointId",
            .vpc_id = "VpcId",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const ProtocolDetails = struct {
    passive_ip: ?[]const u8 = null,
    tls_session_resumption_mode: ?[]const u8 = null,
    set_stat_option: ?[]const u8 = null,
    as2_transports: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .passive_ip = "PassiveIp",
            .tls_session_resumption_mode = "TlsSessionResumptionMode",
            .set_stat_option = "SetStatOption",
            .as2_transports = "As2Transports",
        };
        return @field(mappings, field_name);
    }
};

pub const SftpConnectorConfig = struct {
    user_secret_id: ?[]const u8 = null,
    trusted_host_keys: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_secret_id = "UserSecretId",
            .trusted_host_keys = "TrustedHostKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const As2ConnectorConfig = struct {
    local_profile_id: ?[]const u8 = null,
    partner_profile_id: ?[]const u8 = null,
    message_subject: ?[]const u8 = null,
    compression: ?[]const u8 = null,
    encryption_algorithm: ?[]const u8 = null,
    signing_algorithm: ?[]const u8 = null,
    mdn_signing_algorithm: ?[]const u8 = null,
    mdn_response: ?[]const u8 = null,
    basic_auth_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_profile_id = "LocalProfileId",
            .partner_profile_id = "PartnerProfileId",
            .message_subject = "MessageSubject",
            .compression = "Compression",
            .encryption_algorithm = "EncryptionAlgorithm",
            .signing_algorithm = "SigningAlgorithm",
            .mdn_signing_algorithm = "MdnSigningAlgorithm",
            .mdn_response = "MdnResponse",
            .basic_auth_secret_id = "BasicAuthSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceMetadata = struct {
    user_details: UserDetails,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_details = "UserDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const UserDetails = struct {
    user_name: []const u8,
    server_id: []const u8,
    session_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_name = "UserName",
            .server_id = "ServerId",
            .session_id = "SessionId",
        };
        return @field(mappings, field_name);
    }
};

pub const FileLocation = struct {
    s3_file_location: ?S3FileLocation = null,
    efs_file_location: ?EfsFileLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_file_location = "S3FileLocation",
            .efs_file_location = "EfsFileLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const EfsFileLocation = struct {
    file_system_id: ?[]const u8 = null,
    path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_system_id = "FileSystemId",
            .path = "Path",
        };
        return @field(mappings, field_name);
    }
};

pub const S3FileLocation = struct {
    bucket: ?[]const u8 = null,
    key: ?[]const u8 = null,
    version_id: ?[]const u8 = null,
    etag: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
            .version_id = "VersionId",
            .etag = "Etag",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowStep = struct {
    type: ?[]const u8 = null,
    copy_step_details: ?CopyStepDetails = null,
    custom_step_details: ?CustomStepDetails = null,
    delete_step_details: ?DeleteStepDetails = null,
    tag_step_details: ?TagStepDetails = null,
    decrypt_step_details: ?DecryptStepDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .copy_step_details = "CopyStepDetails",
            .custom_step_details = "CustomStepDetails",
            .delete_step_details = "DeleteStepDetails",
            .tag_step_details = "TagStepDetails",
            .decrypt_step_details = "DecryptStepDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const DecryptStepDetails = struct {
    name: ?[]const u8 = null,
    type: []const u8,
    source_file_location: ?[]const u8 = null,
    overwrite_existing: ?[]const u8 = null,
    destination_file_location: InputFileLocation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .source_file_location = "SourceFileLocation",
            .overwrite_existing = "OverwriteExisting",
            .destination_file_location = "DestinationFileLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const InputFileLocation = struct {
    s3_file_location: ?S3InputFileLocation = null,
    efs_file_location: ?EfsFileLocation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_file_location = "S3FileLocation",
            .efs_file_location = "EfsFileLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const S3InputFileLocation = struct {
    bucket: ?[]const u8 = null,
    key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const TagStepDetails = struct {
    name: ?[]const u8 = null,
    tags: ?[]S3Tag = null,
    source_file_location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .tags = "Tags",
            .source_file_location = "SourceFileLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DeleteStepDetails = struct {
    name: ?[]const u8 = null,
    source_file_location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .source_file_location = "SourceFileLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomStepDetails = struct {
    name: ?[]const u8 = null,
    target: ?[]const u8 = null,
    timeout_seconds: ?i64 = null,
    source_file_location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .target = "Target",
            .timeout_seconds = "TimeoutSeconds",
            .source_file_location = "SourceFileLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const CopyStepDetails = struct {
    name: ?[]const u8 = null,
    destination_file_location: ?InputFileLocation = null,
    overwrite_existing: ?[]const u8 = null,
    source_file_location: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .destination_file_location = "DestinationFileLocation",
            .overwrite_existing = "OverwriteExisting",
            .source_file_location = "SourceFileLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutionStepResult = struct {
    step_type: ?[]const u8 = null,
    outputs: ?[]const u8 = null,
    @"error": ?ExecutionError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .step_type = "StepType",
            .outputs = "Outputs",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutionError = struct {
    type: []const u8,
    message: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};
