const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-09-15";
pub const sdk_id: []const u8 = "TrustedAdvisor";
pub const arn_namespace: ?[]const u8 = "trustedadvisor";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "trustedadvisor";
pub const name: []const u8 = "TrustedAdvisor";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2022-09-15",
    sdk_id: []const u8 = "TrustedAdvisor",
    arn_namespace: ?[]const u8 = "trustedadvisor",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "trustedadvisor",
    name: []const u8 = "TrustedAdvisor",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const get_organization_recommendation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/organization-recommendations/{organizationRecommendationIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetOrganizationRecommendation",
    Request: type = struct {
        organization_recommendation_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_recommendation_identifier = "organizationRecommendationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_organization_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = get_organization_recommendation };
        }
    },
    Response: type = struct {
        organization_recommendation: ?struct {
            id: []const u8,
            type: []const u8,
            check_arn: ?[]const u8 = null,
            status: []const u8,
            lifecycle_stage: ?[]const u8 = null,
            pillars: [][]const u8,
            source: []const u8,
            aws_services: ?[][]const u8 = null,
            name: []const u8,
            resources_aggregates: RecommendationResourcesAggregates,
            pillar_specific_aggregates: ?RecommendationPillarSpecificAggregates = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            arn: []const u8,
            description: []const u8,
            created_by: ?[]const u8 = null,
            updated_on_behalf_of: ?[]const u8 = null,
            updated_on_behalf_of_job_title: ?[]const u8 = null,
            update_reason: ?[]const u8 = null,
            update_reason_code: ?[]const u8 = null,
            resolved_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .type = "type",
                    .check_arn = "checkArn",
                    .status = "status",
                    .lifecycle_stage = "lifecycleStage",
                    .pillars = "pillars",
                    .source = "source",
                    .aws_services = "awsServices",
                    .name = "name",
                    .resources_aggregates = "resourcesAggregates",
                    .pillar_specific_aggregates = "pillarSpecificAggregates",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .arn = "arn",
                    .description = "description",
                    .created_by = "createdBy",
                    .updated_on_behalf_of = "updatedOnBehalfOf",
                    .updated_on_behalf_of_job_title = "updatedOnBehalfOfJobTitle",
                    .update_reason = "updateReason",
                    .update_reason_code = "updateReasonCode",
                    .resolved_at = "resolvedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_recommendation = "organizationRecommendation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_recommendation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/recommendations/{recommendationIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecommendation",
    Request: type = struct {
        recommendation_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_identifier = "recommendationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recommendation) } {
            return .{ .service_metadata = service_metadata, .action = get_recommendation };
        }
    },
    Response: type = struct {
        recommendation: ?struct {
            id: []const u8,
            type: []const u8,
            check_arn: ?[]const u8 = null,
            status: []const u8,
            lifecycle_stage: ?[]const u8 = null,
            pillars: [][]const u8,
            source: []const u8,
            aws_services: ?[][]const u8 = null,
            name: []const u8,
            resources_aggregates: RecommendationResourcesAggregates,
            pillar_specific_aggregates: ?RecommendationPillarSpecificAggregates = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            arn: []const u8,
            description: []const u8,
            created_by: ?[]const u8 = null,
            updated_on_behalf_of: ?[]const u8 = null,
            updated_on_behalf_of_job_title: ?[]const u8 = null,
            update_reason: ?[]const u8 = null,
            update_reason_code: ?[]const u8 = null,
            resolved_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .type = "type",
                    .check_arn = "checkArn",
                    .status = "status",
                    .lifecycle_stage = "lifecycleStage",
                    .pillars = "pillars",
                    .source = "source",
                    .aws_services = "awsServices",
                    .name = "name",
                    .resources_aggregates = "resourcesAggregates",
                    .pillar_specific_aggregates = "pillarSpecificAggregates",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .arn = "arn",
                    .description = "description",
                    .created_by = "createdBy",
                    .updated_on_behalf_of = "updatedOnBehalfOf",
                    .updated_on_behalf_of_job_title = "updatedOnBehalfOfJobTitle",
                    .update_reason = "updateReason",
                    .update_reason_code = "updateReasonCode",
                    .resolved_at = "resolvedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation = "recommendation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_checks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/checks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChecks",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        pillar: ?[]const u8 = null,
        aws_service: ?[]const u8 = null,
        source: ?[]const u8 = null,
        language: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .pillar = "pillar",
            .aws_service = "awsService",
            .source = "source",
            .language = "language",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .pillar = "pillar",
                .aws_service = "awsService",
                .source = "source",
                .language = "language",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_checks) } {
            return .{ .service_metadata = service_metadata, .action = list_checks };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        check_summaries: []struct {
            id: []const u8,
            arn: []const u8,
            name: []const u8,
            description: []const u8,
            pillars: [][]const u8,
            aws_services: [][]const u8,
            source: []const u8,
            metadata: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .name = "name",
                    .description = "description",
                    .pillars = "pillars",
                    .aws_services = "awsServices",
                    .source = "source",
                    .metadata = "metadata",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "metadata", field_name))
                    return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .check_summaries = "checkSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_organization_recommendation_accounts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/organization-recommendations/{organizationRecommendationIdentifier}/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrganizationRecommendationAccounts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        organization_recommendation_identifier: []const u8,
        affected_account_id: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .affected_account_id = "affectedAccountId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .organization_recommendation_identifier = "organizationRecommendationIdentifier",
                .affected_account_id = "affectedAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_recommendation_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_recommendation_accounts };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        account_recommendation_lifecycle_summaries: []struct {
            account_id: ?[]const u8 = null,
            account_recommendation_arn: ?[]const u8 = null,
            lifecycle_stage: ?[]const u8 = null,
            updated_on_behalf_of: ?[]const u8 = null,
            updated_on_behalf_of_job_title: ?[]const u8 = null,
            update_reason: ?[]const u8 = null,
            update_reason_code: ?[]const u8 = null,
            last_updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .account_recommendation_arn = "accountRecommendationArn",
                    .lifecycle_stage = "lifecycleStage",
                    .updated_on_behalf_of = "updatedOnBehalfOf",
                    .updated_on_behalf_of_job_title = "updatedOnBehalfOfJobTitle",
                    .update_reason = "updateReason",
                    .update_reason_code = "updateReasonCode",
                    .last_updated_at = "lastUpdatedAt",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .account_recommendation_lifecycle_summaries = "accountRecommendationLifecycleSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_organization_recommendation_resources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/organization-recommendations/{organizationRecommendationIdentifier}/resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrganizationRecommendationResources",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,
        region_code: ?[]const u8 = null,
        organization_recommendation_identifier: []const u8,
        affected_account_id: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .status = "status",
            .region_code = "regionCode",
            .affected_account_id = "affectedAccountId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .status = "status",
                .region_code = "regionCode",
                .organization_recommendation_identifier = "organizationRecommendationIdentifier",
                .affected_account_id = "affectedAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_recommendation_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_recommendation_resources };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        organization_recommendation_resource_summaries: []struct {
            id: []const u8,
            arn: []const u8,
            aws_resource_id: []const u8,
            region_code: []const u8,
            status: []const u8,
            metadata: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },
            last_updated_at: i64,
            account_id: ?[]const u8 = null,
            recommendation_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .aws_resource_id = "awsResourceId",
                    .region_code = "regionCode",
                    .status = "status",
                    .metadata = "metadata",
                    .last_updated_at = "lastUpdatedAt",
                    .account_id = "accountId",
                    .recommendation_arn = "recommendationArn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "metadata", field_name))
                    return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .organization_recommendation_resource_summaries = "organizationRecommendationResourceSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_organization_recommendations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/organization-recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListOrganizationRecommendations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        type: ?[]const u8 = null,
        status: ?[]const u8 = null,
        pillar: ?[]const u8 = null,
        aws_service: ?[]const u8 = null,
        source: ?[]const u8 = null,
        check_identifier: ?[]const u8 = null,
        after_last_updated_at: ?i64 = null,
        before_last_updated_at: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .type = "type",
            .status = "status",
            .pillar = "pillar",
            .aws_service = "awsService",
            .source = "source",
            .check_identifier = "checkIdentifier",
            .after_last_updated_at = "afterLastUpdatedAt",
            .before_last_updated_at = "beforeLastUpdatedAt",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .type = "type",
                .status = "status",
                .pillar = "pillar",
                .aws_service = "awsService",
                .source = "source",
                .check_identifier = "checkIdentifier",
                .after_last_updated_at = "afterLastUpdatedAt",
                .before_last_updated_at = "beforeLastUpdatedAt",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organization_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_organization_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        organization_recommendation_summaries: []struct {
            id: []const u8,
            type: []const u8,
            check_arn: ?[]const u8 = null,
            status: []const u8,
            lifecycle_stage: ?[]const u8 = null,
            pillars: [][]const u8,
            source: []const u8,
            aws_services: ?[][]const u8 = null,
            name: []const u8,
            resources_aggregates: RecommendationResourcesAggregates,
            pillar_specific_aggregates: ?RecommendationPillarSpecificAggregates = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .type = "type",
                    .check_arn = "checkArn",
                    .status = "status",
                    .lifecycle_stage = "lifecycleStage",
                    .pillars = "pillars",
                    .source = "source",
                    .aws_services = "awsServices",
                    .name = "name",
                    .resources_aggregates = "resourcesAggregates",
                    .pillar_specific_aggregates = "pillarSpecificAggregates",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .organization_recommendation_summaries = "organizationRecommendationSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_recommendation_resources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/recommendations/{recommendationIdentifier}/resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecommendationResources",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,
        region_code: ?[]const u8 = null,
        recommendation_identifier: []const u8,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .status = "status",
            .region_code = "regionCode",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .status = "status",
                .region_code = "regionCode",
                .recommendation_identifier = "recommendationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendation_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendation_resources };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recommendation_resource_summaries: []struct {
            id: []const u8,
            arn: []const u8,
            aws_resource_id: []const u8,
            region_code: []const u8,
            status: []const u8,
            metadata: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },
            last_updated_at: i64,
            recommendation_arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .arn = "arn",
                    .aws_resource_id = "awsResourceId",
                    .region_code = "regionCode",
                    .status = "status",
                    .metadata = "metadata",
                    .last_updated_at = "lastUpdatedAt",
                    .recommendation_arn = "recommendationArn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "metadata", field_name))
                    return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .recommendation_resource_summaries = "recommendationResourceSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_recommendations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecommendations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        type: ?[]const u8 = null,
        status: ?[]const u8 = null,
        pillar: ?[]const u8 = null,
        aws_service: ?[]const u8 = null,
        source: ?[]const u8 = null,
        check_identifier: ?[]const u8 = null,
        after_last_updated_at: ?i64 = null,
        before_last_updated_at: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .type = "type",
            .status = "status",
            .pillar = "pillar",
            .aws_service = "awsService",
            .source = "source",
            .check_identifier = "checkIdentifier",
            .after_last_updated_at = "afterLastUpdatedAt",
            .before_last_updated_at = "beforeLastUpdatedAt",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
                .type = "type",
                .status = "status",
                .pillar = "pillar",
                .aws_service = "awsService",
                .source = "source",
                .check_identifier = "checkIdentifier",
                .after_last_updated_at = "afterLastUpdatedAt",
                .before_last_updated_at = "beforeLastUpdatedAt",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recommendation_summaries: []struct {
            id: []const u8,
            type: []const u8,
            check_arn: ?[]const u8 = null,
            status: []const u8,
            lifecycle_stage: ?[]const u8 = null,
            pillars: [][]const u8,
            source: []const u8,
            aws_services: ?[][]const u8 = null,
            name: []const u8,
            resources_aggregates: RecommendationResourcesAggregates,
            pillar_specific_aggregates: ?RecommendationPillarSpecificAggregates = null,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            arn: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .type = "type",
                    .check_arn = "checkArn",
                    .status = "status",
                    .lifecycle_stage = "lifecycleStage",
                    .pillars = "pillars",
                    .source = "source",
                    .aws_services = "awsServices",
                    .name = "name",
                    .resources_aggregates = "resourcesAggregates",
                    .pillar_specific_aggregates = "pillarSpecificAggregates",
                    .created_at = "createdAt",
                    .last_updated_at = "lastUpdatedAt",
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .recommendation_summaries = "recommendationSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_organization_recommendation_lifecycle: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/organization-recommendations/{organizationRecommendationIdentifier}/lifecycle",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateOrganizationRecommendationLifecycle",
    Request: type = struct {
        lifecycle_stage: []const u8,
        update_reason: ?[]const u8 = null,
        update_reason_code: ?[]const u8 = null,
        organization_recommendation_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_stage = "lifecycleStage",
                .update_reason = "updateReason",
                .update_reason_code = "updateReasonCode",
                .organization_recommendation_identifier = "organizationRecommendationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_organization_recommendation_lifecycle) } {
            return .{ .service_metadata = service_metadata, .action = update_organization_recommendation_lifecycle };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_recommendation_lifecycle: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/recommendations/{recommendationIdentifier}/lifecycle",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRecommendationLifecycle",
    Request: type = struct {
        lifecycle_stage: []const u8,
        update_reason: ?[]const u8 = null,
        update_reason_code: ?[]const u8 = null,
        recommendation_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle_stage = "lifecycleStage",
                .update_reason = "updateReason",
                .update_reason_code = "updateReasonCode",
                .recommendation_identifier = "recommendationIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_recommendation_lifecycle) } {
            return .{ .service_metadata = service_metadata, .action = update_recommendation_lifecycle };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const RecommendationPillarSpecificAggregates = struct {
    cost_optimizing: ?RecommendationCostOptimizingAggregates = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cost_optimizing = "costOptimizing",
        };
        return @field(mappings, field_name);
    }
};

pub const RecommendationCostOptimizingAggregates = struct {
    estimated_monthly_savings: f64,
    estimated_percent_monthly_savings: f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .estimated_monthly_savings = "estimatedMonthlySavings",
            .estimated_percent_monthly_savings = "estimatedPercentMonthlySavings",
        };
        return @field(mappings, field_name);
    }
};

pub const RecommendationResourcesAggregates = struct {
    ok_count: i64,
    warning_count: i64,
    error_count: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ok_count = "okCount",
            .warning_count = "warningCount",
            .error_count = "errorCount",
        };
        return @field(mappings, field_name);
    }
};
