const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-09-27";
pub const sdk_id: []const u8 = "Voice ID";
pub const arn_namespace: ?[]const u8 = "voiceid";
pub const endpoint_prefix: []const u8 = "voiceid";
pub const sigv4_name: []const u8 = "voiceid";
pub const name: []const u8 = "VoiceID";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2021-09-27",
    sdk_id: []const u8 = "Voice ID",
    arn_namespace: ?[]const u8 = "voiceid",
    endpoint_prefix: []const u8 = "voiceid",
    sigv4_name: []const u8 = "voiceid",
    name: []const u8 = "VoiceID",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const associate_fraudster: struct {
    action_name: []const u8 = "AssociateFraudster",
    Request: type = struct {
        domain_id: []const u8,
        watchlist_id: []const u8,
        fraudster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .watchlist_id = "WatchlistId",
                .fraudster_id = "FraudsterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_fraudster) } {
            return .{ .service_metadata = service_metadata, .action = associate_fraudster };
        }
    },
    Response: type = struct {
        fraudster: ?Fraudster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fraudster = "Fraudster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_watchlist: struct {
    action_name: []const u8 = "CreateWatchlist",
    Request: type = struct {
        domain_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .name = "Name",
                .description = "Description",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_watchlist) } {
            return .{ .service_metadata = service_metadata, .action = create_watchlist };
        }
    },
    Response: type = struct {
        watchlist: ?Watchlist = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .watchlist = "Watchlist",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_fraudster: struct {
    action_name: []const u8 = "DeleteFraudster",
    Request: type = struct {
        domain_id: []const u8,
        fraudster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .fraudster_id = "FraudsterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fraudster) } {
            return .{ .service_metadata = service_metadata, .action = delete_fraudster };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_speaker: struct {
    action_name: []const u8 = "DeleteSpeaker",
    Request: type = struct {
        domain_id: []const u8,
        speaker_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .speaker_id = "SpeakerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_speaker) } {
            return .{ .service_metadata = service_metadata, .action = delete_speaker };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_watchlist: struct {
    action_name: []const u8 = "DeleteWatchlist",
    Request: type = struct {
        domain_id: []const u8,
        watchlist_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .watchlist_id = "WatchlistId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_watchlist) } {
            return .{ .service_metadata = service_metadata, .action = delete_watchlist };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_fraudster: struct {
    action_name: []const u8 = "DescribeFraudster",
    Request: type = struct {
        domain_id: []const u8,
        fraudster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .fraudster_id = "FraudsterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fraudster) } {
            return .{ .service_metadata = service_metadata, .action = describe_fraudster };
        }
    },
    Response: type = struct {
        fraudster: ?Fraudster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fraudster = "Fraudster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_fraudster_registration_job: struct {
    action_name: []const u8 = "DescribeFraudsterRegistrationJob",
    Request: type = struct {
        domain_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fraudster_registration_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_fraudster_registration_job };
        }
    },
    Response: type = struct {
        job: ?FraudsterRegistrationJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "Job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_speaker: struct {
    action_name: []const u8 = "DescribeSpeaker",
    Request: type = struct {
        domain_id: []const u8,
        speaker_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .speaker_id = "SpeakerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_speaker) } {
            return .{ .service_metadata = service_metadata, .action = describe_speaker };
        }
    },
    Response: type = struct {
        speaker: ?Speaker = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .speaker = "Speaker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_speaker_enrollment_job: struct {
    action_name: []const u8 = "DescribeSpeakerEnrollmentJob",
    Request: type = struct {
        domain_id: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_speaker_enrollment_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_speaker_enrollment_job };
        }
    },
    Response: type = struct {
        job: ?SpeakerEnrollmentJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "Job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_watchlist: struct {
    action_name: []const u8 = "DescribeWatchlist",
    Request: type = struct {
        domain_id: []const u8,
        watchlist_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .watchlist_id = "WatchlistId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_watchlist) } {
            return .{ .service_metadata = service_metadata, .action = describe_watchlist };
        }
    },
    Response: type = struct {
        watchlist: ?Watchlist = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .watchlist = "Watchlist",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_fraudster: struct {
    action_name: []const u8 = "DisassociateFraudster",
    Request: type = struct {
        domain_id: []const u8,
        watchlist_id: []const u8,
        fraudster_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .watchlist_id = "WatchlistId",
                .fraudster_id = "FraudsterId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_fraudster) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_fraudster };
        }
    },
    Response: type = struct {
        fraudster: ?Fraudster = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fraudster = "Fraudster",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const evaluate_session: struct {
    action_name: []const u8 = "EvaluateSession",
    Request: type = struct {
        domain_id: []const u8,
        session_name_or_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .session_name_or_id = "SessionNameOrId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(evaluate_session) } {
            return .{ .service_metadata = service_metadata, .action = evaluate_session };
        }
    },
    Response: type = struct {
        domain_id: ?[]const u8 = null,
        session_id: ?[]const u8 = null,
        session_name: ?[]const u8 = null,
        streaming_status: ?[]const u8 = null,
        authentication_result: ?struct {
            authentication_result_id: ?[]const u8 = null,
            audio_aggregation_started_at: ?i64 = null,
            audio_aggregation_ended_at: ?i64 = null,
            customer_speaker_id: ?[]const u8 = null,
            generated_speaker_id: ?[]const u8 = null,
            decision: ?[]const u8 = null,
            score: ?i64 = null,
            configuration: ?struct {
                acceptance_threshold: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .acceptance_threshold = "AcceptanceThreshold",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .authentication_result_id = "AuthenticationResultId",
                    .audio_aggregation_started_at = "AudioAggregationStartedAt",
                    .audio_aggregation_ended_at = "AudioAggregationEndedAt",
                    .customer_speaker_id = "CustomerSpeakerId",
                    .generated_speaker_id = "GeneratedSpeakerId",
                    .decision = "Decision",
                    .score = "Score",
                    .configuration = "Configuration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        fraud_detection_result: ?struct {
            fraud_detection_result_id: ?[]const u8 = null,
            audio_aggregation_started_at: ?i64 = null,
            audio_aggregation_ended_at: ?i64 = null,
            configuration: ?struct {
                risk_threshold: ?i64 = null,
                watchlist_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .risk_threshold = "RiskThreshold",
                        .watchlist_id = "WatchlistId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            decision: ?[]const u8 = null,
            reasons: ?[][]const u8 = null,
            risk_details: ?struct {
                known_fraudster_risk: struct {
                    risk_score: i64,
                    generated_fraudster_id: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .risk_score = "RiskScore",
                            .generated_fraudster_id = "GeneratedFraudsterId",
                        };
                        return @field(mappings, field_name);
                    }
                },
                voice_spoofing_risk: struct {
                    risk_score: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .risk_score = "RiskScore",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .known_fraudster_risk = "KnownFraudsterRisk",
                        .voice_spoofing_risk = "VoiceSpoofingRisk",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fraud_detection_result_id = "FraudDetectionResultId",
                    .audio_aggregation_started_at = "AudioAggregationStartedAt",
                    .audio_aggregation_ended_at = "AudioAggregationEndedAt",
                    .configuration = "Configuration",
                    .decision = "Decision",
                    .reasons = "Reasons",
                    .risk_details = "RiskDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .session_id = "SessionId",
                .session_name = "SessionName",
                .streaming_status = "StreamingStatus",
                .authentication_result = "AuthenticationResult",
                .fraud_detection_result = "FraudDetectionResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_fraudster_registration_jobs: struct {
    action_name: []const u8 = "ListFraudsterRegistrationJobs",
    Request: type = struct {
        domain_id: []const u8,
        job_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .job_status = "JobStatus",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fraudster_registration_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_fraudster_registration_jobs };
        }
    },
    Response: type = struct {
        job_summaries: ?[]struct {
            job_name: ?[]const u8 = null,
            job_id: ?[]const u8 = null,
            job_status: ?[]const u8 = null,
            domain_id: ?[]const u8 = null,
            created_at: ?i64 = null,
            ended_at: ?i64 = null,
            failure_details: ?FailureDetails = null,
            job_progress: ?JobProgress = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "JobName",
                    .job_id = "JobId",
                    .job_status = "JobStatus",
                    .domain_id = "DomainId",
                    .created_at = "CreatedAt",
                    .ended_at = "EndedAt",
                    .failure_details = "FailureDetails",
                    .job_progress = "JobProgress",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summaries = "JobSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_fraudsters: struct {
    action_name: []const u8 = "ListFraudsters",
    Request: type = struct {
        domain_id: []const u8,
        watchlist_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .watchlist_id = "WatchlistId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fraudsters) } {
            return .{ .service_metadata = service_metadata, .action = list_fraudsters };
        }
    },
    Response: type = struct {
        fraudster_summaries: ?[]struct {
            domain_id: ?[]const u8 = null,
            generated_fraudster_id: ?[]const u8 = null,
            created_at: ?i64 = null,
            watchlist_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_id = "DomainId",
                    .generated_fraudster_id = "GeneratedFraudsterId",
                    .created_at = "CreatedAt",
                    .watchlist_ids = "WatchlistIds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fraudster_summaries = "FraudsterSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_speaker_enrollment_jobs: struct {
    action_name: []const u8 = "ListSpeakerEnrollmentJobs",
    Request: type = struct {
        domain_id: []const u8,
        job_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .job_status = "JobStatus",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_speaker_enrollment_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_speaker_enrollment_jobs };
        }
    },
    Response: type = struct {
        job_summaries: ?[]struct {
            job_name: ?[]const u8 = null,
            job_id: ?[]const u8 = null,
            job_status: ?[]const u8 = null,
            domain_id: ?[]const u8 = null,
            created_at: ?i64 = null,
            ended_at: ?i64 = null,
            failure_details: ?FailureDetails = null,
            job_progress: ?JobProgress = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "JobName",
                    .job_id = "JobId",
                    .job_status = "JobStatus",
                    .domain_id = "DomainId",
                    .created_at = "CreatedAt",
                    .ended_at = "EndedAt",
                    .failure_details = "FailureDetails",
                    .job_progress = "JobProgress",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summaries = "JobSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_speakers: struct {
    action_name: []const u8 = "ListSpeakers",
    Request: type = struct {
        domain_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_speakers) } {
            return .{ .service_metadata = service_metadata, .action = list_speakers };
        }
    },
    Response: type = struct {
        speaker_summaries: ?[]struct {
            domain_id: ?[]const u8 = null,
            customer_speaker_id: ?[]const u8 = null,
            generated_speaker_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            last_accessed_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_id = "DomainId",
                    .customer_speaker_id = "CustomerSpeakerId",
                    .generated_speaker_id = "GeneratedSpeakerId",
                    .status = "Status",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .last_accessed_at = "LastAccessedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .speaker_summaries = "SpeakerSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_watchlists: struct {
    action_name: []const u8 = "ListWatchlists",
    Request: type = struct {
        domain_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_watchlists) } {
            return .{ .service_metadata = service_metadata, .action = list_watchlists };
        }
    },
    Response: type = struct {
        watchlist_summaries: ?[]struct {
            domain_id: ?[]const u8 = null,
            watchlist_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            default_watchlist: ?bool = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_id = "DomainId",
                    .watchlist_id = "WatchlistId",
                    .name = "Name",
                    .description = "Description",
                    .default_watchlist = "DefaultWatchlist",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .watchlist_summaries = "WatchlistSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const opt_out_speaker: struct {
    action_name: []const u8 = "OptOutSpeaker",
    Request: type = struct {
        domain_id: []const u8,
        speaker_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .speaker_id = "SpeakerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(opt_out_speaker) } {
            return .{ .service_metadata = service_metadata, .action = opt_out_speaker };
        }
    },
    Response: type = struct {
        speaker: ?Speaker = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .speaker = "Speaker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_fraudster_registration_job: struct {
    action_name: []const u8 = "StartFraudsterRegistrationJob",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        job_name: ?[]const u8 = null,
        domain_id: []const u8,
        data_access_role_arn: []const u8,
        registration_config: ?RegistrationConfig = null,
        input_data_config: InputDataConfig,
        output_data_config: OutputDataConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .job_name = "JobName",
                .domain_id = "DomainId",
                .data_access_role_arn = "DataAccessRoleArn",
                .registration_config = "RegistrationConfig",
                .input_data_config = "InputDataConfig",
                .output_data_config = "OutputDataConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_fraudster_registration_job) } {
            return .{ .service_metadata = service_metadata, .action = start_fraudster_registration_job };
        }
    },
    Response: type = struct {
        job: ?FraudsterRegistrationJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "Job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_speaker_enrollment_job: struct {
    action_name: []const u8 = "StartSpeakerEnrollmentJob",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        job_name: ?[]const u8 = null,
        domain_id: []const u8,
        data_access_role_arn: []const u8,
        enrollment_config: ?EnrollmentConfig = null,
        input_data_config: InputDataConfig,
        output_data_config: OutputDataConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .job_name = "JobName",
                .domain_id = "DomainId",
                .data_access_role_arn = "DataAccessRoleArn",
                .enrollment_config = "EnrollmentConfig",
                .input_data_config = "InputDataConfig",
                .output_data_config = "OutputDataConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_speaker_enrollment_job) } {
            return .{ .service_metadata = service_metadata, .action = start_speaker_enrollment_job };
        }
    },
    Response: type = struct {
        job: ?SpeakerEnrollmentJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "Job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_watchlist: struct {
    action_name: []const u8 = "UpdateWatchlist",
    Request: type = struct {
        domain_id: []const u8,
        watchlist_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .watchlist_id = "WatchlistId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_watchlist) } {
            return .{ .service_metadata = service_metadata, .action = update_watchlist };
        }
    },
    Response: type = struct {
        watchlist: ?Watchlist = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .watchlist = "Watchlist",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Watchlist = struct {
    domain_id: ?[]const u8 = null,
    watchlist_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    default_watchlist: ?bool = null,
    created_at: ?i64 = null,
    updated_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_id = "DomainId",
            .watchlist_id = "WatchlistId",
            .name = "Name",
            .description = "Description",
            .default_watchlist = "DefaultWatchlist",
            .created_at = "CreatedAt",
            .updated_at = "UpdatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const SpeakerEnrollmentJob = struct {
    job_name: ?[]const u8 = null,
    job_id: ?[]const u8 = null,
    job_status: ?[]const u8 = null,
    domain_id: ?[]const u8 = null,
    data_access_role_arn: ?[]const u8 = null,
    enrollment_config: ?EnrollmentConfig = null,
    input_data_config: ?InputDataConfig = null,
    output_data_config: ?OutputDataConfig = null,
    created_at: ?i64 = null,
    ended_at: ?i64 = null,
    failure_details: ?FailureDetails = null,
    job_progress: ?JobProgress = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_name = "JobName",
            .job_id = "JobId",
            .job_status = "JobStatus",
            .domain_id = "DomainId",
            .data_access_role_arn = "DataAccessRoleArn",
            .enrollment_config = "EnrollmentConfig",
            .input_data_config = "InputDataConfig",
            .output_data_config = "OutputDataConfig",
            .created_at = "CreatedAt",
            .ended_at = "EndedAt",
            .failure_details = "FailureDetails",
            .job_progress = "JobProgress",
        };
        return @field(mappings, field_name);
    }
};

pub const JobProgress = struct {
    percent_complete: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .percent_complete = "PercentComplete",
        };
        return @field(mappings, field_name);
    }
};

pub const FailureDetails = struct {
    status_code: ?i64 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "StatusCode",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputDataConfig = struct {
    s3_uri: []const u8,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const InputDataConfig = struct {
    s3_uri: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const EnrollmentConfig = struct {
    existing_enrollment_action: ?[]const u8 = null,
    fraud_detection_config: ?EnrollmentJobFraudDetectionConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .existing_enrollment_action = "ExistingEnrollmentAction",
            .fraud_detection_config = "FraudDetectionConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const EnrollmentJobFraudDetectionConfig = struct {
    fraud_detection_action: ?[]const u8 = null,
    risk_threshold: ?i64 = null,
    watchlist_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fraud_detection_action = "FraudDetectionAction",
            .risk_threshold = "RiskThreshold",
            .watchlist_ids = "WatchlistIds",
        };
        return @field(mappings, field_name);
    }
};

pub const FraudsterRegistrationJob = struct {
    job_name: ?[]const u8 = null,
    job_id: ?[]const u8 = null,
    job_status: ?[]const u8 = null,
    domain_id: ?[]const u8 = null,
    data_access_role_arn: ?[]const u8 = null,
    registration_config: ?RegistrationConfig = null,
    input_data_config: ?InputDataConfig = null,
    output_data_config: ?OutputDataConfig = null,
    created_at: ?i64 = null,
    ended_at: ?i64 = null,
    failure_details: ?FailureDetails = null,
    job_progress: ?JobProgress = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_name = "JobName",
            .job_id = "JobId",
            .job_status = "JobStatus",
            .domain_id = "DomainId",
            .data_access_role_arn = "DataAccessRoleArn",
            .registration_config = "RegistrationConfig",
            .input_data_config = "InputDataConfig",
            .output_data_config = "OutputDataConfig",
            .created_at = "CreatedAt",
            .ended_at = "EndedAt",
            .failure_details = "FailureDetails",
            .job_progress = "JobProgress",
        };
        return @field(mappings, field_name);
    }
};

pub const RegistrationConfig = struct {
    duplicate_registration_action: ?[]const u8 = null,
    fraudster_similarity_threshold: ?i64 = null,
    watchlist_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .duplicate_registration_action = "DuplicateRegistrationAction",
            .fraudster_similarity_threshold = "FraudsterSimilarityThreshold",
            .watchlist_ids = "WatchlistIds",
        };
        return @field(mappings, field_name);
    }
};

pub const Speaker = struct {
    domain_id: ?[]const u8 = null,
    customer_speaker_id: ?[]const u8 = null,
    generated_speaker_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_at: ?i64 = null,
    updated_at: ?i64 = null,
    last_accessed_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_id = "DomainId",
            .customer_speaker_id = "CustomerSpeakerId",
            .generated_speaker_id = "GeneratedSpeakerId",
            .status = "Status",
            .created_at = "CreatedAt",
            .updated_at = "UpdatedAt",
            .last_accessed_at = "LastAccessedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const Fraudster = struct {
    domain_id: ?[]const u8 = null,
    generated_fraudster_id: ?[]const u8 = null,
    created_at: ?i64 = null,
    watchlist_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_id = "DomainId",
            .generated_fraudster_id = "GeneratedFraudsterId",
            .created_at = "CreatedAt",
            .watchlist_ids = "WatchlistIds",
        };
        return @field(mappings, field_name);
    }
};
