const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2022-11-30";
pub const sdk_id: []const u8 = "VPC Lattice";
pub const arn_namespace: ?[]const u8 = "vpc-lattice";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "vpc-lattice";
pub const name: []const u8 = "MercuryControlPlane";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2022-11-30",
    sdk_id: []const u8 = "VPC Lattice",
    arn_namespace: ?[]const u8 = "vpc-lattice",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "vpc-lattice",
    name: []const u8 = "MercuryControlPlane",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_update_rule: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/services/{serviceIdentifier}/listeners/{listenerIdentifier}/rules",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateRule",
    Request: type = struct {
        service_identifier: []const u8,
        listener_identifier: []const u8,
        rules: []struct {
            rule_identifier: []const u8,
            match: ?RuleMatch = null,
            priority: ?i64 = null,
            action: ?RuleAction = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_identifier = "ruleIdentifier",
                    .match = "match",
                    .priority = "priority",
                    .action = "action",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_identifier = "serviceIdentifier",
                .listener_identifier = "listenerIdentifier",
                .rules = "rules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_rule) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_rule };
        }
    },
    Response: type = struct {
        successful: ?[]struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            is_default: ?bool = null,
            match: ?RuleMatch = null,
            priority: ?i64 = null,
            action: ?RuleAction = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .id = "id",
                    .name = "name",
                    .is_default = "isDefault",
                    .match = "match",
                    .priority = "priority",
                    .action = "action",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unsuccessful: ?[]struct {
            rule_identifier: ?[]const u8 = null,
            failure_code: ?[]const u8 = null,
            failure_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_identifier = "ruleIdentifier",
                    .failure_code = "failureCode",
                    .failure_message = "failureMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful = "successful",
                .unsuccessful = "unsuccessful",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_auth_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/authpolicy/{resourceIdentifier}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAuthPolicy",
    Request: type = struct {
        resource_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "resourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_auth_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_auth_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resource_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/resourcepolicy/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_auth_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/authpolicy/{resourceIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAuthPolicy",
    Request: type = struct {
        resource_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "resourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_auth_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_auth_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,
        state: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
                .state = "state",
                .created_at = "createdAt",
                .last_updated_at = "lastUpdatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resourcepolicy/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const put_auth_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/authpolicy/{resourceIdentifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAuthPolicy",
    Request: type = struct {
        resource_identifier: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_identifier = "resourceIdentifier",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_auth_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_auth_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "policy",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_resource_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/resourcepolicy/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};

pub const RuleAction = union {
    forward: ?ForwardAction,
    fixed_response: ?FixedResponseAction,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .forward = "forward",
            .fixed_response = "fixedResponse",
        };
        return @field(mappings, field_name);
    }
};

pub const FixedResponseAction = struct {
    status_code: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "statusCode",
        };
        return @field(mappings, field_name);
    }
};

pub const ForwardAction = struct {
    target_groups: []WeightedTargetGroup,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_groups = "targetGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const WeightedTargetGroup = struct {
    target_group_identifier: []const u8,
    weight: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_group_identifier = "targetGroupIdentifier",
            .weight = "weight",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleMatch = union {
    http_match: ?HttpMatch,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_match = "httpMatch",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpMatch = struct {
    method: ?[]const u8 = null,
    path_match: ?PathMatch = null,
    header_matches: ?[]HeaderMatch = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .method = "method",
            .path_match = "pathMatch",
            .header_matches = "headerMatches",
        };
        return @field(mappings, field_name);
    }
};

pub const HeaderMatch = struct {
    name: []const u8,
    match: HeaderMatchType,
    case_sensitive: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .match = "match",
            .case_sensitive = "caseSensitive",
        };
        return @field(mappings, field_name);
    }
};

pub const HeaderMatchType = union {
    exact: ?[]const u8,
    prefix: ?[]const u8,
    contains: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .exact = "exact",
            .prefix = "prefix",
            .contains = "contains",
        };
        return @field(mappings, field_name);
    }
};

pub const PathMatch = struct {
    match: PathMatchType,
    case_sensitive: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match = "match",
            .case_sensitive = "caseSensitive",
        };
        return @field(mappings, field_name);
    }
};

pub const PathMatchType = union {
    exact: ?[]const u8,
    prefix: ?[]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .exact = "exact",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};
