const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-11-28";
pub const sdk_id: []const u8 = "WAF Regional";
pub const arn_namespace: ?[]const u8 = "waf-regional";
pub const endpoint_prefix: []const u8 = "waf-regional";
pub const sigv4_name: []const u8 = "waf-regional";
pub const name: []const u8 = "AWSWAF_Regional_20161128";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-11-28",
    sdk_id: []const u8 = "WAF Regional",
    arn_namespace: ?[]const u8 = "waf-regional",
    endpoint_prefix: []const u8 = "waf-regional",
    sigv4_name: []const u8 = "waf-regional",
    name: []const u8 = "AWSWAF_Regional_20161128",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_web_acl: struct {
    action_name: []const u8 = "AssociateWebACL",
    Request: type = struct {
        web_acl_id: []const u8,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_id = "WebACLId",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = associate_web_acl };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFUnavailableEntity,
    },
} = .{};
pub const create_byte_match_set: struct {
    action_name: []const u8 = "CreateByteMatchSet",
    Request: type = struct {
        name: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_byte_match_set) } {
            return .{ .service_metadata = service_metadata, .action = create_byte_match_set };
        }
    },
    Response: type = struct {
        byte_match_set: ?ByteMatchSet = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byte_match_set = "ByteMatchSet",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDisallowedName,
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFStaleData,
    },
} = .{};
pub const create_geo_match_set: struct {
    action_name: []const u8 = "CreateGeoMatchSet",
    Request: type = struct {
        name: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_geo_match_set) } {
            return .{ .service_metadata = service_metadata, .action = create_geo_match_set };
        }
    },
    Response: type = struct {
        geo_match_set: ?GeoMatchSet = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .geo_match_set = "GeoMatchSet",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDisallowedName,
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFStaleData,
    },
} = .{};
pub const create_ip_set: struct {
    action_name: []const u8 = "CreateIPSet",
    Request: type = struct {
        name: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = create_ip_set };
        }
    },
    Response: type = struct {
        ip_set: ?IPSet = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_set = "IPSet",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDisallowedName,
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFStaleData,
    },
} = .{};
pub const create_rate_based_rule: struct {
    action_name: []const u8 = "CreateRateBasedRule",
    Request: type = struct {
        name: []const u8,
        metric_name: []const u8,
        rate_key: []const u8,
        rate_limit: i64,
        change_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .metric_name = "MetricName",
                .rate_key = "RateKey",
                .rate_limit = "RateLimit",
                .change_token = "ChangeToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rate_based_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_rate_based_rule };
        }
    },
    Response: type = struct {
        rule: ?RateBasedRule = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule = "Rule",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFBadRequest,
        WAFDisallowedName,
        WAFInternalError,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFStaleData,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const create_regex_match_set: struct {
    action_name: []const u8 = "CreateRegexMatchSet",
    Request: type = struct {
        name: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_regex_match_set) } {
            return .{ .service_metadata = service_metadata, .action = create_regex_match_set };
        }
    },
    Response: type = struct {
        regex_match_set: ?RegexMatchSet = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_match_set = "RegexMatchSet",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDisallowedName,
        WAFInternalError,
        WAFLimitsExceeded,
        WAFStaleData,
    },
} = .{};
pub const create_regex_pattern_set: struct {
    action_name: []const u8 = "CreateRegexPatternSet",
    Request: type = struct {
        name: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = create_regex_pattern_set };
        }
    },
    Response: type = struct {
        regex_pattern_set: ?RegexPatternSet = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_pattern_set = "RegexPatternSet",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDisallowedName,
        WAFInternalError,
        WAFLimitsExceeded,
        WAFStaleData,
    },
} = .{};
pub const create_rule: struct {
    action_name: []const u8 = "CreateRule",
    Request: type = struct {
        name: []const u8,
        metric_name: []const u8,
        change_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .metric_name = "MetricName",
                .change_token = "ChangeToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_rule };
        }
    },
    Response: type = struct {
        rule: ?Rule = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule = "Rule",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFBadRequest,
        WAFDisallowedName,
        WAFInternalError,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFStaleData,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const create_rule_group: struct {
    action_name: []const u8 = "CreateRuleGroup",
    Request: type = struct {
        name: []const u8,
        metric_name: []const u8,
        change_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .metric_name = "MetricName",
                .change_token = "ChangeToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = create_rule_group };
        }
    },
    Response: type = struct {
        rule_group: ?RuleGroup = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group = "RuleGroup",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFBadRequest,
        WAFDisallowedName,
        WAFInternalError,
        WAFLimitsExceeded,
        WAFStaleData,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const create_size_constraint_set: struct {
    action_name: []const u8 = "CreateSizeConstraintSet",
    Request: type = struct {
        name: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_size_constraint_set) } {
            return .{ .service_metadata = service_metadata, .action = create_size_constraint_set };
        }
    },
    Response: type = struct {
        size_constraint_set: ?SizeConstraintSet = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .size_constraint_set = "SizeConstraintSet",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDisallowedName,
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFStaleData,
    },
} = .{};
pub const create_sql_injection_match_set: struct {
    action_name: []const u8 = "CreateSqlInjectionMatchSet",
    Request: type = struct {
        name: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sql_injection_match_set) } {
            return .{ .service_metadata = service_metadata, .action = create_sql_injection_match_set };
        }
    },
    Response: type = struct {
        sql_injection_match_set: ?SqlInjectionMatchSet = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sql_injection_match_set = "SqlInjectionMatchSet",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDisallowedName,
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFStaleData,
    },
} = .{};
pub const create_web_acl: struct {
    action_name: []const u8 = "CreateWebACL",
    Request: type = struct {
        name: []const u8,
        metric_name: []const u8,
        default_action: WafAction,
        change_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .metric_name = "MetricName",
                .default_action = "DefaultAction",
                .change_token = "ChangeToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = create_web_acl };
        }
    },
    Response: type = struct {
        web_acl: ?WebACL = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl = "WebACL",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFBadRequest,
        WAFDisallowedName,
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFStaleData,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const create_web_acl_migration_stack: struct {
    action_name: []const u8 = "CreateWebACLMigrationStack",
    Request: type = struct {
        web_acl_id: []const u8,
        s3_bucket_name: []const u8,
        ignore_unsupported_type: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_id = "WebACLId",
                .s3_bucket_name = "S3BucketName",
                .ignore_unsupported_type = "IgnoreUnsupportedType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_web_acl_migration_stack) } {
            return .{ .service_metadata = service_metadata, .action = create_web_acl_migration_stack };
        }
    },
    Response: type = struct {
        s3_object_url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_object_url = "S3ObjectUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFEntityMigration,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const create_xss_match_set: struct {
    action_name: []const u8 = "CreateXssMatchSet",
    Request: type = struct {
        name: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_xss_match_set) } {
            return .{ .service_metadata = service_metadata, .action = create_xss_match_set };
        }
    },
    Response: type = struct {
        xss_match_set: ?XssMatchSet = null,
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .xss_match_set = "XssMatchSet",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDisallowedName,
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFStaleData,
    },
} = .{};
pub const delete_byte_match_set: struct {
    action_name: []const u8 = "DeleteByteMatchSet",
    Request: type = struct {
        byte_match_set_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byte_match_set_id = "ByteMatchSetId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_byte_match_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_byte_match_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const delete_geo_match_set: struct {
    action_name: []const u8 = "DeleteGeoMatchSet",
    Request: type = struct {
        geo_match_set_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .geo_match_set_id = "GeoMatchSetId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_geo_match_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_geo_match_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const delete_ip_set: struct {
    action_name: []const u8 = "DeleteIPSet",
    Request: type = struct {
        ip_set_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_set_id = "IPSetId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_ip_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const delete_logging_configuration: struct {
    action_name: []const u8 = "DeleteLoggingConfiguration",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_logging_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFNonexistentItem,
        WAFStaleData,
    },
} = .{};
pub const delete_permission_policy: struct {
    action_name: []const u8 = "DeletePermissionPolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_permission_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_permission_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFNonexistentItem,
        WAFStaleData,
    },
} = .{};
pub const delete_rate_based_rule: struct {
    action_name: []const u8 = "DeleteRateBasedRule",
    Request: type = struct {
        rule_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_id = "RuleId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rate_based_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_rate_based_rule };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const delete_regex_match_set: struct {
    action_name: []const u8 = "DeleteRegexMatchSet",
    Request: type = struct {
        regex_match_set_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_match_set_id = "RegexMatchSetId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_regex_match_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_regex_match_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const delete_regex_pattern_set: struct {
    action_name: []const u8 = "DeleteRegexPatternSet",
    Request: type = struct {
        regex_pattern_set_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_pattern_set_id = "RegexPatternSetId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_regex_pattern_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const delete_rule: struct {
    action_name: []const u8 = "DeleteRule",
    Request: type = struct {
        rule_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_id = "RuleId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_rule };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const delete_rule_group: struct {
    action_name: []const u8 = "DeleteRuleGroup",
    Request: type = struct {
        rule_group_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group_id = "RuleGroupId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_rule_group };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const delete_size_constraint_set: struct {
    action_name: []const u8 = "DeleteSizeConstraintSet",
    Request: type = struct {
        size_constraint_set_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .size_constraint_set_id = "SizeConstraintSetId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_size_constraint_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_size_constraint_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const delete_sql_injection_match_set: struct {
    action_name: []const u8 = "DeleteSqlInjectionMatchSet",
    Request: type = struct {
        sql_injection_match_set_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sql_injection_match_set_id = "SqlInjectionMatchSetId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sql_injection_match_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_sql_injection_match_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const delete_web_acl: struct {
    action_name: []const u8 = "DeleteWebACL",
    Request: type = struct {
        web_acl_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_id = "WebACLId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = delete_web_acl };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const delete_xss_match_set: struct {
    action_name: []const u8 = "DeleteXssMatchSet",
    Request: type = struct {
        xss_match_set_id: []const u8,
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .xss_match_set_id = "XssMatchSetId",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_xss_match_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_xss_match_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonEmptyEntity,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const disassociate_web_acl: struct {
    action_name: []const u8 = "DisassociateWebACL",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_web_acl };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_byte_match_set: struct {
    action_name: []const u8 = "GetByteMatchSet",
    Request: type = struct {
        byte_match_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byte_match_set_id = "ByteMatchSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_byte_match_set) } {
            return .{ .service_metadata = service_metadata, .action = get_byte_match_set };
        }
    },
    Response: type = struct {
        byte_match_set: ?ByteMatchSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byte_match_set = "ByteMatchSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const get_change_token: struct {
    action_name: []const u8 = "GetChangeToken",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_change_token) } {
            return .{ .service_metadata = service_metadata, .action = get_change_token };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
    },
} = .{};
pub const get_change_token_status: struct {
    action_name: []const u8 = "GetChangeTokenStatus",
    Request: type = struct {
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_change_token_status) } {
            return .{ .service_metadata = service_metadata, .action = get_change_token_status };
        }
    },
    Response: type = struct {
        change_token_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token_status = "ChangeTokenStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFNonexistentItem,
    },
} = .{};
pub const get_geo_match_set: struct {
    action_name: []const u8 = "GetGeoMatchSet",
    Request: type = struct {
        geo_match_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .geo_match_set_id = "GeoMatchSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_geo_match_set) } {
            return .{ .service_metadata = service_metadata, .action = get_geo_match_set };
        }
    },
    Response: type = struct {
        geo_match_set: ?GeoMatchSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .geo_match_set = "GeoMatchSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const get_ip_set: struct {
    action_name: []const u8 = "GetIPSet",
    Request: type = struct {
        ip_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_set_id = "IPSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = get_ip_set };
        }
    },
    Response: type = struct {
        ip_set: ?IPSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_set = "IPSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const get_logging_configuration: struct {
    action_name: []const u8 = "GetLoggingConfiguration",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFNonexistentItem,
    },
} = .{};
pub const get_permission_policy: struct {
    action_name: []const u8 = "GetPermissionPolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_permission_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_permission_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFNonexistentItem,
    },
} = .{};
pub const get_rate_based_rule: struct {
    action_name: []const u8 = "GetRateBasedRule",
    Request: type = struct {
        rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_id = "RuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rate_based_rule) } {
            return .{ .service_metadata = service_metadata, .action = get_rate_based_rule };
        }
    },
    Response: type = struct {
        rule: ?RateBasedRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule = "Rule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const get_rate_based_rule_managed_keys: struct {
    action_name: []const u8 = "GetRateBasedRuleManagedKeys",
    Request: type = struct {
        rule_id: []const u8,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_id = "RuleId",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rate_based_rule_managed_keys) } {
            return .{ .service_metadata = service_metadata, .action = get_rate_based_rule_managed_keys };
        }
    },
    Response: type = struct {
        managed_keys: ?[][]const u8 = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .managed_keys = "ManagedKeys",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_regex_match_set: struct {
    action_name: []const u8 = "GetRegexMatchSet",
    Request: type = struct {
        regex_match_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_match_set_id = "RegexMatchSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_regex_match_set) } {
            return .{ .service_metadata = service_metadata, .action = get_regex_match_set };
        }
    },
    Response: type = struct {
        regex_match_set: ?RegexMatchSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_match_set = "RegexMatchSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const get_regex_pattern_set: struct {
    action_name: []const u8 = "GetRegexPatternSet",
    Request: type = struct {
        regex_pattern_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_pattern_set_id = "RegexPatternSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = get_regex_pattern_set };
        }
    },
    Response: type = struct {
        regex_pattern_set: ?RegexPatternSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_pattern_set = "RegexPatternSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const get_rule: struct {
    action_name: []const u8 = "GetRule",
    Request: type = struct {
        rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_id = "RuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rule) } {
            return .{ .service_metadata = service_metadata, .action = get_rule };
        }
    },
    Response: type = struct {
        rule: ?Rule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule = "Rule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const get_rule_group: struct {
    action_name: []const u8 = "GetRuleGroup",
    Request: type = struct {
        rule_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group_id = "RuleGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = get_rule_group };
        }
    },
    Response: type = struct {
        rule_group: ?RuleGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group = "RuleGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFNonexistentItem,
    },
} = .{};
pub const get_sampled_requests: struct {
    action_name: []const u8 = "GetSampledRequests",
    Request: type = struct {
        web_acl_id: []const u8,
        rule_id: []const u8,
        time_window: TimeWindow,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_id = "WebAclId",
                .rule_id = "RuleId",
                .time_window = "TimeWindow",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sampled_requests) } {
            return .{ .service_metadata = service_metadata, .action = get_sampled_requests };
        }
    },
    Response: type = struct {
        sampled_requests: ?[]struct {
            request: struct {
                client_ip: ?[]const u8 = null,
                country: ?[]const u8 = null,
                uri: ?[]const u8 = null,
                method: ?[]const u8 = null,
                http_version: ?[]const u8 = null,
                headers: ?[]struct {
                    name: ?[]const u8 = null,
                    value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "Name",
                            .value = "Value",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .client_ip = "ClientIP",
                        .country = "Country",
                        .uri = "URI",
                        .method = "Method",
                        .http_version = "HTTPVersion",
                        .headers = "Headers",
                    };
                    return @field(mappings, field_name);
                }
            },
            weight: i64,
            timestamp: ?i64 = null,
            action: ?[]const u8 = null,
            rule_within_rule_group: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .request = "Request",
                    .weight = "Weight",
                    .timestamp = "Timestamp",
                    .action = "Action",
                    .rule_within_rule_group = "RuleWithinRuleGroup",
                };
                return @field(mappings, field_name);
            }
        } = null,
        population_size: ?i64 = null,
        time_window: ?TimeWindow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampled_requests = "SampledRequests",
                .population_size = "PopulationSize",
                .time_window = "TimeWindow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFNonexistentItem,
    },
} = .{};
pub const get_size_constraint_set: struct {
    action_name: []const u8 = "GetSizeConstraintSet",
    Request: type = struct {
        size_constraint_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .size_constraint_set_id = "SizeConstraintSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_size_constraint_set) } {
            return .{ .service_metadata = service_metadata, .action = get_size_constraint_set };
        }
    },
    Response: type = struct {
        size_constraint_set: ?SizeConstraintSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .size_constraint_set = "SizeConstraintSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const get_sql_injection_match_set: struct {
    action_name: []const u8 = "GetSqlInjectionMatchSet",
    Request: type = struct {
        sql_injection_match_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sql_injection_match_set_id = "SqlInjectionMatchSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sql_injection_match_set) } {
            return .{ .service_metadata = service_metadata, .action = get_sql_injection_match_set };
        }
    },
    Response: type = struct {
        sql_injection_match_set: ?SqlInjectionMatchSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sql_injection_match_set = "SqlInjectionMatchSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const get_web_acl: struct {
    action_name: []const u8 = "GetWebACL",
    Request: type = struct {
        web_acl_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_id = "WebACLId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = get_web_acl };
        }
    },
    Response: type = struct {
        web_acl: ?WebACL = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl = "WebACL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const get_web_acl_for_resource: struct {
    action_name: []const u8 = "GetWebACLForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_web_acl_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = get_web_acl_for_resource };
        }
    },
    Response: type = struct {
        web_acl_summary: ?WebACLSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_summary = "WebACLSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFUnavailableEntity,
    },
} = .{};
pub const get_xss_match_set: struct {
    action_name: []const u8 = "GetXssMatchSet",
    Request: type = struct {
        xss_match_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .xss_match_set_id = "XssMatchSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_xss_match_set) } {
            return .{ .service_metadata = service_metadata, .action = get_xss_match_set };
        }
    },
    Response: type = struct {
        xss_match_set: ?XssMatchSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .xss_match_set = "XssMatchSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFNonexistentItem,
    },
} = .{};
pub const list_activated_rules_in_rule_group: struct {
    action_name: []const u8 = "ListActivatedRulesInRuleGroup",
    Request: type = struct {
        rule_group_id: ?[]const u8 = null,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group_id = "RuleGroupId",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_activated_rules_in_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = list_activated_rules_in_rule_group };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        activated_rules: ?[]ActivatedRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .activated_rules = "ActivatedRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const list_byte_match_sets: struct {
    action_name: []const u8 = "ListByteMatchSets",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_byte_match_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_byte_match_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        byte_match_sets: ?[]struct {
            byte_match_set_id: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .byte_match_set_id = "ByteMatchSetId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .byte_match_sets = "ByteMatchSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const list_geo_match_sets: struct {
    action_name: []const u8 = "ListGeoMatchSets",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_geo_match_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_geo_match_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        geo_match_sets: ?[]struct {
            geo_match_set_id: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .geo_match_set_id = "GeoMatchSetId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .geo_match_sets = "GeoMatchSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const list_ip_sets: struct {
    action_name: []const u8 = "ListIPSets",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ip_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_ip_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        ip_sets: ?[]struct {
            ip_set_id: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ip_set_id = "IPSetId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .ip_sets = "IPSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const list_logging_configurations: struct {
    action_name: []const u8 = "ListLoggingConfigurations",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_logging_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_logging_configurations };
        }
    },
    Response: type = struct {
        logging_configurations: ?[]LoggingConfiguration = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configurations = "LoggingConfigurations",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const list_rate_based_rules: struct {
    action_name: []const u8 = "ListRateBasedRules",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rate_based_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_rate_based_rules };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        rules: ?[]RuleSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const list_regex_match_sets: struct {
    action_name: []const u8 = "ListRegexMatchSets",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_regex_match_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_regex_match_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        regex_match_sets: ?[]struct {
            regex_match_set_id: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .regex_match_set_id = "RegexMatchSetId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .regex_match_sets = "RegexMatchSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const list_regex_pattern_sets: struct {
    action_name: []const u8 = "ListRegexPatternSets",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_regex_pattern_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_regex_pattern_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        regex_pattern_sets: ?[]struct {
            regex_pattern_set_id: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .regex_pattern_set_id = "RegexPatternSetId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .regex_pattern_sets = "RegexPatternSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const list_resources_for_web_acl: struct {
    action_name: []const u8 = "ListResourcesForWebACL",
    Request: type = struct {
        web_acl_id: []const u8,
        resource_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_id = "WebACLId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources_for_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = list_resources_for_web_acl };
        }
    },
    Response: type = struct {
        resource_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arns = "ResourceArns",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const list_rule_groups: struct {
    action_name: []const u8 = "ListRuleGroups",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rule_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_rule_groups };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        rule_groups: ?[]struct {
            rule_group_id: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_group_id = "RuleGroupId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .rule_groups = "RuleGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
    },
} = .{};
pub const list_rules: struct {
    action_name: []const u8 = "ListRules",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_rules };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        rules: ?[]RuleSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const list_size_constraint_sets: struct {
    action_name: []const u8 = "ListSizeConstraintSets",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_size_constraint_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_size_constraint_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        size_constraint_sets: ?[]struct {
            size_constraint_set_id: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .size_constraint_set_id = "SizeConstraintSetId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .size_constraint_sets = "SizeConstraintSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const list_sql_injection_match_sets: struct {
    action_name: []const u8 = "ListSqlInjectionMatchSets",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sql_injection_match_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_sql_injection_match_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        sql_injection_match_sets: ?[]struct {
            sql_injection_match_set_id: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sql_injection_match_set_id = "SqlInjectionMatchSetId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .sql_injection_match_sets = "SqlInjectionMatchSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const list_subscribed_rule_groups: struct {
    action_name: []const u8 = "ListSubscribedRuleGroups",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_subscribed_rule_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_subscribed_rule_groups };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        rule_groups: ?[]struct {
            rule_group_id: []const u8,
            name: []const u8,
            metric_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_group_id = "RuleGroupId",
                    .name = "Name",
                    .metric_name = "MetricName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .rule_groups = "RuleGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFNonexistentItem,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        tag_info_for_resource: ?struct {
            resource_arn: ?[]const u8 = null,
            tag_list: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "ResourceARN",
                    .tag_list = "TagList",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .tag_info_for_resource = "TagInfoForResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFBadRequest,
        WAFInternalError,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const list_web_ac_ls: struct {
    action_name: []const u8 = "ListWebACLs",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_web_ac_ls) } {
            return .{ .service_metadata = service_metadata, .action = list_web_ac_ls };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        web_ac_ls: ?[]WebACLSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .web_ac_ls = "WebACLs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const list_xss_match_sets: struct {
    action_name: []const u8 = "ListXssMatchSets",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_xss_match_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_xss_match_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        xss_match_sets: ?[]struct {
            xss_match_set_id: []const u8,
            name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .xss_match_set_id = "XssMatchSetId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .xss_match_sets = "XssMatchSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
    },
} = .{};
pub const put_logging_configuration: struct {
    action_name: []const u8 = "PutLoggingConfiguration",
    Request: type = struct {
        logging_configuration: LoggingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFNonexistentItem,
        WAFServiceLinkedRoleError,
        WAFStaleData,
    },
} = .{};
pub const put_permission_policy: struct {
    action_name: []const u8 = "PutPermissionPolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_permission_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_permission_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidPermissionPolicy,
        WAFNonexistentItem,
        WAFStaleData,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFBadRequest,
        WAFInternalError,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFBadRequest,
        WAFInternalError,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const update_byte_match_set: struct {
    action_name: []const u8 = "UpdateByteMatchSet",
    Request: type = struct {
        byte_match_set_id: []const u8,
        change_token: []const u8,
        updates: []struct {
            action: []const u8,
            byte_match_tuple: ByteMatchTuple,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .byte_match_tuple = "ByteMatchTuple",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .byte_match_set_id = "ByteMatchSetId",
                .change_token = "ChangeToken",
                .updates = "Updates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_byte_match_set) } {
            return .{ .service_metadata = service_metadata, .action = update_byte_match_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFStaleData,
    },
} = .{};
pub const update_geo_match_set: struct {
    action_name: []const u8 = "UpdateGeoMatchSet",
    Request: type = struct {
        geo_match_set_id: []const u8,
        change_token: []const u8,
        updates: []struct {
            action: []const u8,
            geo_match_constraint: GeoMatchConstraint,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .geo_match_constraint = "GeoMatchConstraint",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .geo_match_set_id = "GeoMatchSetId",
                .change_token = "ChangeToken",
                .updates = "Updates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_geo_match_set) } {
            return .{ .service_metadata = service_metadata, .action = update_geo_match_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const update_ip_set: struct {
    action_name: []const u8 = "UpdateIPSet",
    Request: type = struct {
        ip_set_id: []const u8,
        change_token: []const u8,
        updates: []struct {
            action: []const u8,
            ip_set_descriptor: IPSetDescriptor,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .ip_set_descriptor = "IPSetDescriptor",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_set_id = "IPSetId",
                .change_token = "ChangeToken",
                .updates = "Updates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = update_ip_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const update_rate_based_rule: struct {
    action_name: []const u8 = "UpdateRateBasedRule",
    Request: type = struct {
        rule_id: []const u8,
        change_token: []const u8,
        updates: []RuleUpdate,
        rate_limit: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_id = "RuleId",
                .change_token = "ChangeToken",
                .updates = "Updates",
                .rate_limit = "RateLimit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rate_based_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_rate_based_rule };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const update_regex_match_set: struct {
    action_name: []const u8 = "UpdateRegexMatchSet",
    Request: type = struct {
        regex_match_set_id: []const u8,
        updates: []struct {
            action: []const u8,
            regex_match_tuple: RegexMatchTuple,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .regex_match_tuple = "RegexMatchTuple",
                };
                return @field(mappings, field_name);
            }
        },
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_match_set_id = "RegexMatchSetId",
                .updates = "Updates",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_regex_match_set) } {
            return .{ .service_metadata = service_metadata, .action = update_regex_match_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDisallowedName,
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFStaleData,
    },
} = .{};
pub const update_regex_pattern_set: struct {
    action_name: []const u8 = "UpdateRegexPatternSet",
    Request: type = struct {
        regex_pattern_set_id: []const u8,
        updates: []struct {
            action: []const u8,
            regex_pattern_string: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .regex_pattern_string = "RegexPatternString",
                };
                return @field(mappings, field_name);
            }
        },
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_pattern_set_id = "RegexPatternSetId",
                .updates = "Updates",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = update_regex_pattern_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFInvalidRegexPattern,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFStaleData,
    },
} = .{};
pub const update_rule: struct {
    action_name: []const u8 = "UpdateRule",
    Request: type = struct {
        rule_id: []const u8,
        change_token: []const u8,
        updates: []RuleUpdate,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_id = "RuleId",
                .change_token = "ChangeToken",
                .updates = "Updates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_rule };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const update_rule_group: struct {
    action_name: []const u8 = "UpdateRuleGroup",
    Request: type = struct {
        rule_group_id: []const u8,
        updates: []struct {
            action: []const u8,
            activated_rule: ActivatedRule,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .activated_rule = "ActivatedRule",
                };
                return @field(mappings, field_name);
            }
        },
        change_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group_id = "RuleGroupId",
                .updates = "Updates",
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = update_rule_group };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFStaleData,
    },
} = .{};
pub const update_size_constraint_set: struct {
    action_name: []const u8 = "UpdateSizeConstraintSet",
    Request: type = struct {
        size_constraint_set_id: []const u8,
        change_token: []const u8,
        updates: []struct {
            action: []const u8,
            size_constraint: SizeConstraint,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .size_constraint = "SizeConstraint",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .size_constraint_set_id = "SizeConstraintSetId",
                .change_token = "ChangeToken",
                .updates = "Updates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_size_constraint_set) } {
            return .{ .service_metadata = service_metadata, .action = update_size_constraint_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
    },
} = .{};
pub const update_sql_injection_match_set: struct {
    action_name: []const u8 = "UpdateSqlInjectionMatchSet",
    Request: type = struct {
        sql_injection_match_set_id: []const u8,
        change_token: []const u8,
        updates: []struct {
            action: []const u8,
            sql_injection_match_tuple: SqlInjectionMatchTuple,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .sql_injection_match_tuple = "SqlInjectionMatchTuple",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sql_injection_match_set_id = "SqlInjectionMatchSetId",
                .change_token = "ChangeToken",
                .updates = "Updates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sql_injection_match_set) } {
            return .{ .service_metadata = service_metadata, .action = update_sql_injection_match_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFStaleData,
    },
} = .{};
pub const update_web_acl: struct {
    action_name: []const u8 = "UpdateWebACL",
    Request: type = struct {
        web_acl_id: []const u8,
        change_token: []const u8,
        updates: ?[]struct {
            action: []const u8,
            activated_rule: ActivatedRule,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .activated_rule = "ActivatedRule",
                };
                return @field(mappings, field_name);
            }
        } = null,
        default_action: ?WafAction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_id = "WebACLId",
                .change_token = "ChangeToken",
                .updates = "Updates",
                .default_action = "DefaultAction",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = update_web_acl };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFReferencedItem,
        WAFStaleData,
        WAFSubscriptionNotFound,
    },
} = .{};
pub const update_xss_match_set: struct {
    action_name: []const u8 = "UpdateXssMatchSet",
    Request: type = struct {
        xss_match_set_id: []const u8,
        change_token: []const u8,
        updates: []struct {
            action: []const u8,
            xss_match_tuple: XssMatchTuple,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action = "Action",
                    .xss_match_tuple = "XssMatchTuple",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .xss_match_set_id = "XssMatchSetId",
                .change_token = "ChangeToken",
                .updates = "Updates",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_xss_match_set) } {
            return .{ .service_metadata = service_metadata, .action = update_xss_match_set };
        }
    },
    Response: type = struct {
        change_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_token = "ChangeToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidAccount,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentContainer,
        WAFNonexistentItem,
        WAFStaleData,
    },
} = .{};

pub const XssMatchTuple = struct {
    field_to_match: FieldToMatch,
    text_transformation: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .text_transformation = "TextTransformation",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldToMatch = struct {
    type: []const u8,
    data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .data = "Data",
        };
        return @field(mappings, field_name);
    }
};

pub const WafAction = struct {
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivatedRule = struct {
    priority: i64,
    rule_id: []const u8,
    action: ?WafAction = null,
    override_action: ?WafOverrideAction = null,
    type: ?[]const u8 = null,
    excluded_rules: ?[]ExcludedRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .priority = "Priority",
            .rule_id = "RuleId",
            .action = "Action",
            .override_action = "OverrideAction",
            .type = "Type",
            .excluded_rules = "ExcludedRules",
        };
        return @field(mappings, field_name);
    }
};

pub const ExcludedRule = struct {
    rule_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_id = "RuleId",
        };
        return @field(mappings, field_name);
    }
};

pub const WafOverrideAction = struct {
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const SqlInjectionMatchTuple = struct {
    field_to_match: FieldToMatch,
    text_transformation: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .text_transformation = "TextTransformation",
        };
        return @field(mappings, field_name);
    }
};

pub const SizeConstraint = struct {
    field_to_match: FieldToMatch,
    text_transformation: []const u8,
    comparison_operator: []const u8,
    size: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .text_transformation = "TextTransformation",
            .comparison_operator = "ComparisonOperator",
            .size = "Size",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleUpdate = struct {
    action: []const u8,
    predicate: Predicate,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .predicate = "Predicate",
        };
        return @field(mappings, field_name);
    }
};

pub const Predicate = struct {
    negated: bool,
    type: []const u8,
    data_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .negated = "Negated",
            .type = "Type",
            .data_id = "DataId",
        };
        return @field(mappings, field_name);
    }
};

pub const RegexMatchTuple = struct {
    field_to_match: FieldToMatch,
    text_transformation: []const u8,
    regex_pattern_set_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .text_transformation = "TextTransformation",
            .regex_pattern_set_id = "RegexPatternSetId",
        };
        return @field(mappings, field_name);
    }
};

pub const IPSetDescriptor = struct {
    type: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoMatchConstraint = struct {
    type: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ByteMatchTuple = struct {
    field_to_match: FieldToMatch,
    target_string: []const u8,
    text_transformation: []const u8,
    positional_constraint: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .target_string = "TargetString",
            .text_transformation = "TextTransformation",
            .positional_constraint = "PositionalConstraint",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingConfiguration = struct {
    resource_arn: []const u8,
    log_destination_configs: [][]const u8,
    redacted_fields: ?[]FieldToMatch = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .log_destination_configs = "LogDestinationConfigs",
            .redacted_fields = "RedactedFields",
        };
        return @field(mappings, field_name);
    }
};

pub const WebACLSummary = struct {
    web_acl_id: []const u8,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .web_acl_id = "WebACLId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleSummary = struct {
    rule_id: []const u8,
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_id = "RuleId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const XssMatchSet = struct {
    xss_match_set_id: []const u8,
    name: ?[]const u8 = null,
    xss_match_tuples: []XssMatchTuple,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .xss_match_set_id = "XssMatchSetId",
            .name = "Name",
            .xss_match_tuples = "XssMatchTuples",
        };
        return @field(mappings, field_name);
    }
};

pub const WebACL = struct {
    web_acl_id: []const u8,
    name: ?[]const u8 = null,
    metric_name: ?[]const u8 = null,
    default_action: WafAction,
    rules: []ActivatedRule,
    web_acl_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .web_acl_id = "WebACLId",
            .name = "Name",
            .metric_name = "MetricName",
            .default_action = "DefaultAction",
            .rules = "Rules",
            .web_acl_arn = "WebACLArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SqlInjectionMatchSet = struct {
    sql_injection_match_set_id: []const u8,
    name: ?[]const u8 = null,
    sql_injection_match_tuples: []SqlInjectionMatchTuple,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sql_injection_match_set_id = "SqlInjectionMatchSetId",
            .name = "Name",
            .sql_injection_match_tuples = "SqlInjectionMatchTuples",
        };
        return @field(mappings, field_name);
    }
};

pub const SizeConstraintSet = struct {
    size_constraint_set_id: []const u8,
    name: ?[]const u8 = null,
    size_constraints: []SizeConstraint,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .size_constraint_set_id = "SizeConstraintSetId",
            .name = "Name",
            .size_constraints = "SizeConstraints",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeWindow = struct {
    start_time: i64,
    end_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroup = struct {
    rule_group_id: []const u8,
    name: ?[]const u8 = null,
    metric_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_group_id = "RuleGroupId",
            .name = "Name",
            .metric_name = "MetricName",
        };
        return @field(mappings, field_name);
    }
};

pub const Rule = struct {
    rule_id: []const u8,
    name: ?[]const u8 = null,
    metric_name: ?[]const u8 = null,
    predicates: []Predicate,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_id = "RuleId",
            .name = "Name",
            .metric_name = "MetricName",
            .predicates = "Predicates",
        };
        return @field(mappings, field_name);
    }
};

pub const RegexPatternSet = struct {
    regex_pattern_set_id: []const u8,
    name: ?[]const u8 = null,
    regex_pattern_strings: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .regex_pattern_set_id = "RegexPatternSetId",
            .name = "Name",
            .regex_pattern_strings = "RegexPatternStrings",
        };
        return @field(mappings, field_name);
    }
};

pub const RegexMatchSet = struct {
    regex_match_set_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    regex_match_tuples: ?[]RegexMatchTuple = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .regex_match_set_id = "RegexMatchSetId",
            .name = "Name",
            .regex_match_tuples = "RegexMatchTuples",
        };
        return @field(mappings, field_name);
    }
};

pub const RateBasedRule = struct {
    rule_id: []const u8,
    name: ?[]const u8 = null,
    metric_name: ?[]const u8 = null,
    match_predicates: []Predicate,
    rate_key: []const u8,
    rate_limit: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_id = "RuleId",
            .name = "Name",
            .metric_name = "MetricName",
            .match_predicates = "MatchPredicates",
            .rate_key = "RateKey",
            .rate_limit = "RateLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const IPSet = struct {
    ip_set_id: []const u8,
    name: ?[]const u8 = null,
    ip_set_descriptors: []IPSetDescriptor,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_set_id = "IPSetId",
            .name = "Name",
            .ip_set_descriptors = "IPSetDescriptors",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoMatchSet = struct {
    geo_match_set_id: []const u8,
    name: ?[]const u8 = null,
    geo_match_constraints: []GeoMatchConstraint,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .geo_match_set_id = "GeoMatchSetId",
            .name = "Name",
            .geo_match_constraints = "GeoMatchConstraints",
        };
        return @field(mappings, field_name);
    }
};

pub const ByteMatchSet = struct {
    byte_match_set_id: []const u8,
    name: ?[]const u8 = null,
    byte_match_tuples: []ByteMatchTuple,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .byte_match_set_id = "ByteMatchSetId",
            .name = "Name",
            .byte_match_tuples = "ByteMatchTuples",
        };
        return @field(mappings, field_name);
    }
};
