const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-07-29";
pub const sdk_id: []const u8 = "WAFV2";
pub const arn_namespace: ?[]const u8 = "wafv2";
pub const endpoint_prefix: []const u8 = "wafv2";
pub const sigv4_name: []const u8 = "wafv2";
pub const name: []const u8 = "AWSWAF_20190729";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-07-29",
    sdk_id: []const u8 = "WAFV2",
    arn_namespace: ?[]const u8 = "wafv2",
    endpoint_prefix: []const u8 = "wafv2",
    sigv4_name: []const u8 = "wafv2",
    name: []const u8 = "AWSWAF_20190729",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_web_acl: struct {
    action_name: []const u8 = "AssociateWebACL",
    Request: type = struct {
        web_acl_arn: []const u8,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_arn = "WebACLArn",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = associate_web_acl };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFUnavailableEntity,
    },
} = .{};
pub const check_capacity: struct {
    action_name: []const u8 = "CheckCapacity",
    Request: type = struct {
        scope: []const u8,
        rules: []Rule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(check_capacity) } {
            return .{ .service_metadata = service_metadata, .action = check_capacity };
        }
    },
    Response: type = struct {
        capacity: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity = "Capacity",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFExpiredManagedRuleGroupVersion,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFInvalidResource,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFSubscriptionNotFound,
        WAFUnavailableEntity,
    },
} = .{};
pub const create_api_key: struct {
    action_name: []const u8 = "CreateAPIKey",
    Request: type = struct {
        scope: []const u8,
        token_domains: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .token_domains = "TokenDomains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_api_key) } {
            return .{ .service_metadata = service_metadata, .action = create_api_key };
        }
    },
    Response: type = struct {
        api_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_key = "APIKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
    },
} = .{};
pub const create_ip_set: struct {
    action_name: []const u8 = "CreateIPSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        description: ?[]const u8 = null,
        ip_address_version: []const u8,
        addresses: [][]const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .description = "Description",
                .ip_address_version = "IPAddressVersion",
                .addresses = "Addresses",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = create_ip_set };
        }
    },
    Response: type = struct {
        summary: ?IPSetSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "Summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const create_regex_pattern_set: struct {
    action_name: []const u8 = "CreateRegexPatternSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        description: ?[]const u8 = null,
        regular_expression_list: []Regex,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .description = "Description",
                .regular_expression_list = "RegularExpressionList",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = create_regex_pattern_set };
        }
    },
    Response: type = struct {
        summary: ?RegexPatternSetSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "Summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const create_rule_group: struct {
    action_name: []const u8 = "CreateRuleGroup",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        capacity: i64,
        description: ?[]const u8 = null,
        rules: ?[]Rule = null,
        visibility_config: VisibilityConfig,
        tags: ?[]Tag = null,
        custom_response_bodies: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CustomResponseBody = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .capacity = "Capacity",
                .description = "Description",
                .rules = "Rules",
                .visibility_config = "VisibilityConfig",
                .tags = "Tags",
                .custom_response_bodies = "CustomResponseBodies",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_response_bodies", field_name))
                return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = create_rule_group };
        }
    },
    Response: type = struct {
        summary: ?RuleGroupSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "Summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFSubscriptionNotFound,
        WAFTagOperation,
        WAFTagOperationInternalError,
        WAFUnavailableEntity,
    },
} = .{};
pub const create_web_acl: struct {
    action_name: []const u8 = "CreateWebACL",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        default_action: DefaultAction,
        description: ?[]const u8 = null,
        rules: ?[]Rule = null,
        visibility_config: VisibilityConfig,
        tags: ?[]Tag = null,
        custom_response_bodies: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CustomResponseBody = null,
        } = null,
        captcha_config: ?CaptchaConfig = null,
        challenge_config: ?ChallengeConfig = null,
        token_domains: ?[][]const u8 = null,
        association_config: ?AssociationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .default_action = "DefaultAction",
                .description = "Description",
                .rules = "Rules",
                .visibility_config = "VisibilityConfig",
                .tags = "Tags",
                .custom_response_bodies = "CustomResponseBodies",
                .captcha_config = "CaptchaConfig",
                .challenge_config = "ChallengeConfig",
                .token_domains = "TokenDomains",
                .association_config = "AssociationConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_response_bodies", field_name))
                return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = create_web_acl };
        }
    },
    Response: type = struct {
        summary: ?WebACLSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "Summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFConfigurationWarning,
        WAFDuplicateItem,
        WAFExpiredManagedRuleGroupVersion,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFInvalidResource,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFSubscriptionNotFound,
        WAFTagOperation,
        WAFTagOperationInternalError,
        WAFUnavailableEntity,
    },
} = .{};
pub const delete_api_key: struct {
    action_name: []const u8 = "DeleteAPIKey",
    Request: type = struct {
        scope: []const u8,
        api_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .api_key = "APIKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_api_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_api_key };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const delete_firewall_manager_rule_groups: struct {
    action_name: []const u8 = "DeleteFirewallManagerRuleGroups",
    Request: type = struct {
        web_acl_arn: []const u8,
        web_acl_lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_arn = "WebACLArn",
                .web_acl_lock_token = "WebACLLockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_firewall_manager_rule_groups) } {
            return .{ .service_metadata = service_metadata, .action = delete_firewall_manager_rule_groups };
        }
    },
    Response: type = struct {
        next_web_acl_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_web_acl_lock_token = "NextWebACLLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const delete_ip_set: struct {
    action_name: []const u8 = "DeleteIPSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_ip_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFAssociatedItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const delete_logging_configuration: struct {
    action_name: []const u8 = "DeleteLoggingConfiguration",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_logging_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const delete_permission_policy: struct {
    action_name: []const u8 = "DeletePermissionPolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_permission_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_permission_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const delete_regex_pattern_set: struct {
    action_name: []const u8 = "DeleteRegexPatternSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_regex_pattern_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFAssociatedItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const delete_rule_group: struct {
    action_name: []const u8 = "DeleteRuleGroup",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_rule_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFAssociatedItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const delete_web_acl: struct {
    action_name: []const u8 = "DeleteWebACL",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = delete_web_acl };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFAssociatedItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const describe_all_managed_products: struct {
    action_name: []const u8 = "DescribeAllManagedProducts",
    Request: type = struct {
        scope: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_all_managed_products) } {
            return .{ .service_metadata = service_metadata, .action = describe_all_managed_products };
        }
    },
    Response: type = struct {
        managed_products: ?[]ManagedProductDescriptor = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .managed_products = "ManagedProducts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
    },
} = .{};
pub const describe_managed_products_by_vendor: struct {
    action_name: []const u8 = "DescribeManagedProductsByVendor",
    Request: type = struct {
        vendor_name: []const u8,
        scope: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vendor_name = "VendorName",
                .scope = "Scope",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_managed_products_by_vendor) } {
            return .{ .service_metadata = service_metadata, .action = describe_managed_products_by_vendor };
        }
    },
    Response: type = struct {
        managed_products: ?[]ManagedProductDescriptor = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .managed_products = "ManagedProducts",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const describe_managed_rule_group: struct {
    action_name: []const u8 = "DescribeManagedRuleGroup",
    Request: type = struct {
        vendor_name: []const u8,
        name: []const u8,
        scope: []const u8,
        version_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vendor_name = "VendorName",
                .name = "Name",
                .scope = "Scope",
                .version_name = "VersionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_managed_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_managed_rule_group };
        }
    },
    Response: type = struct {
        version_name: ?[]const u8 = null,
        sns_topic_arn: ?[]const u8 = null,
        capacity: ?i64 = null,
        rules: ?[]struct {
            name: ?[]const u8 = null,
            action: ?RuleAction = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .action = "Action",
                };
                return @field(mappings, field_name);
            }
        } = null,
        label_namespace: ?[]const u8 = null,
        available_labels: ?[]LabelSummary = null,
        consumed_labels: ?[]LabelSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version_name = "VersionName",
                .sns_topic_arn = "SnsTopicArn",
                .capacity = "Capacity",
                .rules = "Rules",
                .label_namespace = "LabelNamespace",
                .available_labels = "AvailableLabels",
                .consumed_labels = "ConsumedLabels",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFExpiredManagedRuleGroupVersion,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFInvalidResource,
        WAFNonexistentItem,
    },
} = .{};
pub const disassociate_web_acl: struct {
    action_name: []const u8 = "DisassociateWebACL",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_web_acl };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const generate_mobile_sdk_release_url: struct {
    action_name: []const u8 = "GenerateMobileSdkReleaseUrl",
    Request: type = struct {
        platform: []const u8,
        release_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform = "Platform",
                .release_version = "ReleaseVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_mobile_sdk_release_url) } {
            return .{ .service_metadata = service_metadata, .action = generate_mobile_sdk_release_url };
        }
    },
    Response: type = struct {
        url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .url = "Url",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_decrypted_api_key: struct {
    action_name: []const u8 = "GetDecryptedAPIKey",
    Request: type = struct {
        scope: []const u8,
        api_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .api_key = "APIKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_decrypted_api_key) } {
            return .{ .service_metadata = service_metadata, .action = get_decrypted_api_key };
        }
    },
    Response: type = struct {
        token_domains: ?[][]const u8 = null,
        creation_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token_domains = "TokenDomains",
                .creation_timestamp = "CreationTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFInvalidResource,
    },
} = .{};
pub const get_ip_set: struct {
    action_name: []const u8 = "GetIPSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = get_ip_set };
        }
    },
    Response: type = struct {
        ip_set: ?struct {
            name: []const u8,
            id: []const u8,
            arn: []const u8,
            description: ?[]const u8 = null,
            ip_address_version: []const u8,
            addresses: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .arn = "ARN",
                    .description = "Description",
                    .ip_address_version = "IPAddressVersion",
                    .addresses = "Addresses",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_set = "IPSet",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_logging_configuration: struct {
    action_name: []const u8 = "GetLoggingConfiguration",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_managed_rule_set: struct {
    action_name: []const u8 = "GetManagedRuleSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_managed_rule_set) } {
            return .{ .service_metadata = service_metadata, .action = get_managed_rule_set };
        }
    },
    Response: type = struct {
        managed_rule_set: ?struct {
            name: []const u8,
            id: []const u8,
            arn: []const u8,
            description: ?[]const u8 = null,
            published_versions: ?[]struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    associated_rule_group_arn: ?[]const u8 = null,
                    capacity: ?i64 = null,
                    forecasted_lifetime: ?i64 = null,
                    publish_timestamp: ?i64 = null,
                    last_update_timestamp: ?i64 = null,
                    expiry_timestamp: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .associated_rule_group_arn = "AssociatedRuleGroupArn",
                            .capacity = "Capacity",
                            .forecasted_lifetime = "ForecastedLifetime",
                            .publish_timestamp = "PublishTimestamp",
                            .last_update_timestamp = "LastUpdateTimestamp",
                            .expiry_timestamp = "ExpiryTimestamp",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
            } = null,
            recommended_version: ?[]const u8 = null,
            label_namespace: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .arn = "ARN",
                    .description = "Description",
                    .published_versions = "PublishedVersions",
                    .recommended_version = "RecommendedVersion",
                    .label_namespace = "LabelNamespace",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "published_versions", field_name))
                    return try serializeMap(self.published_versions, self.fieldNameFor("published_versions"), options, out_stream);
                return false;
            }
        } = null,
        lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .managed_rule_set = "ManagedRuleSet",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_mobile_sdk_release: struct {
    action_name: []const u8 = "GetMobileSdkRelease",
    Request: type = struct {
        platform: []const u8,
        release_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform = "Platform",
                .release_version = "ReleaseVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_mobile_sdk_release) } {
            return .{ .service_metadata = service_metadata, .action = get_mobile_sdk_release };
        }
    },
    Response: type = struct {
        mobile_sdk_release: ?struct {
            release_version: ?[]const u8 = null,
            timestamp: ?i64 = null,
            release_notes: ?[]const u8 = null,
            tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .release_version = "ReleaseVersion",
                    .timestamp = "Timestamp",
                    .release_notes = "ReleaseNotes",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mobile_sdk_release = "MobileSdkRelease",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_permission_policy: struct {
    action_name: []const u8 = "GetPermissionPolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_permission_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_permission_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_rate_based_statement_managed_keys: struct {
    action_name: []const u8 = "GetRateBasedStatementManagedKeys",
    Request: type = struct {
        scope: []const u8,
        web_acl_name: []const u8,
        web_acl_id: []const u8,
        rule_group_rule_name: ?[]const u8 = null,
        rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .web_acl_name = "WebACLName",
                .web_acl_id = "WebACLId",
                .rule_group_rule_name = "RuleGroupRuleName",
                .rule_name = "RuleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rate_based_statement_managed_keys) } {
            return .{ .service_metadata = service_metadata, .action = get_rate_based_statement_managed_keys };
        }
    },
    Response: type = struct {
        managed_keys_ipv4: ?RateBasedStatementManagedKeysIPSet = null,
        managed_keys_ipv6: ?RateBasedStatementManagedKeysIPSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .managed_keys_ipv4 = "ManagedKeysIPV4",
                .managed_keys_ipv6 = "ManagedKeysIPV6",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFUnsupportedAggregateKeyType,
    },
} = .{};
pub const get_regex_pattern_set: struct {
    action_name: []const u8 = "GetRegexPatternSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = get_regex_pattern_set };
        }
    },
    Response: type = struct {
        regex_pattern_set: ?struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            regular_expression_list: ?[]Regex = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .arn = "ARN",
                    .description = "Description",
                    .regular_expression_list = "RegularExpressionList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_pattern_set = "RegexPatternSet",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_rule_group: struct {
    action_name: []const u8 = "GetRuleGroup",
    Request: type = struct {
        name: ?[]const u8 = null,
        scope: ?[]const u8 = null,
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .arn = "ARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = get_rule_group };
        }
    },
    Response: type = struct {
        rule_group: ?struct {
            name: []const u8,
            id: []const u8,
            capacity: i64,
            arn: []const u8,
            description: ?[]const u8 = null,
            rules: ?[]Rule = null,
            visibility_config: VisibilityConfig,
            label_namespace: ?[]const u8 = null,
            custom_response_bodies: ?[]struct {
                key: ?[]const u8 = null,
                value: ?CustomResponseBody = null,
            } = null,
            available_labels: ?[]LabelSummary = null,
            consumed_labels: ?[]LabelSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .capacity = "Capacity",
                    .arn = "ARN",
                    .description = "Description",
                    .rules = "Rules",
                    .visibility_config = "VisibilityConfig",
                    .label_namespace = "LabelNamespace",
                    .custom_response_bodies = "CustomResponseBodies",
                    .available_labels = "AvailableLabels",
                    .consumed_labels = "ConsumedLabels",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "custom_response_bodies", field_name))
                    return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
                return false;
            }
        } = null,
        lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group = "RuleGroup",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_sampled_requests: struct {
    action_name: []const u8 = "GetSampledRequests",
    Request: type = struct {
        web_acl_arn: []const u8,
        rule_metric_name: []const u8,
        scope: []const u8,
        time_window: TimeWindow,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_arn = "WebAclArn",
                .rule_metric_name = "RuleMetricName",
                .scope = "Scope",
                .time_window = "TimeWindow",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sampled_requests) } {
            return .{ .service_metadata = service_metadata, .action = get_sampled_requests };
        }
    },
    Response: type = struct {
        sampled_requests: ?[]struct {
            request: struct {
                client_ip: ?[]const u8 = null,
                country: ?[]const u8 = null,
                uri: ?[]const u8 = null,
                method: ?[]const u8 = null,
                http_version: ?[]const u8 = null,
                headers: ?[]HTTPHeader = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .client_ip = "ClientIP",
                        .country = "Country",
                        .uri = "URI",
                        .method = "Method",
                        .http_version = "HTTPVersion",
                        .headers = "Headers",
                    };
                    return @field(mappings, field_name);
                }
            },
            weight: i64,
            timestamp: ?i64 = null,
            action: ?[]const u8 = null,
            rule_name_within_rule_group: ?[]const u8 = null,
            request_headers_inserted: ?[]HTTPHeader = null,
            response_code_sent: ?i64 = null,
            labels: ?[]Label = null,
            captcha_response: ?struct {
                response_code: ?i64 = null,
                solve_timestamp: ?i64 = null,
                failure_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .response_code = "ResponseCode",
                        .solve_timestamp = "SolveTimestamp",
                        .failure_reason = "FailureReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            challenge_response: ?struct {
                response_code: ?i64 = null,
                solve_timestamp: ?i64 = null,
                failure_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .response_code = "ResponseCode",
                        .solve_timestamp = "SolveTimestamp",
                        .failure_reason = "FailureReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            overridden_action: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .request = "Request",
                    .weight = "Weight",
                    .timestamp = "Timestamp",
                    .action = "Action",
                    .rule_name_within_rule_group = "RuleNameWithinRuleGroup",
                    .request_headers_inserted = "RequestHeadersInserted",
                    .response_code_sent = "ResponseCodeSent",
                    .labels = "Labels",
                    .captcha_response = "CaptchaResponse",
                    .challenge_response = "ChallengeResponse",
                    .overridden_action = "OverriddenAction",
                };
                return @field(mappings, field_name);
            }
        } = null,
        population_size: ?i64 = null,
        time_window: ?TimeWindow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampled_requests = "SampledRequests",
                .population_size = "PopulationSize",
                .time_window = "TimeWindow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_web_acl: struct {
    action_name: []const u8 = "GetWebACL",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = get_web_acl };
        }
    },
    Response: type = struct {
        web_acl: ?WebACL = null,
        lock_token: ?[]const u8 = null,
        application_integration_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl = "WebACL",
                .lock_token = "LockToken",
                .application_integration_url = "ApplicationIntegrationURL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_web_acl_for_resource: struct {
    action_name: []const u8 = "GetWebACLForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_web_acl_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = get_web_acl_for_resource };
        }
    },
    Response: type = struct {
        web_acl: ?WebACL = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl = "WebACL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFUnavailableEntity,
    },
} = .{};
pub const list_api_keys: struct {
    action_name: []const u8 = "ListAPIKeys",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_api_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_api_keys };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        api_key_summaries: ?[]struct {
            token_domains: ?[][]const u8 = null,
            api_key: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            version: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .token_domains = "TokenDomains",
                    .api_key = "APIKey",
                    .creation_timestamp = "CreationTimestamp",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }
        } = null,
        application_integration_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .api_key_summaries = "APIKeySummaries",
                .application_integration_url = "ApplicationIntegrationURL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFInvalidResource,
    },
} = .{};
pub const list_available_managed_rule_groups: struct {
    action_name: []const u8 = "ListAvailableManagedRuleGroups",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_available_managed_rule_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_available_managed_rule_groups };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        managed_rule_groups: ?[]struct {
            vendor_name: ?[]const u8 = null,
            name: ?[]const u8 = null,
            versioning_supported: ?bool = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vendor_name = "VendorName",
                    .name = "Name",
                    .versioning_supported = "VersioningSupported",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .managed_rule_groups = "ManagedRuleGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_available_managed_rule_group_versions: struct {
    action_name: []const u8 = "ListAvailableManagedRuleGroupVersions",
    Request: type = struct {
        vendor_name: []const u8,
        name: []const u8,
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vendor_name = "VendorName",
                .name = "Name",
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_available_managed_rule_group_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_available_managed_rule_group_versions };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        versions: ?[]struct {
            name: ?[]const u8 = null,
            last_update_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .last_update_timestamp = "LastUpdateTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        current_default_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .versions = "Versions",
                .current_default_version = "CurrentDefaultVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const list_ip_sets: struct {
    action_name: []const u8 = "ListIPSets",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ip_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_ip_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        ip_sets: ?[]IPSetSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .ip_sets = "IPSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_logging_configurations: struct {
    action_name: []const u8 = "ListLoggingConfigurations",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_logging_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_logging_configurations };
        }
    },
    Response: type = struct {
        logging_configurations: ?[]LoggingConfiguration = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configurations = "LoggingConfigurations",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_managed_rule_sets: struct {
    action_name: []const u8 = "ListManagedRuleSets",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_managed_rule_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_managed_rule_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        managed_rule_sets: ?[]struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            lock_token: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            label_namespace: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .description = "Description",
                    .lock_token = "LockToken",
                    .arn = "ARN",
                    .label_namespace = "LabelNamespace",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .managed_rule_sets = "ManagedRuleSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_mobile_sdk_releases: struct {
    action_name: []const u8 = "ListMobileSdkReleases",
    Request: type = struct {
        platform: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .platform = "Platform",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_mobile_sdk_releases) } {
            return .{ .service_metadata = service_metadata, .action = list_mobile_sdk_releases };
        }
    },
    Response: type = struct {
        release_summaries: ?[]struct {
            release_version: ?[]const u8 = null,
            timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .release_version = "ReleaseVersion",
                    .timestamp = "Timestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .release_summaries = "ReleaseSummaries",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_regex_pattern_sets: struct {
    action_name: []const u8 = "ListRegexPatternSets",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_regex_pattern_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_regex_pattern_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        regex_pattern_sets: ?[]RegexPatternSetSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .regex_pattern_sets = "RegexPatternSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_resources_for_web_acl: struct {
    action_name: []const u8 = "ListResourcesForWebACL",
    Request: type = struct {
        web_acl_arn: []const u8,
        resource_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_arn = "WebACLArn",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources_for_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = list_resources_for_web_acl };
        }
    },
    Response: type = struct {
        resource_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arns = "ResourceArns",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const list_rule_groups: struct {
    action_name: []const u8 = "ListRuleGroups",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rule_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_rule_groups };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        rule_groups: ?[]RuleGroupSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .rule_groups = "RuleGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        tag_info_for_resource: ?struct {
            resource_arn: ?[]const u8 = null,
            tag_list: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "ResourceARN",
                    .tag_list = "TagList",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .tag_info_for_resource = "TagInfoForResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const list_web_ac_ls: struct {
    action_name: []const u8 = "ListWebACLs",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_web_ac_ls) } {
            return .{ .service_metadata = service_metadata, .action = list_web_ac_ls };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        web_ac_ls: ?[]WebACLSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .web_ac_ls = "WebACLs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const put_logging_configuration: struct {
    action_name: []const u8 = "PutLoggingConfiguration",
    Request: type = struct {
        logging_configuration: LoggingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFLogDestinationPermissionIssue,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFServiceLinkedRoleError,
    },
} = .{};
pub const put_managed_rule_set_versions: struct {
    action_name: []const u8 = "PutManagedRuleSetVersions",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        lock_token: []const u8,
        recommended_version: ?[]const u8 = null,
        versions_to_publish: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                associated_rule_group_arn: ?[]const u8 = null,
                forecasted_lifetime: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .associated_rule_group_arn = "AssociatedRuleGroupArn",
                        .forecasted_lifetime = "ForecastedLifetime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .lock_token = "LockToken",
                .recommended_version = "RecommendedVersion",
                .versions_to_publish = "VersionsToPublish",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "versions_to_publish", field_name))
                return try serializeMap(self.versions_to_publish, self.fieldNameFor("versions_to_publish"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_managed_rule_set_versions) } {
            return .{ .service_metadata = service_metadata, .action = put_managed_rule_set_versions };
        }
    },
    Response: type = struct {
        next_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_lock_token = "NextLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const put_permission_policy: struct {
    action_name: []const u8 = "PutPermissionPolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_permission_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_permission_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFInvalidPermissionPolicy,
        WAFNonexistentItem,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const update_ip_set: struct {
    action_name: []const u8 = "UpdateIPSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        description: ?[]const u8 = null,
        addresses: [][]const u8,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .description = "Description",
                .addresses = "Addresses",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = update_ip_set };
        }
    },
    Response: type = struct {
        next_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_lock_token = "NextLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const update_managed_rule_set_version_expiry_date: struct {
    action_name: []const u8 = "UpdateManagedRuleSetVersionExpiryDate",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        lock_token: []const u8,
        version_to_expire: []const u8,
        expiry_timestamp: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .lock_token = "LockToken",
                .version_to_expire = "VersionToExpire",
                .expiry_timestamp = "ExpiryTimestamp",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_managed_rule_set_version_expiry_date) } {
            return .{ .service_metadata = service_metadata, .action = update_managed_rule_set_version_expiry_date };
        }
    },
    Response: type = struct {
        expiring_version: ?[]const u8 = null,
        expiry_timestamp: ?i64 = null,
        next_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .expiring_version = "ExpiringVersion",
                .expiry_timestamp = "ExpiryTimestamp",
                .next_lock_token = "NextLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const update_regex_pattern_set: struct {
    action_name: []const u8 = "UpdateRegexPatternSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        description: ?[]const u8 = null,
        regular_expression_list: []Regex,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .description = "Description",
                .regular_expression_list = "RegularExpressionList",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = update_regex_pattern_set };
        }
    },
    Response: type = struct {
        next_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_lock_token = "NextLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const update_rule_group: struct {
    action_name: []const u8 = "UpdateRuleGroup",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        description: ?[]const u8 = null,
        rules: ?[]Rule = null,
        visibility_config: VisibilityConfig,
        lock_token: []const u8,
        custom_response_bodies: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CustomResponseBody = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .description = "Description",
                .rules = "Rules",
                .visibility_config = "VisibilityConfig",
                .lock_token = "LockToken",
                .custom_response_bodies = "CustomResponseBodies",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_response_bodies", field_name))
                return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = update_rule_group };
        }
    },
    Response: type = struct {
        next_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_lock_token = "NextLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFConfigurationWarning,
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFSubscriptionNotFound,
        WAFUnavailableEntity,
    },
} = .{};
pub const update_web_acl: struct {
    action_name: []const u8 = "UpdateWebACL",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        default_action: DefaultAction,
        description: ?[]const u8 = null,
        rules: ?[]Rule = null,
        visibility_config: VisibilityConfig,
        lock_token: []const u8,
        custom_response_bodies: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CustomResponseBody = null,
        } = null,
        captcha_config: ?CaptchaConfig = null,
        challenge_config: ?ChallengeConfig = null,
        token_domains: ?[][]const u8 = null,
        association_config: ?AssociationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .default_action = "DefaultAction",
                .description = "Description",
                .rules = "Rules",
                .visibility_config = "VisibilityConfig",
                .lock_token = "LockToken",
                .custom_response_bodies = "CustomResponseBodies",
                .captcha_config = "CaptchaConfig",
                .challenge_config = "ChallengeConfig",
                .token_domains = "TokenDomains",
                .association_config = "AssociationConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_response_bodies", field_name))
                return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = update_web_acl };
        }
    },
    Response: type = struct {
        next_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_lock_token = "NextLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFConfigurationWarning,
        WAFDuplicateItem,
        WAFExpiredManagedRuleGroupVersion,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFInvalidResource,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFSubscriptionNotFound,
        WAFUnavailableEntity,
    },
} = .{};

pub const AssociationConfig = struct {
    request_body: ?[]struct {
        key: ?[]const u8 = null,
        value: ?RequestBodyAssociatedResourceTypeConfig = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .request_body = "RequestBody",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "request_body", field_name))
            return try serializeMap(self.request_body, self.fieldNameFor("request_body"), options, out_stream);
        return false;
    }
};

pub const RequestBodyAssociatedResourceTypeConfig = struct {
    default_size_inspection_limit: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_size_inspection_limit = "DefaultSizeInspectionLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const ChallengeConfig = struct {
    immunity_time_property: ?ImmunityTimeProperty = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .immunity_time_property = "ImmunityTimeProperty",
        };
        return @field(mappings, field_name);
    }
};

pub const ImmunityTimeProperty = struct {
    immunity_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .immunity_time = "ImmunityTime",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptchaConfig = struct {
    immunity_time_property: ?ImmunityTimeProperty = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .immunity_time_property = "ImmunityTimeProperty",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomResponseBody = struct {
    content_type: []const u8,
    content: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_type = "ContentType",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const VisibilityConfig = struct {
    sampled_requests_enabled: bool,
    cloud_watch_metrics_enabled: bool,
    metric_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sampled_requests_enabled = "SampledRequestsEnabled",
            .cloud_watch_metrics_enabled = "CloudWatchMetricsEnabled",
            .metric_name = "MetricName",
        };
        return @field(mappings, field_name);
    }
};

pub const Rule = struct {
    name: []const u8,
    priority: i64,
    statement: Statement,
    action: ?RuleAction = null,
    override_action: ?OverrideAction = null,
    rule_labels: ?[]Label = null,
    visibility_config: VisibilityConfig,
    captcha_config: ?CaptchaConfig = null,
    challenge_config: ?ChallengeConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .priority = "Priority",
            .statement = "Statement",
            .action = "Action",
            .override_action = "OverrideAction",
            .rule_labels = "RuleLabels",
            .visibility_config = "VisibilityConfig",
            .captcha_config = "CaptchaConfig",
            .challenge_config = "ChallengeConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const Label = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const OverrideAction = struct {
    count: ?CountAction = null,
    none: ?NoneAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .none = "None",
        };
        return @field(mappings, field_name);
    }
};

pub const NoneAction = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const CountAction = struct {
    custom_request_handling: ?CustomRequestHandling = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_request_handling = "CustomRequestHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomRequestHandling = struct {
    insert_headers: []CustomHTTPHeader,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insert_headers = "InsertHeaders",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomHTTPHeader = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleAction = struct {
    block: ?BlockAction = null,
    allow: ?AllowAction = null,
    count: ?CountAction = null,
    captcha: ?CaptchaAction = null,
    challenge: ?ChallengeAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block = "Block",
            .allow = "Allow",
            .count = "Count",
            .captcha = "Captcha",
            .challenge = "Challenge",
        };
        return @field(mappings, field_name);
    }
};

pub const ChallengeAction = struct {
    custom_request_handling: ?CustomRequestHandling = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_request_handling = "CustomRequestHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptchaAction = struct {
    custom_request_handling: ?CustomRequestHandling = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_request_handling = "CustomRequestHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const AllowAction = struct {
    custom_request_handling: ?CustomRequestHandling = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_request_handling = "CustomRequestHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const BlockAction = struct {
    custom_response: ?CustomResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_response = "CustomResponse",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomResponse = struct {
    response_code: i64,
    custom_response_body_key: ?[]const u8 = null,
    response_headers: ?[]CustomHTTPHeader = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .response_code = "ResponseCode",
            .custom_response_body_key = "CustomResponseBodyKey",
            .response_headers = "ResponseHeaders",
        };
        return @field(mappings, field_name);
    }
};

pub const Statement = struct {
    byte_match_statement: ?ByteMatchStatement = null,
    sqli_match_statement: ?SqliMatchStatement = null,
    xss_match_statement: ?XssMatchStatement = null,
    size_constraint_statement: ?SizeConstraintStatement = null,
    geo_match_statement: ?GeoMatchStatement = null,
    rule_group_reference_statement: ?RuleGroupReferenceStatement = null,
    ip_set_reference_statement: ?IPSetReferenceStatement = null,
    regex_pattern_set_reference_statement: ?RegexPatternSetReferenceStatement = null,
    rate_based_statement: ?RateBasedStatement = null,
    and_statement: ?AndStatement = null,
    or_statement: ?OrStatement = null,
    not_statement: ?NotStatement = null,
    managed_rule_group_statement: ?ManagedRuleGroupStatement = null,
    label_match_statement: ?LabelMatchStatement = null,
    regex_match_statement: ?RegexMatchStatement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .byte_match_statement = "ByteMatchStatement",
            .sqli_match_statement = "SqliMatchStatement",
            .xss_match_statement = "XssMatchStatement",
            .size_constraint_statement = "SizeConstraintStatement",
            .geo_match_statement = "GeoMatchStatement",
            .rule_group_reference_statement = "RuleGroupReferenceStatement",
            .ip_set_reference_statement = "IPSetReferenceStatement",
            .regex_pattern_set_reference_statement = "RegexPatternSetReferenceStatement",
            .rate_based_statement = "RateBasedStatement",
            .and_statement = "AndStatement",
            .or_statement = "OrStatement",
            .not_statement = "NotStatement",
            .managed_rule_group_statement = "ManagedRuleGroupStatement",
            .label_match_statement = "LabelMatchStatement",
            .regex_match_statement = "RegexMatchStatement",
        };
        return @field(mappings, field_name);
    }
};

pub const RegexMatchStatement = struct {
    regex_string: []const u8,
    field_to_match: FieldToMatch,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .regex_string = "RegexString",
            .field_to_match = "FieldToMatch",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const TextTransformation = struct {
    priority: i64,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .priority = "Priority",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldToMatch = struct {
    single_header: ?SingleHeader = null,
    single_query_argument: ?SingleQueryArgument = null,
    all_query_arguments: ?AllQueryArguments = null,
    uri_path: ?UriPath = null,
    query_string: ?QueryString = null,
    body: ?Body = null,
    method: ?Method = null,
    json_body: ?JsonBody = null,
    headers: ?Headers = null,
    cookies: ?Cookies = null,
    header_order: ?HeaderOrder = null,
    ja3_fingerprint: ?JA3Fingerprint = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .single_header = "SingleHeader",
            .single_query_argument = "SingleQueryArgument",
            .all_query_arguments = "AllQueryArguments",
            .uri_path = "UriPath",
            .query_string = "QueryString",
            .body = "Body",
            .method = "Method",
            .json_body = "JsonBody",
            .headers = "Headers",
            .cookies = "Cookies",
            .header_order = "HeaderOrder",
            .ja3_fingerprint = "JA3Fingerprint",
        };
        return @field(mappings, field_name);
    }
};

pub const JA3Fingerprint = struct {
    fallback_behavior: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fallback_behavior = "FallbackBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const HeaderOrder = struct {
    oversize_handling: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .oversize_handling = "OversizeHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const Cookies = struct {
    match_pattern: CookieMatchPattern,
    match_scope: []const u8,
    oversize_handling: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_pattern = "MatchPattern",
            .match_scope = "MatchScope",
            .oversize_handling = "OversizeHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const CookieMatchPattern = struct {
    all: ?All = null,
    included_cookies: ?[][]const u8 = null,
    excluded_cookies: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .all = "All",
            .included_cookies = "IncludedCookies",
            .excluded_cookies = "ExcludedCookies",
        };
        return @field(mappings, field_name);
    }
};

pub const All = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Headers = struct {
    match_pattern: HeaderMatchPattern,
    match_scope: []const u8,
    oversize_handling: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_pattern = "MatchPattern",
            .match_scope = "MatchScope",
            .oversize_handling = "OversizeHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const HeaderMatchPattern = struct {
    all: ?All = null,
    included_headers: ?[][]const u8 = null,
    excluded_headers: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .all = "All",
            .included_headers = "IncludedHeaders",
            .excluded_headers = "ExcludedHeaders",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonBody = struct {
    match_pattern: JsonMatchPattern,
    match_scope: []const u8,
    invalid_fallback_behavior: ?[]const u8 = null,
    oversize_handling: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_pattern = "MatchPattern",
            .match_scope = "MatchScope",
            .invalid_fallback_behavior = "InvalidFallbackBehavior",
            .oversize_handling = "OversizeHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonMatchPattern = struct {
    all: ?All = null,
    included_paths: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .all = "All",
            .included_paths = "IncludedPaths",
        };
        return @field(mappings, field_name);
    }
};

pub const Method = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Body = struct {
    oversize_handling: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .oversize_handling = "OversizeHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryString = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const UriPath = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const AllQueryArguments = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const SingleQueryArgument = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const SingleHeader = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelMatchStatement = struct {
    scope: []const u8,
    key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scope = "Scope",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const ManagedRuleGroupStatement = struct {
    vendor_name: []const u8,
    name: []const u8,
    version: ?[]const u8 = null,
    excluded_rules: ?[]ExcludedRule = null,
    scope_down_statement: ?Statement = null,
    managed_rule_group_configs: ?[]ManagedRuleGroupConfig = null,
    rule_action_overrides: ?[]RuleActionOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vendor_name = "VendorName",
            .name = "Name",
            .version = "Version",
            .excluded_rules = "ExcludedRules",
            .scope_down_statement = "ScopeDownStatement",
            .managed_rule_group_configs = "ManagedRuleGroupConfigs",
            .rule_action_overrides = "RuleActionOverrides",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleActionOverride = struct {
    name: []const u8,
    action_to_use: RuleAction,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .action_to_use = "ActionToUse",
        };
        return @field(mappings, field_name);
    }
};

pub const ManagedRuleGroupConfig = struct {
    login_path: ?[]const u8 = null,
    payload_type: ?[]const u8 = null,
    username_field: ?UsernameField = null,
    password_field: ?PasswordField = null,
    aws_managed_rules_bot_control_rule_set: ?AWSManagedRulesBotControlRuleSet = null,
    aws_managed_rules_atp_rule_set: ?AWSManagedRulesATPRuleSet = null,
    aws_managed_rules_acfp_rule_set: ?AWSManagedRulesACFPRuleSet = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .login_path = "LoginPath",
            .payload_type = "PayloadType",
            .username_field = "UsernameField",
            .password_field = "PasswordField",
            .aws_managed_rules_bot_control_rule_set = "AWSManagedRulesBotControlRuleSet",
            .aws_managed_rules_atp_rule_set = "AWSManagedRulesATPRuleSet",
            .aws_managed_rules_acfp_rule_set = "AWSManagedRulesACFPRuleSet",
        };
        return @field(mappings, field_name);
    }
};

pub const AWSManagedRulesACFPRuleSet = struct {
    creation_path: []const u8,
    registration_page_path: []const u8,
    request_inspection: RequestInspectionACFP,
    response_inspection: ?ResponseInspection = null,
    enable_regex_in_path: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_path = "CreationPath",
            .registration_page_path = "RegistrationPagePath",
            .request_inspection = "RequestInspection",
            .response_inspection = "ResponseInspection",
            .enable_regex_in_path = "EnableRegexInPath",
        };
        return @field(mappings, field_name);
    }
};

pub const ResponseInspection = struct {
    status_code: ?ResponseInspectionStatusCode = null,
    header: ?ResponseInspectionHeader = null,
    body_contains: ?ResponseInspectionBodyContains = null,
    json: ?ResponseInspectionJson = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "StatusCode",
            .header = "Header",
            .body_contains = "BodyContains",
            .json = "Json",
        };
        return @field(mappings, field_name);
    }
};

pub const ResponseInspectionJson = struct {
    identifier: []const u8,
    success_values: [][]const u8,
    failure_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
            .success_values = "SuccessValues",
            .failure_values = "FailureValues",
        };
        return @field(mappings, field_name);
    }
};

pub const ResponseInspectionBodyContains = struct {
    success_strings: [][]const u8,
    failure_strings: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .success_strings = "SuccessStrings",
            .failure_strings = "FailureStrings",
        };
        return @field(mappings, field_name);
    }
};

pub const ResponseInspectionHeader = struct {
    name: []const u8,
    success_values: [][]const u8,
    failure_values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .success_values = "SuccessValues",
            .failure_values = "FailureValues",
        };
        return @field(mappings, field_name);
    }
};

pub const ResponseInspectionStatusCode = struct {
    success_codes: []i64,
    failure_codes: []i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .success_codes = "SuccessCodes",
            .failure_codes = "FailureCodes",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestInspectionACFP = struct {
    payload_type: []const u8,
    username_field: ?UsernameField = null,
    password_field: ?PasswordField = null,
    email_field: ?EmailField = null,
    phone_number_fields: ?[]PhoneNumberField = null,
    address_fields: ?[]AddressField = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .payload_type = "PayloadType",
            .username_field = "UsernameField",
            .password_field = "PasswordField",
            .email_field = "EmailField",
            .phone_number_fields = "PhoneNumberFields",
            .address_fields = "AddressFields",
        };
        return @field(mappings, field_name);
    }
};

pub const AddressField = struct {
    identifier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberField = struct {
    identifier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
        };
        return @field(mappings, field_name);
    }
};

pub const EmailField = struct {
    identifier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
        };
        return @field(mappings, field_name);
    }
};

pub const PasswordField = struct {
    identifier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
        };
        return @field(mappings, field_name);
    }
};

pub const UsernameField = struct {
    identifier: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "Identifier",
        };
        return @field(mappings, field_name);
    }
};

pub const AWSManagedRulesATPRuleSet = struct {
    login_path: []const u8,
    request_inspection: ?RequestInspection = null,
    response_inspection: ?ResponseInspection = null,
    enable_regex_in_path: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .login_path = "LoginPath",
            .request_inspection = "RequestInspection",
            .response_inspection = "ResponseInspection",
            .enable_regex_in_path = "EnableRegexInPath",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestInspection = struct {
    payload_type: []const u8,
    username_field: UsernameField,
    password_field: PasswordField,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .payload_type = "PayloadType",
            .username_field = "UsernameField",
            .password_field = "PasswordField",
        };
        return @field(mappings, field_name);
    }
};

pub const AWSManagedRulesBotControlRuleSet = struct {
    inspection_level: []const u8,
    enable_machine_learning: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inspection_level = "InspectionLevel",
            .enable_machine_learning = "EnableMachineLearning",
        };
        return @field(mappings, field_name);
    }
};

pub const ExcludedRule = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const NotStatement = struct {
    statement: Statement,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statement = "Statement",
        };
        return @field(mappings, field_name);
    }
};

pub const OrStatement = struct {
    statements: []Statement,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statements = "Statements",
        };
        return @field(mappings, field_name);
    }
};

pub const AndStatement = struct {
    statements: []Statement,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statements = "Statements",
        };
        return @field(mappings, field_name);
    }
};

pub const RateBasedStatement = struct {
    limit: i64,
    evaluation_window_sec: ?i64 = null,
    aggregate_key_type: []const u8,
    scope_down_statement: ?Statement = null,
    forwarded_ip_config: ?ForwardedIPConfig = null,
    custom_keys: ?[]RateBasedStatementCustomKey = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .limit = "Limit",
            .evaluation_window_sec = "EvaluationWindowSec",
            .aggregate_key_type = "AggregateKeyType",
            .scope_down_statement = "ScopeDownStatement",
            .forwarded_ip_config = "ForwardedIPConfig",
            .custom_keys = "CustomKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const RateBasedStatementCustomKey = struct {
    header: ?RateLimitHeader = null,
    cookie: ?RateLimitCookie = null,
    query_argument: ?RateLimitQueryArgument = null,
    query_string: ?RateLimitQueryString = null,
    http_method: ?RateLimitHTTPMethod = null,
    forwarded_ip: ?RateLimitForwardedIP = null,
    ip: ?RateLimitIP = null,
    label_namespace: ?RateLimitLabelNamespace = null,
    uri_path: ?RateLimitUriPath = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header = "Header",
            .cookie = "Cookie",
            .query_argument = "QueryArgument",
            .query_string = "QueryString",
            .http_method = "HTTPMethod",
            .forwarded_ip = "ForwardedIP",
            .ip = "IP",
            .label_namespace = "LabelNamespace",
            .uri_path = "UriPath",
        };
        return @field(mappings, field_name);
    }
};

pub const RateLimitUriPath = struct {
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const RateLimitLabelNamespace = struct {
    namespace: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "Namespace",
        };
        return @field(mappings, field_name);
    }
};

pub const RateLimitIP = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const RateLimitForwardedIP = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const RateLimitHTTPMethod = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const RateLimitQueryString = struct {
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const RateLimitQueryArgument = struct {
    name: []const u8,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const RateLimitCookie = struct {
    name: []const u8,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const RateLimitHeader = struct {
    name: []const u8,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const ForwardedIPConfig = struct {
    header_name: []const u8,
    fallback_behavior: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_name = "HeaderName",
            .fallback_behavior = "FallbackBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const RegexPatternSetReferenceStatement = struct {
    arn: []const u8,
    field_to_match: FieldToMatch,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "ARN",
            .field_to_match = "FieldToMatch",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const IPSetReferenceStatement = struct {
    arn: []const u8,
    ip_set_forwarded_ip_config: ?IPSetForwardedIPConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "ARN",
            .ip_set_forwarded_ip_config = "IPSetForwardedIPConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const IPSetForwardedIPConfig = struct {
    header_name: []const u8,
    fallback_behavior: []const u8,
    position: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_name = "HeaderName",
            .fallback_behavior = "FallbackBehavior",
            .position = "Position",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupReferenceStatement = struct {
    arn: []const u8,
    excluded_rules: ?[]ExcludedRule = null,
    rule_action_overrides: ?[]RuleActionOverride = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "ARN",
            .excluded_rules = "ExcludedRules",
            .rule_action_overrides = "RuleActionOverrides",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoMatchStatement = struct {
    country_codes: ?[][]const u8 = null,
    forwarded_ip_config: ?ForwardedIPConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .country_codes = "CountryCodes",
            .forwarded_ip_config = "ForwardedIPConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const SizeConstraintStatement = struct {
    field_to_match: FieldToMatch,
    comparison_operator: []const u8,
    size: i64,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .comparison_operator = "ComparisonOperator",
            .size = "Size",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const XssMatchStatement = struct {
    field_to_match: FieldToMatch,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const SqliMatchStatement = struct {
    field_to_match: FieldToMatch,
    text_transformations: []TextTransformation,
    sensitivity_level: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .text_transformations = "TextTransformations",
            .sensitivity_level = "SensitivityLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const ByteMatchStatement = struct {
    search_string: []const u8,
    field_to_match: FieldToMatch,
    text_transformations: []TextTransformation,
    positional_constraint: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .search_string = "SearchString",
            .field_to_match = "FieldToMatch",
            .text_transformations = "TextTransformations",
            .positional_constraint = "PositionalConstraint",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultAction = struct {
    block: ?BlockAction = null,
    allow: ?AllowAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block = "Block",
            .allow = "Allow",
        };
        return @field(mappings, field_name);
    }
};

pub const Regex = struct {
    regex_string: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .regex_string = "RegexString",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingConfiguration = struct {
    resource_arn: []const u8,
    log_destination_configs: [][]const u8,
    redacted_fields: ?[]FieldToMatch = null,
    managed_by_firewall_manager: ?bool = null,
    logging_filter: ?LoggingFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .log_destination_configs = "LogDestinationConfigs",
            .redacted_fields = "RedactedFields",
            .managed_by_firewall_manager = "ManagedByFirewallManager",
            .logging_filter = "LoggingFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingFilter = struct {
    filters: []Filter,
    default_behavior: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filters = "Filters",
            .default_behavior = "DefaultBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    behavior: []const u8,
    requirement: []const u8,
    conditions: []Condition,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .behavior = "Behavior",
            .requirement = "Requirement",
            .conditions = "Conditions",
        };
        return @field(mappings, field_name);
    }
};

pub const Condition = struct {
    action_condition: ?ActionCondition = null,
    label_name_condition: ?LabelNameCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_condition = "ActionCondition",
            .label_name_condition = "LabelNameCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelNameCondition = struct {
    label_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .label_name = "LabelName",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionCondition = struct {
    action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
        };
        return @field(mappings, field_name);
    }
};

pub const WebACLSummary = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    lock_token: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .id = "Id",
            .description = "Description",
            .lock_token = "LockToken",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSummary = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    lock_token: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .id = "Id",
            .description = "Description",
            .lock_token = "LockToken",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const RegexPatternSetSummary = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    lock_token: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .id = "Id",
            .description = "Description",
            .lock_token = "LockToken",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const IPSetSummary = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    lock_token: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .id = "Id",
            .description = "Description",
            .lock_token = "LockToken",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const WebACL = struct {
    name: []const u8,
    id: []const u8,
    arn: []const u8,
    default_action: DefaultAction,
    description: ?[]const u8 = null,
    rules: ?[]Rule = null,
    visibility_config: VisibilityConfig,
    capacity: ?i64 = null,
    pre_process_firewall_manager_rule_groups: ?[]FirewallManagerRuleGroup = null,
    post_process_firewall_manager_rule_groups: ?[]FirewallManagerRuleGroup = null,
    managed_by_firewall_manager: ?bool = null,
    label_namespace: ?[]const u8 = null,
    custom_response_bodies: ?[]struct {
        key: ?[]const u8 = null,
        value: ?CustomResponseBody = null,
    } = null,
    captcha_config: ?CaptchaConfig = null,
    challenge_config: ?ChallengeConfig = null,
    token_domains: ?[][]const u8 = null,
    association_config: ?AssociationConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .id = "Id",
            .arn = "ARN",
            .default_action = "DefaultAction",
            .description = "Description",
            .rules = "Rules",
            .visibility_config = "VisibilityConfig",
            .capacity = "Capacity",
            .pre_process_firewall_manager_rule_groups = "PreProcessFirewallManagerRuleGroups",
            .post_process_firewall_manager_rule_groups = "PostProcessFirewallManagerRuleGroups",
            .managed_by_firewall_manager = "ManagedByFirewallManager",
            .label_namespace = "LabelNamespace",
            .custom_response_bodies = "CustomResponseBodies",
            .captcha_config = "CaptchaConfig",
            .challenge_config = "ChallengeConfig",
            .token_domains = "TokenDomains",
            .association_config = "AssociationConfig",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "custom_response_bodies", field_name))
            return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
        return false;
    }
};

pub const FirewallManagerRuleGroup = struct {
    name: []const u8,
    priority: i64,
    firewall_manager_statement: FirewallManagerStatement,
    override_action: OverrideAction,
    visibility_config: VisibilityConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .priority = "Priority",
            .firewall_manager_statement = "FirewallManagerStatement",
            .override_action = "OverrideAction",
            .visibility_config = "VisibilityConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const FirewallManagerStatement = struct {
    managed_rule_group_statement: ?ManagedRuleGroupStatement = null,
    rule_group_reference_statement: ?RuleGroupReferenceStatement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .managed_rule_group_statement = "ManagedRuleGroupStatement",
            .rule_group_reference_statement = "RuleGroupReferenceStatement",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeWindow = struct {
    start_time: i64,
    end_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const HTTPHeader = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelSummary = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const RateBasedStatementManagedKeysIPSet = struct {
    ip_address_version: ?[]const u8 = null,
    addresses: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address_version = "IPAddressVersion",
            .addresses = "Addresses",
        };
        return @field(mappings, field_name);
    }
};

pub const ManagedProductDescriptor = struct {
    vendor_name: ?[]const u8 = null,
    managed_rule_set_name: ?[]const u8 = null,
    product_id: ?[]const u8 = null,
    product_link: ?[]const u8 = null,
    product_title: ?[]const u8 = null,
    product_description: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    is_versioning_supported: ?bool = null,
    is_advanced_managed_rule_set: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vendor_name = "VendorName",
            .managed_rule_set_name = "ManagedRuleSetName",
            .product_id = "ProductId",
            .product_link = "ProductLink",
            .product_title = "ProductTitle",
            .product_description = "ProductDescription",
            .sns_topic_arn = "SnsTopicArn",
            .is_versioning_supported = "IsVersioningSupported",
            .is_advanced_managed_rule_set = "IsAdvancedManagedRuleSet",
        };
        return @field(mappings, field_name);
    }
};
