const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-03-31";
pub const sdk_id: []const u8 = "WellArchitected";
pub const arn_namespace: ?[]const u8 = "wellarchitected";
pub const endpoint_prefix: []const u8 = "wellarchitected";
pub const sigv4_name: []const u8 = "wellarchitected";
pub const name: []const u8 = "WellArchitectedApiServiceLambda";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-03-31",
    sdk_id: []const u8 = "WellArchitected",
    arn_namespace: ?[]const u8 = "wellarchitected",
    endpoint_prefix: []const u8 = "wellarchitected",
    sigv4_name: []const u8 = "wellarchitected",
    name: []const u8 = "WellArchitectedApiServiceLambda",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_lenses: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/associateLenses",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateLenses",
    Request: type = struct {
        workload_id: []const u8,
        lens_aliases: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_aliases = "LensAliases",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_lenses) } {
            return .{ .service_metadata = service_metadata, .action = associate_lenses };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_profiles: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/associateProfiles",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateProfiles",
    Request: type = struct {
        workload_id: []const u8,
        profile_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .profile_arns = "ProfileArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_profiles) } {
            return .{ .service_metadata = service_metadata, .action = associate_profiles };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_lens_share: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/lenses/{LensAlias}/shares",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLensShare",
    Request: type = struct {
        lens_alias: []const u8,
        shared_with: []const u8,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .shared_with = "SharedWith",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lens_share) } {
            return .{ .service_metadata = service_metadata, .action = create_lens_share };
        }
    },
    Response: type = struct {
        share_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_id = "ShareId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_lens_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/lenses/{LensAlias}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLensVersion",
    Request: type = struct {
        lens_alias: []const u8,
        lens_version: []const u8,
        is_major_version: ?bool = null,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .lens_version = "LensVersion",
                .is_major_version = "IsMajorVersion",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_lens_version) } {
            return .{ .service_metadata = service_metadata, .action = create_lens_version };
        }
    },
    Response: type = struct {
        lens_arn: ?[]const u8 = null,
        lens_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_arn = "LensArn",
                .lens_version = "LensVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_milestone: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloads/{WorkloadId}/milestones",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateMilestone",
    Request: type = struct {
        workload_id: []const u8,
        milestone_name: []const u8,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_name = "MilestoneName",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_milestone) } {
            return .{ .service_metadata = service_metadata, .action = create_milestone };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProfile",
    Request: type = struct {
        profile_name: []const u8,
        profile_description: []const u8,
        profile_questions: []ProfileQuestionUpdate,
        client_request_token: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name = "ProfileName",
                .profile_description = "ProfileDescription",
                .profile_questions = "ProfileQuestions",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_profile };
        }
    },
    Response: type = struct {
        profile_arn: ?[]const u8 = null,
        profile_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_arn = "ProfileArn",
                .profile_version = "ProfileVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_profile_share: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/profiles/{ProfileArn}/shares",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProfileShare",
    Request: type = struct {
        profile_arn: []const u8,
        shared_with: []const u8,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_arn = "ProfileArn",
                .shared_with = "SharedWith",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_profile_share) } {
            return .{ .service_metadata = service_metadata, .action = create_profile_share };
        }
    },
    Response: type = struct {
        share_id: ?[]const u8 = null,
        profile_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_id = "ShareId",
                .profile_arn = "ProfileArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_review_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/reviewTemplates",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateReviewTemplate",
    Request: type = struct {
        template_name: []const u8,
        description: []const u8,
        lenses: [][]const u8,
        notes: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_name = "TemplateName",
                .description = "Description",
                .lenses = "Lenses",
                .notes = "Notes",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_review_template) } {
            return .{ .service_metadata = service_metadata, .action = create_review_template };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_template_share: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/templates/shares/{TemplateArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTemplateShare",
    Request: type = struct {
        template_arn: []const u8,
        shared_with: []const u8,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .shared_with = "SharedWith",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_template_share) } {
            return .{ .service_metadata = service_metadata, .action = create_template_share };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,
        share_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .share_id = "ShareId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_workload: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloads",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorkload",
    Request: type = struct {
        workload_name: []const u8,
        description: []const u8,
        environment: []const u8,
        account_ids: ?[][]const u8 = null,
        aws_regions: ?[][]const u8 = null,
        non_aws_regions: ?[][]const u8 = null,
        pillar_priorities: ?[][]const u8 = null,
        architectural_design: ?[]const u8 = null,
        review_owner: ?[]const u8 = null,
        industry_type: ?[]const u8 = null,
        industry: ?[]const u8 = null,
        lenses: [][]const u8,
        notes: ?[]const u8 = null,
        client_request_token: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        discovery_config: ?WorkloadDiscoveryConfig = null,
        applications: ?[][]const u8 = null,
        profile_arns: ?[][]const u8 = null,
        review_template_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_name = "WorkloadName",
                .description = "Description",
                .environment = "Environment",
                .account_ids = "AccountIds",
                .aws_regions = "AwsRegions",
                .non_aws_regions = "NonAwsRegions",
                .pillar_priorities = "PillarPriorities",
                .architectural_design = "ArchitecturalDesign",
                .review_owner = "ReviewOwner",
                .industry_type = "IndustryType",
                .industry = "Industry",
                .lenses = "Lenses",
                .notes = "Notes",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
                .discovery_config = "DiscoveryConfig",
                .applications = "Applications",
                .profile_arns = "ProfileArns",
                .review_template_arns = "ReviewTemplateArns",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workload) } {
            return .{ .service_metadata = service_metadata, .action = create_workload };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        workload_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_arn = "WorkloadArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_workload_share: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloads/{WorkloadId}/shares",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateWorkloadShare",
    Request: type = struct {
        workload_id: []const u8,
        shared_with: []const u8,
        permission_type: []const u8,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .shared_with = "SharedWith",
                .permission_type = "PermissionType",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workload_share) } {
            return .{ .service_metadata = service_metadata, .action = create_workload_share };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        share_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .share_id = "ShareId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_lens: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/lenses/{LensAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLens",
    Request: type = struct {
        lens_alias: []const u8,
        client_request_token: []const u8,
        lens_status: []const u8,

        pub const http_query = .{
            .client_request_token = "ClientRequestToken",
            .lens_status = "LensStatus",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .client_request_token = "ClientRequestToken",
                .lens_status = "LensStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lens) } {
            return .{ .service_metadata = service_metadata, .action = delete_lens };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_lens_share: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/lenses/{LensAlias}/shares/{ShareId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLensShare",
    Request: type = struct {
        share_id: []const u8,
        lens_alias: []const u8,
        client_request_token: []const u8,

        pub const http_query = .{
            .client_request_token = "ClientRequestToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_id = "ShareId",
                .lens_alias = "LensAlias",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lens_share) } {
            return .{ .service_metadata = service_metadata, .action = delete_lens_share };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/profiles/{ProfileArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProfile",
    Request: type = struct {
        profile_arn: []const u8,
        client_request_token: []const u8,

        pub const http_query = .{
            .client_request_token = "ClientRequestToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_arn = "ProfileArn",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_profile_share: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/profiles/{ProfileArn}/shares/{ShareId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProfileShare",
    Request: type = struct {
        share_id: []const u8,
        profile_arn: []const u8,
        client_request_token: []const u8,

        pub const http_query = .{
            .client_request_token = "ClientRequestToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_id = "ShareId",
                .profile_arn = "ProfileArn",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile_share) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile_share };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_review_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/reviewTemplates/{TemplateArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteReviewTemplate",
    Request: type = struct {
        template_arn: []const u8,
        client_request_token: []const u8,

        pub const http_query = .{
            .client_request_token = "ClientRequestToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_review_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_review_template };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_template_share: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/templates/shares/{TemplateArn}/{ShareId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTemplateShare",
    Request: type = struct {
        share_id: []const u8,
        template_arn: []const u8,
        client_request_token: []const u8,

        pub const http_query = .{
            .client_request_token = "ClientRequestToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_id = "ShareId",
                .template_arn = "TemplateArn",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_template_share) } {
            return .{ .service_metadata = service_metadata, .action = delete_template_share };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_workload: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/workloads/{WorkloadId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorkload",
    Request: type = struct {
        workload_id: []const u8,
        client_request_token: []const u8,

        pub const http_query = .{
            .client_request_token = "ClientRequestToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workload) } {
            return .{ .service_metadata = service_metadata, .action = delete_workload };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_workload_share: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/workloads/{WorkloadId}/shares/{ShareId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteWorkloadShare",
    Request: type = struct {
        share_id: []const u8,
        workload_id: []const u8,
        client_request_token: []const u8,

        pub const http_query = .{
            .client_request_token = "ClientRequestToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_id = "ShareId",
                .workload_id = "WorkloadId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workload_share) } {
            return .{ .service_metadata = service_metadata, .action = delete_workload_share };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_lenses: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/disassociateLenses",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateLenses",
    Request: type = struct {
        workload_id: []const u8,
        lens_aliases: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_aliases = "LensAliases",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_lenses) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_lenses };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_profiles: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/disassociateProfiles",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateProfiles",
    Request: type = struct {
        workload_id: []const u8,
        profile_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .profile_arns = "ProfileArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_profiles) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_profiles };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const export_lens: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/lenses/{LensAlias}/export",
        .success_code = 200,
    };

    action_name: []const u8 = "ExportLens",
    Request: type = struct {
        lens_alias: []const u8,
        lens_version: ?[]const u8 = null,

        pub const http_query = .{
            .lens_version = "LensVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .lens_version = "LensVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_lens) } {
            return .{ .service_metadata = service_metadata, .action = export_lens };
        }
    },
    Response: type = struct {
        lens_json: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_json = "LensJSON",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_answer: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/answers/{QuestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAnswer",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        question_id: []const u8,
        milestone_number: ?i64 = null,

        pub const http_query = .{
            .milestone_number = "MilestoneNumber",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .question_id = "QuestionId",
                .milestone_number = "MilestoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_answer) } {
            return .{ .service_metadata = service_metadata, .action = get_answer };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_alias: ?[]const u8 = null,
        lens_arn: ?[]const u8 = null,
        answer: ?Answer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_alias = "LensAlias",
                .lens_arn = "LensArn",
                .answer = "Answer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_consolidated_report: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/consolidatedReport",
        .success_code = 200,
    };

    action_name: []const u8 = "GetConsolidatedReport",
    Request: type = struct {
        format: []const u8,
        include_shared_resources: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .format = "Format",
            .include_shared_resources = "IncludeSharedResources",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .format = "Format",
                .include_shared_resources = "IncludeSharedResources",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_consolidated_report) } {
            return .{ .service_metadata = service_metadata, .action = get_consolidated_report };
        }
    },
    Response: type = struct {
        metrics: ?[]struct {
            metric_type: ?[]const u8 = null,
            risk_counts: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            workload_id: ?[]const u8 = null,
            workload_name: ?[]const u8 = null,
            workload_arn: ?[]const u8 = null,
            updated_at: ?i64 = null,
            lenses: ?[]struct {
                lens_arn: ?[]const u8 = null,
                pillars: ?[]struct {
                    pillar_id: ?[]const u8 = null,
                    risk_counts: ?[]struct {
                        key: ?[]const u8 = null,
                        value: ?i64 = null,
                    } = null,
                    questions: ?[]struct {
                        question_id: ?[]const u8 = null,
                        risk: ?[]const u8 = null,
                        best_practices: ?[]struct {
                            choice_id: ?[]const u8 = null,
                            choice_title: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .choice_id = "ChoiceId",
                                    .choice_title = "ChoiceTitle",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .question_id = "QuestionId",
                                .risk = "Risk",
                                .best_practices = "BestPractices",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .pillar_id = "PillarId",
                            .risk_counts = "RiskCounts",
                            .questions = "Questions",
                        };
                        return @field(mappings, field_name);
                    }

                    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                        if (std.mem.eql(u8, "risk_counts", field_name))
                            return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
                        return false;
                    }
                } = null,
                risk_counts: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?i64 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .lens_arn = "LensArn",
                        .pillars = "Pillars",
                        .risk_counts = "RiskCounts",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "risk_counts", field_name))
                        return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
                    return false;
                }
            } = null,
            lenses_applied_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .metric_type = "MetricType",
                    .risk_counts = "RiskCounts",
                    .workload_id = "WorkloadId",
                    .workload_name = "WorkloadName",
                    .workload_arn = "WorkloadArn",
                    .updated_at = "UpdatedAt",
                    .lenses = "Lenses",
                    .lenses_applied_count = "LensesAppliedCount",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "risk_counts", field_name))
                    return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,
        base64_string: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metrics = "Metrics",
                .next_token = "NextToken",
                .base64_string = "Base64String",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_lens: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/lenses/{LensAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLens",
    Request: type = struct {
        lens_alias: []const u8,
        lens_version: ?[]const u8 = null,

        pub const http_query = .{
            .lens_version = "LensVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .lens_version = "LensVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lens) } {
            return .{ .service_metadata = service_metadata, .action = get_lens };
        }
    },
    Response: type = struct {
        lens: ?struct {
            lens_arn: ?[]const u8 = null,
            lens_version: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            share_invitation_id: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lens_arn = "LensArn",
                    .lens_version = "LensVersion",
                    .name = "Name",
                    .description = "Description",
                    .owner = "Owner",
                    .share_invitation_id = "ShareInvitationId",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens = "Lens",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_lens_review: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLensReview",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        milestone_number: ?i64 = null,

        pub const http_query = .{
            .milestone_number = "MilestoneNumber",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .milestone_number = "MilestoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lens_review) } {
            return .{ .service_metadata = service_metadata, .action = get_lens_review };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_review: ?LensReview = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_review = "LensReview",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_lens_review_report: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/report",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLensReviewReport",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        milestone_number: ?i64 = null,

        pub const http_query = .{
            .milestone_number = "MilestoneNumber",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .milestone_number = "MilestoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lens_review_report) } {
            return .{ .service_metadata = service_metadata, .action = get_lens_review_report };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_review_report: ?struct {
            lens_alias: ?[]const u8 = null,
            lens_arn: ?[]const u8 = null,
            base64_string: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lens_alias = "LensAlias",
                    .lens_arn = "LensArn",
                    .base64_string = "Base64String",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_review_report = "LensReviewReport",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_lens_version_difference: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/lenses/{LensAlias}/versionDifference",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLensVersionDifference",
    Request: type = struct {
        lens_alias: []const u8,
        base_lens_version: ?[]const u8 = null,
        target_lens_version: ?[]const u8 = null,

        pub const http_query = .{
            .base_lens_version = "BaseLensVersion",
            .target_lens_version = "TargetLensVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .base_lens_version = "BaseLensVersion",
                .target_lens_version = "TargetLensVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lens_version_difference) } {
            return .{ .service_metadata = service_metadata, .action = get_lens_version_difference };
        }
    },
    Response: type = struct {
        lens_alias: ?[]const u8 = null,
        lens_arn: ?[]const u8 = null,
        base_lens_version: ?[]const u8 = null,
        target_lens_version: ?[]const u8 = null,
        latest_lens_version: ?[]const u8 = null,
        version_differences: ?struct {
            pillar_differences: ?[]struct {
                pillar_id: ?[]const u8 = null,
                pillar_name: ?[]const u8 = null,
                difference_status: ?[]const u8 = null,
                question_differences: ?[]struct {
                    question_id: ?[]const u8 = null,
                    question_title: ?[]const u8 = null,
                    difference_status: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .question_id = "QuestionId",
                            .question_title = "QuestionTitle",
                            .difference_status = "DifferenceStatus",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pillar_id = "PillarId",
                        .pillar_name = "PillarName",
                        .difference_status = "DifferenceStatus",
                        .question_differences = "QuestionDifferences",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pillar_differences = "PillarDifferences",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .lens_arn = "LensArn",
                .base_lens_version = "BaseLensVersion",
                .target_lens_version = "TargetLensVersion",
                .latest_lens_version = "LatestLensVersion",
                .version_differences = "VersionDifferences",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_milestone: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/milestones/{MilestoneNumber}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMilestone",
    Request: type = struct {
        workload_id: []const u8,
        milestone_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_milestone) } {
            return .{ .service_metadata = service_metadata, .action = get_milestone };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone: ?struct {
            milestone_number: ?i64 = null,
            milestone_name: ?[]const u8 = null,
            recorded_at: ?i64 = null,
            workload: ?Workload = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .milestone_number = "MilestoneNumber",
                    .milestone_name = "MilestoneName",
                    .recorded_at = "RecordedAt",
                    .workload = "Workload",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone = "Milestone",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/profiles/{ProfileArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProfile",
    Request: type = struct {
        profile_arn: []const u8,
        profile_version: ?[]const u8 = null,

        pub const http_query = .{
            .profile_version = "ProfileVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_arn = "ProfileArn",
                .profile_version = "ProfileVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_profile };
        }
    },
    Response: type = struct {
        profile: ?Profile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile = "Profile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_profile_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/profileTemplate",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProfileTemplate",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_profile_template) } {
            return .{ .service_metadata = service_metadata, .action = get_profile_template };
        }
    },
    Response: type = struct {
        profile_template: ?struct {
            template_name: ?[]const u8 = null,
            template_questions: ?[]struct {
                question_id: ?[]const u8 = null,
                question_title: ?[]const u8 = null,
                question_description: ?[]const u8 = null,
                question_choices: ?[]struct {
                    choice_id: ?[]const u8 = null,
                    choice_title: ?[]const u8 = null,
                    choice_description: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .choice_id = "ChoiceId",
                            .choice_title = "ChoiceTitle",
                            .choice_description = "ChoiceDescription",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                min_selected_choices: ?i64 = null,
                max_selected_choices: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .question_id = "QuestionId",
                        .question_title = "QuestionTitle",
                        .question_description = "QuestionDescription",
                        .question_choices = "QuestionChoices",
                        .min_selected_choices = "MinSelectedChoices",
                        .max_selected_choices = "MaxSelectedChoices",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .template_name = "TemplateName",
                    .template_questions = "TemplateQuestions",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_template = "ProfileTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_review_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/reviewTemplates/{TemplateArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetReviewTemplate",
    Request: type = struct {
        template_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_review_template) } {
            return .{ .service_metadata = service_metadata, .action = get_review_template };
        }
    },
    Response: type = struct {
        review_template: ?ReviewTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .review_template = "ReviewTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_review_template_answer: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/reviewTemplates/{TemplateArn}/lensReviews/{LensAlias}/answers/{QuestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetReviewTemplateAnswer",
    Request: type = struct {
        template_arn: []const u8,
        lens_alias: []const u8,
        question_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_alias = "LensAlias",
                .question_id = "QuestionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_review_template_answer) } {
            return .{ .service_metadata = service_metadata, .action = get_review_template_answer };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,
        lens_alias: ?[]const u8 = null,
        answer: ?ReviewTemplateAnswer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_alias = "LensAlias",
                .answer = "Answer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_review_template_lens_review: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/reviewTemplates/{TemplateArn}/lensReviews/{LensAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetReviewTemplateLensReview",
    Request: type = struct {
        template_arn: []const u8,
        lens_alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_alias = "LensAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_review_template_lens_review) } {
            return .{ .service_metadata = service_metadata, .action = get_review_template_lens_review };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,
        lens_review: ?ReviewTemplateLensReview = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_review = "LensReview",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_workload: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWorkload",
    Request: type = struct {
        workload_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workload) } {
            return .{ .service_metadata = service_metadata, .action = get_workload };
        }
    },
    Response: type = struct {
        workload: ?Workload = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload = "Workload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const import_lens: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/importLens",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportLens",
    Request: type = struct {
        lens_alias: ?[]const u8 = null,
        json_string: []const u8,
        client_request_token: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .json_string = "JSONString",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_lens) } {
            return .{ .service_metadata = service_metadata, .action = import_lens };
        }
    },
    Response: type = struct {
        lens_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_arn = "LensArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_answers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/answers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnswers",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        pillar_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        question_priority: ?[]const u8 = null,

        pub const http_query = .{
            .pillar_id = "PillarId",
            .milestone_number = "MilestoneNumber",
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .question_priority = "QuestionPriority",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .pillar_id = "PillarId",
                .milestone_number = "MilestoneNumber",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .question_priority = "QuestionPriority",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_answers) } {
            return .{ .service_metadata = service_metadata, .action = list_answers };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_alias: ?[]const u8 = null,
        lens_arn: ?[]const u8 = null,
        answer_summaries: ?[]struct {
            question_id: ?[]const u8 = null,
            pillar_id: ?[]const u8 = null,
            question_title: ?[]const u8 = null,
            choices: ?[]Choice = null,
            selected_choices: ?[][]const u8 = null,
            choice_answer_summaries: ?[]ChoiceAnswerSummary = null,
            is_applicable: ?bool = null,
            risk: ?[]const u8 = null,
            reason: ?[]const u8 = null,
            question_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .question_id = "QuestionId",
                    .pillar_id = "PillarId",
                    .question_title = "QuestionTitle",
                    .choices = "Choices",
                    .selected_choices = "SelectedChoices",
                    .choice_answer_summaries = "ChoiceAnswerSummaries",
                    .is_applicable = "IsApplicable",
                    .risk = "Risk",
                    .reason = "Reason",
                    .question_type = "QuestionType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_alias = "LensAlias",
                .lens_arn = "LensArn",
                .answer_summaries = "AnswerSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_check_details: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloads/{WorkloadId}/checks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCheckDetails",
    Request: type = struct {
        workload_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        lens_arn: []const u8,
        pillar_id: []const u8,
        question_id: []const u8,
        choice_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .lens_arn = "LensArn",
                .pillar_id = "PillarId",
                .question_id = "QuestionId",
                .choice_id = "ChoiceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_check_details) } {
            return .{ .service_metadata = service_metadata, .action = list_check_details };
        }
    },
    Response: type = struct {
        check_details: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            provider: ?[]const u8 = null,
            lens_arn: ?[]const u8 = null,
            pillar_id: ?[]const u8 = null,
            question_id: ?[]const u8 = null,
            choice_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            flagged_resources: ?i64 = null,
            reason: ?[]const u8 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .description = "Description",
                    .provider = "Provider",
                    .lens_arn = "LensArn",
                    .pillar_id = "PillarId",
                    .question_id = "QuestionId",
                    .choice_id = "ChoiceId",
                    .status = "Status",
                    .account_id = "AccountId",
                    .flagged_resources = "FlaggedResources",
                    .reason = "Reason",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_details = "CheckDetails",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_check_summaries: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloads/{WorkloadId}/checkSummaries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCheckSummaries",
    Request: type = struct {
        workload_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        lens_arn: []const u8,
        pillar_id: []const u8,
        question_id: []const u8,
        choice_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .lens_arn = "LensArn",
                .pillar_id = "PillarId",
                .question_id = "QuestionId",
                .choice_id = "ChoiceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_check_summaries) } {
            return .{ .service_metadata = service_metadata, .action = list_check_summaries };
        }
    },
    Response: type = struct {
        check_summaries: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            provider: ?[]const u8 = null,
            description: ?[]const u8 = null,
            updated_at: ?i64 = null,
            lens_arn: ?[]const u8 = null,
            pillar_id: ?[]const u8 = null,
            question_id: ?[]const u8 = null,
            choice_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            account_summary: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .provider = "Provider",
                    .description = "Description",
                    .updated_at = "UpdatedAt",
                    .lens_arn = "LensArn",
                    .pillar_id = "PillarId",
                    .question_id = "QuestionId",
                    .choice_id = "ChoiceId",
                    .status = "Status",
                    .account_summary = "AccountSummary",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "account_summary", field_name))
                    return try serializeMap(self.account_summary, self.fieldNameFor("account_summary"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .check_summaries = "CheckSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_lenses: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/lenses",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLenses",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        lens_type: ?[]const u8 = null,
        lens_status: ?[]const u8 = null,
        lens_name: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .lens_type = "LensType",
            .lens_status = "LensStatus",
            .lens_name = "LensName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .lens_type = "LensType",
                .lens_status = "LensStatus",
                .lens_name = "LensName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lenses) } {
            return .{ .service_metadata = service_metadata, .action = list_lenses };
        }
    },
    Response: type = struct {
        lens_summaries: ?[]struct {
            lens_arn: ?[]const u8 = null,
            lens_alias: ?[]const u8 = null,
            lens_name: ?[]const u8 = null,
            lens_type: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            lens_version: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            lens_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lens_arn = "LensArn",
                    .lens_alias = "LensAlias",
                    .lens_name = "LensName",
                    .lens_type = "LensType",
                    .description = "Description",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                    .lens_version = "LensVersion",
                    .owner = "Owner",
                    .lens_status = "LensStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_summaries = "LensSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_lens_review_improvements: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/improvements",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLensReviewImprovements",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        pillar_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        question_priority: ?[]const u8 = null,

        pub const http_query = .{
            .pillar_id = "PillarId",
            .milestone_number = "MilestoneNumber",
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .question_priority = "QuestionPriority",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .pillar_id = "PillarId",
                .milestone_number = "MilestoneNumber",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .question_priority = "QuestionPriority",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lens_review_improvements) } {
            return .{ .service_metadata = service_metadata, .action = list_lens_review_improvements };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_alias: ?[]const u8 = null,
        lens_arn: ?[]const u8 = null,
        improvement_summaries: ?[]struct {
            question_id: ?[]const u8 = null,
            pillar_id: ?[]const u8 = null,
            question_title: ?[]const u8 = null,
            risk: ?[]const u8 = null,
            improvement_plan_url: ?[]const u8 = null,
            improvement_plans: ?[]struct {
                choice_id: ?[]const u8 = null,
                display_text: ?[]const u8 = null,
                improvement_plan_url: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .choice_id = "ChoiceId",
                        .display_text = "DisplayText",
                        .improvement_plan_url = "ImprovementPlanUrl",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .question_id = "QuestionId",
                    .pillar_id = "PillarId",
                    .question_title = "QuestionTitle",
                    .risk = "Risk",
                    .improvement_plan_url = "ImprovementPlanUrl",
                    .improvement_plans = "ImprovementPlans",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_alias = "LensAlias",
                .lens_arn = "LensArn",
                .improvement_summaries = "ImprovementSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_lens_reviews: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/lensReviews",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLensReviews",
    Request: type = struct {
        workload_id: []const u8,
        milestone_number: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .milestone_number = "MilestoneNumber",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lens_reviews) } {
            return .{ .service_metadata = service_metadata, .action = list_lens_reviews };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_number: ?i64 = null,
        lens_review_summaries: ?[]struct {
            lens_alias: ?[]const u8 = null,
            lens_arn: ?[]const u8 = null,
            lens_version: ?[]const u8 = null,
            lens_name: ?[]const u8 = null,
            lens_status: ?[]const u8 = null,
            updated_at: ?i64 = null,
            risk_counts: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            profiles: ?[]WorkloadProfile = null,
            prioritized_risk_counts: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lens_alias = "LensAlias",
                    .lens_arn = "LensArn",
                    .lens_version = "LensVersion",
                    .lens_name = "LensName",
                    .lens_status = "LensStatus",
                    .updated_at = "UpdatedAt",
                    .risk_counts = "RiskCounts",
                    .profiles = "Profiles",
                    .prioritized_risk_counts = "PrioritizedRiskCounts",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "risk_counts", field_name))
                    return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
                if (std.mem.eql(u8, "prioritized_risk_counts", field_name))
                    return try serializeMap(self.prioritized_risk_counts, self.fieldNameFor("prioritized_risk_counts"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_number = "MilestoneNumber",
                .lens_review_summaries = "LensReviewSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_lens_shares: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/lenses/{LensAlias}/shares",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLensShares",
    Request: type = struct {
        lens_alias: []const u8,
        shared_with_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .shared_with_prefix = "SharedWithPrefix",
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .status = "Status",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_alias = "LensAlias",
                .shared_with_prefix = "SharedWithPrefix",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lens_shares) } {
            return .{ .service_metadata = service_metadata, .action = list_lens_shares };
        }
    },
    Response: type = struct {
        lens_share_summaries: ?[]struct {
            share_id: ?[]const u8 = null,
            shared_with: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_id = "ShareId",
                    .shared_with = "SharedWith",
                    .status = "Status",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lens_share_summaries = "LensShareSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_milestones: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloads/{WorkloadId}/milestonesSummaries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMilestones",
    Request: type = struct {
        workload_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_milestones) } {
            return .{ .service_metadata = service_metadata, .action = list_milestones };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        milestone_summaries: ?[]struct {
            milestone_number: ?i64 = null,
            milestone_name: ?[]const u8 = null,
            recorded_at: ?i64 = null,
            workload_summary: ?WorkloadSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .milestone_number = "MilestoneNumber",
                    .milestone_name = "MilestoneName",
                    .recorded_at = "RecordedAt",
                    .workload_summary = "WorkloadSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .milestone_summaries = "MilestoneSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_notifications: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/notifications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNotifications",
    Request: type = struct {
        workload_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notifications) } {
            return .{ .service_metadata = service_metadata, .action = list_notifications };
        }
    },
    Response: type = struct {
        notification_summaries: ?[]struct {
            type: ?[]const u8 = null,
            lens_upgrade_summary: ?struct {
                workload_id: ?[]const u8 = null,
                workload_name: ?[]const u8 = null,
                lens_alias: ?[]const u8 = null,
                lens_arn: ?[]const u8 = null,
                current_lens_version: ?[]const u8 = null,
                latest_lens_version: ?[]const u8 = null,
                resource_arn: ?[]const u8 = null,
                resource_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .workload_id = "WorkloadId",
                        .workload_name = "WorkloadName",
                        .lens_alias = "LensAlias",
                        .lens_arn = "LensArn",
                        .current_lens_version = "CurrentLensVersion",
                        .latest_lens_version = "LatestLensVersion",
                        .resource_arn = "ResourceArn",
                        .resource_name = "ResourceName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .lens_upgrade_summary = "LensUpgradeSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notification_summaries = "NotificationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_profile_notifications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/profileNotifications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProfileNotifications",
    Request: type = struct {
        workload_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .workload_id = "WorkloadId",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profile_notifications) } {
            return .{ .service_metadata = service_metadata, .action = list_profile_notifications };
        }
    },
    Response: type = struct {
        notification_summaries: ?[]struct {
            current_profile_version: ?[]const u8 = null,
            latest_profile_version: ?[]const u8 = null,
            type: ?[]const u8 = null,
            profile_arn: ?[]const u8 = null,
            profile_name: ?[]const u8 = null,
            workload_id: ?[]const u8 = null,
            workload_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .current_profile_version = "CurrentProfileVersion",
                    .latest_profile_version = "LatestProfileVersion",
                    .type = "Type",
                    .profile_arn = "ProfileArn",
                    .profile_name = "ProfileName",
                    .workload_id = "WorkloadId",
                    .workload_name = "WorkloadName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notification_summaries = "NotificationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/profileSummaries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProfiles",
    Request: type = struct {
        profile_name_prefix: ?[]const u8 = null,
        profile_owner_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .profile_name_prefix = "ProfileNamePrefix",
            .profile_owner_type = "ProfileOwnerType",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_name_prefix = "ProfileNamePrefix",
                .profile_owner_type = "ProfileOwnerType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_profiles };
        }
    },
    Response: type = struct {
        profile_summaries: ?[]struct {
            profile_arn: ?[]const u8 = null,
            profile_version: ?[]const u8 = null,
            profile_name: ?[]const u8 = null,
            profile_description: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .profile_arn = "ProfileArn",
                    .profile_version = "ProfileVersion",
                    .profile_name = "ProfileName",
                    .profile_description = "ProfileDescription",
                    .owner = "Owner",
                    .created_at = "CreatedAt",
                    .updated_at = "UpdatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_summaries = "ProfileSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_profile_shares: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/profiles/{ProfileArn}/shares",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProfileShares",
    Request: type = struct {
        profile_arn: []const u8,
        shared_with_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .shared_with_prefix = "SharedWithPrefix",
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .status = "Status",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_arn = "ProfileArn",
                .shared_with_prefix = "SharedWithPrefix",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profile_shares) } {
            return .{ .service_metadata = service_metadata, .action = list_profile_shares };
        }
    },
    Response: type = struct {
        profile_share_summaries: ?[]struct {
            share_id: ?[]const u8 = null,
            shared_with: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_id = "ShareId",
                    .shared_with = "SharedWith",
                    .status = "Status",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_share_summaries = "ProfileShareSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_review_template_answers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/reviewTemplates/{TemplateArn}/lensReviews/{LensAlias}/answers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReviewTemplateAnswers",
    Request: type = struct {
        template_arn: []const u8,
        lens_alias: []const u8,
        pillar_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .pillar_id = "PillarId",
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_alias = "LensAlias",
                .pillar_id = "PillarId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_review_template_answers) } {
            return .{ .service_metadata = service_metadata, .action = list_review_template_answers };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,
        lens_alias: ?[]const u8 = null,
        answer_summaries: ?[]struct {
            question_id: ?[]const u8 = null,
            pillar_id: ?[]const u8 = null,
            question_title: ?[]const u8 = null,
            choices: ?[]Choice = null,
            selected_choices: ?[][]const u8 = null,
            choice_answer_summaries: ?[]ChoiceAnswerSummary = null,
            is_applicable: ?bool = null,
            answer_status: ?[]const u8 = null,
            reason: ?[]const u8 = null,
            question_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .question_id = "QuestionId",
                    .pillar_id = "PillarId",
                    .question_title = "QuestionTitle",
                    .choices = "Choices",
                    .selected_choices = "SelectedChoices",
                    .choice_answer_summaries = "ChoiceAnswerSummaries",
                    .is_applicable = "IsApplicable",
                    .answer_status = "AnswerStatus",
                    .reason = "Reason",
                    .question_type = "QuestionType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_alias = "LensAlias",
                .answer_summaries = "AnswerSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_review_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/reviewTemplates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReviewTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "NextToken",
            .max_results = "MaxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_review_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_review_templates };
        }
    },
    Response: type = struct {
        review_templates: ?[]struct {
            description: ?[]const u8 = null,
            lenses: ?[][]const u8 = null,
            owner: ?[]const u8 = null,
            updated_at: ?i64 = null,
            template_arn: ?[]const u8 = null,
            template_name: ?[]const u8 = null,
            update_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .lenses = "Lenses",
                    .owner = "Owner",
                    .updated_at = "UpdatedAt",
                    .template_arn = "TemplateArn",
                    .template_name = "TemplateName",
                    .update_status = "UpdateStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .review_templates = "ReviewTemplates",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_share_invitations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/shareInvitations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListShareInvitations",
    Request: type = struct {
        workload_name_prefix: ?[]const u8 = null,
        lens_name_prefix: ?[]const u8 = null,
        share_resource_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        profile_name_prefix: ?[]const u8 = null,
        template_name_prefix: ?[]const u8 = null,

        pub const http_query = .{
            .workload_name_prefix = "WorkloadNamePrefix",
            .lens_name_prefix = "LensNamePrefix",
            .share_resource_type = "ShareResourceType",
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .profile_name_prefix = "ProfileNamePrefix",
            .template_name_prefix = "TemplateNamePrefix",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_name_prefix = "WorkloadNamePrefix",
                .lens_name_prefix = "LensNamePrefix",
                .share_resource_type = "ShareResourceType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .profile_name_prefix = "ProfileNamePrefix",
                .template_name_prefix = "TemplateNamePrefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_share_invitations) } {
            return .{ .service_metadata = service_metadata, .action = list_share_invitations };
        }
    },
    Response: type = struct {
        share_invitation_summaries: ?[]struct {
            share_invitation_id: ?[]const u8 = null,
            shared_by: ?[]const u8 = null,
            shared_with: ?[]const u8 = null,
            permission_type: ?[]const u8 = null,
            share_resource_type: ?[]const u8 = null,
            workload_name: ?[]const u8 = null,
            workload_id: ?[]const u8 = null,
            lens_name: ?[]const u8 = null,
            lens_arn: ?[]const u8 = null,
            profile_name: ?[]const u8 = null,
            profile_arn: ?[]const u8 = null,
            template_name: ?[]const u8 = null,
            template_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_invitation_id = "ShareInvitationId",
                    .shared_by = "SharedBy",
                    .shared_with = "SharedWith",
                    .permission_type = "PermissionType",
                    .share_resource_type = "ShareResourceType",
                    .workload_name = "WorkloadName",
                    .workload_id = "WorkloadId",
                    .lens_name = "LensName",
                    .lens_arn = "LensArn",
                    .profile_name = "ProfileName",
                    .profile_arn = "ProfileArn",
                    .template_name = "TemplateName",
                    .template_arn = "TemplateArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_invitation_summaries = "ShareInvitationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{WorkloadArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        workload_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_arn = "WorkloadArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const list_template_shares: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/templates/shares/{TemplateArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTemplateShares",
    Request: type = struct {
        template_arn: []const u8,
        shared_with_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .shared_with_prefix = "SharedWithPrefix",
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .status = "Status",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .shared_with_prefix = "SharedWithPrefix",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_template_shares) } {
            return .{ .service_metadata = service_metadata, .action = list_template_shares };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,
        template_share_summaries: ?[]struct {
            share_id: ?[]const u8 = null,
            shared_with: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_id = "ShareId",
                    .shared_with = "SharedWith",
                    .status = "Status",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .template_share_summaries = "TemplateShareSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_workloads: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/workloadsSummaries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkloads",
    Request: type = struct {
        workload_name_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_name_prefix = "WorkloadNamePrefix",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workloads) } {
            return .{ .service_metadata = service_metadata, .action = list_workloads };
        }
    },
    Response: type = struct {
        workload_summaries: ?[]WorkloadSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_summaries = "WorkloadSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_workload_shares: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/workloads/{WorkloadId}/shares",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWorkloadShares",
    Request: type = struct {
        workload_id: []const u8,
        shared_with_prefix: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,

        pub const http_query = .{
            .shared_with_prefix = "SharedWithPrefix",
            .next_token = "NextToken",
            .max_results = "MaxResults",
            .status = "Status",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .shared_with_prefix = "SharedWithPrefix",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workload_shares) } {
            return .{ .service_metadata = service_metadata, .action = list_workload_shares };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        workload_share_summaries: ?[]struct {
            share_id: ?[]const u8 = null,
            shared_with: ?[]const u8 = null,
            permission_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_id = "ShareId",
                    .shared_with = "SharedWith",
                    .permission_type = "PermissionType",
                    .status = "Status",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_share_summaries = "WorkloadShareSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{WorkloadArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        workload_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_arn = "WorkloadArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{WorkloadArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        workload_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_arn = "WorkloadArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_answer: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/answers/{QuestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAnswer",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        question_id: []const u8,
        selected_choices: ?[][]const u8 = null,
        choice_updates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ChoiceUpdate = null,
        } = null,
        notes: ?[]const u8 = null,
        is_applicable: ?bool = null,
        reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .question_id = "QuestionId",
                .selected_choices = "SelectedChoices",
                .choice_updates = "ChoiceUpdates",
                .notes = "Notes",
                .is_applicable = "IsApplicable",
                .reason = "Reason",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "choice_updates", field_name))
                return try serializeMap(self.choice_updates, self.fieldNameFor("choice_updates"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_answer) } {
            return .{ .service_metadata = service_metadata, .action = update_answer };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        lens_alias: ?[]const u8 = null,
        lens_arn: ?[]const u8 = null,
        answer: ?Answer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .lens_arn = "LensArn",
                .answer = "Answer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_global_settings: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/global-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGlobalSettings",
    Request: type = struct {
        organization_sharing_status: ?[]const u8 = null,
        discovery_integration_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_sharing_status = "OrganizationSharingStatus",
                .discovery_integration_status = "DiscoveryIntegrationStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_global_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_global_settings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_lens_review: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLensReview",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        lens_notes: ?[]const u8 = null,
        pillar_notes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .lens_notes = "LensNotes",
                .pillar_notes = "PillarNotes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "pillar_notes", field_name))
                return try serializeMap(self.pillar_notes, self.fieldNameFor("pillar_notes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_lens_review) } {
            return .{ .service_metadata = service_metadata, .action = update_lens_review };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        lens_review: ?LensReview = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_review = "LensReview",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_profile: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/profiles/{ProfileArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateProfile",
    Request: type = struct {
        profile_arn: []const u8,
        profile_description: ?[]const u8 = null,
        profile_questions: ?[]ProfileQuestionUpdate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_arn = "ProfileArn",
                .profile_description = "ProfileDescription",
                .profile_questions = "ProfileQuestions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_profile };
        }
    },
    Response: type = struct {
        profile: ?Profile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile = "Profile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_review_template: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/reviewTemplates/{TemplateArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateReviewTemplate",
    Request: type = struct {
        template_arn: []const u8,
        template_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        notes: ?[]const u8 = null,
        lenses_to_associate: ?[][]const u8 = null,
        lenses_to_disassociate: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .template_name = "TemplateName",
                .description = "Description",
                .notes = "Notes",
                .lenses_to_associate = "LensesToAssociate",
                .lenses_to_disassociate = "LensesToDisassociate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_review_template) } {
            return .{ .service_metadata = service_metadata, .action = update_review_template };
        }
    },
    Response: type = struct {
        review_template: ?ReviewTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .review_template = "ReviewTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_review_template_answer: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/reviewTemplates/{TemplateArn}/lensReviews/{LensAlias}/answers/{QuestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateReviewTemplateAnswer",
    Request: type = struct {
        template_arn: []const u8,
        lens_alias: []const u8,
        question_id: []const u8,
        selected_choices: ?[][]const u8 = null,
        choice_updates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ChoiceUpdate = null,
        } = null,
        notes: ?[]const u8 = null,
        is_applicable: ?bool = null,
        reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_alias = "LensAlias",
                .question_id = "QuestionId",
                .selected_choices = "SelectedChoices",
                .choice_updates = "ChoiceUpdates",
                .notes = "Notes",
                .is_applicable = "IsApplicable",
                .reason = "Reason",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "choice_updates", field_name))
                return try serializeMap(self.choice_updates, self.fieldNameFor("choice_updates"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_review_template_answer) } {
            return .{ .service_metadata = service_metadata, .action = update_review_template_answer };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,
        lens_alias: ?[]const u8 = null,
        answer: ?ReviewTemplateAnswer = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_alias = "LensAlias",
                .answer = "Answer",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_review_template_lens_review: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/reviewTemplates/{TemplateArn}/lensReviews/{LensAlias}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateReviewTemplateLensReview",
    Request: type = struct {
        template_arn: []const u8,
        lens_alias: []const u8,
        lens_notes: ?[]const u8 = null,
        pillar_notes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_alias = "LensAlias",
                .lens_notes = "LensNotes",
                .pillar_notes = "PillarNotes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "pillar_notes", field_name))
                return try serializeMap(self.pillar_notes, self.fieldNameFor("pillar_notes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_review_template_lens_review) } {
            return .{ .service_metadata = service_metadata, .action = update_review_template_lens_review };
        }
    },
    Response: type = struct {
        template_arn: ?[]const u8 = null,
        lens_review: ?ReviewTemplateLensReview = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_review = "LensReview",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_share_invitation: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/shareInvitations/{ShareInvitationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateShareInvitation",
    Request: type = struct {
        share_invitation_id: []const u8,
        share_invitation_action: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_invitation_id = "ShareInvitationId",
                .share_invitation_action = "ShareInvitationAction",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_share_invitation) } {
            return .{ .service_metadata = service_metadata, .action = update_share_invitation };
        }
    },
    Response: type = struct {
        share_invitation: ?struct {
            share_invitation_id: ?[]const u8 = null,
            share_resource_type: ?[]const u8 = null,
            workload_id: ?[]const u8 = null,
            lens_alias: ?[]const u8 = null,
            lens_arn: ?[]const u8 = null,
            profile_arn: ?[]const u8 = null,
            template_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_invitation_id = "ShareInvitationId",
                    .share_resource_type = "ShareResourceType",
                    .workload_id = "WorkloadId",
                    .lens_alias = "LensAlias",
                    .lens_arn = "LensArn",
                    .profile_arn = "ProfileArn",
                    .template_arn = "TemplateArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_invitation = "ShareInvitation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_workload: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateWorkload",
    Request: type = struct {
        workload_id: []const u8,
        workload_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        environment: ?[]const u8 = null,
        account_ids: ?[][]const u8 = null,
        aws_regions: ?[][]const u8 = null,
        non_aws_regions: ?[][]const u8 = null,
        pillar_priorities: ?[][]const u8 = null,
        architectural_design: ?[]const u8 = null,
        review_owner: ?[]const u8 = null,
        is_review_owner_update_acknowledged: ?bool = null,
        industry_type: ?[]const u8 = null,
        industry: ?[]const u8 = null,
        notes: ?[]const u8 = null,
        improvement_status: ?[]const u8 = null,
        discovery_config: ?WorkloadDiscoveryConfig = null,
        applications: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_name = "WorkloadName",
                .description = "Description",
                .environment = "Environment",
                .account_ids = "AccountIds",
                .aws_regions = "AwsRegions",
                .non_aws_regions = "NonAwsRegions",
                .pillar_priorities = "PillarPriorities",
                .architectural_design = "ArchitecturalDesign",
                .review_owner = "ReviewOwner",
                .is_review_owner_update_acknowledged = "IsReviewOwnerUpdateAcknowledged",
                .industry_type = "IndustryType",
                .industry = "Industry",
                .notes = "Notes",
                .improvement_status = "ImprovementStatus",
                .discovery_config = "DiscoveryConfig",
                .applications = "Applications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workload) } {
            return .{ .service_metadata = service_metadata, .action = update_workload };
        }
    },
    Response: type = struct {
        workload: ?Workload = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload = "Workload",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_workload_share: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/workloads/{WorkloadId}/shares/{ShareId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateWorkloadShare",
    Request: type = struct {
        share_id: []const u8,
        workload_id: []const u8,
        permission_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_id = "ShareId",
                .workload_id = "WorkloadId",
                .permission_type = "PermissionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workload_share) } {
            return .{ .service_metadata = service_metadata, .action = update_workload_share };
        }
    },
    Response: type = struct {
        workload_id: ?[]const u8 = null,
        workload_share: ?struct {
            share_id: ?[]const u8 = null,
            shared_by: ?[]const u8 = null,
            shared_with: ?[]const u8 = null,
            permission_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            workload_name: ?[]const u8 = null,
            workload_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .share_id = "ShareId",
                    .shared_by = "SharedBy",
                    .shared_with = "SharedWith",
                    .permission_type = "PermissionType",
                    .status = "Status",
                    .workload_name = "WorkloadName",
                    .workload_id = "WorkloadId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .workload_share = "WorkloadShare",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const upgrade_lens_review: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/workloads/{WorkloadId}/lensReviews/{LensAlias}/upgrade",
        .success_code = 200,
    };

    action_name: []const u8 = "UpgradeLensReview",
    Request: type = struct {
        workload_id: []const u8,
        lens_alias: []const u8,
        milestone_name: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .lens_alias = "LensAlias",
                .milestone_name = "MilestoneName",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upgrade_lens_review) } {
            return .{ .service_metadata = service_metadata, .action = upgrade_lens_review };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const upgrade_profile_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/workloads/{WorkloadId}/profiles/{ProfileArn}/upgrade",
        .success_code = 200,
    };

    action_name: []const u8 = "UpgradeProfileVersion",
    Request: type = struct {
        workload_id: []const u8,
        profile_arn: []const u8,
        milestone_name: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workload_id = "WorkloadId",
                .profile_arn = "ProfileArn",
                .milestone_name = "MilestoneName",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upgrade_profile_version) } {
            return .{ .service_metadata = service_metadata, .action = upgrade_profile_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const upgrade_review_template_lens_review: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/reviewTemplates/{TemplateArn}/lensReviews/{LensAlias}/upgrade",
        .success_code = 200,
    };

    action_name: []const u8 = "UpgradeReviewTemplateLensReview",
    Request: type = struct {
        template_arn: []const u8,
        lens_alias: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_arn = "TemplateArn",
                .lens_alias = "LensAlias",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upgrade_review_template_lens_review) } {
            return .{ .service_metadata = service_metadata, .action = upgrade_review_template_lens_review };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Workload = struct {
    workload_id: ?[]const u8 = null,
    workload_arn: ?[]const u8 = null,
    workload_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    environment: ?[]const u8 = null,
    updated_at: ?i64 = null,
    account_ids: ?[][]const u8 = null,
    aws_regions: ?[][]const u8 = null,
    non_aws_regions: ?[][]const u8 = null,
    architectural_design: ?[]const u8 = null,
    review_owner: ?[]const u8 = null,
    review_restriction_date: ?i64 = null,
    is_review_owner_update_acknowledged: ?bool = null,
    industry_type: ?[]const u8 = null,
    industry: ?[]const u8 = null,
    notes: ?[]const u8 = null,
    improvement_status: ?[]const u8 = null,
    risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    pillar_priorities: ?[][]const u8 = null,
    lenses: ?[][]const u8 = null,
    owner: ?[]const u8 = null,
    share_invitation_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    discovery_config: ?WorkloadDiscoveryConfig = null,
    applications: ?[][]const u8 = null,
    profiles: ?[]WorkloadProfile = null,
    prioritized_risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workload_id = "WorkloadId",
            .workload_arn = "WorkloadArn",
            .workload_name = "WorkloadName",
            .description = "Description",
            .environment = "Environment",
            .updated_at = "UpdatedAt",
            .account_ids = "AccountIds",
            .aws_regions = "AwsRegions",
            .non_aws_regions = "NonAwsRegions",
            .architectural_design = "ArchitecturalDesign",
            .review_owner = "ReviewOwner",
            .review_restriction_date = "ReviewRestrictionDate",
            .is_review_owner_update_acknowledged = "IsReviewOwnerUpdateAcknowledged",
            .industry_type = "IndustryType",
            .industry = "Industry",
            .notes = "Notes",
            .improvement_status = "ImprovementStatus",
            .risk_counts = "RiskCounts",
            .pillar_priorities = "PillarPriorities",
            .lenses = "Lenses",
            .owner = "Owner",
            .share_invitation_id = "ShareInvitationId",
            .tags = "Tags",
            .discovery_config = "DiscoveryConfig",
            .applications = "Applications",
            .profiles = "Profiles",
            .prioritized_risk_counts = "PrioritizedRiskCounts",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "risk_counts", field_name))
            return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        if (std.mem.eql(u8, "prioritized_risk_counts", field_name))
            return try serializeMap(self.prioritized_risk_counts, self.fieldNameFor("prioritized_risk_counts"), options, out_stream);
        return false;
    }
};

pub const WorkloadProfile = struct {
    profile_arn: ?[]const u8 = null,
    profile_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .profile_arn = "ProfileArn",
            .profile_version = "ProfileVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkloadDiscoveryConfig = struct {
    trusted_advisor_integration_status: ?[]const u8 = null,
    workload_resource_definition: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .trusted_advisor_integration_status = "TrustedAdvisorIntegrationStatus",
            .workload_resource_definition = "WorkloadResourceDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const ReviewTemplateLensReview = struct {
    lens_alias: ?[]const u8 = null,
    lens_arn: ?[]const u8 = null,
    lens_version: ?[]const u8 = null,
    lens_name: ?[]const u8 = null,
    lens_status: ?[]const u8 = null,
    pillar_review_summaries: ?[]ReviewTemplatePillarReviewSummary = null,
    updated_at: ?i64 = null,
    notes: ?[]const u8 = null,
    question_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    next_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lens_alias = "LensAlias",
            .lens_arn = "LensArn",
            .lens_version = "LensVersion",
            .lens_name = "LensName",
            .lens_status = "LensStatus",
            .pillar_review_summaries = "PillarReviewSummaries",
            .updated_at = "UpdatedAt",
            .notes = "Notes",
            .question_counts = "QuestionCounts",
            .next_token = "NextToken",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "question_counts", field_name))
            return try serializeMap(self.question_counts, self.fieldNameFor("question_counts"), options, out_stream);
        return false;
    }
};

pub const ReviewTemplatePillarReviewSummary = struct {
    pillar_id: ?[]const u8 = null,
    pillar_name: ?[]const u8 = null,
    notes: ?[]const u8 = null,
    question_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pillar_id = "PillarId",
            .pillar_name = "PillarName",
            .notes = "Notes",
            .question_counts = "QuestionCounts",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "question_counts", field_name))
            return try serializeMap(self.question_counts, self.fieldNameFor("question_counts"), options, out_stream);
        return false;
    }
};

pub const ReviewTemplateAnswer = struct {
    question_id: ?[]const u8 = null,
    pillar_id: ?[]const u8 = null,
    question_title: ?[]const u8 = null,
    question_description: ?[]const u8 = null,
    improvement_plan_url: ?[]const u8 = null,
    helpful_resource_url: ?[]const u8 = null,
    helpful_resource_display_text: ?[]const u8 = null,
    choices: ?[]Choice = null,
    selected_choices: ?[][]const u8 = null,
    choice_answers: ?[]ChoiceAnswer = null,
    is_applicable: ?bool = null,
    answer_status: ?[]const u8 = null,
    notes: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .question_id = "QuestionId",
            .pillar_id = "PillarId",
            .question_title = "QuestionTitle",
            .question_description = "QuestionDescription",
            .improvement_plan_url = "ImprovementPlanUrl",
            .helpful_resource_url = "HelpfulResourceUrl",
            .helpful_resource_display_text = "HelpfulResourceDisplayText",
            .choices = "Choices",
            .selected_choices = "SelectedChoices",
            .choice_answers = "ChoiceAnswers",
            .is_applicable = "IsApplicable",
            .answer_status = "AnswerStatus",
            .notes = "Notes",
            .reason = "Reason",
        };
        return @field(mappings, field_name);
    }
};

pub const ChoiceAnswer = struct {
    choice_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,
    notes: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .choice_id = "ChoiceId",
            .status = "Status",
            .reason = "Reason",
            .notes = "Notes",
        };
        return @field(mappings, field_name);
    }
};

pub const Choice = struct {
    choice_id: ?[]const u8 = null,
    title: ?[]const u8 = null,
    description: ?[]const u8 = null,
    helpful_resource: ?ChoiceContent = null,
    improvement_plan: ?ChoiceContent = null,
    additional_resources: ?[]AdditionalResources = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .choice_id = "ChoiceId",
            .title = "Title",
            .description = "Description",
            .helpful_resource = "HelpfulResource",
            .improvement_plan = "ImprovementPlan",
            .additional_resources = "AdditionalResources",
        };
        return @field(mappings, field_name);
    }
};

pub const AdditionalResources = struct {
    type: ?[]const u8 = null,
    content: ?[]ChoiceContent = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const ChoiceContent = struct {
    display_text: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .display_text = "DisplayText",
            .url = "Url",
        };
        return @field(mappings, field_name);
    }
};

pub const ChoiceUpdate = struct {
    status: []const u8,
    reason: ?[]const u8 = null,
    notes: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .reason = "Reason",
            .notes = "Notes",
        };
        return @field(mappings, field_name);
    }
};

pub const ReviewTemplate = struct {
    description: ?[]const u8 = null,
    lenses: ?[][]const u8 = null,
    notes: ?[]const u8 = null,
    question_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    owner: ?[]const u8 = null,
    updated_at: ?i64 = null,
    template_arn: ?[]const u8 = null,
    template_name: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    update_status: ?[]const u8 = null,
    share_invitation_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "Description",
            .lenses = "Lenses",
            .notes = "Notes",
            .question_counts = "QuestionCounts",
            .owner = "Owner",
            .updated_at = "UpdatedAt",
            .template_arn = "TemplateArn",
            .template_name = "TemplateName",
            .tags = "Tags",
            .update_status = "UpdateStatus",
            .share_invitation_id = "ShareInvitationId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "question_counts", field_name))
            return try serializeMap(self.question_counts, self.fieldNameFor("question_counts"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Profile = struct {
    profile_arn: ?[]const u8 = null,
    profile_version: ?[]const u8 = null,
    profile_name: ?[]const u8 = null,
    profile_description: ?[]const u8 = null,
    profile_questions: ?[]ProfileQuestion = null,
    owner: ?[]const u8 = null,
    created_at: ?i64 = null,
    updated_at: ?i64 = null,
    share_invitation_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .profile_arn = "ProfileArn",
            .profile_version = "ProfileVersion",
            .profile_name = "ProfileName",
            .profile_description = "ProfileDescription",
            .profile_questions = "ProfileQuestions",
            .owner = "Owner",
            .created_at = "CreatedAt",
            .updated_at = "UpdatedAt",
            .share_invitation_id = "ShareInvitationId",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ProfileQuestion = struct {
    question_id: ?[]const u8 = null,
    question_title: ?[]const u8 = null,
    question_description: ?[]const u8 = null,
    question_choices: ?[]ProfileChoice = null,
    selected_choice_ids: ?[][]const u8 = null,
    min_selected_choices: ?i64 = null,
    max_selected_choices: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .question_id = "QuestionId",
            .question_title = "QuestionTitle",
            .question_description = "QuestionDescription",
            .question_choices = "QuestionChoices",
            .selected_choice_ids = "SelectedChoiceIds",
            .min_selected_choices = "MinSelectedChoices",
            .max_selected_choices = "MaxSelectedChoices",
        };
        return @field(mappings, field_name);
    }
};

pub const ProfileChoice = struct {
    choice_id: ?[]const u8 = null,
    choice_title: ?[]const u8 = null,
    choice_description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .choice_id = "ChoiceId",
            .choice_title = "ChoiceTitle",
            .choice_description = "ChoiceDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const ProfileQuestionUpdate = struct {
    question_id: ?[]const u8 = null,
    selected_choice_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .question_id = "QuestionId",
            .selected_choice_ids = "SelectedChoiceIds",
        };
        return @field(mappings, field_name);
    }
};

pub const LensReview = struct {
    lens_alias: ?[]const u8 = null,
    lens_arn: ?[]const u8 = null,
    lens_version: ?[]const u8 = null,
    lens_name: ?[]const u8 = null,
    lens_status: ?[]const u8 = null,
    pillar_review_summaries: ?[]PillarReviewSummary = null,
    updated_at: ?i64 = null,
    notes: ?[]const u8 = null,
    risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    next_token: ?[]const u8 = null,
    profiles: ?[]WorkloadProfile = null,
    prioritized_risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lens_alias = "LensAlias",
            .lens_arn = "LensArn",
            .lens_version = "LensVersion",
            .lens_name = "LensName",
            .lens_status = "LensStatus",
            .pillar_review_summaries = "PillarReviewSummaries",
            .updated_at = "UpdatedAt",
            .notes = "Notes",
            .risk_counts = "RiskCounts",
            .next_token = "NextToken",
            .profiles = "Profiles",
            .prioritized_risk_counts = "PrioritizedRiskCounts",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "risk_counts", field_name))
            return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
        if (std.mem.eql(u8, "prioritized_risk_counts", field_name))
            return try serializeMap(self.prioritized_risk_counts, self.fieldNameFor("prioritized_risk_counts"), options, out_stream);
        return false;
    }
};

pub const PillarReviewSummary = struct {
    pillar_id: ?[]const u8 = null,
    pillar_name: ?[]const u8 = null,
    notes: ?[]const u8 = null,
    risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    prioritized_risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pillar_id = "PillarId",
            .pillar_name = "PillarName",
            .notes = "Notes",
            .risk_counts = "RiskCounts",
            .prioritized_risk_counts = "PrioritizedRiskCounts",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "risk_counts", field_name))
            return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
        if (std.mem.eql(u8, "prioritized_risk_counts", field_name))
            return try serializeMap(self.prioritized_risk_counts, self.fieldNameFor("prioritized_risk_counts"), options, out_stream);
        return false;
    }
};

pub const Answer = struct {
    question_id: ?[]const u8 = null,
    pillar_id: ?[]const u8 = null,
    question_title: ?[]const u8 = null,
    question_description: ?[]const u8 = null,
    improvement_plan_url: ?[]const u8 = null,
    helpful_resource_url: ?[]const u8 = null,
    helpful_resource_display_text: ?[]const u8 = null,
    choices: ?[]Choice = null,
    selected_choices: ?[][]const u8 = null,
    choice_answers: ?[]ChoiceAnswer = null,
    is_applicable: ?bool = null,
    risk: ?[]const u8 = null,
    notes: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .question_id = "QuestionId",
            .pillar_id = "PillarId",
            .question_title = "QuestionTitle",
            .question_description = "QuestionDescription",
            .improvement_plan_url = "ImprovementPlanUrl",
            .helpful_resource_url = "HelpfulResourceUrl",
            .helpful_resource_display_text = "HelpfulResourceDisplayText",
            .choices = "Choices",
            .selected_choices = "SelectedChoices",
            .choice_answers = "ChoiceAnswers",
            .is_applicable = "IsApplicable",
            .risk = "Risk",
            .notes = "Notes",
            .reason = "Reason",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkloadSummary = struct {
    workload_id: ?[]const u8 = null,
    workload_arn: ?[]const u8 = null,
    workload_name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    updated_at: ?i64 = null,
    lenses: ?[][]const u8 = null,
    risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    improvement_status: ?[]const u8 = null,
    profiles: ?[]WorkloadProfile = null,
    prioritized_risk_counts: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workload_id = "WorkloadId",
            .workload_arn = "WorkloadArn",
            .workload_name = "WorkloadName",
            .owner = "Owner",
            .updated_at = "UpdatedAt",
            .lenses = "Lenses",
            .risk_counts = "RiskCounts",
            .improvement_status = "ImprovementStatus",
            .profiles = "Profiles",
            .prioritized_risk_counts = "PrioritizedRiskCounts",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "risk_counts", field_name))
            return try serializeMap(self.risk_counts, self.fieldNameFor("risk_counts"), options, out_stream);
        if (std.mem.eql(u8, "prioritized_risk_counts", field_name))
            return try serializeMap(self.prioritized_risk_counts, self.fieldNameFor("prioritized_risk_counts"), options, out_stream);
        return false;
    }
};

pub const ChoiceAnswerSummary = struct {
    choice_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .choice_id = "ChoiceId",
            .status = "Status",
            .reason = "Reason",
        };
        return @field(mappings, field_name);
    }
};
