const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-05-01";
pub const sdk_id: []const u8 = "WorkDocs";
pub const arn_namespace: ?[]const u8 = "workdocs";
pub const endpoint_prefix: []const u8 = "workdocs";
pub const sigv4_name: []const u8 = "workdocs";
pub const name: []const u8 = "AWSGorillaBoyService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-05-01",
    sdk_id: []const u8 = "WorkDocs",
    arn_namespace: ?[]const u8 = "workdocs",
    endpoint_prefix: []const u8 = "workdocs",
    sigv4_name: []const u8 = "workdocs",
    name: []const u8 = "AWSGorillaBoyService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const abort_document_version_upload: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/documents/{DocumentId}/versions/{VersionId}",
        .success_code = 204,
    };

    action_name: []const u8 = "AbortDocumentVersionUpload",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        version_id: []const u8,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(abort_document_version_upload) } {
            return .{ .service_metadata = service_metadata, .action = abort_document_version_upload };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotExists,
        FailedDependency,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const activate_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/api/v1/users/{UserId}/activation",
        .success_code = 200,
    };

    action_name: []const u8 = "ActivateUser",
    Request: type = struct {
        user_id: []const u8,
        authentication_token: ?[]const u8 = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .authentication_token = "AuthenticationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(activate_user) } {
            return .{ .service_metadata = service_metadata, .action = activate_user };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const add_resource_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/api/v1/resources/{ResourceId}/permissions",
        .success_code = 201,
    };

    action_name: []const u8 = "AddResourcePermissions",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        resource_id: []const u8,
        principals: []struct {
            id: []const u8,
            type: []const u8,
            role: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                    .role = "Role",
                };
                return @field(mappings, field_name);
            }
        },
        notification_options: ?struct {
            send_email: ?bool = null,
            email_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .send_email = "SendEmail",
                    .email_message = "EmailMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .resource_id = "ResourceId",
                .principals = "Principals",
                .notification_options = "NotificationOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_resource_permissions) } {
            return .{ .service_metadata = service_metadata, .action = add_resource_permissions };
        }
    },
    Response: type = struct {
        share_results: ?[]struct {
            principal_id: ?[]const u8 = null,
            invitee_principal_id: ?[]const u8 = null,
            role: ?[]const u8 = null,
            status: ?[]const u8 = null,
            share_id: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .principal_id = "PrincipalId",
                    .invitee_principal_id = "InviteePrincipalId",
                    .role = "Role",
                    .status = "Status",
                    .share_id = "ShareId",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .share_results = "ShareResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        FailedDependency,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const create_comment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/api/v1/documents/{DocumentId}/versions/{VersionId}/comment",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateComment",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        version_id: []const u8,
        parent_id: ?[]const u8 = null,
        thread_id: ?[]const u8 = null,
        text: []const u8,
        visibility: ?[]const u8 = null,
        notify_collaborators: ?bool = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .version_id = "VersionId",
                .parent_id = "ParentId",
                .thread_id = "ThreadId",
                .text = "Text",
                .visibility = "Visibility",
                .notify_collaborators = "NotifyCollaborators",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_comment) } {
            return .{ .service_metadata = service_metadata, .action = create_comment };
        }
    },
    Response: type = struct {
        comment: ?Comment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comment = "Comment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DocumentLockedForComments,
        EntityNotExists,
        FailedDependency,
        InvalidCommentOperation,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const create_custom_metadata: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/api/v1/resources/{ResourceId}/customMetadata",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCustomMetadata",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        resource_id: []const u8,
        version_id: ?[]const u8 = null,
        custom_metadata: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub const http_query = .{
            .version_id = "versionid",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .resource_id = "ResourceId",
                .version_id = "VersionId",
                .custom_metadata = "CustomMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_metadata", field_name))
                return try serializeMap(self.custom_metadata, self.fieldNameFor("custom_metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_custom_metadata) } {
            return .{ .service_metadata = service_metadata, .action = create_custom_metadata };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CustomMetadataLimitExceeded,
        EntityNotExists,
        FailedDependency,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const create_folder: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/api/v1/folders",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateFolder",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        name: ?[]const u8 = null,
        parent_folder_id: []const u8,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .name = "Name",
                .parent_folder_id = "ParentFolderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_folder) } {
            return .{ .service_metadata = service_metadata, .action = create_folder };
        }
    },
    Response: type = struct {
        metadata: ?FolderMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata = "Metadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        ConflictingOperation,
        EntityAlreadyExists,
        EntityNotExists,
        FailedDependency,
        LimitExceeded,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const create_labels: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/api/v1/resources/{ResourceId}/labels",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLabels",
    Request: type = struct {
        resource_id: []const u8,
        labels: [][]const u8,
        authentication_token: ?[]const u8 = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .labels = "Labels",
                .authentication_token = "AuthenticationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_labels) } {
            return .{ .service_metadata = service_metadata, .action = create_labels };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        ServiceUnavailable,
        TooManyLabels,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const create_notification_subscription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/api/v1/organizations/{OrganizationId}/subscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateNotificationSubscription",
    Request: type = struct {
        organization_id: []const u8,
        endpoint: []const u8,
        protocol: []const u8,
        subscription_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .endpoint = "Endpoint",
                .protocol = "Protocol",
                .subscription_type = "SubscriptionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_notification_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_notification_subscription };
        }
    },
    Response: type = struct {
        subscription: ?Subscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription = "Subscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        ServiceUnavailable,
        TooManySubscriptions,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const create_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/api/v1/users",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        organization_id: ?[]const u8 = null,
        username: []const u8,
        email_address: ?[]const u8 = null,
        given_name: []const u8,
        surname: []const u8,
        password: []const u8,
        time_zone_id: ?[]const u8 = null,
        storage_rule: ?StorageRuleType = null,
        authentication_token: ?[]const u8 = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .username = "Username",
                .email_address = "EmailAddress",
                .given_name = "GivenName",
                .surname = "Surname",
                .password = "Password",
                .time_zone_id = "TimeZoneId",
                .storage_rule = "StorageRule",
                .authentication_token = "AuthenticationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityAlreadyExists,
        FailedDependency,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const deactivate_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/users/{UserId}/activation",
        .success_code = 204,
    };

    action_name: []const u8 = "DeactivateUser",
    Request: type = struct {
        user_id: []const u8,
        authentication_token: ?[]const u8 = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .authentication_token = "AuthenticationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deactivate_user) } {
            return .{ .service_metadata = service_metadata, .action = deactivate_user };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const delete_comment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/documents/{DocumentId}/versions/{VersionId}/comment/{CommentId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteComment",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        version_id: []const u8,
        comment_id: []const u8,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .version_id = "VersionId",
                .comment_id = "CommentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_comment) } {
            return .{ .service_metadata = service_metadata, .action = delete_comment };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DocumentLockedForComments,
        EntityNotExists,
        FailedDependency,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const delete_custom_metadata: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/resources/{ResourceId}/customMetadata",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCustomMetadata",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        resource_id: []const u8,
        version_id: ?[]const u8 = null,
        keys: ?[][]const u8 = null,
        delete_all: ?bool = null,

        pub const http_query = .{
            .version_id = "versionId",
            .keys = "keys",
            .delete_all = "deleteAll",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .resource_id = "ResourceId",
                .version_id = "VersionId",
                .keys = "Keys",
                .delete_all = "DeleteAll",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_custom_metadata) } {
            return .{ .service_metadata = service_metadata, .action = delete_custom_metadata };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const delete_document: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/documents/{DocumentId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDocument",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_document) } {
            return .{ .service_metadata = service_metadata, .action = delete_document };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        ConflictingOperation,
        EntityNotExists,
        FailedDependency,
        LimitExceeded,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const delete_document_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/documentVersions/{DocumentId}/versions/{VersionId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDocumentVersion",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        version_id: []const u8,
        delete_prior_versions: bool,

        pub const http_query = .{
            .delete_prior_versions = "deletePriorVersions",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .version_id = "VersionId",
                .delete_prior_versions = "DeletePriorVersions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_document_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_document_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        ConflictingOperation,
        EntityNotExists,
        FailedDependency,
        InvalidOperation,
        ProhibitedState,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const delete_folder: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/folders/{FolderId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFolder",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        folder_id: []const u8,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .folder_id = "FolderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_folder) } {
            return .{ .service_metadata = service_metadata, .action = delete_folder };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        ConflictingOperation,
        EntityNotExists,
        FailedDependency,
        LimitExceeded,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const delete_folder_contents: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/folders/{FolderId}/contents",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteFolderContents",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        folder_id: []const u8,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .folder_id = "FolderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_folder_contents) } {
            return .{ .service_metadata = service_metadata, .action = delete_folder_contents };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConflictingOperation,
        EntityNotExists,
        FailedDependency,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const delete_labels: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/resources/{ResourceId}/labels",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLabels",
    Request: type = struct {
        resource_id: []const u8,
        authentication_token: ?[]const u8 = null,
        labels: ?[][]const u8 = null,
        delete_all: ?bool = null,

        pub const http_query = .{
            .labels = "labels",
            .delete_all = "deleteAll",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .authentication_token = "AuthenticationToken",
                .labels = "Labels",
                .delete_all = "DeleteAll",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_labels) } {
            return .{ .service_metadata = service_metadata, .action = delete_labels };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const delete_notification_subscription: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/organizations/{OrganizationId}/subscriptions/{SubscriptionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteNotificationSubscription",
    Request: type = struct {
        subscription_id: []const u8,
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_id = "SubscriptionId",
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_notification_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_notification_subscription };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        EntityNotExists,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const delete_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/users/{UserId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        user_id: []const u8,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const describe_activities: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/activities",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeActivities",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        organization_id: ?[]const u8 = null,
        activity_types: ?[]const u8 = null,
        resource_id: ?[]const u8 = null,
        user_id: ?[]const u8 = null,
        include_indirect_activities: ?bool = null,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub const http_query = .{
            .start_time = "startTime",
            .end_time = "endTime",
            .organization_id = "organizationId",
            .activity_types = "activityTypes",
            .resource_id = "resourceId",
            .user_id = "userId",
            .include_indirect_activities = "includeIndirectActivities",
            .limit = "limit",
            .marker = "marker",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .organization_id = "OrganizationId",
                .activity_types = "ActivityTypes",
                .resource_id = "ResourceId",
                .user_id = "UserId",
                .include_indirect_activities = "IncludeIndirectActivities",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_activities) } {
            return .{ .service_metadata = service_metadata, .action = describe_activities };
        }
    },
    Response: type = struct {
        user_activities: ?[]struct {
            type: ?[]const u8 = null,
            time_stamp: ?i64 = null,
            is_indirect_activity: ?bool = null,
            organization_id: ?[]const u8 = null,
            initiator: ?UserMetadata = null,
            participants: ?struct {
                users: ?[]UserMetadata = null,
                groups: ?[]GroupMetadata = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .users = "Users",
                        .groups = "Groups",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            resource_metadata: ?ResourceMetadata = null,
            original_parent: ?ResourceMetadata = null,
            comment_metadata: ?CommentMetadata = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .time_stamp = "TimeStamp",
                    .is_indirect_activity = "IsIndirectActivity",
                    .organization_id = "OrganizationId",
                    .initiator = "Initiator",
                    .participants = "Participants",
                    .resource_metadata = "ResourceMetadata",
                    .original_parent = "OriginalParent",
                    .comment_metadata = "CommentMetadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_activities = "UserActivities",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        FailedDependency,
        InvalidArgument,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const describe_comments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/documents/{DocumentId}/versions/{VersionId}/comments",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeComments",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        version_id: []const u8,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub const http_query = .{
            .limit = "limit",
            .marker = "marker",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .version_id = "VersionId",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_comments) } {
            return .{ .service_metadata = service_metadata, .action = describe_comments };
        }
    },
    Response: type = struct {
        comments: ?[]Comment = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .comments = "Comments",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const describe_document_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/documents/{DocumentId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDocumentVersions",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,
        include: ?[]const u8 = null,
        fields: ?[]const u8 = null,

        pub const http_query = .{
            .marker = "marker",
            .limit = "limit",
            .include = "include",
            .fields = "fields",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .marker = "Marker",
                .limit = "Limit",
                .include = "Include",
                .fields = "Fields",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_document_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_document_versions };
        }
    },
    Response: type = struct {
        document_versions: ?[]DocumentVersionMetadata = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_versions = "DocumentVersions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        InvalidArgument,
        InvalidPassword,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const describe_folder_contents: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/folders/{FolderId}/contents",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFolderContents",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        folder_id: []const u8,
        sort: ?[]const u8 = null,
        order: ?[]const u8 = null,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,
        type: ?[]const u8 = null,
        include: ?[]const u8 = null,

        pub const http_query = .{
            .sort = "sort",
            .order = "order",
            .limit = "limit",
            .marker = "marker",
            .type = "type",
            .include = "include",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .folder_id = "FolderId",
                .sort = "Sort",
                .order = "Order",
                .limit = "Limit",
                .marker = "Marker",
                .type = "Type",
                .include = "Include",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_folder_contents) } {
            return .{ .service_metadata = service_metadata, .action = describe_folder_contents };
        }
    },
    Response: type = struct {
        folders: ?[]FolderMetadata = null,
        documents: ?[]DocumentMetadata = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .folders = "Folders",
                .documents = "Documents",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        InvalidArgument,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const describe_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGroups",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        search_query: []const u8,
        organization_id: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .search_query = "searchQuery",
            .organization_id = "organizationId",
            .marker = "marker",
            .limit = "limit",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .search_query = "SearchQuery",
                .organization_id = "OrganizationId",
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_groups };
        }
    },
    Response: type = struct {
        groups: ?[]GroupMetadata = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "Groups",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        FailedDependency,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const describe_notification_subscriptions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/organizations/{OrganizationId}/subscriptions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeNotificationSubscriptions",
    Request: type = struct {
        organization_id: []const u8,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .marker = "marker",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .marker = "Marker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_notification_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = describe_notification_subscriptions };
        }
    },
    Response: type = struct {
        subscriptions: ?[]Subscription = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscriptions = "Subscriptions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        ServiceUnavailable,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const describe_resource_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/resources/{ResourceId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeResourcePermissions",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        resource_id: []const u8,
        principal_id: ?[]const u8 = null,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub const http_query = .{
            .principal_id = "principalId",
            .limit = "limit",
            .marker = "marker",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .resource_id = "ResourceId",
                .principal_id = "PrincipalId",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource_permissions };
        }
    },
    Response: type = struct {
        principals: ?[]struct {
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            roles: ?[]struct {
                role: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .role = "Role",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                    .roles = "Roles",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principals = "Principals",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        FailedDependency,
        InvalidArgument,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const describe_root_folders: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/me/root",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRootFolders",
    Request: type = struct {
        authentication_token: []const u8,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub const http_query = .{
            .limit = "limit",
            .marker = "marker",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_root_folders) } {
            return .{ .service_metadata = service_metadata, .action = describe_root_folders };
        }
    },
    Response: type = struct {
        folders: ?[]FolderMetadata = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .folders = "Folders",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        FailedDependency,
        InvalidArgument,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const describe_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/users",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUsers",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        organization_id: ?[]const u8 = null,
        user_ids: ?[]const u8 = null,
        query: ?[]const u8 = null,
        include: ?[]const u8 = null,
        order: ?[]const u8 = null,
        sort: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        limit: ?i64 = null,
        fields: ?[]const u8 = null,

        pub const http_query = .{
            .organization_id = "organizationId",
            .user_ids = "userIds",
            .query = "query",
            .include = "include",
            .order = "order",
            .sort = "sort",
            .marker = "marker",
            .limit = "limit",
            .fields = "fields",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .organization_id = "OrganizationId",
                .user_ids = "UserIds",
                .query = "Query",
                .include = "Include",
                .order = "Order",
                .sort = "Sort",
                .marker = "Marker",
                .limit = "Limit",
                .fields = "Fields",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_users) } {
            return .{ .service_metadata = service_metadata, .action = describe_users };
        }
    },
    Response: type = struct {
        users: ?[]User = null,
        total_number_of_users: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .total_number_of_users = "TotalNumberOfUsers",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        InvalidArgument,
        RequestedEntityTooLarge,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const get_current_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/me",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCurrentUser",
    Request: type = struct {
        authentication_token: []const u8,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_current_user) } {
            return .{ .service_metadata = service_metadata, .action = get_current_user };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const get_document: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/documents/{DocumentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDocument",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        include_custom_metadata: ?bool = null,

        pub const http_query = .{
            .include_custom_metadata = "includeCustomMetadata",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .include_custom_metadata = "IncludeCustomMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_document) } {
            return .{ .service_metadata = service_metadata, .action = get_document };
        }
    },
    Response: type = struct {
        metadata: ?DocumentMetadata = null,
        custom_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata = "Metadata",
                .custom_metadata = "CustomMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_metadata", field_name))
                return try serializeMap(self.custom_metadata, self.fieldNameFor("custom_metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        InvalidArgument,
        InvalidPassword,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const get_document_path: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/documents/{DocumentId}/path",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDocumentPath",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        limit: ?i64 = null,
        fields: ?[]const u8 = null,
        marker: ?[]const u8 = null,

        pub const http_query = .{
            .limit = "limit",
            .fields = "fields",
            .marker = "marker",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .limit = "Limit",
                .fields = "Fields",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_document_path) } {
            return .{ .service_metadata = service_metadata, .action = get_document_path };
        }
    },
    Response: type = struct {
        path: ?ResourcePath = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .path = "Path",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const get_document_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/documents/{DocumentId}/versions/{VersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDocumentVersion",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        version_id: []const u8,
        fields: ?[]const u8 = null,
        include_custom_metadata: ?bool = null,

        pub const http_query = .{
            .fields = "fields",
            .include_custom_metadata = "includeCustomMetadata",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .version_id = "VersionId",
                .fields = "Fields",
                .include_custom_metadata = "IncludeCustomMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_document_version) } {
            return .{ .service_metadata = service_metadata, .action = get_document_version };
        }
    },
    Response: type = struct {
        metadata: ?DocumentVersionMetadata = null,
        custom_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata = "Metadata",
                .custom_metadata = "CustomMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_metadata", field_name))
                return try serializeMap(self.custom_metadata, self.fieldNameFor("custom_metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        InvalidPassword,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const get_folder: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/folders/{FolderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFolder",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        folder_id: []const u8,
        include_custom_metadata: ?bool = null,

        pub const http_query = .{
            .include_custom_metadata = "includeCustomMetadata",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .folder_id = "FolderId",
                .include_custom_metadata = "IncludeCustomMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_folder) } {
            return .{ .service_metadata = service_metadata, .action = get_folder };
        }
    },
    Response: type = struct {
        metadata: ?FolderMetadata = null,
        custom_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata = "Metadata",
                .custom_metadata = "CustomMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_metadata", field_name))
                return try serializeMap(self.custom_metadata, self.fieldNameFor("custom_metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        InvalidArgument,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const get_folder_path: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/folders/{FolderId}/path",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFolderPath",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        folder_id: []const u8,
        limit: ?i64 = null,
        fields: ?[]const u8 = null,
        marker: ?[]const u8 = null,

        pub const http_query = .{
            .limit = "limit",
            .fields = "fields",
            .marker = "marker",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .folder_id = "FolderId",
                .limit = "Limit",
                .fields = "Fields",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_folder_path) } {
            return .{ .service_metadata = service_metadata, .action = get_folder_path };
        }
    },
    Response: type = struct {
        path: ?ResourcePath = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .path = "Path",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotExists,
        FailedDependency,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const get_resources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/api/v1/resources",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResources",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        user_id: ?[]const u8 = null,
        collection_type: ?[]const u8 = null,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,

        pub const http_query = .{
            .user_id = "userId",
            .collection_type = "collectionType",
            .limit = "limit",
            .marker = "marker",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .user_id = "UserId",
                .collection_type = "CollectionType",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resources) } {
            return .{ .service_metadata = service_metadata, .action = get_resources };
        }
    },
    Response: type = struct {
        folders: ?[]FolderMetadata = null,
        documents: ?[]DocumentMetadata = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .folders = "Folders",
                .documents = "Documents",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        FailedDependency,
        InvalidArgument,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const initiate_document_version_upload: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/api/v1/documents",
        .success_code = 201,
    };

    action_name: []const u8 = "InitiateDocumentVersionUpload",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        content_created_timestamp: ?i64 = null,
        content_modified_timestamp: ?i64 = null,
        content_type: ?[]const u8 = null,
        document_size_in_bytes: ?i64 = null,
        parent_folder_id: ?[]const u8 = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .id = "Id",
                .name = "Name",
                .content_created_timestamp = "ContentCreatedTimestamp",
                .content_modified_timestamp = "ContentModifiedTimestamp",
                .content_type = "ContentType",
                .document_size_in_bytes = "DocumentSizeInBytes",
                .parent_folder_id = "ParentFolderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(initiate_document_version_upload) } {
            return .{ .service_metadata = service_metadata, .action = initiate_document_version_upload };
        }
    },
    Response: type = struct {
        metadata: ?DocumentMetadata = null,
        upload_metadata: ?struct {
            upload_url: ?[]const u8 = null,
            signed_headers: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .upload_url = "UploadUrl",
                    .signed_headers = "SignedHeaders",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "signed_headers", field_name))
                    return try serializeMap(self.signed_headers, self.fieldNameFor("signed_headers"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata = "Metadata",
                .upload_metadata = "UploadMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DraftUploadOutOfSync,
        EntityAlreadyExists,
        EntityNotExists,
        FailedDependency,
        InvalidArgument,
        InvalidPassword,
        LimitExceeded,
        ProhibitedState,
        ResourceAlreadyCheckedOut,
        ServiceUnavailable,
        StorageLimitExceeded,
        StorageLimitWillExceed,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const remove_all_resource_permissions: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/resources/{ResourceId}/permissions",
        .success_code = 204,
    };

    action_name: []const u8 = "RemoveAllResourcePermissions",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        resource_id: []const u8,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_all_resource_permissions) } {
            return .{ .service_metadata = service_metadata, .action = remove_all_resource_permissions };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        FailedDependency,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const remove_resource_permission: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/api/v1/resources/{ResourceId}/permissions/{PrincipalId}",
        .success_code = 204,
    };

    action_name: []const u8 = "RemoveResourcePermission",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        resource_id: []const u8,
        principal_id: []const u8,
        principal_type: ?[]const u8 = null,

        pub const http_query = .{
            .principal_type = "type",
        };

        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .resource_id = "ResourceId",
                .principal_id = "PrincipalId",
                .principal_type = "PrincipalType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_resource_permission) } {
            return .{ .service_metadata = service_metadata, .action = remove_resource_permission };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        FailedDependency,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const restore_document_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/api/v1/documentVersions/restore/{DocumentId}",
        .success_code = 204,
    };

    action_name: []const u8 = "RestoreDocumentVersions",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_document_versions) } {
            return .{ .service_metadata = service_metadata, .action = restore_document_versions };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        ConflictingOperation,
        EntityNotExists,
        FailedDependency,
        InvalidOperation,
        ProhibitedState,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const search_resources: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/api/v1/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchResources",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        query_text: ?[]const u8 = null,
        query_scopes: ?[][]const u8 = null,
        organization_id: ?[]const u8 = null,
        additional_response_fields: ?[][]const u8 = null,
        filters: ?struct {
            text_locales: ?[][]const u8 = null,
            content_categories: ?[][]const u8 = null,
            resource_types: ?[][]const u8 = null,
            labels: ?[][]const u8 = null,
            principals: ?[]struct {
                id: []const u8,
                roles: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .roles = "Roles",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            ancestor_ids: ?[][]const u8 = null,
            search_collection_types: ?[][]const u8 = null,
            size_range: ?struct {
                start_value: ?i64 = null,
                end_value: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .start_value = "StartValue",
                        .end_value = "EndValue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            created_range: ?DateRangeType = null,
            modified_range: ?DateRangeType = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .text_locales = "TextLocales",
                    .content_categories = "ContentCategories",
                    .resource_types = "ResourceTypes",
                    .labels = "Labels",
                    .principals = "Principals",
                    .ancestor_ids = "AncestorIds",
                    .search_collection_types = "SearchCollectionTypes",
                    .size_range = "SizeRange",
                    .created_range = "CreatedRange",
                    .modified_range = "ModifiedRange",
                };
                return @field(mappings, field_name);
            }
        } = null,
        order_by: ?[]struct {
            field: ?[]const u8 = null,
            order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field = "Field",
                    .order = "Order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        limit: ?i64 = null,
        marker: ?[]const u8 = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .query_text = "QueryText",
                .query_scopes = "QueryScopes",
                .organization_id = "OrganizationId",
                .additional_response_fields = "AdditionalResponseFields",
                .filters = "Filters",
                .order_by = "OrderBy",
                .limit = "Limit",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_resources) } {
            return .{ .service_metadata = service_metadata, .action = search_resources };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            resource_type: ?[]const u8 = null,
            web_url: ?[]const u8 = null,
            document_metadata: ?DocumentMetadata = null,
            folder_metadata: ?FolderMetadata = null,
            comment_metadata: ?CommentMetadata = null,
            document_version_metadata: ?DocumentVersionMetadata = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_type = "ResourceType",
                    .web_url = "WebUrl",
                    .document_metadata = "DocumentMetadata",
                    .folder_metadata = "FolderMetadata",
                    .comment_metadata = "CommentMetadata",
                    .document_version_metadata = "DocumentVersionMetadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArgument,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const update_document: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/api/v1/documents/{DocumentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDocument",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        name: ?[]const u8 = null,
        parent_folder_id: ?[]const u8 = null,
        resource_state: ?[]const u8 = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .name = "Name",
                .parent_folder_id = "ParentFolderId",
                .resource_state = "ResourceState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_document) } {
            return .{ .service_metadata = service_metadata, .action = update_document };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        ConflictingOperation,
        EntityAlreadyExists,
        EntityNotExists,
        FailedDependency,
        LimitExceeded,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const update_document_version: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/api/v1/documents/{DocumentId}/versions/{VersionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDocumentVersion",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        document_id: []const u8,
        version_id: []const u8,
        version_status: ?[]const u8 = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .document_id = "DocumentId",
                .version_id = "VersionId",
                .version_status = "VersionStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_document_version) } {
            return .{ .service_metadata = service_metadata, .action = update_document_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotExists,
        FailedDependency,
        InvalidOperation,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const update_folder: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/api/v1/folders/{FolderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFolder",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        folder_id: []const u8,
        name: ?[]const u8 = null,
        parent_folder_id: ?[]const u8 = null,
        resource_state: ?[]const u8 = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .folder_id = "FolderId",
                .name = "Name",
                .parent_folder_id = "ParentFolderId",
                .resource_state = "ResourceState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_folder) } {
            return .{ .service_metadata = service_metadata, .action = update_folder };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ConcurrentModification,
        ConflictingOperation,
        EntityAlreadyExists,
        EntityNotExists,
        FailedDependency,
        LimitExceeded,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};
pub const update_user: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/api/v1/users/{UserId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        authentication_token: ?[]const u8 = null,
        user_id: []const u8,
        given_name: ?[]const u8 = null,
        surname: ?[]const u8 = null,
        type: ?[]const u8 = null,
        storage_rule: ?StorageRuleType = null,
        time_zone_id: ?[]const u8 = null,
        locale: ?[]const u8 = null,
        grant_poweruser_privileges: ?[]const u8 = null,
        pub const http_header = .{
            .authentication_token = "Authentication",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authentication_token = "AuthenticationToken",
                .user_id = "UserId",
                .given_name = "GivenName",
                .surname = "Surname",
                .type = "Type",
                .storage_rule = "StorageRule",
                .time_zone_id = "TimeZoneId",
                .locale = "Locale",
                .grant_poweruser_privileges = "GrantPoweruserPrivileges",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DeactivatingLastSystemUser,
        EntityNotExists,
        FailedDependency,
        IllegalUserState,
        InvalidArgument,
        ProhibitedState,
        ServiceUnavailable,
        UnauthorizedOperation,
        UnauthorizedResourceAccess,
    },
} = .{};

pub const User = struct {
    id: ?[]const u8 = null,
    username: ?[]const u8 = null,
    email_address: ?[]const u8 = null,
    given_name: ?[]const u8 = null,
    surname: ?[]const u8 = null,
    organization_id: ?[]const u8 = null,
    root_folder_id: ?[]const u8 = null,
    recycle_bin_folder_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    type: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    modified_timestamp: ?i64 = null,
    time_zone_id: ?[]const u8 = null,
    locale: ?[]const u8 = null,
    storage: ?UserStorageMetadata = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .username = "Username",
            .email_address = "EmailAddress",
            .given_name = "GivenName",
            .surname = "Surname",
            .organization_id = "OrganizationId",
            .root_folder_id = "RootFolderId",
            .recycle_bin_folder_id = "RecycleBinFolderId",
            .status = "Status",
            .type = "Type",
            .created_timestamp = "CreatedTimestamp",
            .modified_timestamp = "ModifiedTimestamp",
            .time_zone_id = "TimeZoneId",
            .locale = "Locale",
            .storage = "Storage",
        };
        return @field(mappings, field_name);
    }
};

pub const UserStorageMetadata = struct {
    storage_utilized_in_bytes: ?i64 = null,
    storage_rule: ?StorageRuleType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_utilized_in_bytes = "StorageUtilizedInBytes",
            .storage_rule = "StorageRule",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageRuleType = struct {
    storage_allocated_in_bytes: ?i64 = null,
    storage_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_allocated_in_bytes = "StorageAllocatedInBytes",
            .storage_type = "StorageType",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentVersionMetadata = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    content_type: ?[]const u8 = null,
    size: ?i64 = null,
    signature: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    modified_timestamp: ?i64 = null,
    content_created_timestamp: ?i64 = null,
    content_modified_timestamp: ?i64 = null,
    creator_id: ?[]const u8 = null,
    thumbnail: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    source: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .content_type = "ContentType",
            .size = "Size",
            .signature = "Signature",
            .status = "Status",
            .created_timestamp = "CreatedTimestamp",
            .modified_timestamp = "ModifiedTimestamp",
            .content_created_timestamp = "ContentCreatedTimestamp",
            .content_modified_timestamp = "ContentModifiedTimestamp",
            .creator_id = "CreatorId",
            .thumbnail = "Thumbnail",
            .source = "Source",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "thumbnail", field_name))
            return try serializeMap(self.thumbnail, self.fieldNameFor("thumbnail"), options, out_stream);
        if (std.mem.eql(u8, "source", field_name))
            return try serializeMap(self.source, self.fieldNameFor("source"), options, out_stream);
        return false;
    }
};

pub const CommentMetadata = struct {
    comment_id: ?[]const u8 = null,
    contributor: ?User = null,
    created_timestamp: ?i64 = null,
    comment_status: ?[]const u8 = null,
    recipient_id: ?[]const u8 = null,
    contributor_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment_id = "CommentId",
            .contributor = "Contributor",
            .created_timestamp = "CreatedTimestamp",
            .comment_status = "CommentStatus",
            .recipient_id = "RecipientId",
            .contributor_id = "ContributorId",
        };
        return @field(mappings, field_name);
    }
};

pub const FolderMetadata = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    creator_id: ?[]const u8 = null,
    parent_folder_id: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    modified_timestamp: ?i64 = null,
    resource_state: ?[]const u8 = null,
    signature: ?[]const u8 = null,
    labels: ?[][]const u8 = null,
    size: ?i64 = null,
    latest_version_size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .creator_id = "CreatorId",
            .parent_folder_id = "ParentFolderId",
            .created_timestamp = "CreatedTimestamp",
            .modified_timestamp = "ModifiedTimestamp",
            .resource_state = "ResourceState",
            .signature = "Signature",
            .labels = "Labels",
            .size = "Size",
            .latest_version_size = "LatestVersionSize",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentMetadata = struct {
    id: ?[]const u8 = null,
    creator_id: ?[]const u8 = null,
    parent_folder_id: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    modified_timestamp: ?i64 = null,
    latest_version_metadata: ?DocumentVersionMetadata = null,
    resource_state: ?[]const u8 = null,
    labels: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .creator_id = "CreatorId",
            .parent_folder_id = "ParentFolderId",
            .created_timestamp = "CreatedTimestamp",
            .modified_timestamp = "ModifiedTimestamp",
            .latest_version_metadata = "LatestVersionMetadata",
            .resource_state = "ResourceState",
            .labels = "Labels",
        };
        return @field(mappings, field_name);
    }
};

pub const DateRangeType = struct {
    start_value: ?i64 = null,
    end_value: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_value = "StartValue",
            .end_value = "EndValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePath = struct {
    components: ?[]ResourcePathComponent = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .components = "Components",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePathComponent = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Subscription = struct {
    subscription_id: ?[]const u8 = null,
    end_point: ?[]const u8 = null,
    protocol: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subscription_id = "SubscriptionId",
            .end_point = "EndPoint",
            .protocol = "Protocol",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupMetadata = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Comment = struct {
    comment_id: []const u8,
    parent_id: ?[]const u8 = null,
    thread_id: ?[]const u8 = null,
    text: ?[]const u8 = null,
    contributor: ?User = null,
    created_timestamp: ?i64 = null,
    status: ?[]const u8 = null,
    visibility: ?[]const u8 = null,
    recipient_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comment_id = "CommentId",
            .parent_id = "ParentId",
            .thread_id = "ThreadId",
            .text = "Text",
            .contributor = "Contributor",
            .created_timestamp = "CreatedTimestamp",
            .status = "Status",
            .visibility = "Visibility",
            .recipient_id = "RecipientId",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceMetadata = struct {
    type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    original_name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    version_id: ?[]const u8 = null,
    owner: ?UserMetadata = null,
    parent_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .name = "Name",
            .original_name = "OriginalName",
            .id = "Id",
            .version_id = "VersionId",
            .owner = "Owner",
            .parent_id = "ParentId",
        };
        return @field(mappings, field_name);
    }
};

pub const UserMetadata = struct {
    id: ?[]const u8 = null,
    username: ?[]const u8 = null,
    given_name: ?[]const u8 = null,
    surname: ?[]const u8 = null,
    email_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .username = "Username",
            .given_name = "GivenName",
            .surname = "Surname",
            .email_address = "EmailAddress",
        };
        return @field(mappings, field_name);
    }
};
