const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-09-25";
pub const sdk_id: []const u8 = "WorkLink";
pub const arn_namespace: ?[]const u8 = "worklink";
pub const endpoint_prefix: []const u8 = "worklink";
pub const sigv4_name: []const u8 = "worklink";
pub const name: []const u8 = "WorkLink";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-09-25",
    sdk_id: []const u8 = "WorkLink",
    arn_namespace: ?[]const u8 = "worklink",
    endpoint_prefix: []const u8 = "worklink",
    sigv4_name: []const u8 = "worklink",
    name: []const u8 = "WorkLink",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/associateDomain",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateDomain",
    Request: type = struct {
        fleet_arn: []const u8,
        domain_name: []const u8,
        display_name: ?[]const u8 = null,
        acm_certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .domain_name = "DomainName",
                .display_name = "DisplayName",
                .acm_certificate_arn = "AcmCertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_domain) } {
            return .{ .service_metadata = service_metadata, .action = associate_domain };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const associate_website_authorization_provider: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/associateWebsiteAuthorizationProvider",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateWebsiteAuthorizationProvider",
    Request: type = struct {
        fleet_arn: []const u8,
        authorization_provider_type: []const u8,
        domain_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .authorization_provider_type = "AuthorizationProviderType",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_website_authorization_provider) } {
            return .{ .service_metadata = service_metadata, .action = associate_website_authorization_provider };
        }
    },
    Response: type = struct {
        authorization_provider_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorization_provider_id = "AuthorizationProviderId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const associate_website_certificate_authority: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/associateWebsiteCertificateAuthority",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateWebsiteCertificateAuthority",
    Request: type = struct {
        fleet_arn: []const u8,
        certificate: []const u8,
        display_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .certificate = "Certificate",
                .display_name = "DisplayName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_website_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = associate_website_certificate_authority };
        }
    },
    Response: type = struct {
        website_ca_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .website_ca_id = "WebsiteCaId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_fleet: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createFleet",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFleet",
    Request: type = struct {
        fleet_name: []const u8,
        display_name: ?[]const u8 = null,
        optimize_for_end_user_location: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_name = "FleetName",
                .display_name = "DisplayName",
                .optimize_for_end_user_location = "OptimizeForEndUserLocation",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fleet) } {
            return .{ .service_metadata = service_metadata, .action = create_fleet };
        }
    },
    Response: type = struct {
        fleet_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_fleet: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deleteFleet",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFleet",
    Request: type = struct {
        fleet_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fleet) } {
            return .{ .service_metadata = service_metadata, .action = delete_fleet };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_audit_stream_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeAuditStreamConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAuditStreamConfiguration",
    Request: type = struct {
        fleet_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_audit_stream_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_audit_stream_configuration };
        }
    },
    Response: type = struct {
        audit_stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .audit_stream_arn = "AuditStreamArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_company_network_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeCompanyNetworkConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCompanyNetworkConfiguration",
    Request: type = struct {
        fleet_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_company_network_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_company_network_configuration };
        }
    },
    Response: type = struct {
        vpc_id: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        security_group_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_id = "VpcId",
                .subnet_ids = "SubnetIds",
                .security_group_ids = "SecurityGroupIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeDevice",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDevice",
    Request: type = struct {
        fleet_arn: []const u8,
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_device) } {
            return .{ .service_metadata = service_metadata, .action = describe_device };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        model: ?[]const u8 = null,
        manufacturer: ?[]const u8 = null,
        operating_system: ?[]const u8 = null,
        operating_system_version: ?[]const u8 = null,
        patch_level: ?[]const u8 = null,
        first_accessed_time: ?i64 = null,
        last_accessed_time: ?i64 = null,
        username: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .model = "Model",
                .manufacturer = "Manufacturer",
                .operating_system = "OperatingSystem",
                .operating_system_version = "OperatingSystemVersion",
                .patch_level = "PatchLevel",
                .first_accessed_time = "FirstAccessedTime",
                .last_accessed_time = "LastAccessedTime",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_device_policy_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeDevicePolicyConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDevicePolicyConfiguration",
    Request: type = struct {
        fleet_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_device_policy_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_device_policy_configuration };
        }
    },
    Response: type = struct {
        device_ca_certificate: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_ca_certificate = "DeviceCaCertificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeDomain",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDomain",
    Request: type = struct {
        fleet_arn: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain };
        }
    },
    Response: type = struct {
        domain_name: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        created_time: ?i64 = null,
        domain_status: ?[]const u8 = null,
        acm_certificate_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .display_name = "DisplayName",
                .created_time = "CreatedTime",
                .domain_status = "DomainStatus",
                .acm_certificate_arn = "AcmCertificateArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_fleet_metadata: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeFleetMetadata",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFleetMetadata",
    Request: type = struct {
        fleet_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_metadata) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_metadata };
        }
    },
    Response: type = struct {
        created_time: ?i64 = null,
        last_updated_time: ?i64 = null,
        fleet_name: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        optimize_for_end_user_location: ?bool = null,
        company_code: ?[]const u8 = null,
        fleet_status: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_time = "CreatedTime",
                .last_updated_time = "LastUpdatedTime",
                .fleet_name = "FleetName",
                .display_name = "DisplayName",
                .optimize_for_end_user_location = "OptimizeForEndUserLocation",
                .company_code = "CompanyCode",
                .fleet_status = "FleetStatus",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_identity_provider_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeIdentityProviderConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIdentityProviderConfiguration",
    Request: type = struct {
        fleet_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_identity_provider_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_identity_provider_configuration };
        }
    },
    Response: type = struct {
        identity_provider_type: ?[]const u8 = null,
        service_provider_saml_metadata: ?[]const u8 = null,
        identity_provider_saml_metadata: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_provider_type = "IdentityProviderType",
                .service_provider_saml_metadata = "ServiceProviderSamlMetadata",
                .identity_provider_saml_metadata = "IdentityProviderSamlMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const describe_website_certificate_authority: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/describeWebsiteCertificateAuthority",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeWebsiteCertificateAuthority",
    Request: type = struct {
        fleet_arn: []const u8,
        website_ca_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .website_ca_id = "WebsiteCaId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_website_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = describe_website_certificate_authority };
        }
    },
    Response: type = struct {
        certificate: ?[]const u8 = null,
        created_time: ?i64 = null,
        display_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
                .created_time = "CreatedTime",
                .display_name = "DisplayName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const disassociate_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/disassociateDomain",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateDomain",
    Request: type = struct {
        fleet_arn: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_domain) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_domain };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const disassociate_website_authorization_provider: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/disassociateWebsiteAuthorizationProvider",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateWebsiteAuthorizationProvider",
    Request: type = struct {
        fleet_arn: []const u8,
        authorization_provider_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .authorization_provider_id = "AuthorizationProviderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_website_authorization_provider) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_website_authorization_provider };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const disassociate_website_certificate_authority: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/disassociateWebsiteCertificateAuthority",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateWebsiteCertificateAuthority",
    Request: type = struct {
        fleet_arn: []const u8,
        website_ca_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .website_ca_id = "WebsiteCaId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_website_certificate_authority) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_website_certificate_authority };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_devices: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listDevices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDevices",
    Request: type = struct {
        fleet_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_devices };
        }
    },
    Response: type = struct {
        devices: ?[]struct {
            device_id: ?[]const u8 = null,
            device_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_id = "DeviceId",
                    .device_status = "DeviceStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .devices = "Devices",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_domains: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listDomains",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomains",
    Request: type = struct {
        fleet_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domains) } {
            return .{ .service_metadata = service_metadata, .action = list_domains };
        }
    },
    Response: type = struct {
        domains: ?[]struct {
            domain_name: []const u8,
            display_name: ?[]const u8 = null,
            created_time: i64,
            domain_status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .display_name = "DisplayName",
                    .created_time = "CreatedTime",
                    .domain_status = "DomainStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domains = "Domains",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_fleets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listFleets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFleets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_fleets) } {
            return .{ .service_metadata = service_metadata, .action = list_fleets };
        }
    },
    Response: type = struct {
        fleet_summary_list: ?[]struct {
            fleet_arn: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            fleet_name: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            company_code: ?[]const u8 = null,
            fleet_status: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fleet_arn = "FleetArn",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .fleet_name = "FleetName",
                    .display_name = "DisplayName",
                    .company_code = "CompanyCode",
                    .fleet_status = "FleetStatus",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_summary_list = "FleetSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidRequest,
    },
} = .{};
pub const list_website_authorization_providers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listWebsiteAuthorizationProviders",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWebsiteAuthorizationProviders",
    Request: type = struct {
        fleet_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_website_authorization_providers) } {
            return .{ .service_metadata = service_metadata, .action = list_website_authorization_providers };
        }
    },
    Response: type = struct {
        website_authorization_providers: ?[]struct {
            authorization_provider_id: ?[]const u8 = null,
            authorization_provider_type: []const u8,
            domain_name: ?[]const u8 = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .authorization_provider_id = "AuthorizationProviderId",
                    .authorization_provider_type = "AuthorizationProviderType",
                    .domain_name = "DomainName",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .website_authorization_providers = "WebsiteAuthorizationProviders",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_website_certificate_authorities: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/listWebsiteCertificateAuthorities",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWebsiteCertificateAuthorities",
    Request: type = struct {
        fleet_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_website_certificate_authorities) } {
            return .{ .service_metadata = service_metadata, .action = list_website_certificate_authorities };
        }
    },
    Response: type = struct {
        website_certificate_authorities: ?[]struct {
            website_ca_id: ?[]const u8 = null,
            created_time: ?i64 = null,
            display_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .website_ca_id = "WebsiteCaId",
                    .created_time = "CreatedTime",
                    .display_name = "DisplayName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .website_certificate_authorities = "WebsiteCertificateAuthorities",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const restore_domain_access: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restoreDomainAccess",
        .success_code = 200,
    };

    action_name: []const u8 = "RestoreDomainAccess",
    Request: type = struct {
        fleet_arn: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_domain_access) } {
            return .{ .service_metadata = service_metadata, .action = restore_domain_access };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const revoke_domain_access: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/revokeDomainAccess",
        .success_code = 200,
    };

    action_name: []const u8 = "RevokeDomainAccess",
    Request: type = struct {
        fleet_arn: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_domain_access) } {
            return .{ .service_metadata = service_metadata, .action = revoke_domain_access };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const sign_out_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/signOutUser",
        .success_code = 200,
    };

    action_name: []const u8 = "SignOutUser",
    Request: type = struct {
        fleet_arn: []const u8,
        username: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .username = "Username",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(sign_out_user) } {
            return .{ .service_metadata = service_metadata, .action = sign_out_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
    },
} = .{};
pub const update_audit_stream_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateAuditStreamConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAuditStreamConfiguration",
    Request: type = struct {
        fleet_arn: []const u8,
        audit_stream_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .audit_stream_arn = "AuditStreamArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_audit_stream_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_audit_stream_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_company_network_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateCompanyNetworkConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateCompanyNetworkConfiguration",
    Request: type = struct {
        fleet_arn: []const u8,
        vpc_id: []const u8,
        subnet_ids: [][]const u8,
        security_group_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .vpc_id = "VpcId",
                .subnet_ids = "SubnetIds",
                .security_group_ids = "SecurityGroupIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_company_network_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_company_network_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_device_policy_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateDevicePolicyConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDevicePolicyConfiguration",
    Request: type = struct {
        fleet_arn: []const u8,
        device_ca_certificate: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .device_ca_certificate = "DeviceCaCertificate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device_policy_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_device_policy_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_domain_metadata: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateDomainMetadata",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDomainMetadata",
    Request: type = struct {
        fleet_arn: []const u8,
        domain_name: []const u8,
        display_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .domain_name = "DomainName",
                .display_name = "DisplayName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_domain_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_domain_metadata };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_fleet_metadata: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateFleetMetadata",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFleetMetadata",
    Request: type = struct {
        fleet_arn: []const u8,
        display_name: ?[]const u8 = null,
        optimize_for_end_user_location: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .display_name = "DisplayName",
                .optimize_for_end_user_location = "OptimizeForEndUserLocation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_fleet_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_fleet_metadata };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_identity_provider_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/updateIdentityProviderConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIdentityProviderConfiguration",
    Request: type = struct {
        fleet_arn: []const u8,
        identity_provider_type: []const u8,
        identity_provider_saml_metadata: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_arn = "FleetArn",
                .identity_provider_type = "IdentityProviderType",
                .identity_provider_saml_metadata = "IdentityProviderSamlMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_identity_provider_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_identity_provider_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServerError,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
