const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-10-01";
pub const sdk_id: []const u8 = "WorkMail";
pub const arn_namespace: ?[]const u8 = "workmail";
pub const endpoint_prefix: []const u8 = "workmail";
pub const sigv4_name: []const u8 = "workmail";
pub const name: []const u8 = "WorkMailService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-10-01",
    sdk_id: []const u8 = "WorkMail",
    arn_namespace: ?[]const u8 = "workmail",
    endpoint_prefix: []const u8 = "workmail",
    sigv4_name: []const u8 = "workmail",
    name: []const u8 = "WorkMailService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_delegate_to_resource: struct {
    action_name: []const u8 = "AssociateDelegateToResource",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,
        entity_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
                .entity_id = "EntityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_delegate_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = associate_delegate_to_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const associate_member_to_group: struct {
    action_name: []const u8 = "AssociateMemberToGroup",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,
        member_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
                .member_id = "MemberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_member_to_group) } {
            return .{ .service_metadata = service_metadata, .action = associate_member_to_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const assume_impersonation_role: struct {
    action_name: []const u8 = "AssumeImpersonationRole",
    Request: type = struct {
        organization_id: []const u8,
        impersonation_role_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .impersonation_role_id = "ImpersonationRoleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(assume_impersonation_role) } {
            return .{ .service_metadata = service_metadata, .action = assume_impersonation_role };
        }
    },
    Response: type = struct {
        token: ?[]const u8 = null,
        expires_in: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .token = "Token",
                .expires_in = "ExpiresIn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const cancel_mailbox_export_job: struct {
    action_name: []const u8 = "CancelMailboxExportJob",
    Request: type = struct {
        client_token: []const u8,
        job_id: []const u8,
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .job_id = "JobId",
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_mailbox_export_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_mailbox_export_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const create_alias: struct {
    action_name: []const u8 = "CreateAlias",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_alias };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EmailAddressInUse,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        LimitExceeded,
        MailDomainNotFound,
        MailDomainState,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const create_availability_configuration: struct {
    action_name: []const u8 = "CreateAvailabilityConfiguration",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        organization_id: []const u8,
        domain_name: []const u8,
        ews_provider: ?EwsAvailabilityProvider = null,
        lambda_provider: ?LambdaAvailabilityProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .organization_id = "OrganizationId",
                .domain_name = "DomainName",
                .ews_provider = "EwsProvider",
                .lambda_provider = "LambdaProvider",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_availability_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_availability_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LimitExceeded,
        NameAvailability,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const create_group: struct {
    action_name: []const u8 = "CreateGroup",
    Request: type = struct {
        organization_id: []const u8,
        name: []const u8,
        hidden_from_global_address_list: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .name = "Name",
                .hidden_from_global_address_list = "HiddenFromGlobalAddressList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group) } {
            return .{ .service_metadata = service_metadata, .action = create_group };
        }
    },
    Response: type = struct {
        group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        InvalidParameter,
        NameAvailability,
        OrganizationNotFound,
        OrganizationState,
        ReservedName,
        UnsupportedOperation,
    },
} = .{};
pub const create_impersonation_role: struct {
    action_name: []const u8 = "CreateImpersonationRole",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        organization_id: []const u8,
        name: []const u8,
        type: []const u8,
        description: ?[]const u8 = null,
        rules: []ImpersonationRule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .organization_id = "OrganizationId",
                .name = "Name",
                .type = "Type",
                .description = "Description",
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_impersonation_role) } {
            return .{ .service_metadata = service_metadata, .action = create_impersonation_role };
        }
    },
    Response: type = struct {
        impersonation_role_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .impersonation_role_id = "ImpersonationRoleId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        LimitExceeded,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const create_mobile_device_access_rule: struct {
    action_name: []const u8 = "CreateMobileDeviceAccessRule",
    Request: type = struct {
        organization_id: []const u8,
        client_token: ?[]const u8 = null,
        name: []const u8,
        description: ?[]const u8 = null,
        effect: []const u8,
        device_types: ?[][]const u8 = null,
        not_device_types: ?[][]const u8 = null,
        device_models: ?[][]const u8 = null,
        not_device_models: ?[][]const u8 = null,
        device_operating_systems: ?[][]const u8 = null,
        not_device_operating_systems: ?[][]const u8 = null,
        device_user_agents: ?[][]const u8 = null,
        not_device_user_agents: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .client_token = "ClientToken",
                .name = "Name",
                .description = "Description",
                .effect = "Effect",
                .device_types = "DeviceTypes",
                .not_device_types = "NotDeviceTypes",
                .device_models = "DeviceModels",
                .not_device_models = "NotDeviceModels",
                .device_operating_systems = "DeviceOperatingSystems",
                .not_device_operating_systems = "NotDeviceOperatingSystems",
                .device_user_agents = "DeviceUserAgents",
                .not_device_user_agents = "NotDeviceUserAgents",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_mobile_device_access_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_mobile_device_access_rule };
        }
    },
    Response: type = struct {
        mobile_device_access_rule_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mobile_device_access_rule_id = "MobileDeviceAccessRuleId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LimitExceeded,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const create_organization: struct {
    action_name: []const u8 = "CreateOrganization",
    Request: type = struct {
        directory_id: ?[]const u8 = null,
        alias: []const u8,
        client_token: ?[]const u8 = null,
        domains: ?[]struct {
            domain_name: []const u8,
            hosted_zone_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .hosted_zone_id = "HostedZoneId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        kms_key_arn: ?[]const u8 = null,
        enable_interoperability: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .alias = "Alias",
                .client_token = "ClientToken",
                .domains = "Domains",
                .kms_key_arn = "KmsKeyArn",
                .enable_interoperability = "EnableInteroperability",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_organization) } {
            return .{ .service_metadata = service_metadata, .action = create_organization };
        }
    },
    Response: type = struct {
        organization_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryInUse,
        DirectoryUnavailable,
        InvalidParameter,
        LimitExceeded,
        NameAvailability,
    },
} = .{};
pub const create_resource: struct {
    action_name: []const u8 = "CreateResource",
    Request: type = struct {
        organization_id: []const u8,
        name: []const u8,
        type: []const u8,
        description: ?[]const u8 = null,
        hidden_from_global_address_list: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .name = "Name",
                .type = "Type",
                .description = "Description",
                .hidden_from_global_address_list = "HiddenFromGlobalAddressList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource) } {
            return .{ .service_metadata = service_metadata, .action = create_resource };
        }
    },
    Response: type = struct {
        resource_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        InvalidParameter,
        NameAvailability,
        OrganizationNotFound,
        OrganizationState,
        ReservedName,
        UnsupportedOperation,
    },
} = .{};
pub const create_user: struct {
    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        organization_id: []const u8,
        name: []const u8,
        display_name: []const u8,
        password: ?[]const u8 = null,
        role: ?[]const u8 = null,
        first_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        hidden_from_global_address_list: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .name = "Name",
                .display_name = "DisplayName",
                .password = "Password",
                .role = "Role",
                .first_name = "FirstName",
                .last_name = "LastName",
                .hidden_from_global_address_list = "HiddenFromGlobalAddressList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        InvalidParameter,
        InvalidPassword,
        NameAvailability,
        OrganizationNotFound,
        OrganizationState,
        ReservedName,
        UnsupportedOperation,
    },
} = .{};
pub const delete_access_control_rule: struct {
    action_name: []const u8 = "DeleteAccessControlRule",
    Request: type = struct {
        organization_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_control_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_control_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_alias: struct {
    action_name: []const u8 = "DeleteAlias",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .alias = "Alias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_alias };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_availability_configuration: struct {
    action_name: []const u8 = "DeleteAvailabilityConfiguration",
    Request: type = struct {
        organization_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_availability_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_availability_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_email_monitoring_configuration: struct {
    action_name: []const u8 = "DeleteEmailMonitoringConfiguration",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_email_monitoring_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_email_monitoring_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_group: struct {
    action_name: []const u8 = "DeleteGroup",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const delete_impersonation_role: struct {
    action_name: []const u8 = "DeleteImpersonationRole",
    Request: type = struct {
        organization_id: []const u8,
        impersonation_role_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .impersonation_role_id = "ImpersonationRoleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_impersonation_role) } {
            return .{ .service_metadata = service_metadata, .action = delete_impersonation_role };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_mailbox_permissions: struct {
    action_name: []const u8 = "DeleteMailboxPermissions",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        grantee_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .grantee_id = "GranteeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_mailbox_permissions) } {
            return .{ .service_metadata = service_metadata, .action = delete_mailbox_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_mobile_device_access_override: struct {
    action_name: []const u8 = "DeleteMobileDeviceAccessOverride",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_mobile_device_access_override) } {
            return .{ .service_metadata = service_metadata, .action = delete_mobile_device_access_override };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_mobile_device_access_rule: struct {
    action_name: []const u8 = "DeleteMobileDeviceAccessRule",
    Request: type = struct {
        organization_id: []const u8,
        mobile_device_access_rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .mobile_device_access_rule_id = "MobileDeviceAccessRuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_mobile_device_access_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_mobile_device_access_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_organization: struct {
    action_name: []const u8 = "DeleteOrganization",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        organization_id: []const u8,
        delete_directory: bool,
        force_delete: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .organization_id = "OrganizationId",
                .delete_directory = "DeleteDirectory",
                .force_delete = "ForceDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_organization) } {
            return .{ .service_metadata = service_metadata, .action = delete_organization };
        }
    },
    Response: type = struct {
        organization_id: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_resource: struct {
    action_name: []const u8 = "DeleteResource",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const delete_retention_policy: struct {
    action_name: []const u8 = "DeleteRetentionPolicy",
    Request: type = struct {
        organization_id: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_retention_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_retention_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const delete_user: struct {
    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const deregister_from_work_mail: struct {
    action_name: []const u8 = "DeregisterFromWorkMail",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_from_work_mail) } {
            return .{ .service_metadata = service_metadata, .action = deregister_from_work_mail };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const deregister_mail_domain: struct {
    action_name: []const u8 = "DeregisterMailDomain",
    Request: type = struct {
        organization_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_mail_domain) } {
            return .{ .service_metadata = service_metadata, .action = deregister_mail_domain };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidCustomSesConfiguration,
        InvalidParameter,
        MailDomainInUse,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const describe_email_monitoring_configuration: struct {
    action_name: []const u8 = "DescribeEmailMonitoringConfiguration",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_email_monitoring_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_email_monitoring_configuration };
        }
    },
    Response: type = struct {
        role_arn: ?[]const u8 = null,
        log_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .role_arn = "RoleArn",
                .log_group_arn = "LogGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const describe_entity: struct {
    action_name: []const u8 = "DescribeEntity",
    Request: type = struct {
        organization_id: []const u8,
        email: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .email = "Email",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_entity) } {
            return .{ .service_metadata = service_metadata, .action = describe_entity };
        }
    },
    Response: type = struct {
        entity_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_id = "EntityId",
                .name = "Name",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const describe_group: struct {
    action_name: []const u8 = "DescribeGroup",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_group };
        }
    },
    Response: type = struct {
        group_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        email: ?[]const u8 = null,
        state: ?[]const u8 = null,
        enabled_date: ?i64 = null,
        disabled_date: ?i64 = null,
        hidden_from_global_address_list: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .name = "Name",
                .email = "Email",
                .state = "State",
                .enabled_date = "EnabledDate",
                .disabled_date = "DisabledDate",
                .hidden_from_global_address_list = "HiddenFromGlobalAddressList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const describe_inbound_dmarc_settings: struct {
    action_name: []const u8 = "DescribeInboundDmarcSettings",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_inbound_dmarc_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_inbound_dmarc_settings };
        }
    },
    Response: type = struct {
        enforced: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .enforced = "Enforced",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const describe_mailbox_export_job: struct {
    action_name: []const u8 = "DescribeMailboxExportJob",
    Request: type = struct {
        job_id: []const u8,
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_mailbox_export_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_mailbox_export_job };
        }
    },
    Response: type = struct {
        entity_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        s3_bucket_name: ?[]const u8 = null,
        s3_prefix: ?[]const u8 = null,
        s3_path: ?[]const u8 = null,
        estimated_progress: ?i64 = null,
        state: ?[]const u8 = null,
        error_info: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_id = "EntityId",
                .description = "Description",
                .role_arn = "RoleArn",
                .kms_key_arn = "KmsKeyArn",
                .s3_bucket_name = "S3BucketName",
                .s3_prefix = "S3Prefix",
                .s3_path = "S3Path",
                .estimated_progress = "EstimatedProgress",
                .state = "State",
                .error_info = "ErrorInfo",
                .start_time = "StartTime",
                .end_time = "EndTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const describe_organization: struct {
    action_name: []const u8 = "DescribeOrganization",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_organization) } {
            return .{ .service_metadata = service_metadata, .action = describe_organization };
        }
    },
    Response: type = struct {
        organization_id: ?[]const u8 = null,
        alias: ?[]const u8 = null,
        state: ?[]const u8 = null,
        directory_id: ?[]const u8 = null,
        directory_type: ?[]const u8 = null,
        default_mail_domain: ?[]const u8 = null,
        completed_date: ?i64 = null,
        error_message: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        migration_admin: ?[]const u8 = null,
        interoperability_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .alias = "Alias",
                .state = "State",
                .directory_id = "DirectoryId",
                .directory_type = "DirectoryType",
                .default_mail_domain = "DefaultMailDomain",
                .completed_date = "CompletedDate",
                .error_message = "ErrorMessage",
                .arn = "ARN",
                .migration_admin = "MigrationAdmin",
                .interoperability_enabled = "InteroperabilityEnabled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
    },
} = .{};
pub const describe_resource: struct {
    action_name: []const u8 = "DescribeResource",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource };
        }
    },
    Response: type = struct {
        resource_id: ?[]const u8 = null,
        email: ?[]const u8 = null,
        name: ?[]const u8 = null,
        type: ?[]const u8 = null,
        booking_options: ?BookingOptions = null,
        state: ?[]const u8 = null,
        enabled_date: ?i64 = null,
        disabled_date: ?i64 = null,
        description: ?[]const u8 = null,
        hidden_from_global_address_list: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .email = "Email",
                .name = "Name",
                .type = "Type",
                .booking_options = "BookingOptions",
                .state = "State",
                .enabled_date = "EnabledDate",
                .disabled_date = "DisabledDate",
                .description = "Description",
                .hidden_from_global_address_list = "HiddenFromGlobalAddressList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const describe_user: struct {
    action_name: []const u8 = "DescribeUser",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        email: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        state: ?[]const u8 = null,
        user_role: ?[]const u8 = null,
        enabled_date: ?i64 = null,
        disabled_date: ?i64 = null,
        mailbox_provisioned_date: ?i64 = null,
        mailbox_deprovisioned_date: ?i64 = null,
        first_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        hidden_from_global_address_list: ?bool = null,
        initials: ?[]const u8 = null,
        telephone: ?[]const u8 = null,
        street: ?[]const u8 = null,
        job_title: ?[]const u8 = null,
        city: ?[]const u8 = null,
        company: ?[]const u8 = null,
        zip_code: ?[]const u8 = null,
        department: ?[]const u8 = null,
        country: ?[]const u8 = null,
        office: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .name = "Name",
                .email = "Email",
                .display_name = "DisplayName",
                .state = "State",
                .user_role = "UserRole",
                .enabled_date = "EnabledDate",
                .disabled_date = "DisabledDate",
                .mailbox_provisioned_date = "MailboxProvisionedDate",
                .mailbox_deprovisioned_date = "MailboxDeprovisionedDate",
                .first_name = "FirstName",
                .last_name = "LastName",
                .hidden_from_global_address_list = "HiddenFromGlobalAddressList",
                .initials = "Initials",
                .telephone = "Telephone",
                .street = "Street",
                .job_title = "JobTitle",
                .city = "City",
                .company = "Company",
                .zip_code = "ZipCode",
                .department = "Department",
                .country = "Country",
                .office = "Office",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const disassociate_delegate_from_resource: struct {
    action_name: []const u8 = "DisassociateDelegateFromResource",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,
        entity_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
                .entity_id = "EntityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_delegate_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_delegate_from_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const disassociate_member_from_group: struct {
    action_name: []const u8 = "DisassociateMemberFromGroup",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,
        member_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
                .member_id = "MemberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_member_from_group) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_member_from_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const get_access_control_effect: struct {
    action_name: []const u8 = "GetAccessControlEffect",
    Request: type = struct {
        organization_id: []const u8,
        ip_address: []const u8,
        action: []const u8,
        user_id: ?[]const u8 = null,
        impersonation_role_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .ip_address = "IpAddress",
                .action = "Action",
                .user_id = "UserId",
                .impersonation_role_id = "ImpersonationRoleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_control_effect) } {
            return .{ .service_metadata = service_metadata, .action = get_access_control_effect };
        }
    },
    Response: type = struct {
        effect: ?[]const u8 = null,
        matched_rules: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .effect = "Effect",
                .matched_rules = "MatchedRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const get_default_retention_policy: struct {
    action_name: []const u8 = "GetDefaultRetentionPolicy",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_default_retention_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_default_retention_policy };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        folder_configurations: ?[]FolderConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .folder_configurations = "FolderConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const get_impersonation_role: struct {
    action_name: []const u8 = "GetImpersonationRole",
    Request: type = struct {
        organization_id: []const u8,
        impersonation_role_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .impersonation_role_id = "ImpersonationRoleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_impersonation_role) } {
            return .{ .service_metadata = service_metadata, .action = get_impersonation_role };
        }
    },
    Response: type = struct {
        impersonation_role_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        rules: ?[]ImpersonationRule = null,
        date_created: ?i64 = null,
        date_modified: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .impersonation_role_id = "ImpersonationRoleId",
                .name = "Name",
                .type = "Type",
                .description = "Description",
                .rules = "Rules",
                .date_created = "DateCreated",
                .date_modified = "DateModified",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const get_impersonation_role_effect: struct {
    action_name: []const u8 = "GetImpersonationRoleEffect",
    Request: type = struct {
        organization_id: []const u8,
        impersonation_role_id: []const u8,
        target_user: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .impersonation_role_id = "ImpersonationRoleId",
                .target_user = "TargetUser",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_impersonation_role_effect) } {
            return .{ .service_metadata = service_metadata, .action = get_impersonation_role_effect };
        }
    },
    Response: type = struct {
        type: ?[]const u8 = null,
        effect: ?[]const u8 = null,
        matched_rules: ?[]struct {
            impersonation_rule_id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .impersonation_rule_id = "ImpersonationRuleId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .effect = "Effect",
                .matched_rules = "MatchedRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const get_mailbox_details: struct {
    action_name: []const u8 = "GetMailboxDetails",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_mailbox_details) } {
            return .{ .service_metadata = service_metadata, .action = get_mailbox_details };
        }
    },
    Response: type = struct {
        mailbox_quota: ?i64 = null,
        mailbox_size: ?f64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mailbox_quota = "MailboxQuota",
                .mailbox_size = "MailboxSize",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const get_mail_domain: struct {
    action_name: []const u8 = "GetMailDomain",
    Request: type = struct {
        organization_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_mail_domain) } {
            return .{ .service_metadata = service_metadata, .action = get_mail_domain };
        }
    },
    Response: type = struct {
        records: ?[]struct {
            type: ?[]const u8 = null,
            hostname: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .hostname = "Hostname",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        is_test_domain: ?bool = null,
        is_default: ?bool = null,
        ownership_verification_status: ?[]const u8 = null,
        dkim_verification_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .records = "Records",
                .is_test_domain = "IsTestDomain",
                .is_default = "IsDefault",
                .ownership_verification_status = "OwnershipVerificationStatus",
                .dkim_verification_status = "DkimVerificationStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MailDomainNotFound,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const get_mobile_device_access_effect: struct {
    action_name: []const u8 = "GetMobileDeviceAccessEffect",
    Request: type = struct {
        organization_id: []const u8,
        device_type: ?[]const u8 = null,
        device_model: ?[]const u8 = null,
        device_operating_system: ?[]const u8 = null,
        device_user_agent: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .device_type = "DeviceType",
                .device_model = "DeviceModel",
                .device_operating_system = "DeviceOperatingSystem",
                .device_user_agent = "DeviceUserAgent",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_mobile_device_access_effect) } {
            return .{ .service_metadata = service_metadata, .action = get_mobile_device_access_effect };
        }
    },
    Response: type = struct {
        effect: ?[]const u8 = null,
        matched_rules: ?[]struct {
            mobile_device_access_rule_id: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mobile_device_access_rule_id = "MobileDeviceAccessRuleId",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .effect = "Effect",
                .matched_rules = "MatchedRules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const get_mobile_device_access_override: struct {
    action_name: []const u8 = "GetMobileDeviceAccessOverride",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,
        device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
                .device_id = "DeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_mobile_device_access_override) } {
            return .{ .service_metadata = service_metadata, .action = get_mobile_device_access_override };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        device_id: ?[]const u8 = null,
        effect: ?[]const u8 = null,
        description: ?[]const u8 = null,
        date_created: ?i64 = null,
        date_modified: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .device_id = "DeviceId",
                .effect = "Effect",
                .description = "Description",
                .date_created = "DateCreated",
                .date_modified = "DateModified",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const list_access_control_rules: struct {
    action_name: []const u8 = "ListAccessControlRules",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_control_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_access_control_rules };
        }
    },
    Response: type = struct {
        rules: ?[]struct {
            name: ?[]const u8 = null,
            effect: ?[]const u8 = null,
            description: ?[]const u8 = null,
            ip_ranges: ?[][]const u8 = null,
            not_ip_ranges: ?[][]const u8 = null,
            actions: ?[][]const u8 = null,
            not_actions: ?[][]const u8 = null,
            user_ids: ?[][]const u8 = null,
            not_user_ids: ?[][]const u8 = null,
            date_created: ?i64 = null,
            date_modified: ?i64 = null,
            impersonation_role_ids: ?[][]const u8 = null,
            not_impersonation_role_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .effect = "Effect",
                    .description = "Description",
                    .ip_ranges = "IpRanges",
                    .not_ip_ranges = "NotIpRanges",
                    .actions = "Actions",
                    .not_actions = "NotActions",
                    .user_ids = "UserIds",
                    .not_user_ids = "NotUserIds",
                    .date_created = "DateCreated",
                    .date_modified = "DateModified",
                    .impersonation_role_ids = "ImpersonationRoleIds",
                    .not_impersonation_role_ids = "NotImpersonationRoleIds",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_aliases: struct {
    action_name: []const u8 = "ListAliases",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_aliases };
        }
    },
    Response: type = struct {
        aliases: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aliases = "Aliases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_availability_configurations: struct {
    action_name: []const u8 = "ListAvailabilityConfigurations",
    Request: type = struct {
        organization_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_availability_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_availability_configurations };
        }
    },
    Response: type = struct {
        availability_configurations: ?[]struct {
            domain_name: ?[]const u8 = null,
            provider_type: ?[]const u8 = null,
            ews_provider: ?struct {
                ews_endpoint: ?[]const u8 = null,
                ews_username: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .ews_endpoint = "EwsEndpoint",
                        .ews_username = "EwsUsername",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lambda_provider: ?LambdaAvailabilityProvider = null,
            date_created: ?i64 = null,
            date_modified: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .provider_type = "ProviderType",
                    .ews_provider = "EwsProvider",
                    .lambda_provider = "LambdaProvider",
                    .date_created = "DateCreated",
                    .date_modified = "DateModified",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_configurations = "AvailabilityConfigurations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_group_members: struct {
    action_name: []const u8 = "ListGroupMembers",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_group_members) } {
            return .{ .service_metadata = service_metadata, .action = list_group_members };
        }
    },
    Response: type = struct {
        members: ?[]struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            enabled_date: ?i64 = null,
            disabled_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .type = "Type",
                    .state = "State",
                    .enabled_date = "EnabledDate",
                    .disabled_date = "DisabledDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "Members",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_groups: struct {
    action_name: []const u8 = "ListGroups",
    Request: type = struct {
        organization_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?struct {
            name_prefix: ?[]const u8 = null,
            primary_email_prefix: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name_prefix = "NamePrefix",
                    .primary_email_prefix = "PrimaryEmailPrefix",
                    .state = "State",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_groups };
        }
    },
    Response: type = struct {
        groups: ?[]struct {
            id: ?[]const u8 = null,
            email: ?[]const u8 = null,
            name: ?[]const u8 = null,
            state: ?[]const u8 = null,
            enabled_date: ?i64 = null,
            disabled_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .email = "Email",
                    .name = "Name",
                    .state = "State",
                    .enabled_date = "EnabledDate",
                    .disabled_date = "DisabledDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "Groups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_groups_for_entity: struct {
    action_name: []const u8 = "ListGroupsForEntity",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        filters: ?struct {
            group_name_prefix: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_name_prefix = "GroupNamePrefix",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups_for_entity) } {
            return .{ .service_metadata = service_metadata, .action = list_groups_for_entity };
        }
    },
    Response: type = struct {
        groups: ?[]struct {
            group_id: ?[]const u8 = null,
            group_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_id = "GroupId",
                    .group_name = "GroupName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "Groups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_impersonation_roles: struct {
    action_name: []const u8 = "ListImpersonationRoles",
    Request: type = struct {
        organization_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_impersonation_roles) } {
            return .{ .service_metadata = service_metadata, .action = list_impersonation_roles };
        }
    },
    Response: type = struct {
        roles: ?[]struct {
            impersonation_role_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            date_created: ?i64 = null,
            date_modified: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .impersonation_role_id = "ImpersonationRoleId",
                    .name = "Name",
                    .type = "Type",
                    .date_created = "DateCreated",
                    .date_modified = "DateModified",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .roles = "Roles",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_mailbox_export_jobs: struct {
    action_name: []const u8 = "ListMailboxExportJobs",
    Request: type = struct {
        organization_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_mailbox_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_mailbox_export_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            job_id: ?[]const u8 = null,
            entity_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            s3_bucket_name: ?[]const u8 = null,
            s3_path: ?[]const u8 = null,
            estimated_progress: ?i64 = null,
            state: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .entity_id = "EntityId",
                    .description = "Description",
                    .s3_bucket_name = "S3BucketName",
                    .s3_path = "S3Path",
                    .estimated_progress = "EstimatedProgress",
                    .state = "State",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_mailbox_permissions: struct {
    action_name: []const u8 = "ListMailboxPermissions",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_mailbox_permissions) } {
            return .{ .service_metadata = service_metadata, .action = list_mailbox_permissions };
        }
    },
    Response: type = struct {
        permissions: ?[]struct {
            grantee_id: []const u8,
            grantee_type: []const u8,
            permission_values: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .grantee_id = "GranteeId",
                    .grantee_type = "GranteeType",
                    .permission_values = "PermissionValues",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "Permissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_mail_domains: struct {
    action_name: []const u8 = "ListMailDomains",
    Request: type = struct {
        organization_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_mail_domains) } {
            return .{ .service_metadata = service_metadata, .action = list_mail_domains };
        }
    },
    Response: type = struct {
        mail_domains: ?[]struct {
            domain_name: ?[]const u8 = null,
            default_domain: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .default_domain = "DefaultDomain",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mail_domains = "MailDomains",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_mobile_device_access_overrides: struct {
    action_name: []const u8 = "ListMobileDeviceAccessOverrides",
    Request: type = struct {
        organization_id: []const u8,
        user_id: ?[]const u8 = null,
        device_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
                .device_id = "DeviceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_mobile_device_access_overrides) } {
            return .{ .service_metadata = service_metadata, .action = list_mobile_device_access_overrides };
        }
    },
    Response: type = struct {
        overrides: ?[]struct {
            user_id: ?[]const u8 = null,
            device_id: ?[]const u8 = null,
            effect: ?[]const u8 = null,
            description: ?[]const u8 = null,
            date_created: ?i64 = null,
            date_modified: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_id = "UserId",
                    .device_id = "DeviceId",
                    .effect = "Effect",
                    .description = "Description",
                    .date_created = "DateCreated",
                    .date_modified = "DateModified",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .overrides = "Overrides",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_mobile_device_access_rules: struct {
    action_name: []const u8 = "ListMobileDeviceAccessRules",
    Request: type = struct {
        organization_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_mobile_device_access_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_mobile_device_access_rules };
        }
    },
    Response: type = struct {
        rules: ?[]struct {
            mobile_device_access_rule_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            effect: ?[]const u8 = null,
            device_types: ?[][]const u8 = null,
            not_device_types: ?[][]const u8 = null,
            device_models: ?[][]const u8 = null,
            not_device_models: ?[][]const u8 = null,
            device_operating_systems: ?[][]const u8 = null,
            not_device_operating_systems: ?[][]const u8 = null,
            device_user_agents: ?[][]const u8 = null,
            not_device_user_agents: ?[][]const u8 = null,
            date_created: ?i64 = null,
            date_modified: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mobile_device_access_rule_id = "MobileDeviceAccessRuleId",
                    .name = "Name",
                    .description = "Description",
                    .effect = "Effect",
                    .device_types = "DeviceTypes",
                    .not_device_types = "NotDeviceTypes",
                    .device_models = "DeviceModels",
                    .not_device_models = "NotDeviceModels",
                    .device_operating_systems = "DeviceOperatingSystems",
                    .not_device_operating_systems = "NotDeviceOperatingSystems",
                    .device_user_agents = "DeviceUserAgents",
                    .not_device_user_agents = "NotDeviceUserAgents",
                    .date_created = "DateCreated",
                    .date_modified = "DateModified",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const list_organizations: struct {
    action_name: []const u8 = "ListOrganizations",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_organizations) } {
            return .{ .service_metadata = service_metadata, .action = list_organizations };
        }
    },
    Response: type = struct {
        organization_summaries: ?[]struct {
            organization_id: ?[]const u8 = null,
            alias: ?[]const u8 = null,
            default_mail_domain: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .organization_id = "OrganizationId",
                    .alias = "Alias",
                    .default_mail_domain = "DefaultMailDomain",
                    .error_message = "ErrorMessage",
                    .state = "State",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_summaries = "OrganizationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
    },
} = .{};
pub const list_resource_delegates: struct {
    action_name: []const u8 = "ListResourceDelegates",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_delegates) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_delegates };
        }
    },
    Response: type = struct {
        delegates: ?[]struct {
            id: []const u8,
            type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delegates = "Delegates",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const list_resources: struct {
    action_name: []const u8 = "ListResources",
    Request: type = struct {
        organization_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?struct {
            name_prefix: ?[]const u8 = null,
            primary_email_prefix: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name_prefix = "NamePrefix",
                    .primary_email_prefix = "PrimaryEmailPrefix",
                    .state = "State",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_resources };
        }
    },
    Response: type = struct {
        resources: ?[]struct {
            id: ?[]const u8 = null,
            email: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            enabled_date: ?i64 = null,
            disabled_date: ?i64 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .email = "Email",
                    .name = "Name",
                    .type = "Type",
                    .state = "State",
                    .enabled_date = "EnabledDate",
                    .disabled_date = "DisabledDate",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resources = "Resources",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_users: struct {
    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        organization_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?struct {
            username_prefix: ?[]const u8 = null,
            display_name_prefix: ?[]const u8 = null,
            primary_email_prefix: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .username_prefix = "UsernamePrefix",
                    .display_name_prefix = "DisplayNamePrefix",
                    .primary_email_prefix = "PrimaryEmailPrefix",
                    .state = "State",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        users: ?[]struct {
            id: ?[]const u8 = null,
            email: ?[]const u8 = null,
            name: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            state: ?[]const u8 = null,
            user_role: ?[]const u8 = null,
            enabled_date: ?i64 = null,
            disabled_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .email = "Email",
                    .name = "Name",
                    .display_name = "DisplayName",
                    .state = "State",
                    .user_role = "UserRole",
                    .enabled_date = "EnabledDate",
                    .disabled_date = "DisabledDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const put_access_control_rule: struct {
    action_name: []const u8 = "PutAccessControlRule",
    Request: type = struct {
        name: []const u8,
        effect: []const u8,
        description: []const u8,
        ip_ranges: ?[][]const u8 = null,
        not_ip_ranges: ?[][]const u8 = null,
        actions: ?[][]const u8 = null,
        not_actions: ?[][]const u8 = null,
        user_ids: ?[][]const u8 = null,
        not_user_ids: ?[][]const u8 = null,
        organization_id: []const u8,
        impersonation_role_ids: ?[][]const u8 = null,
        not_impersonation_role_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .effect = "Effect",
                .description = "Description",
                .ip_ranges = "IpRanges",
                .not_ip_ranges = "NotIpRanges",
                .actions = "Actions",
                .not_actions = "NotActions",
                .user_ids = "UserIds",
                .not_user_ids = "NotUserIds",
                .organization_id = "OrganizationId",
                .impersonation_role_ids = "ImpersonationRoleIds",
                .not_impersonation_role_ids = "NotImpersonationRoleIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_access_control_rule) } {
            return .{ .service_metadata = service_metadata, .action = put_access_control_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        LimitExceeded,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const put_email_monitoring_configuration: struct {
    action_name: []const u8 = "PutEmailMonitoringConfiguration",
    Request: type = struct {
        organization_id: []const u8,
        role_arn: []const u8,
        log_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .role_arn = "RoleArn",
                .log_group_arn = "LogGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_email_monitoring_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_email_monitoring_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const put_inbound_dmarc_settings: struct {
    action_name: []const u8 = "PutInboundDmarcSettings",
    Request: type = struct {
        organization_id: []const u8,
        enforced: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .enforced = "Enforced",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_inbound_dmarc_settings) } {
            return .{ .service_metadata = service_metadata, .action = put_inbound_dmarc_settings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const put_mailbox_permissions: struct {
    action_name: []const u8 = "PutMailboxPermissions",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        grantee_id: []const u8,
        permission_values: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .grantee_id = "GranteeId",
                .permission_values = "PermissionValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_mailbox_permissions) } {
            return .{ .service_metadata = service_metadata, .action = put_mailbox_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const put_mobile_device_access_override: struct {
    action_name: []const u8 = "PutMobileDeviceAccessOverride",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,
        device_id: []const u8,
        effect: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
                .device_id = "DeviceId",
                .effect = "Effect",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_mobile_device_access_override) } {
            return .{ .service_metadata = service_metadata, .action = put_mobile_device_access_override };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const put_retention_policy: struct {
    action_name: []const u8 = "PutRetentionPolicy",
    Request: type = struct {
        organization_id: []const u8,
        id: ?[]const u8 = null,
        name: []const u8,
        description: ?[]const u8 = null,
        folder_configurations: []FolderConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .folder_configurations = "FolderConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_retention_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_retention_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LimitExceeded,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const register_mail_domain: struct {
    action_name: []const u8 = "RegisterMailDomain",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        organization_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .organization_id = "OrganizationId",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_mail_domain) } {
            return .{ .service_metadata = service_metadata, .action = register_mail_domain };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LimitExceeded,
        MailDomainInUse,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const register_to_work_mail: struct {
    action_name: []const u8 = "RegisterToWorkMail",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        email: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .email = "Email",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_to_work_mail) } {
            return .{ .service_metadata = service_metadata, .action = register_to_work_mail };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EmailAddressInUse,
        EntityAlreadyRegistered,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        MailDomainNotFound,
        MailDomainState,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const reset_password: struct {
    action_name: []const u8 = "ResetPassword",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,
        password: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
                .password = "Password",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_password) } {
            return .{ .service_metadata = service_metadata, .action = reset_password };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        InvalidPassword,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const start_mailbox_export_job: struct {
    action_name: []const u8 = "StartMailboxExportJob",
    Request: type = struct {
        client_token: []const u8,
        organization_id: []const u8,
        entity_id: []const u8,
        description: ?[]const u8 = null,
        role_arn: []const u8,
        kms_key_arn: []const u8,
        s3_bucket_name: []const u8,
        s3_prefix: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .description = "Description",
                .role_arn = "RoleArn",
                .kms_key_arn = "KmsKeyArn",
                .s3_bucket_name = "S3BucketName",
                .s3_prefix = "S3Prefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_mailbox_export_job) } {
            return .{ .service_metadata = service_metadata, .action = start_mailbox_export_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        LimitExceeded,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationState,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const test_availability_configuration: struct {
    action_name: []const u8 = "TestAvailabilityConfiguration",
    Request: type = struct {
        organization_id: []const u8,
        domain_name: ?[]const u8 = null,
        ews_provider: ?EwsAvailabilityProvider = null,
        lambda_provider: ?LambdaAvailabilityProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .domain_name = "DomainName",
                .ews_provider = "EwsProvider",
                .lambda_provider = "LambdaProvider",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_availability_configuration) } {
            return .{ .service_metadata = service_metadata, .action = test_availability_configuration };
        }
    },
    Response: type = struct {
        test_passed: ?bool = null,
        failure_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .test_passed = "TestPassed",
                .failure_reason = "FailureReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_availability_configuration: struct {
    action_name: []const u8 = "UpdateAvailabilityConfiguration",
    Request: type = struct {
        organization_id: []const u8,
        domain_name: []const u8,
        ews_provider: ?EwsAvailabilityProvider = null,
        lambda_provider: ?LambdaAvailabilityProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .domain_name = "DomainName",
                .ews_provider = "EwsProvider",
                .lambda_provider = "LambdaProvider",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_availability_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_availability_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const update_default_mail_domain: struct {
    action_name: []const u8 = "UpdateDefaultMailDomain",
    Request: type = struct {
        organization_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_default_mail_domain) } {
            return .{ .service_metadata = service_metadata, .action = update_default_mail_domain };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        MailDomainNotFound,
        MailDomainState,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const update_group: struct {
    action_name: []const u8 = "UpdateGroup",
    Request: type = struct {
        organization_id: []const u8,
        group_id: []const u8,
        hidden_from_global_address_list: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .group_id = "GroupId",
                .hidden_from_global_address_list = "HiddenFromGlobalAddressList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_group) } {
            return .{ .service_metadata = service_metadata, .action = update_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const update_impersonation_role: struct {
    action_name: []const u8 = "UpdateImpersonationRole",
    Request: type = struct {
        organization_id: []const u8,
        impersonation_role_id: []const u8,
        name: []const u8,
        type: []const u8,
        description: ?[]const u8 = null,
        rules: []ImpersonationRule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .impersonation_role_id = "ImpersonationRoleId",
                .name = "Name",
                .type = "Type",
                .description = "Description",
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_impersonation_role) } {
            return .{ .service_metadata = service_metadata, .action = update_impersonation_role };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        LimitExceeded,
        OrganizationNotFound,
        OrganizationState,
        ResourceNotFound,
    },
} = .{};
pub const update_mailbox_quota: struct {
    action_name: []const u8 = "UpdateMailboxQuota",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,
        mailbox_quota: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
                .mailbox_quota = "MailboxQuota",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_mailbox_quota) } {
            return .{ .service_metadata = service_metadata, .action = update_mailbox_quota };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const update_mobile_device_access_rule: struct {
    action_name: []const u8 = "UpdateMobileDeviceAccessRule",
    Request: type = struct {
        organization_id: []const u8,
        mobile_device_access_rule_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        effect: []const u8,
        device_types: ?[][]const u8 = null,
        not_device_types: ?[][]const u8 = null,
        device_models: ?[][]const u8 = null,
        not_device_models: ?[][]const u8 = null,
        device_operating_systems: ?[][]const u8 = null,
        not_device_operating_systems: ?[][]const u8 = null,
        device_user_agents: ?[][]const u8 = null,
        not_device_user_agents: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .mobile_device_access_rule_id = "MobileDeviceAccessRuleId",
                .name = "Name",
                .description = "Description",
                .effect = "Effect",
                .device_types = "DeviceTypes",
                .not_device_types = "NotDeviceTypes",
                .device_models = "DeviceModels",
                .not_device_models = "NotDeviceModels",
                .device_operating_systems = "DeviceOperatingSystems",
                .not_device_operating_systems = "NotDeviceOperatingSystems",
                .device_user_agents = "DeviceUserAgents",
                .not_device_user_agents = "NotDeviceUserAgents",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_mobile_device_access_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_mobile_device_access_rule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
    },
} = .{};
pub const update_primary_email_address: struct {
    action_name: []const u8 = "UpdatePrimaryEmailAddress",
    Request: type = struct {
        organization_id: []const u8,
        entity_id: []const u8,
        email: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .entity_id = "EntityId",
                .email = "Email",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_primary_email_address) } {
            return .{ .service_metadata = service_metadata, .action = update_primary_email_address };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EmailAddressInUse,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        MailDomainNotFound,
        MailDomainState,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const update_resource: struct {
    action_name: []const u8 = "UpdateResource",
    Request: type = struct {
        organization_id: []const u8,
        resource_id: []const u8,
        name: ?[]const u8 = null,
        booking_options: ?BookingOptions = null,
        description: ?[]const u8 = null,
        type: ?[]const u8 = null,
        hidden_from_global_address_list: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .resource_id = "ResourceId",
                .name = "Name",
                .booking_options = "BookingOptions",
                .description = "Description",
                .type = "Type",
                .hidden_from_global_address_list = "HiddenFromGlobalAddressList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource) } {
            return .{ .service_metadata = service_metadata, .action = update_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryUnavailable,
        EmailAddressInUse,
        EntityNotFound,
        EntityState,
        InvalidConfiguration,
        InvalidParameter,
        MailDomainNotFound,
        MailDomainState,
        NameAvailability,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};
pub const update_user: struct {
    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        organization_id: []const u8,
        user_id: []const u8,
        role: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        first_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        hidden_from_global_address_list: ?bool = null,
        initials: ?[]const u8 = null,
        telephone: ?[]const u8 = null,
        street: ?[]const u8 = null,
        job_title: ?[]const u8 = null,
        city: ?[]const u8 = null,
        company: ?[]const u8 = null,
        zip_code: ?[]const u8 = null,
        department: ?[]const u8 = null,
        country: ?[]const u8 = null,
        office: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .organization_id = "OrganizationId",
                .user_id = "UserId",
                .role = "Role",
                .display_name = "DisplayName",
                .first_name = "FirstName",
                .last_name = "LastName",
                .hidden_from_global_address_list = "HiddenFromGlobalAddressList",
                .initials = "Initials",
                .telephone = "Telephone",
                .street = "Street",
                .job_title = "JobTitle",
                .city = "City",
                .company = "Company",
                .zip_code = "ZipCode",
                .department = "Department",
                .country = "Country",
                .office = "Office",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DirectoryServiceAuthenticationFailed,
        DirectoryUnavailable,
        EntityNotFound,
        EntityState,
        InvalidParameter,
        OrganizationNotFound,
        OrganizationState,
        UnsupportedOperation,
    },
} = .{};

pub const BookingOptions = struct {
    auto_accept_requests: ?bool = null,
    auto_decline_recurring_requests: ?bool = null,
    auto_decline_conflicting_requests: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_accept_requests = "AutoAcceptRequests",
            .auto_decline_recurring_requests = "AutoDeclineRecurringRequests",
            .auto_decline_conflicting_requests = "AutoDeclineConflictingRequests",
        };
        return @field(mappings, field_name);
    }
};

pub const ImpersonationRule = struct {
    impersonation_rule_id: []const u8,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    effect: []const u8,
    target_users: ?[][]const u8 = null,
    not_target_users: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .impersonation_rule_id = "ImpersonationRuleId",
            .name = "Name",
            .description = "Description",
            .effect = "Effect",
            .target_users = "TargetUsers",
            .not_target_users = "NotTargetUsers",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaAvailabilityProvider = struct {
    lambda_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_arn = "LambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const EwsAvailabilityProvider = struct {
    ews_endpoint: []const u8,
    ews_username: []const u8,
    ews_password: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ews_endpoint = "EwsEndpoint",
            .ews_username = "EwsUsername",
            .ews_password = "EwsPassword",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const FolderConfiguration = struct {
    name: []const u8,
    action: []const u8,
    period: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .action = "Action",
            .period = "Period",
        };
        return @field(mappings, field_name);
    }
};
