const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-05-01";
pub const sdk_id: []const u8 = "WorkMailMessageFlow";
pub const arn_namespace: ?[]const u8 = "workmailmessageflow";
pub const endpoint_prefix: []const u8 = "workmailmessageflow";
pub const sigv4_name: []const u8 = "workmailmessageflow";
pub const name: []const u8 = "GiraffeMessageInTransitService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-05-01",
    sdk_id: []const u8 = "WorkMailMessageFlow",
    arn_namespace: ?[]const u8 = "workmailmessageflow",
    endpoint_prefix: []const u8 = "workmailmessageflow",
    sigv4_name: []const u8 = "workmailmessageflow",
    name: []const u8 = "GiraffeMessageInTransitService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const get_raw_message_content: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/messages/{messageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRawMessageContent",
    Request: type = struct {
        message_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "messageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_raw_message_content) } {
            return .{ .service_metadata = service_metadata, .action = get_raw_message_content };
        }
    },
    Response: type = struct {
        message_content: []const u8,

        pub const http_payload: []const u8 = "message_content";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_content = "messageContent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const put_raw_message_content: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/messages/{messageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutRawMessageContent",
    Request: type = struct {
        message_id: []const u8,
        content: struct {
            s3_reference: struct {
                bucket: []const u8,
                key: []const u8,
                object_version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bucket = "bucket",
                        .key = "key",
                        .object_version = "objectVersion",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_reference = "s3Reference",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "messageId",
                .content = "content",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_raw_message_content) } {
            return .{ .service_metadata = service_metadata, .action = put_raw_message_content };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidContentLocation,
        MessageFrozen,
        MessageRejected,
        ResourceNotFound,
    },
} = .{};
