const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-04-08";
pub const sdk_id: []const u8 = "WorkSpaces";
pub const arn_namespace: ?[]const u8 = "workspaces";
pub const endpoint_prefix: []const u8 = "workspaces";
pub const sigv4_name: []const u8 = "workspaces";
pub const name: []const u8 = "WorkspacesService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-04-08",
    sdk_id: []const u8 = "WorkSpaces",
    arn_namespace: ?[]const u8 = "workspaces",
    endpoint_prefix: []const u8 = "workspaces",
    sigv4_name: []const u8 = "workspaces",
    name: []const u8 = "WorkspacesService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_connection_alias: struct {
    action_name: []const u8 = "AssociateConnectionAlias",
    Request: type = struct {
        alias_id: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_connection_alias) } {
            return .{ .service_metadata = service_metadata, .action = associate_connection_alias };
        }
    },
    Response: type = struct {
        connection_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_identifier = "ConnectionIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceAssociated,
        ResourceNotFound,
    },
} = .{};
pub const associate_ip_groups: struct {
    action_name: []const u8 = "AssociateIpGroups",
    Request: type = struct {
        directory_id: []const u8,
        group_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .group_ids = "GroupIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_ip_groups) } {
            return .{ .service_metadata = service_metadata, .action = associate_ip_groups };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const associate_workspace_application: struct {
    action_name: []const u8 = "AssociateWorkspaceApplication",
    Request: type = struct {
        workspace_id: []const u8,
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_workspace_application) } {
            return .{ .service_metadata = service_metadata, .action = associate_workspace_application };
        }
    },
    Response: type = struct {
        association: ?WorkspaceResourceAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "Association",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ApplicationNotSupported,
        ComputeNotCompatible,
        IncompatibleApplications,
        InvalidParameterValues,
        OperatingSystemNotCompatible,
        OperationNotSupported,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const authorize_ip_rules: struct {
    action_name: []const u8 = "AuthorizeIpRules",
    Request: type = struct {
        group_id: []const u8,
        user_rules: []IpRuleItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .user_rules = "UserRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_ip_rules) } {
            return .{ .service_metadata = service_metadata, .action = authorize_ip_rules };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const copy_workspace_image: struct {
    action_name: []const u8 = "CopyWorkspaceImage",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        source_image_id: []const u8,
        source_region: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .source_image_id = "SourceImageId",
                .source_region = "SourceRegion",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_workspace_image) } {
            return .{ .service_metadata = service_metadata, .action = copy_workspace_image };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const create_connect_client_add_in: struct {
    action_name: []const u8 = "CreateConnectClientAddIn",
    Request: type = struct {
        resource_id: []const u8,
        name: []const u8,
        url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .name = "Name",
                .url = "URL",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connect_client_add_in) } {
            return .{ .service_metadata = service_metadata, .action = create_connect_client_add_in };
        }
    },
    Response: type = struct {
        add_in_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .add_in_id = "AddInId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceAlreadyExists,
        ResourceCreationFailed,
        ResourceNotFound,
    },
} = .{};
pub const create_connection_alias: struct {
    action_name: []const u8 = "CreateConnectionAlias",
    Request: type = struct {
        connection_string: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_string = "ConnectionString",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_connection_alias };
        }
    },
    Response: type = struct {
        alias_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_ip_group: struct {
    action_name: []const u8 = "CreateIpGroup",
    Request: type = struct {
        group_name: []const u8,
        group_desc: ?[]const u8 = null,
        user_rules: ?[]IpRuleItem = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group_desc = "GroupDesc",
                .user_rules = "UserRules",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ip_group) } {
            return .{ .service_metadata = service_metadata, .action = create_ip_group };
        }
    },
    Response: type = struct {
        group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceAlreadyExists,
        ResourceCreationFailed,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_standby_workspaces: struct {
    action_name: []const u8 = "CreateStandbyWorkspaces",
    Request: type = struct {
        primary_region: []const u8,
        standby_workspaces: []StandbyWorkspace,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .primary_region = "PrimaryRegion",
                .standby_workspaces = "StandbyWorkspaces",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_standby_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = create_standby_workspaces };
        }
    },
    Response: type = struct {
        failed_standby_requests: ?[]struct {
            standby_workspace_request: ?StandbyWorkspace = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .standby_workspace_request = "StandbyWorkspaceRequest",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        pending_standby_requests: ?[]struct {
            user_name: ?[]const u8 = null,
            directory_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            workspace_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_name = "UserName",
                    .directory_id = "DirectoryId",
                    .state = "State",
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_standby_requests = "FailedStandbyRequests",
                .pending_standby_requests = "PendingStandbyRequests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_tags: struct {
    action_name: []const u8 = "CreateTags",
    Request: type = struct {
        resource_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tags) } {
            return .{ .service_metadata = service_metadata, .action = create_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_updated_workspace_image: struct {
    action_name: []const u8 = "CreateUpdatedWorkspaceImage",
    Request: type = struct {
        name: []const u8,
        description: []const u8,
        source_image_id: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .source_image_id = "SourceImageId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_updated_workspace_image) } {
            return .{ .service_metadata = service_metadata, .action = create_updated_workspace_image };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_workspace_bundle: struct {
    action_name: []const u8 = "CreateWorkspaceBundle",
    Request: type = struct {
        bundle_name: []const u8,
        bundle_description: []const u8,
        image_id: []const u8,
        compute_type: ComputeType,
        user_storage: UserStorage,
        root_storage: ?RootStorage = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_name = "BundleName",
                .bundle_description = "BundleDescription",
                .image_id = "ImageId",
                .compute_type = "ComputeType",
                .user_storage = "UserStorage",
                .root_storage = "RootStorage",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workspace_bundle) } {
            return .{ .service_metadata = service_metadata, .action = create_workspace_bundle };
        }
    },
    Response: type = struct {
        workspace_bundle: ?WorkspaceBundle = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_bundle = "WorkspaceBundle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const create_workspace_image: struct {
    action_name: []const u8 = "CreateWorkspaceImage",
    Request: type = struct {
        name: []const u8,
        description: []const u8,
        workspace_id: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .workspace_id = "WorkspaceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workspace_image) } {
            return .{ .service_metadata = service_metadata, .action = create_workspace_image };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        operating_system: ?OperatingSystem = null,
        state: ?[]const u8 = null,
        required_tenancy: ?[]const u8 = null,
        created: ?i64 = null,
        owner_account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .name = "Name",
                .description = "Description",
                .operating_system = "OperatingSystem",
                .state = "State",
                .required_tenancy = "RequiredTenancy",
                .created = "Created",
                .owner_account_id = "OwnerAccountId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_workspaces: struct {
    action_name: []const u8 = "CreateWorkspaces",
    Request: type = struct {
        workspaces: []WorkspaceRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspaces = "Workspaces",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = create_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]struct {
            workspace_request: ?WorkspaceRequest = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_request = "WorkspaceRequest",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        pending_requests: ?[]Workspace = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
                .pending_requests = "PendingRequests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
        ResourceLimitExceeded,
    },
} = .{};
pub const delete_client_branding: struct {
    action_name: []const u8 = "DeleteClientBranding",
    Request: type = struct {
        resource_id: []const u8,
        platforms: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .platforms = "Platforms",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_client_branding) } {
            return .{ .service_metadata = service_metadata, .action = delete_client_branding };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const delete_connect_client_add_in: struct {
    action_name: []const u8 = "DeleteConnectClientAddIn",
    Request: type = struct {
        add_in_id: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .add_in_id = "AddInId",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connect_client_add_in) } {
            return .{ .service_metadata = service_metadata, .action = delete_connect_client_add_in };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const delete_connection_alias: struct {
    action_name: []const u8 = "DeleteConnectionAlias",
    Request: type = struct {
        alias_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection_alias };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceAssociated,
        ResourceNotFound,
    },
} = .{};
pub const delete_ip_group: struct {
    action_name: []const u8 = "DeleteIpGroup",
    Request: type = struct {
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ip_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_ip_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceAssociated,
        ResourceNotFound,
    },
} = .{};
pub const delete_tags: struct {
    action_name: []const u8 = "DeleteTags",
    Request: type = struct {
        resource_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tags) } {
            return .{ .service_metadata = service_metadata, .action = delete_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const delete_workspace_bundle: struct {
    action_name: []const u8 = "DeleteWorkspaceBundle",
    Request: type = struct {
        bundle_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_id = "BundleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workspace_bundle) } {
            return .{ .service_metadata = service_metadata, .action = delete_workspace_bundle };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceAssociated,
        ResourceNotFound,
    },
} = .{};
pub const delete_workspace_image: struct {
    action_name: []const u8 = "DeleteWorkspaceImage",
    Request: type = struct {
        image_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workspace_image) } {
            return .{ .service_metadata = service_metadata, .action = delete_workspace_image };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceAssociated,
    },
} = .{};
pub const deploy_workspace_applications: struct {
    action_name: []const u8 = "DeployWorkspaceApplications",
    Request: type = struct {
        workspace_id: []const u8,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
                .force = "Force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deploy_workspace_applications) } {
            return .{ .service_metadata = service_metadata, .action = deploy_workspace_applications };
        }
    },
    Response: type = struct {
        deployment: ?struct {
            associations: ?[]WorkspaceResourceAssociation = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .associations = "Associations",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment = "Deployment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IncompatibleApplications,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const deregister_workspace_directory: struct {
    action_name: []const u8 = "DeregisterWorkspaceDirectory",
    Request: type = struct {
        directory_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_workspace_directory) } {
            return .{ .service_metadata = service_metadata, .action = deregister_workspace_directory };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const describe_account: struct {
    action_name: []const u8 = "DescribeAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account) } {
            return .{ .service_metadata = service_metadata, .action = describe_account };
        }
    },
    Response: type = struct {
        dedicated_tenancy_support: ?[]const u8 = null,
        dedicated_tenancy_management_cidr_range: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_tenancy_support = "DedicatedTenancySupport",
                .dedicated_tenancy_management_cidr_range = "DedicatedTenancyManagementCidrRange",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
    },
} = .{};
pub const describe_account_modifications: struct {
    action_name: []const u8 = "DescribeAccountModifications",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_modifications) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_modifications };
        }
    },
    Response: type = struct {
        account_modifications: ?[]struct {
            modification_state: ?[]const u8 = null,
            dedicated_tenancy_support: ?[]const u8 = null,
            dedicated_tenancy_management_cidr_range: ?[]const u8 = null,
            start_time: ?i64 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .modification_state = "ModificationState",
                    .dedicated_tenancy_support = "DedicatedTenancySupport",
                    .dedicated_tenancy_management_cidr_range = "DedicatedTenancyManagementCidrRange",
                    .start_time = "StartTime",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_modifications = "AccountModifications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
    },
} = .{};
pub const describe_application_associations: struct {
    action_name: []const u8 = "DescribeApplicationAssociations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        application_id: []const u8,
        associated_resource_types: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .application_id = "ApplicationId",
                .associated_resource_types = "AssociatedResourceTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_application_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_application_associations };
        }
    },
    Response: type = struct {
        associations: ?[]struct {
            application_id: ?[]const u8 = null,
            associated_resource_id: ?[]const u8 = null,
            associated_resource_type: ?[]const u8 = null,
            created: ?i64 = null,
            last_updated_time: ?i64 = null,
            state: ?[]const u8 = null,
            state_reason: ?AssociationStateReason = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .associated_resource_id = "AssociatedResourceId",
                    .associated_resource_type = "AssociatedResourceType",
                    .created = "Created",
                    .last_updated_time = "LastUpdatedTime",
                    .state = "State",
                    .state_reason = "StateReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "Associations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const describe_applications: struct {
    action_name: []const u8 = "DescribeApplications",
    Request: type = struct {
        application_ids: ?[][]const u8 = null,
        compute_type_names: ?[][]const u8 = null,
        license_type: ?[]const u8 = null,
        operating_system_names: ?[][]const u8 = null,
        owner: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .application_ids = "ApplicationIds",
                .compute_type_names = "ComputeTypeNames",
                .license_type = "LicenseType",
                .operating_system_names = "OperatingSystemNames",
                .owner = "Owner",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_applications) } {
            return .{ .service_metadata = service_metadata, .action = describe_applications };
        }
    },
    Response: type = struct {
        applications: ?[]struct {
            application_id: ?[]const u8 = null,
            created: ?i64 = null,
            description: ?[]const u8 = null,
            license_type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            state: ?[]const u8 = null,
            supported_compute_type_names: ?[][]const u8 = null,
            supported_operating_system_names: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .application_id = "ApplicationId",
                    .created = "Created",
                    .description = "Description",
                    .license_type = "LicenseType",
                    .name = "Name",
                    .owner = "Owner",
                    .state = "State",
                    .supported_compute_type_names = "SupportedComputeTypeNames",
                    .supported_operating_system_names = "SupportedOperatingSystemNames",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applications = "Applications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const describe_bundle_associations: struct {
    action_name: []const u8 = "DescribeBundleAssociations",
    Request: type = struct {
        bundle_id: []const u8,
        associated_resource_types: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_id = "BundleId",
                .associated_resource_types = "AssociatedResourceTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bundle_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_bundle_associations };
        }
    },
    Response: type = struct {
        associations: ?[]struct {
            associated_resource_id: ?[]const u8 = null,
            associated_resource_type: ?[]const u8 = null,
            bundle_id: ?[]const u8 = null,
            created: ?i64 = null,
            last_updated_time: ?i64 = null,
            state: ?[]const u8 = null,
            state_reason: ?AssociationStateReason = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .associated_resource_id = "AssociatedResourceId",
                    .associated_resource_type = "AssociatedResourceType",
                    .bundle_id = "BundleId",
                    .created = "Created",
                    .last_updated_time = "LastUpdatedTime",
                    .state = "State",
                    .state_reason = "StateReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "Associations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const describe_client_branding: struct {
    action_name: []const u8 = "DescribeClientBranding",
    Request: type = struct {
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_client_branding) } {
            return .{ .service_metadata = service_metadata, .action = describe_client_branding };
        }
    },
    Response: type = struct {
        device_type_windows: ?DefaultClientBrandingAttributes = null,
        device_type_osx: ?DefaultClientBrandingAttributes = null,
        device_type_android: ?DefaultClientBrandingAttributes = null,
        device_type_ios: ?IosClientBrandingAttributes = null,
        device_type_linux: ?DefaultClientBrandingAttributes = null,
        device_type_web: ?DefaultClientBrandingAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_type_windows = "DeviceTypeWindows",
                .device_type_osx = "DeviceTypeOsx",
                .device_type_android = "DeviceTypeAndroid",
                .device_type_ios = "DeviceTypeIos",
                .device_type_linux = "DeviceTypeLinux",
                .device_type_web = "DeviceTypeWeb",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const describe_client_properties: struct {
    action_name: []const u8 = "DescribeClientProperties",
    Request: type = struct {
        resource_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_ids = "ResourceIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_client_properties) } {
            return .{ .service_metadata = service_metadata, .action = describe_client_properties };
        }
    },
    Response: type = struct {
        client_properties_list: ?[]struct {
            resource_id: ?[]const u8 = null,
            client_properties: ?ClientProperties = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_id = "ResourceId",
                    .client_properties = "ClientProperties",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_properties_list = "ClientPropertiesList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const describe_connect_client_add_ins: struct {
    action_name: []const u8 = "DescribeConnectClientAddIns",
    Request: type = struct {
        resource_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connect_client_add_ins) } {
            return .{ .service_metadata = service_metadata, .action = describe_connect_client_add_ins };
        }
    },
    Response: type = struct {
        add_ins: ?[]struct {
            add_in_id: ?[]const u8 = null,
            resource_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add_in_id = "AddInId",
                    .resource_id = "ResourceId",
                    .name = "Name",
                    .url = "URL",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .add_ins = "AddIns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const describe_connection_aliases: struct {
    action_name: []const u8 = "DescribeConnectionAliases",
    Request: type = struct {
        alias_ids: ?[][]const u8 = null,
        resource_id: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_ids = "AliasIds",
                .resource_id = "ResourceId",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connection_aliases) } {
            return .{ .service_metadata = service_metadata, .action = describe_connection_aliases };
        }
    },
    Response: type = struct {
        connection_aliases: ?[]struct {
            connection_string: ?[]const u8 = null,
            alias_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            owner_account_id: ?[]const u8 = null,
            associations: ?[]struct {
                association_status: ?[]const u8 = null,
                associated_account_id: ?[]const u8 = null,
                resource_id: ?[]const u8 = null,
                connection_identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .association_status = "AssociationStatus",
                        .associated_account_id = "AssociatedAccountId",
                        .resource_id = "ResourceId",
                        .connection_identifier = "ConnectionIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connection_string = "ConnectionString",
                    .alias_id = "AliasId",
                    .state = "State",
                    .owner_account_id = "OwnerAccountId",
                    .associations = "Associations",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_aliases = "ConnectionAliases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
    },
} = .{};
pub const describe_connection_alias_permissions: struct {
    action_name: []const u8 = "DescribeConnectionAliasPermissions",
    Request: type = struct {
        alias_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connection_alias_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_connection_alias_permissions };
        }
    },
    Response: type = struct {
        alias_id: ?[]const u8 = null,
        connection_alias_permissions: ?[]ConnectionAliasPermission = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
                .connection_alias_permissions = "ConnectionAliasPermissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const describe_image_associations: struct {
    action_name: []const u8 = "DescribeImageAssociations",
    Request: type = struct {
        image_id: []const u8,
        associated_resource_types: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .associated_resource_types = "AssociatedResourceTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_image_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_image_associations };
        }
    },
    Response: type = struct {
        associations: ?[]struct {
            associated_resource_id: ?[]const u8 = null,
            associated_resource_type: ?[]const u8 = null,
            created: ?i64 = null,
            last_updated_time: ?i64 = null,
            image_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            state_reason: ?AssociationStateReason = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .associated_resource_id = "AssociatedResourceId",
                    .associated_resource_type = "AssociatedResourceType",
                    .created = "Created",
                    .last_updated_time = "LastUpdatedTime",
                    .image_id = "ImageId",
                    .state = "State",
                    .state_reason = "StateReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "Associations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const describe_ip_groups: struct {
    action_name: []const u8 = "DescribeIpGroups",
    Request: type = struct {
        group_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_ids = "GroupIds",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ip_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_ip_groups };
        }
    },
    Response: type = struct {
        result: ?[]struct {
            group_id: ?[]const u8 = null,
            group_name: ?[]const u8 = null,
            group_desc: ?[]const u8 = null,
            user_rules: ?[]IpRuleItem = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_id = "groupId",
                    .group_name = "groupName",
                    .group_desc = "groupDesc",
                    .user_rules = "userRules",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "Result",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
    },
} = .{};
pub const describe_tags: struct {
    action_name: []const u8 = "DescribeTags",
    Request: type = struct {
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tags) } {
            return .{ .service_metadata = service_metadata, .action = describe_tags };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_workspace_associations: struct {
    action_name: []const u8 = "DescribeWorkspaceAssociations",
    Request: type = struct {
        workspace_id: []const u8,
        associated_resource_types: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
                .associated_resource_types = "AssociatedResourceTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_associations };
        }
    },
    Response: type = struct {
        associations: ?[]WorkspaceResourceAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .associations = "Associations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const describe_workspace_bundles: struct {
    action_name: []const u8 = "DescribeWorkspaceBundles",
    Request: type = struct {
        bundle_ids: ?[][]const u8 = null,
        owner: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_ids = "BundleIds",
                .owner = "Owner",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_bundles) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_bundles };
        }
    },
    Response: type = struct {
        bundles: ?[]WorkspaceBundle = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundles = "Bundles",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
    },
} = .{};
pub const describe_workspace_directories: struct {
    action_name: []const u8 = "DescribeWorkspaceDirectories",
    Request: type = struct {
        directory_ids: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_ids = "DirectoryIds",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_directories) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_directories };
        }
    },
    Response: type = struct {
        directories: ?[]struct {
            directory_id: ?[]const u8 = null,
            alias: ?[]const u8 = null,
            directory_name: ?[]const u8 = null,
            registration_code: ?[]const u8 = null,
            subnet_ids: ?[][]const u8 = null,
            dns_ip_addresses: ?[][]const u8 = null,
            customer_user_name: ?[]const u8 = null,
            iam_role_id: ?[]const u8 = null,
            directory_type: ?[]const u8 = null,
            workspace_security_group_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            workspace_creation_properties: ?struct {
                enable_work_docs: ?bool = null,
                enable_internet_access: ?bool = null,
                default_ou: ?[]const u8 = null,
                custom_security_group_id: ?[]const u8 = null,
                user_enabled_as_local_administrator: ?bool = null,
                enable_maintenance_mode: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .enable_work_docs = "EnableWorkDocs",
                        .enable_internet_access = "EnableInternetAccess",
                        .default_ou = "DefaultOu",
                        .custom_security_group_id = "CustomSecurityGroupId",
                        .user_enabled_as_local_administrator = "UserEnabledAsLocalAdministrator",
                        .enable_maintenance_mode = "EnableMaintenanceMode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            ip_group_ids: ?[][]const u8 = null,
            workspace_access_properties: ?WorkspaceAccessProperties = null,
            tenancy: ?[]const u8 = null,
            selfservice_permissions: ?SelfservicePermissions = null,
            saml_properties: ?SamlProperties = null,
            certificate_based_auth_properties: ?CertificateBasedAuthProperties = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .alias = "Alias",
                    .directory_name = "DirectoryName",
                    .registration_code = "RegistrationCode",
                    .subnet_ids = "SubnetIds",
                    .dns_ip_addresses = "DnsIpAddresses",
                    .customer_user_name = "CustomerUserName",
                    .iam_role_id = "IamRoleId",
                    .directory_type = "DirectoryType",
                    .workspace_security_group_id = "WorkspaceSecurityGroupId",
                    .state = "State",
                    .workspace_creation_properties = "WorkspaceCreationProperties",
                    .ip_group_ids = "ipGroupIds",
                    .workspace_access_properties = "WorkspaceAccessProperties",
                    .tenancy = "Tenancy",
                    .selfservice_permissions = "SelfservicePermissions",
                    .saml_properties = "SamlProperties",
                    .certificate_based_auth_properties = "CertificateBasedAuthProperties",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directories = "Directories",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
    },
} = .{};
pub const describe_workspace_image_permissions: struct {
    action_name: []const u8 = "DescribeWorkspaceImagePermissions",
    Request: type = struct {
        image_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_image_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_image_permissions };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,
        image_permissions: ?[]struct {
            shared_account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .shared_account_id = "SharedAccountId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .image_permissions = "ImagePermissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const describe_workspace_images: struct {
    action_name: []const u8 = "DescribeWorkspaceImages",
    Request: type = struct {
        image_ids: ?[][]const u8 = null,
        image_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_ids = "ImageIds",
                .image_type = "ImageType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_images) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_images };
        }
    },
    Response: type = struct {
        images: ?[]struct {
            image_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            operating_system: ?OperatingSystem = null,
            state: ?[]const u8 = null,
            required_tenancy: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            created: ?i64 = null,
            owner_account_id: ?[]const u8 = null,
            updates: ?struct {
                update_available: ?bool = null,
                description: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .update_available = "UpdateAvailable",
                        .description = "Description",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            error_details: ?[]struct {
                error_code: ?[]const u8 = null,
                error_message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "ErrorCode",
                        .error_message = "ErrorMessage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_id = "ImageId",
                    .name = "Name",
                    .description = "Description",
                    .operating_system = "OperatingSystem",
                    .state = "State",
                    .required_tenancy = "RequiredTenancy",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                    .created = "Created",
                    .owner_account_id = "OwnerAccountId",
                    .updates = "Updates",
                    .error_details = "ErrorDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .images = "Images",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
    },
} = .{};
pub const describe_workspaces: struct {
    action_name: []const u8 = "DescribeWorkspaces",
    Request: type = struct {
        workspace_ids: ?[][]const u8 = null,
        directory_id: ?[]const u8 = null,
        user_name: ?[]const u8 = null,
        bundle_id: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,
        workspace_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_ids = "WorkspaceIds",
                .directory_id = "DirectoryId",
                .user_name = "UserName",
                .bundle_id = "BundleId",
                .limit = "Limit",
                .next_token = "NextToken",
                .workspace_name = "WorkspaceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspaces };
        }
    },
    Response: type = struct {
        workspaces: ?[]Workspace = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspaces = "Workspaces",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
        ResourceUnavailable,
    },
} = .{};
pub const describe_workspaces_connection_status: struct {
    action_name: []const u8 = "DescribeWorkspacesConnectionStatus",
    Request: type = struct {
        workspace_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_ids = "WorkspaceIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspaces_connection_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspaces_connection_status };
        }
    },
    Response: type = struct {
        workspaces_connection_status: ?[]struct {
            workspace_id: ?[]const u8 = null,
            connection_state: ?[]const u8 = null,
            connection_state_check_timestamp: ?i64 = null,
            last_known_user_connection_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                    .connection_state = "ConnectionState",
                    .connection_state_check_timestamp = "ConnectionStateCheckTimestamp",
                    .last_known_user_connection_timestamp = "LastKnownUserConnectionTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspaces_connection_status = "WorkspacesConnectionStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
    },
} = .{};
pub const describe_workspace_snapshots: struct {
    action_name: []const u8 = "DescribeWorkspaceSnapshots",
    Request: type = struct {
        workspace_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_snapshots };
        }
    },
    Response: type = struct {
        rebuild_snapshots: ?[]Snapshot = null,
        restore_snapshots: ?[]Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rebuild_snapshots = "RebuildSnapshots",
                .restore_snapshots = "RestoreSnapshots",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_connection_alias: struct {
    action_name: []const u8 = "DisassociateConnectionAlias",
    Request: type = struct {
        alias_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_connection_alias) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_connection_alias };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_ip_groups: struct {
    action_name: []const u8 = "DisassociateIpGroups",
    Request: type = struct {
        directory_id: []const u8,
        group_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .group_ids = "GroupIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_ip_groups) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_ip_groups };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_workspace_application: struct {
    action_name: []const u8 = "DisassociateWorkspaceApplication",
    Request: type = struct {
        workspace_id: []const u8,
        application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
                .application_id = "ApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_workspace_application) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_workspace_application };
        }
    },
    Response: type = struct {
        association: ?WorkspaceResourceAssociation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association = "Association",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const import_client_branding: struct {
    action_name: []const u8 = "ImportClientBranding",
    Request: type = struct {
        resource_id: []const u8,
        device_type_windows: ?DefaultImportClientBrandingAttributes = null,
        device_type_osx: ?DefaultImportClientBrandingAttributes = null,
        device_type_android: ?DefaultImportClientBrandingAttributes = null,
        device_type_ios: ?struct {
            logo: ?[]const u8 = null,
            logo2x: ?[]const u8 = null,
            logo3x: ?[]const u8 = null,
            support_email: ?[]const u8 = null,
            support_link: ?[]const u8 = null,
            forgot_password_link: ?[]const u8 = null,
            login_message: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .logo = "Logo",
                    .logo2x = "Logo2x",
                    .logo3x = "Logo3x",
                    .support_email = "SupportEmail",
                    .support_link = "SupportLink",
                    .forgot_password_link = "ForgotPasswordLink",
                    .login_message = "LoginMessage",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "login_message", field_name))
                    return try serializeMap(self.login_message, self.fieldNameFor("login_message"), options, out_stream);
                return false;
            }
        } = null,
        device_type_linux: ?DefaultImportClientBrandingAttributes = null,
        device_type_web: ?DefaultImportClientBrandingAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .device_type_windows = "DeviceTypeWindows",
                .device_type_osx = "DeviceTypeOsx",
                .device_type_android = "DeviceTypeAndroid",
                .device_type_ios = "DeviceTypeIos",
                .device_type_linux = "DeviceTypeLinux",
                .device_type_web = "DeviceTypeWeb",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_client_branding) } {
            return .{ .service_metadata = service_metadata, .action = import_client_branding };
        }
    },
    Response: type = struct {
        device_type_windows: ?DefaultClientBrandingAttributes = null,
        device_type_osx: ?DefaultClientBrandingAttributes = null,
        device_type_android: ?DefaultClientBrandingAttributes = null,
        device_type_ios: ?IosClientBrandingAttributes = null,
        device_type_linux: ?DefaultClientBrandingAttributes = null,
        device_type_web: ?DefaultClientBrandingAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_type_windows = "DeviceTypeWindows",
                .device_type_osx = "DeviceTypeOsx",
                .device_type_android = "DeviceTypeAndroid",
                .device_type_ios = "DeviceTypeIos",
                .device_type_linux = "DeviceTypeLinux",
                .device_type_web = "DeviceTypeWeb",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const import_workspace_image: struct {
    action_name: []const u8 = "ImportWorkspaceImage",
    Request: type = struct {
        ec2_image_id: []const u8,
        ingestion_process: []const u8,
        image_name: []const u8,
        image_description: []const u8,
        tags: ?[]Tag = null,
        applications: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ec2_image_id = "Ec2ImageId",
                .ingestion_process = "IngestionProcess",
                .image_name = "ImageName",
                .image_description = "ImageDescription",
                .tags = "Tags",
                .applications = "Applications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_workspace_image) } {
            return .{ .service_metadata = service_metadata, .action = import_workspace_image };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const list_available_management_cidr_ranges: struct {
    action_name: []const u8 = "ListAvailableManagementCidrRanges",
    Request: type = struct {
        management_cidr_range_constraint: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .management_cidr_range_constraint = "ManagementCidrRangeConstraint",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_available_management_cidr_ranges) } {
            return .{ .service_metadata = service_metadata, .action = list_available_management_cidr_ranges };
        }
    },
    Response: type = struct {
        management_cidr_ranges: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .management_cidr_ranges = "ManagementCidrRanges",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
    },
} = .{};
pub const migrate_workspace: struct {
    action_name: []const u8 = "MigrateWorkspace",
    Request: type = struct {
        source_workspace_id: []const u8,
        bundle_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_workspace_id = "SourceWorkspaceId",
                .bundle_id = "BundleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(migrate_workspace) } {
            return .{ .service_metadata = service_metadata, .action = migrate_workspace };
        }
    },
    Response: type = struct {
        source_workspace_id: ?[]const u8 = null,
        target_workspace_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_workspace_id = "SourceWorkspaceId",
                .target_workspace_id = "TargetWorkspaceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationInProgress,
        OperationNotSupported,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const modify_account: struct {
    action_name: []const u8 = "ModifyAccount",
    Request: type = struct {
        dedicated_tenancy_support: ?[]const u8 = null,
        dedicated_tenancy_management_cidr_range: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_tenancy_support = "DedicatedTenancySupport",
                .dedicated_tenancy_management_cidr_range = "DedicatedTenancyManagementCidrRange",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_account) } {
            return .{ .service_metadata = service_metadata, .action = modify_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const modify_certificate_based_auth_properties: struct {
    action_name: []const u8 = "ModifyCertificateBasedAuthProperties",
    Request: type = struct {
        resource_id: []const u8,
        certificate_based_auth_properties: ?CertificateBasedAuthProperties = null,
        properties_to_delete: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .certificate_based_auth_properties = "CertificateBasedAuthProperties",
                .properties_to_delete = "PropertiesToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_certificate_based_auth_properties) } {
            return .{ .service_metadata = service_metadata, .action = modify_certificate_based_auth_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const modify_client_properties: struct {
    action_name: []const u8 = "ModifyClientProperties",
    Request: type = struct {
        resource_id: []const u8,
        client_properties: ClientProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .client_properties = "ClientProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_client_properties) } {
            return .{ .service_metadata = service_metadata, .action = modify_client_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const modify_saml_properties: struct {
    action_name: []const u8 = "ModifySamlProperties",
    Request: type = struct {
        resource_id: []const u8,
        saml_properties: ?SamlProperties = null,
        properties_to_delete: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .saml_properties = "SamlProperties",
                .properties_to_delete = "PropertiesToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_saml_properties) } {
            return .{ .service_metadata = service_metadata, .action = modify_saml_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const modify_selfservice_permissions: struct {
    action_name: []const u8 = "ModifySelfservicePermissions",
    Request: type = struct {
        resource_id: []const u8,
        selfservice_permissions: SelfservicePermissions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .selfservice_permissions = "SelfservicePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_selfservice_permissions) } {
            return .{ .service_metadata = service_metadata, .action = modify_selfservice_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const modify_workspace_access_properties: struct {
    action_name: []const u8 = "ModifyWorkspaceAccessProperties",
    Request: type = struct {
        resource_id: []const u8,
        workspace_access_properties: WorkspaceAccessProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .workspace_access_properties = "WorkspaceAccessProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_workspace_access_properties) } {
            return .{ .service_metadata = service_metadata, .action = modify_workspace_access_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
    },
} = .{};
pub const modify_workspace_creation_properties: struct {
    action_name: []const u8 = "ModifyWorkspaceCreationProperties",
    Request: type = struct {
        resource_id: []const u8,
        workspace_creation_properties: struct {
            enable_work_docs: ?bool = null,
            enable_internet_access: ?bool = null,
            default_ou: ?[]const u8 = null,
            custom_security_group_id: ?[]const u8 = null,
            user_enabled_as_local_administrator: ?bool = null,
            enable_maintenance_mode: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enable_work_docs = "EnableWorkDocs",
                    .enable_internet_access = "EnableInternetAccess",
                    .default_ou = "DefaultOu",
                    .custom_security_group_id = "CustomSecurityGroupId",
                    .user_enabled_as_local_administrator = "UserEnabledAsLocalAdministrator",
                    .enable_maintenance_mode = "EnableMaintenanceMode",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .workspace_creation_properties = "WorkspaceCreationProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_workspace_creation_properties) } {
            return .{ .service_metadata = service_metadata, .action = modify_workspace_creation_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const modify_workspace_properties: struct {
    action_name: []const u8 = "ModifyWorkspaceProperties",
    Request: type = struct {
        workspace_id: []const u8,
        workspace_properties: ?WorkspaceProperties = null,
        data_replication: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
                .workspace_properties = "WorkspaceProperties",
                .data_replication = "DataReplication",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_workspace_properties) } {
            return .{ .service_metadata = service_metadata, .action = modify_workspace_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationInProgress,
        ResourceNotFound,
        ResourceUnavailable,
        UnsupportedWorkspaceConfiguration,
    },
} = .{};
pub const modify_workspace_state: struct {
    action_name: []const u8 = "ModifyWorkspaceState",
    Request: type = struct {
        workspace_id: []const u8,
        workspace_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
                .workspace_state = "WorkspaceState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_workspace_state) } {
            return .{ .service_metadata = service_metadata, .action = modify_workspace_state };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const reboot_workspaces: struct {
    action_name: []const u8 = "RebootWorkspaces",
    Request: type = struct {
        reboot_workspace_requests: []struct {
            workspace_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reboot_workspace_requests = "RebootWorkspaceRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = reboot_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]FailedWorkspaceChangeRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotSupported,
    },
} = .{};
pub const rebuild_workspaces: struct {
    action_name: []const u8 = "RebuildWorkspaces",
    Request: type = struct {
        rebuild_workspace_requests: []struct {
            workspace_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rebuild_workspace_requests = "RebuildWorkspaceRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rebuild_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = rebuild_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]FailedWorkspaceChangeRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotSupported,
    },
} = .{};
pub const register_workspace_directory: struct {
    action_name: []const u8 = "RegisterWorkspaceDirectory",
    Request: type = struct {
        directory_id: []const u8,
        subnet_ids: ?[][]const u8 = null,
        enable_work_docs: bool,
        enable_self_service: ?bool = null,
        tenancy: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .subnet_ids = "SubnetIds",
                .enable_work_docs = "EnableWorkDocs",
                .enable_self_service = "EnableSelfService",
                .tenancy = "Tenancy",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_workspace_directory) } {
            return .{ .service_metadata = service_metadata, .action = register_workspace_directory };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceLimitExceeded,
        ResourceNotFound,
        UnsupportedNetworkConfiguration,
        WorkspacesDefaultRoleNotFound,
    },
} = .{};
pub const restore_workspace: struct {
    action_name: []const u8 = "RestoreWorkspace",
    Request: type = struct {
        workspace_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_workspace) } {
            return .{ .service_metadata = service_metadata, .action = restore_workspace };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const revoke_ip_rules: struct {
    action_name: []const u8 = "RevokeIpRules",
    Request: type = struct {
        group_id: []const u8,
        user_rules: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .user_rules = "UserRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_ip_rules) } {
            return .{ .service_metadata = service_metadata, .action = revoke_ip_rules };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const start_workspaces: struct {
    action_name: []const u8 = "StartWorkspaces",
    Request: type = struct {
        start_workspace_requests: []struct {
            workspace_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_workspace_requests = "StartWorkspaceRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = start_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]FailedWorkspaceChangeRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const stop_workspaces: struct {
    action_name: []const u8 = "StopWorkspaces",
    Request: type = struct {
        stop_workspace_requests: []struct {
            workspace_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stop_workspace_requests = "StopWorkspaceRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = stop_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]FailedWorkspaceChangeRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const terminate_workspaces: struct {
    action_name: []const u8 = "TerminateWorkspaces",
    Request: type = struct {
        terminate_workspace_requests: []struct {
            workspace_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .terminate_workspace_requests = "TerminateWorkspaceRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = terminate_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]FailedWorkspaceChangeRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_connect_client_add_in: struct {
    action_name: []const u8 = "UpdateConnectClientAddIn",
    Request: type = struct {
        add_in_id: []const u8,
        resource_id: []const u8,
        name: ?[]const u8 = null,
        url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .add_in_id = "AddInId",
                .resource_id = "ResourceId",
                .name = "Name",
                .url = "URL",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connect_client_add_in) } {
            return .{ .service_metadata = service_metadata, .action = update_connect_client_add_in };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const update_connection_alias_permission: struct {
    action_name: []const u8 = "UpdateConnectionAliasPermission",
    Request: type = struct {
        alias_id: []const u8,
        connection_alias_permission: ConnectionAliasPermission,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
                .connection_alias_permission = "ConnectionAliasPermission",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connection_alias_permission) } {
            return .{ .service_metadata = service_metadata, .action = update_connection_alias_permission };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceAssociated,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_rules_of_ip_group: struct {
    action_name: []const u8 = "UpdateRulesOfIpGroup",
    Request: type = struct {
        group_id: []const u8,
        user_rules: []IpRuleItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .user_rules = "UserRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rules_of_ip_group) } {
            return .{ .service_metadata = service_metadata, .action = update_rules_of_ip_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_workspace_bundle: struct {
    action_name: []const u8 = "UpdateWorkspaceBundle",
    Request: type = struct {
        bundle_id: ?[]const u8 = null,
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_id = "BundleId",
                .image_id = "ImageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workspace_bundle) } {
            return .{ .service_metadata = service_metadata, .action = update_workspace_bundle };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const update_workspace_image_permission: struct {
    action_name: []const u8 = "UpdateWorkspaceImagePermission",
    Request: type = struct {
        image_id: []const u8,
        allow_copy_image: bool,
        shared_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .allow_copy_image = "AllowCopyImage",
                .shared_account_id = "SharedAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workspace_image_permission) } {
            return .{ .service_metadata = service_metadata, .action = update_workspace_image_permission };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};

pub const IpRuleItem = struct {
    ip_rule: ?[]const u8 = null,
    rule_desc: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_rule = "ipRule",
            .rule_desc = "ruleDesc",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionAliasPermission = struct {
    shared_account_id: []const u8,
    allow_association: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .shared_account_id = "SharedAccountId",
            .allow_association = "AllowAssociation",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedWorkspaceChangeRequest = struct {
    workspace_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workspace_id = "WorkspaceId",
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkspaceProperties = struct {
    running_mode: ?[]const u8 = null,
    running_mode_auto_stop_timeout_in_minutes: ?i64 = null,
    root_volume_size_gib: ?i64 = null,
    user_volume_size_gib: ?i64 = null,
    compute_type_name: ?[]const u8 = null,
    protocols: ?[][]const u8 = null,
    operating_system_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .running_mode = "RunningMode",
            .running_mode_auto_stop_timeout_in_minutes = "RunningModeAutoStopTimeoutInMinutes",
            .root_volume_size_gib = "RootVolumeSizeGib",
            .user_volume_size_gib = "UserVolumeSizeGib",
            .compute_type_name = "ComputeTypeName",
            .protocols = "Protocols",
            .operating_system_name = "OperatingSystemName",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkspaceAccessProperties = struct {
    device_type_windows: ?[]const u8 = null,
    device_type_osx: ?[]const u8 = null,
    device_type_web: ?[]const u8 = null,
    device_type_ios: ?[]const u8 = null,
    device_type_android: ?[]const u8 = null,
    device_type_chrome_os: ?[]const u8 = null,
    device_type_zero_client: ?[]const u8 = null,
    device_type_linux: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_type_windows = "DeviceTypeWindows",
            .device_type_osx = "DeviceTypeOsx",
            .device_type_web = "DeviceTypeWeb",
            .device_type_ios = "DeviceTypeIos",
            .device_type_android = "DeviceTypeAndroid",
            .device_type_chrome_os = "DeviceTypeChromeOs",
            .device_type_zero_client = "DeviceTypeZeroClient",
            .device_type_linux = "DeviceTypeLinux",
        };
        return @field(mappings, field_name);
    }
};

pub const SelfservicePermissions = struct {
    restart_workspace: ?[]const u8 = null,
    increase_volume_size: ?[]const u8 = null,
    change_compute_type: ?[]const u8 = null,
    switch_running_mode: ?[]const u8 = null,
    rebuild_workspace: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .restart_workspace = "RestartWorkspace",
            .increase_volume_size = "IncreaseVolumeSize",
            .change_compute_type = "ChangeComputeType",
            .switch_running_mode = "SwitchRunningMode",
            .rebuild_workspace = "RebuildWorkspace",
        };
        return @field(mappings, field_name);
    }
};

pub const SamlProperties = struct {
    status: ?[]const u8 = null,
    user_access_url: ?[]const u8 = null,
    relay_state_parameter_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .user_access_url = "UserAccessUrl",
            .relay_state_parameter_name = "RelayStateParameterName",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientProperties = struct {
    reconnect_enabled: ?[]const u8 = null,
    log_upload_enabled: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reconnect_enabled = "ReconnectEnabled",
            .log_upload_enabled = "LogUploadEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const CertificateBasedAuthProperties = struct {
    status: ?[]const u8 = null,
    certificate_authority_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .certificate_authority_arn = "CertificateAuthorityArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultClientBrandingAttributes = struct {
    logo_url: ?[]const u8 = null,
    support_email: ?[]const u8 = null,
    support_link: ?[]const u8 = null,
    forgot_password_link: ?[]const u8 = null,
    login_message: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .logo_url = "LogoUrl",
            .support_email = "SupportEmail",
            .support_link = "SupportLink",
            .forgot_password_link = "ForgotPasswordLink",
            .login_message = "LoginMessage",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "login_message", field_name))
            return try serializeMap(self.login_message, self.fieldNameFor("login_message"), options, out_stream);
        return false;
    }
};

pub const IosClientBrandingAttributes = struct {
    logo_url: ?[]const u8 = null,
    logo2x_url: ?[]const u8 = null,
    logo3x_url: ?[]const u8 = null,
    support_email: ?[]const u8 = null,
    support_link: ?[]const u8 = null,
    forgot_password_link: ?[]const u8 = null,
    login_message: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .logo_url = "LogoUrl",
            .logo2x_url = "Logo2xUrl",
            .logo3x_url = "Logo3xUrl",
            .support_email = "SupportEmail",
            .support_link = "SupportLink",
            .forgot_password_link = "ForgotPasswordLink",
            .login_message = "LoginMessage",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "login_message", field_name))
            return try serializeMap(self.login_message, self.fieldNameFor("login_message"), options, out_stream);
        return false;
    }
};

pub const DefaultImportClientBrandingAttributes = struct {
    logo: ?[]const u8 = null,
    support_email: ?[]const u8 = null,
    support_link: ?[]const u8 = null,
    forgot_password_link: ?[]const u8 = null,
    login_message: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .logo = "Logo",
            .support_email = "SupportEmail",
            .support_link = "SupportLink",
            .forgot_password_link = "ForgotPasswordLink",
            .login_message = "LoginMessage",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "login_message", field_name))
            return try serializeMap(self.login_message, self.fieldNameFor("login_message"), options, out_stream);
        return false;
    }
};

pub const WorkspaceResourceAssociation = struct {
    associated_resource_id: ?[]const u8 = null,
    associated_resource_type: ?[]const u8 = null,
    created: ?i64 = null,
    last_updated_time: ?i64 = null,
    state: ?[]const u8 = null,
    state_reason: ?AssociationStateReason = null,
    workspace_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .associated_resource_id = "AssociatedResourceId",
            .associated_resource_type = "AssociatedResourceType",
            .created = "Created",
            .last_updated_time = "LastUpdatedTime",
            .state = "State",
            .state_reason = "StateReason",
            .workspace_id = "WorkspaceId",
        };
        return @field(mappings, field_name);
    }
};

pub const AssociationStateReason = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const Snapshot = struct {
    snapshot_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .snapshot_time = "SnapshotTime",
        };
        return @field(mappings, field_name);
    }
};

pub const Workspace = struct {
    workspace_id: ?[]const u8 = null,
    directory_id: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,
    state: ?[]const u8 = null,
    bundle_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    computer_name: ?[]const u8 = null,
    volume_encryption_key: ?[]const u8 = null,
    user_volume_encryption_enabled: ?bool = null,
    root_volume_encryption_enabled: ?bool = null,
    workspace_name: ?[]const u8 = null,
    workspace_properties: ?WorkspaceProperties = null,
    modification_states: ?[]ModificationState = null,
    related_workspaces: ?[]RelatedWorkspaceProperties = null,
    data_replication_settings: ?DataReplicationSettings = null,
    standby_workspaces_properties: ?[]StandbyWorkspacesProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workspace_id = "WorkspaceId",
            .directory_id = "DirectoryId",
            .user_name = "UserName",
            .ip_address = "IpAddress",
            .state = "State",
            .bundle_id = "BundleId",
            .subnet_id = "SubnetId",
            .error_message = "ErrorMessage",
            .error_code = "ErrorCode",
            .computer_name = "ComputerName",
            .volume_encryption_key = "VolumeEncryptionKey",
            .user_volume_encryption_enabled = "UserVolumeEncryptionEnabled",
            .root_volume_encryption_enabled = "RootVolumeEncryptionEnabled",
            .workspace_name = "WorkspaceName",
            .workspace_properties = "WorkspaceProperties",
            .modification_states = "ModificationStates",
            .related_workspaces = "RelatedWorkspaces",
            .data_replication_settings = "DataReplicationSettings",
            .standby_workspaces_properties = "StandbyWorkspacesProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const StandbyWorkspacesProperties = struct {
    standby_workspace_id: ?[]const u8 = null,
    data_replication: ?[]const u8 = null,
    recovery_snapshot_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .standby_workspace_id = "StandbyWorkspaceId",
            .data_replication = "DataReplication",
            .recovery_snapshot_time = "RecoverySnapshotTime",
        };
        return @field(mappings, field_name);
    }
};

pub const DataReplicationSettings = struct {
    data_replication: ?[]const u8 = null,
    recovery_snapshot_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_replication = "DataReplication",
            .recovery_snapshot_time = "RecoverySnapshotTime",
        };
        return @field(mappings, field_name);
    }
};

pub const RelatedWorkspaceProperties = struct {
    workspace_id: ?[]const u8 = null,
    region: ?[]const u8 = null,
    state: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workspace_id = "WorkspaceId",
            .region = "Region",
            .state = "State",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const ModificationState = struct {
    resource: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource = "Resource",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const OperatingSystem = struct {
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkspaceBundle = struct {
    bundle_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    description: ?[]const u8 = null,
    image_id: ?[]const u8 = null,
    root_storage: ?RootStorage = null,
    user_storage: ?UserStorage = null,
    compute_type: ?ComputeType = null,
    last_updated_time: ?i64 = null,
    creation_time: ?i64 = null,
    state: ?[]const u8 = null,
    bundle_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bundle_id = "BundleId",
            .name = "Name",
            .owner = "Owner",
            .description = "Description",
            .image_id = "ImageId",
            .root_storage = "RootStorage",
            .user_storage = "UserStorage",
            .compute_type = "ComputeType",
            .last_updated_time = "LastUpdatedTime",
            .creation_time = "CreationTime",
            .state = "State",
            .bundle_type = "BundleType",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeType = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const UserStorage = struct {
    capacity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity = "Capacity",
        };
        return @field(mappings, field_name);
    }
};

pub const RootStorage = struct {
    capacity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity = "Capacity",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkspaceRequest = struct {
    directory_id: []const u8,
    user_name: []const u8,
    bundle_id: []const u8,
    volume_encryption_key: ?[]const u8 = null,
    user_volume_encryption_enabled: ?bool = null,
    root_volume_encryption_enabled: ?bool = null,
    workspace_properties: ?WorkspaceProperties = null,
    tags: ?[]Tag = null,
    workspace_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .directory_id = "DirectoryId",
            .user_name = "UserName",
            .bundle_id = "BundleId",
            .volume_encryption_key = "VolumeEncryptionKey",
            .user_volume_encryption_enabled = "UserVolumeEncryptionEnabled",
            .root_volume_encryption_enabled = "RootVolumeEncryptionEnabled",
            .workspace_properties = "WorkspaceProperties",
            .tags = "Tags",
            .workspace_name = "WorkspaceName",
        };
        return @field(mappings, field_name);
    }
};

pub const StandbyWorkspace = struct {
    primary_workspace_id: []const u8,
    volume_encryption_key: ?[]const u8 = null,
    directory_id: []const u8,
    tags: ?[]Tag = null,
    data_replication: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_workspace_id = "PrimaryWorkspaceId",
            .volume_encryption_key = "VolumeEncryptionKey",
            .directory_id = "DirectoryId",
            .tags = "Tags",
            .data_replication = "DataReplication",
        };
        return @field(mappings, field_name);
    }
};
