const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2023-08-22";
pub const sdk_id: []const u8 = "WorkSpaces Thin Client";
pub const arn_namespace: ?[]const u8 = "thinclient";
pub const endpoint_prefix: []const u8 = "";
pub const sigv4_name: []const u8 = "thinclient";
pub const name: []const u8 = "ThinClient";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2023-08-22",
    sdk_id: []const u8 = "WorkSpaces Thin Client",
    arn_namespace: ?[]const u8 = "thinclient",
    endpoint_prefix: []const u8 = "",
    sigv4_name: []const u8 = "thinclient",
    name: []const u8 = "ThinClient",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/environments",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateEnvironment",
    Request: type = struct {
        name: ?[]const u8 = null,
        desktop_arn: []const u8,
        desktop_endpoint: ?[]const u8 = null,
        software_set_update_schedule: ?[]const u8 = null,
        maintenance_window: ?MaintenanceWindow = null,
        software_set_update_mode: ?[]const u8 = null,
        desired_software_set_id: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .desktop_arn = "desktopArn",
                .desktop_endpoint = "desktopEndpoint",
                .software_set_update_schedule = "softwareSetUpdateSchedule",
                .maintenance_window = "maintenanceWindow",
                .software_set_update_mode = "softwareSetUpdateMode",
                .desired_software_set_id = "desiredSoftwareSetId",
                .kms_key_arn = "kmsKeyArn",
                .client_token = "clientToken",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_environment };
        }
    },
    Response: type = struct {
        environment: ?EnvironmentSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_device: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/devices/{id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDevice",
    Request: type = struct {
        id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_device) } {
            return .{ .service_metadata = service_metadata, .action = delete_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_environment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/environments/{id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteEnvironment",
    Request: type = struct {
        id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const deregister_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/deregister-device/{id}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeregisterDevice",
    Request: type = struct {
        id: []const u8,
        target_device_status: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .target_device_status = "targetDeviceStatus",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_device) } {
            return .{ .service_metadata = service_metadata, .action = deregister_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_device: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/devices/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDevice",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device) } {
            return .{ .service_metadata = service_metadata, .action = get_device };
        }
    },
    Response: type = struct {
        device: ?struct {
            id: ?[]const u8 = null,
            serial_number: ?[]const u8 = null,
            name: ?[]const u8 = null,
            model: ?[]const u8 = null,
            environment_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            current_software_set_id: ?[]const u8 = null,
            current_software_set_version: ?[]const u8 = null,
            desired_software_set_id: ?[]const u8 = null,
            pending_software_set_id: ?[]const u8 = null,
            pending_software_set_version: ?[]const u8 = null,
            software_set_update_schedule: ?[]const u8 = null,
            software_set_compliance_status: ?[]const u8 = null,
            software_set_update_status: ?[]const u8 = null,
            last_connected_at: ?i64 = null,
            last_posture_at: ?i64 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            arn: ?[]const u8 = null,
            kms_key_arn: ?[]const u8 = null,
            tags: ?EmbeddedTag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .serial_number = "serialNumber",
                    .name = "name",
                    .model = "model",
                    .environment_id = "environmentId",
                    .status = "status",
                    .current_software_set_id = "currentSoftwareSetId",
                    .current_software_set_version = "currentSoftwareSetVersion",
                    .desired_software_set_id = "desiredSoftwareSetId",
                    .pending_software_set_id = "pendingSoftwareSetId",
                    .pending_software_set_version = "pendingSoftwareSetVersion",
                    .software_set_update_schedule = "softwareSetUpdateSchedule",
                    .software_set_compliance_status = "softwareSetComplianceStatus",
                    .software_set_update_status = "softwareSetUpdateStatus",
                    .last_connected_at = "lastConnectedAt",
                    .last_posture_at = "lastPostureAt",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .arn = "arn",
                    .kms_key_arn = "kmsKeyArn",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_environment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnvironment",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_environment) } {
            return .{ .service_metadata = service_metadata, .action = get_environment };
        }
    },
    Response: type = struct {
        environment: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            desktop_arn: ?[]const u8 = null,
            desktop_endpoint: ?[]const u8 = null,
            desktop_type: ?[]const u8 = null,
            activation_code: ?[]const u8 = null,
            registered_devices_count: ?i64 = null,
            software_set_update_schedule: ?[]const u8 = null,
            maintenance_window: ?MaintenanceWindow = null,
            software_set_update_mode: ?[]const u8 = null,
            desired_software_set_id: ?[]const u8 = null,
            pending_software_set_id: ?[]const u8 = null,
            pending_software_set_version: ?[]const u8 = null,
            software_set_compliance_status: ?[]const u8 = null,
            created_at: ?i64 = null,
            updated_at: ?i64 = null,
            arn: ?[]const u8 = null,
            kms_key_arn: ?[]const u8 = null,
            tags: ?EmbeddedTag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .name = "name",
                    .desktop_arn = "desktopArn",
                    .desktop_endpoint = "desktopEndpoint",
                    .desktop_type = "desktopType",
                    .activation_code = "activationCode",
                    .registered_devices_count = "registeredDevicesCount",
                    .software_set_update_schedule = "softwareSetUpdateSchedule",
                    .maintenance_window = "maintenanceWindow",
                    .software_set_update_mode = "softwareSetUpdateMode",
                    .desired_software_set_id = "desiredSoftwareSetId",
                    .pending_software_set_id = "pendingSoftwareSetId",
                    .pending_software_set_version = "pendingSoftwareSetVersion",
                    .software_set_compliance_status = "softwareSetComplianceStatus",
                    .created_at = "createdAt",
                    .updated_at = "updatedAt",
                    .arn = "arn",
                    .kms_key_arn = "kmsKeyArn",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_software_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/softwaresets/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSoftwareSet",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_software_set) } {
            return .{ .service_metadata = service_metadata, .action = get_software_set };
        }
    },
    Response: type = struct {
        software_set: ?struct {
            id: ?[]const u8 = null,
            version: ?[]const u8 = null,
            released_at: ?i64 = null,
            supported_until: ?i64 = null,
            validation_status: ?[]const u8 = null,
            software: ?[]struct {
                name: ?[]const u8 = null,
                version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .version = "version",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .version = "version",
                    .released_at = "releasedAt",
                    .supported_until = "supportedUntil",
                    .validation_status = "validationStatus",
                    .software = "software",
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .software_set = "softwareSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_devices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/devices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDevices",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_devices };
        }
    },
    Response: type = struct {
        devices: ?[]DeviceSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .devices = "devices",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_environments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnvironments",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environments) } {
            return .{ .service_metadata = service_metadata, .action = list_environments };
        }
    },
    Response: type = struct {
        environments: ?[]EnvironmentSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environments = "environments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_software_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/softwaresets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSoftwareSets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_software_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_software_sets };
        }
    },
    Response: type = struct {
        software_sets: ?[]struct {
            id: ?[]const u8 = null,
            version: ?[]const u8 = null,
            released_at: ?i64 = null,
            supported_until: ?i64 = null,
            validation_status: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .version = "version",
                    .released_at = "releasedAt",
                    .supported_until = "supportedUntil",
                    .validation_status = "validationStatus",
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .software_sets = "softwareSets",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const update_device: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/devices/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDevice",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        desired_software_set_id: ?[]const u8 = null,
        software_set_update_schedule: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .desired_software_set_id = "desiredSoftwareSetId",
                .software_set_update_schedule = "softwareSetUpdateSchedule",
                .kms_key_arn = "kmsKeyArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device) } {
            return .{ .service_metadata = service_metadata, .action = update_device };
        }
    },
    Response: type = struct {
        device: ?DeviceSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device = "device",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_environment: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/environments/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEnvironment",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        desktop_arn: ?[]const u8 = null,
        desktop_endpoint: ?[]const u8 = null,
        software_set_update_schedule: ?[]const u8 = null,
        maintenance_window: ?MaintenanceWindow = null,
        software_set_update_mode: ?[]const u8 = null,
        desired_software_set_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .desktop_arn = "desktopArn",
                .desktop_endpoint = "desktopEndpoint",
                .software_set_update_schedule = "softwareSetUpdateSchedule",
                .maintenance_window = "maintenanceWindow",
                .software_set_update_mode = "softwareSetUpdateMode",
                .desired_software_set_id = "desiredSoftwareSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_environment };
        }
    },
    Response: type = struct {
        environment: ?EnvironmentSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_software_set: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/softwaresets/{id}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateSoftwareSet",
    Request: type = struct {
        id: []const u8,
        validation_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .validation_status = "validationStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_software_set) } {
            return .{ .service_metadata = service_metadata, .action = update_software_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const EnvironmentSummary = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    desktop_arn: ?[]const u8 = null,
    desktop_endpoint: ?[]const u8 = null,
    desktop_type: ?[]const u8 = null,
    activation_code: ?[]const u8 = null,
    software_set_update_schedule: ?[]const u8 = null,
    maintenance_window: ?MaintenanceWindow = null,
    software_set_update_mode: ?[]const u8 = null,
    desired_software_set_id: ?[]const u8 = null,
    pending_software_set_id: ?[]const u8 = null,
    created_at: ?i64 = null,
    updated_at: ?i64 = null,
    arn: ?[]const u8 = null,
    tags: ?EmbeddedTag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .desktop_arn = "desktopArn",
            .desktop_endpoint = "desktopEndpoint",
            .desktop_type = "desktopType",
            .activation_code = "activationCode",
            .software_set_update_schedule = "softwareSetUpdateSchedule",
            .maintenance_window = "maintenanceWindow",
            .software_set_update_mode = "softwareSetUpdateMode",
            .desired_software_set_id = "desiredSoftwareSetId",
            .pending_software_set_id = "pendingSoftwareSetId",
            .created_at = "createdAt",
            .updated_at = "updatedAt",
            .arn = "arn",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }
};

pub const EmbeddedTag = struct {
    resource_arn: ?[]const u8 = null,
    internal_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "resourceArn",
            .internal_id = "internalId",
        };
        return @field(mappings, field_name);
    }
};

pub const MaintenanceWindow = struct {
    type: ?[]const u8 = null,
    start_time_hour: ?i64 = null,
    start_time_minute: ?i64 = null,
    end_time_hour: ?i64 = null,
    end_time_minute: ?i64 = null,
    days_of_the_week: ?[][]const u8 = null,
    apply_time_of: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .start_time_hour = "startTimeHour",
            .start_time_minute = "startTimeMinute",
            .end_time_hour = "endTimeHour",
            .end_time_minute = "endTimeMinute",
            .days_of_the_week = "daysOfTheWeek",
            .apply_time_of = "applyTimeOf",
        };
        return @field(mappings, field_name);
    }
};

pub const DeviceSummary = struct {
    id: ?[]const u8 = null,
    serial_number: ?[]const u8 = null,
    name: ?[]const u8 = null,
    model: ?[]const u8 = null,
    environment_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    current_software_set_id: ?[]const u8 = null,
    desired_software_set_id: ?[]const u8 = null,
    pending_software_set_id: ?[]const u8 = null,
    software_set_update_schedule: ?[]const u8 = null,
    last_connected_at: ?i64 = null,
    last_posture_at: ?i64 = null,
    created_at: ?i64 = null,
    updated_at: ?i64 = null,
    arn: ?[]const u8 = null,
    tags: ?EmbeddedTag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .serial_number = "serialNumber",
            .name = "name",
            .model = "model",
            .environment_id = "environmentId",
            .status = "status",
            .current_software_set_id = "currentSoftwareSetId",
            .desired_software_set_id = "desiredSoftwareSetId",
            .pending_software_set_id = "pendingSoftwareSetId",
            .software_set_update_schedule = "softwareSetUpdateSchedule",
            .last_connected_at = "lastConnectedAt",
            .last_posture_at = "lastPostureAt",
            .created_at = "createdAt",
            .updated_at = "updatedAt",
            .arn = "arn",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }
};
