const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-04-12";
pub const sdk_id: []const u8 = "XRay";
pub const arn_namespace: ?[]const u8 = "xray";
pub const endpoint_prefix: []const u8 = "xray";
pub const sigv4_name: []const u8 = "xray";
pub const name: []const u8 = "AWSXRay";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-04-12",
    sdk_id: []const u8 = "XRay",
    arn_namespace: ?[]const u8 = "xray",
    endpoint_prefix: []const u8 = "xray",
    sigv4_name: []const u8 = "xray",
    name: []const u8 = "AWSXRay",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_get_traces: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/Traces",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetTraces",
    Request: type = struct {
        trace_ids: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trace_ids = "TraceIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_traces) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_traces };
        }
    },
    Response: type = struct {
        traces: ?[]struct {
            id: ?[]const u8 = null,
            duration: ?f64 = null,
            limit_exceeded: ?bool = null,
            segments: ?[]struct {
                id: ?[]const u8 = null,
                document: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .document = "Document",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .duration = "Duration",
                    .limit_exceeded = "LimitExceeded",
                    .segments = "Segments",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unprocessed_trace_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traces = "Traces",
                .unprocessed_trace_ids = "UnprocessedTraceIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const create_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateGroup",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGroup",
    Request: type = struct {
        group_name: []const u8,
        filter_expression: ?[]const u8 = null,
        insights_configuration: ?InsightsConfiguration = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .filter_expression = "FilterExpression",
                .insights_configuration = "InsightsConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group) } {
            return .{ .service_metadata = service_metadata, .action = create_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const create_sampling_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/CreateSamplingRule",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSamplingRule",
    Request: type = struct {
        sampling_rule: SamplingRule,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampling_rule = "SamplingRule",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sampling_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_sampling_rule };
        }
    },
    Response: type = struct {
        sampling_rule_record: ?SamplingRuleRecord = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampling_rule_record = "SamplingRuleRecord",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        RuleLimitExceeded,
        Throttled,
    },
} = .{};
pub const delete_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteGroup",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGroup",
    Request: type = struct {
        group_name: ?[]const u8 = null,
        group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group_arn = "GroupARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const delete_resource_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteResourcePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        policy_name: []const u8,
        policy_revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "PolicyName",
                .policy_revision_id = "PolicyRevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPolicyRevisionId,
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const delete_sampling_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/DeleteSamplingRule",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSamplingRule",
    Request: type = struct {
        rule_name: ?[]const u8 = null,
        rule_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_name = "RuleName",
                .rule_arn = "RuleARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sampling_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_sampling_rule };
        }
    },
    Response: type = struct {
        sampling_rule_record: ?SamplingRuleRecord = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampling_rule_record = "SamplingRuleRecord",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_encryption_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/EncryptionConfig",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEncryptionConfig",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_encryption_config) } {
            return .{ .service_metadata = service_metadata, .action = get_encryption_config };
        }
    },
    Response: type = struct {
        encryption_config: ?EncryptionConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_config = "EncryptionConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetGroup",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroup",
    Request: type = struct {
        group_name: ?[]const u8 = null,
        group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group_arn = "GroupARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_group) } {
            return .{ .service_metadata = service_metadata, .action = get_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_groups: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/Groups",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_groups) } {
            return .{ .service_metadata = service_metadata, .action = get_groups };
        }
    },
    Response: type = struct {
        groups: ?[]struct {
            group_name: ?[]const u8 = null,
            group_arn: ?[]const u8 = null,
            filter_expression: ?[]const u8 = null,
            insights_configuration: ?InsightsConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_name = "GroupName",
                    .group_arn = "GroupARN",
                    .filter_expression = "FilterExpression",
                    .insights_configuration = "InsightsConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "Groups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_insight: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/Insight",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInsight",
    Request: type = struct {
        insight_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insight) } {
            return .{ .service_metadata = service_metadata, .action = get_insight };
        }
    },
    Response: type = struct {
        insight: ?struct {
            insight_id: ?[]const u8 = null,
            group_arn: ?[]const u8 = null,
            group_name: ?[]const u8 = null,
            root_cause_service_id: ?ServiceId = null,
            categories: ?[][]const u8 = null,
            state: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            summary: ?[]const u8 = null,
            client_request_impact_statistics: ?RequestImpactStatistics = null,
            root_cause_service_request_impact_statistics: ?RequestImpactStatistics = null,
            top_anomalous_services: ?[]AnomalousService = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .insight_id = "InsightId",
                    .group_arn = "GroupARN",
                    .group_name = "GroupName",
                    .root_cause_service_id = "RootCauseServiceId",
                    .categories = "Categories",
                    .state = "State",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .summary = "Summary",
                    .client_request_impact_statistics = "ClientRequestImpactStatistics",
                    .root_cause_service_request_impact_statistics = "RootCauseServiceRequestImpactStatistics",
                    .top_anomalous_services = "TopAnomalousServices",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight = "Insight",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_insight_events: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/InsightEvents",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInsightEvents",
    Request: type = struct {
        insight_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insight_events) } {
            return .{ .service_metadata = service_metadata, .action = get_insight_events };
        }
    },
    Response: type = struct {
        insight_events: ?[]struct {
            summary: ?[]const u8 = null,
            event_time: ?i64 = null,
            client_request_impact_statistics: ?RequestImpactStatistics = null,
            root_cause_service_request_impact_statistics: ?RequestImpactStatistics = null,
            top_anomalous_services: ?[]AnomalousService = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .summary = "Summary",
                    .event_time = "EventTime",
                    .client_request_impact_statistics = "ClientRequestImpactStatistics",
                    .root_cause_service_request_impact_statistics = "RootCauseServiceRequestImpactStatistics",
                    .top_anomalous_services = "TopAnomalousServices",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_events = "InsightEvents",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_insight_impact_graph: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/InsightImpactGraph",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInsightImpactGraph",
    Request: type = struct {
        insight_id: []const u8,
        start_time: i64,
        end_time: i64,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insight_impact_graph) } {
            return .{ .service_metadata = service_metadata, .action = get_insight_impact_graph };
        }
    },
    Response: type = struct {
        insight_id: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        service_graph_start_time: ?i64 = null,
        service_graph_end_time: ?i64 = null,
        services: ?[]struct {
            reference_id: ?i64 = null,
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            names: ?[][]const u8 = null,
            account_id: ?[]const u8 = null,
            edges: ?[]struct {
                reference_id: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .reference_id = "ReferenceId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reference_id = "ReferenceId",
                    .type = "Type",
                    .name = "Name",
                    .names = "Names",
                    .account_id = "AccountId",
                    .edges = "Edges",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .service_graph_start_time = "ServiceGraphStartTime",
                .service_graph_end_time = "ServiceGraphEndTime",
                .services = "Services",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_insight_summaries: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/InsightSummaries",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInsightSummaries",
    Request: type = struct {
        states: ?[][]const u8 = null,
        group_arn: ?[]const u8 = null,
        group_name: ?[]const u8 = null,
        start_time: i64,
        end_time: i64,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .states = "States",
                .group_arn = "GroupARN",
                .group_name = "GroupName",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insight_summaries) } {
            return .{ .service_metadata = service_metadata, .action = get_insight_summaries };
        }
    },
    Response: type = struct {
        insight_summaries: ?[]struct {
            insight_id: ?[]const u8 = null,
            group_arn: ?[]const u8 = null,
            group_name: ?[]const u8 = null,
            root_cause_service_id: ?ServiceId = null,
            categories: ?[][]const u8 = null,
            state: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            summary: ?[]const u8 = null,
            client_request_impact_statistics: ?RequestImpactStatistics = null,
            root_cause_service_request_impact_statistics: ?RequestImpactStatistics = null,
            top_anomalous_services: ?[]AnomalousService = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .insight_id = "InsightId",
                    .group_arn = "GroupARN",
                    .group_name = "GroupName",
                    .root_cause_service_id = "RootCauseServiceId",
                    .categories = "Categories",
                    .state = "State",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .summary = "Summary",
                    .client_request_impact_statistics = "ClientRequestImpactStatistics",
                    .root_cause_service_request_impact_statistics = "RootCauseServiceRequestImpactStatistics",
                    .top_anomalous_services = "TopAnomalousServices",
                    .last_update_time = "LastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_summaries = "InsightSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_sampling_rules: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/GetSamplingRules",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSamplingRules",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sampling_rules) } {
            return .{ .service_metadata = service_metadata, .action = get_sampling_rules };
        }
    },
    Response: type = struct {
        sampling_rule_records: ?[]SamplingRuleRecord = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampling_rule_records = "SamplingRuleRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_sampling_statistic_summaries: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/SamplingStatisticSummaries",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSamplingStatisticSummaries",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sampling_statistic_summaries) } {
            return .{ .service_metadata = service_metadata, .action = get_sampling_statistic_summaries };
        }
    },
    Response: type = struct {
        sampling_statistic_summaries: ?[]struct {
            rule_name: ?[]const u8 = null,
            timestamp: ?i64 = null,
            request_count: ?i64 = null,
            borrow_count: ?i64 = null,
            sampled_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_name = "RuleName",
                    .timestamp = "Timestamp",
                    .request_count = "RequestCount",
                    .borrow_count = "BorrowCount",
                    .sampled_count = "SampledCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampling_statistic_summaries = "SamplingStatisticSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_sampling_targets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/SamplingTargets",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSamplingTargets",
    Request: type = struct {
        sampling_statistics_documents: []struct {
            rule_name: []const u8,
            client_id: []const u8,
            timestamp: i64,
            request_count: i64,
            sampled_count: i64,
            borrow_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_name = "RuleName",
                    .client_id = "ClientID",
                    .timestamp = "Timestamp",
                    .request_count = "RequestCount",
                    .sampled_count = "SampledCount",
                    .borrow_count = "BorrowCount",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampling_statistics_documents = "SamplingStatisticsDocuments",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sampling_targets) } {
            return .{ .service_metadata = service_metadata, .action = get_sampling_targets };
        }
    },
    Response: type = struct {
        sampling_target_documents: ?[]struct {
            rule_name: ?[]const u8 = null,
            fixed_rate: ?f64 = null,
            reservoir_quota: ?i64 = null,
            reservoir_quota_ttl: ?i64 = null,
            interval: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_name = "RuleName",
                    .fixed_rate = "FixedRate",
                    .reservoir_quota = "ReservoirQuota",
                    .reservoir_quota_ttl = "ReservoirQuotaTTL",
                    .interval = "Interval",
                };
                return @field(mappings, field_name);
            }
        } = null,
        last_rule_modification: ?i64 = null,
        unprocessed_statistics: ?[]struct {
            rule_name: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_name = "RuleName",
                    .error_code = "ErrorCode",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampling_target_documents = "SamplingTargetDocuments",
                .last_rule_modification = "LastRuleModification",
                .unprocessed_statistics = "UnprocessedStatistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_service_graph: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ServiceGraph",
        .success_code = 200,
    };

    action_name: []const u8 = "GetServiceGraph",
    Request: type = struct {
        start_time: i64,
        end_time: i64,
        group_name: ?[]const u8 = null,
        group_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time = "StartTime",
                .end_time = "EndTime",
                .group_name = "GroupName",
                .group_arn = "GroupARN",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service_graph) } {
            return .{ .service_metadata = service_metadata, .action = get_service_graph };
        }
    },
    Response: type = struct {
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        services: ?[]Service = null,
        contains_old_group_versions: ?bool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time = "StartTime",
                .end_time = "EndTime",
                .services = "Services",
                .contains_old_group_versions = "ContainsOldGroupVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_time_series_service_statistics: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/TimeSeriesServiceStatistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTimeSeriesServiceStatistics",
    Request: type = struct {
        start_time: i64,
        end_time: i64,
        group_name: ?[]const u8 = null,
        group_arn: ?[]const u8 = null,
        entity_selector_expression: ?[]const u8 = null,
        period: ?i64 = null,
        forecast_statistics: ?bool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time = "StartTime",
                .end_time = "EndTime",
                .group_name = "GroupName",
                .group_arn = "GroupARN",
                .entity_selector_expression = "EntitySelectorExpression",
                .period = "Period",
                .forecast_statistics = "ForecastStatistics",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_time_series_service_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_time_series_service_statistics };
        }
    },
    Response: type = struct {
        time_series_service_statistics: ?[]struct {
            timestamp: ?i64 = null,
            edge_summary_statistics: ?EdgeStatistics = null,
            service_summary_statistics: ?ServiceStatistics = null,
            service_forecast_statistics: ?struct {
                fault_count_high: ?i64 = null,
                fault_count_low: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .fault_count_high = "FaultCountHigh",
                        .fault_count_low = "FaultCountLow",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            response_time_histogram: ?[]HistogramEntry = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .edge_summary_statistics = "EdgeSummaryStatistics",
                    .service_summary_statistics = "ServiceSummaryStatistics",
                    .service_forecast_statistics = "ServiceForecastStatistics",
                    .response_time_histogram = "ResponseTimeHistogram",
                };
                return @field(mappings, field_name);
            }
        } = null,
        contains_old_group_versions: ?bool = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .time_series_service_statistics = "TimeSeriesServiceStatistics",
                .contains_old_group_versions = "ContainsOldGroupVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_trace_graph: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/TraceGraph",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTraceGraph",
    Request: type = struct {
        trace_ids: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trace_ids = "TraceIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_trace_graph) } {
            return .{ .service_metadata = service_metadata, .action = get_trace_graph };
        }
    },
    Response: type = struct {
        services: ?[]Service = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .services = "Services",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const get_trace_summaries: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/TraceSummaries",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTraceSummaries",
    Request: type = struct {
        start_time: i64,
        end_time: i64,
        time_range_type: ?[]const u8 = null,
        sampling: ?bool = null,
        sampling_strategy: ?struct {
            name: ?[]const u8 = null,
            value: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filter_expression: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time = "StartTime",
                .end_time = "EndTime",
                .time_range_type = "TimeRangeType",
                .sampling = "Sampling",
                .sampling_strategy = "SamplingStrategy",
                .filter_expression = "FilterExpression",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_trace_summaries) } {
            return .{ .service_metadata = service_metadata, .action = get_trace_summaries };
        }
    },
    Response: type = struct {
        trace_summaries: ?[]struct {
            id: ?[]const u8 = null,
            start_time: ?i64 = null,
            duration: ?f64 = null,
            response_time: ?f64 = null,
            has_fault: ?bool = null,
            has_error: ?bool = null,
            has_throttle: ?bool = null,
            is_partial: ?bool = null,
            http: ?struct {
                http_url: ?[]const u8 = null,
                http_status: ?i64 = null,
                http_method: ?[]const u8 = null,
                user_agent: ?[]const u8 = null,
                client_ip: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .http_url = "HttpURL",
                        .http_status = "HttpStatus",
                        .http_method = "HttpMethod",
                        .user_agent = "UserAgent",
                        .client_ip = "ClientIp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            annotations: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]struct {
                    annotation_value: ?union {
                        number_value: ?f64,
                        boolean_value: ?bool,
                        string_value: ?[]const u8,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .number_value = "NumberValue",
                                .boolean_value = "BooleanValue",
                                .string_value = "StringValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    service_ids: ?[]ServiceId = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .annotation_value = "AnnotationValue",
                            .service_ids = "ServiceIds",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
            } = null,
            users: ?[]struct {
                user_name: ?[]const u8 = null,
                service_ids: ?[]ServiceId = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .user_name = "UserName",
                        .service_ids = "ServiceIds",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            service_ids: ?[]ServiceId = null,
            resource_ar_ns: ?[]struct {
                arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .arn = "ARN",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            instance_ids: ?[]struct {
                id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            availability_zones: ?[]struct {
                name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            entry_point: ?ServiceId = null,
            fault_root_causes: ?[]struct {
                services: ?[]struct {
                    name: ?[]const u8 = null,
                    names: ?[][]const u8 = null,
                    type: ?[]const u8 = null,
                    account_id: ?[]const u8 = null,
                    entity_path: ?[]struct {
                        name: ?[]const u8 = null,
                        exceptions: ?[]RootCauseException = null,
                        remote: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .name = "Name",
                                .exceptions = "Exceptions",
                                .remote = "Remote",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    inferred: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "Name",
                            .names = "Names",
                            .type = "Type",
                            .account_id = "AccountId",
                            .entity_path = "EntityPath",
                            .inferred = "Inferred",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                client_impacting: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .services = "Services",
                        .client_impacting = "ClientImpacting",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            error_root_causes: ?[]struct {
                services: ?[]struct {
                    name: ?[]const u8 = null,
                    names: ?[][]const u8 = null,
                    type: ?[]const u8 = null,
                    account_id: ?[]const u8 = null,
                    entity_path: ?[]struct {
                        name: ?[]const u8 = null,
                        exceptions: ?[]RootCauseException = null,
                        remote: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .name = "Name",
                                .exceptions = "Exceptions",
                                .remote = "Remote",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    inferred: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "Name",
                            .names = "Names",
                            .type = "Type",
                            .account_id = "AccountId",
                            .entity_path = "EntityPath",
                            .inferred = "Inferred",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                client_impacting: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .services = "Services",
                        .client_impacting = "ClientImpacting",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            response_time_root_causes: ?[]struct {
                services: ?[]struct {
                    name: ?[]const u8 = null,
                    names: ?[][]const u8 = null,
                    type: ?[]const u8 = null,
                    account_id: ?[]const u8 = null,
                    entity_path: ?[]struct {
                        name: ?[]const u8 = null,
                        coverage: ?f64 = null,
                        remote: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .name = "Name",
                                .coverage = "Coverage",
                                .remote = "Remote",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    inferred: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "Name",
                            .names = "Names",
                            .type = "Type",
                            .account_id = "AccountId",
                            .entity_path = "EntityPath",
                            .inferred = "Inferred",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                client_impacting: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .services = "Services",
                        .client_impacting = "ClientImpacting",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            revision: ?i64 = null,
            matched_event_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .start_time = "StartTime",
                    .duration = "Duration",
                    .response_time = "ResponseTime",
                    .has_fault = "HasFault",
                    .has_error = "HasError",
                    .has_throttle = "HasThrottle",
                    .is_partial = "IsPartial",
                    .http = "Http",
                    .annotations = "Annotations",
                    .users = "Users",
                    .service_ids = "ServiceIds",
                    .resource_ar_ns = "ResourceARNs",
                    .instance_ids = "InstanceIds",
                    .availability_zones = "AvailabilityZones",
                    .entry_point = "EntryPoint",
                    .fault_root_causes = "FaultRootCauses",
                    .error_root_causes = "ErrorRootCauses",
                    .response_time_root_causes = "ResponseTimeRootCauses",
                    .revision = "Revision",
                    .matched_event_time = "MatchedEventTime",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "annotations", field_name))
                    return try serializeMap(self.annotations, self.fieldNameFor("annotations"), options, out_stream);
                return false;
            }
        } = null,
        approximate_time: ?i64 = null,
        traces_processed_count: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trace_summaries = "TraceSummaries",
                .approximate_time = "ApproximateTime",
                .traces_processed_count = "TracesProcessedCount",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const list_resource_policies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListResourcePolicies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResourcePolicies",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resource_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_resource_policies };
        }
    },
    Response: type = struct {
        resource_policies: ?[]ResourcePolicy = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_policies = "ResourcePolicies",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListTagsForResource",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        Throttled,
    },
} = .{};
pub const put_encryption_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/PutEncryptionConfig",
        .success_code = 200,
    };

    action_name: []const u8 = "PutEncryptionConfig",
    Request: type = struct {
        key_id: ?[]const u8 = null,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_id = "KeyId",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_encryption_config) } {
            return .{ .service_metadata = service_metadata, .action = put_encryption_config };
        }
    },
    Response: type = struct {
        encryption_config: ?EncryptionConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .encryption_config = "EncryptionConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const put_resource_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/PutResourcePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        policy_name: []const u8,
        policy_document: []const u8,
        policy_revision_id: ?[]const u8 = null,
        bypass_policy_lockout_check: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_name = "PolicyName",
                .policy_document = "PolicyDocument",
                .policy_revision_id = "PolicyRevisionId",
                .bypass_policy_lockout_check = "BypassPolicyLockoutCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        resource_policy: ?ResourcePolicy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidPolicyRevisionId,
        LockoutPrevention,
        MalformedPolicyDocument,
        PolicyCountLimitExceeded,
        PolicySizeLimitExceeded,
        Throttled,
    },
} = .{};
pub const put_telemetry_records: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/TelemetryRecords",
        .success_code = 200,
    };

    action_name: []const u8 = "PutTelemetryRecords",
    Request: type = struct {
        telemetry_records: []struct {
            timestamp: i64,
            segments_received_count: ?i64 = null,
            segments_sent_count: ?i64 = null,
            segments_spillover_count: ?i64 = null,
            segments_rejected_count: ?i64 = null,
            backend_connection_errors: ?struct {
                timeout_count: ?i64 = null,
                connection_refused_count: ?i64 = null,
                http_code4xx_count: ?i64 = null,
                http_code5xx_count: ?i64 = null,
                unknown_host_count: ?i64 = null,
                other_count: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .timeout_count = "TimeoutCount",
                        .connection_refused_count = "ConnectionRefusedCount",
                        .http_code4xx_count = "HTTPCode4XXCount",
                        .http_code5xx_count = "HTTPCode5XXCount",
                        .unknown_host_count = "UnknownHostCount",
                        .other_count = "OtherCount",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .segments_received_count = "SegmentsReceivedCount",
                    .segments_sent_count = "SegmentsSentCount",
                    .segments_spillover_count = "SegmentsSpilloverCount",
                    .segments_rejected_count = "SegmentsRejectedCount",
                    .backend_connection_errors = "BackendConnectionErrors",
                };
                return @field(mappings, field_name);
            }
        },
        ec2_instance_id: ?[]const u8 = null,
        hostname: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .telemetry_records = "TelemetryRecords",
                .ec2_instance_id = "EC2InstanceId",
                .hostname = "Hostname",
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_telemetry_records) } {
            return .{ .service_metadata = service_metadata, .action = put_telemetry_records };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const put_trace_segments: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/TraceSegments",
        .success_code = 200,
    };

    action_name: []const u8 = "PutTraceSegments",
    Request: type = struct {
        trace_segment_documents: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trace_segment_documents = "TraceSegmentDocuments",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_trace_segments) } {
            return .{ .service_metadata = service_metadata, .action = put_trace_segments };
        }
    },
    Response: type = struct {
        unprocessed_trace_segments: ?[]struct {
            id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .error_code = "ErrorCode",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .unprocessed_trace_segments = "UnprocessedTraceSegments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/TagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        Throttled,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UntagResource",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ResourceNotFound,
        Throttled,
    },
} = .{};
pub const update_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateGroup",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGroup",
    Request: type = struct {
        group_name: ?[]const u8 = null,
        group_arn: ?[]const u8 = null,
        filter_expression: ?[]const u8 = null,
        insights_configuration: ?InsightsConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group_arn = "GroupARN",
                .filter_expression = "FilterExpression",
                .insights_configuration = "InsightsConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_group) } {
            return .{ .service_metadata = service_metadata, .action = update_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};
pub const update_sampling_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/UpdateSamplingRule",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSamplingRule",
    Request: type = struct {
        sampling_rule_update: struct {
            rule_name: ?[]const u8 = null,
            rule_arn: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            priority: ?i64 = null,
            fixed_rate: ?f64 = null,
            reservoir_size: ?i64 = null,
            host: ?[]const u8 = null,
            service_name: ?[]const u8 = null,
            service_type: ?[]const u8 = null,
            http_method: ?[]const u8 = null,
            url_path: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_name = "RuleName",
                    .rule_arn = "RuleARN",
                    .resource_arn = "ResourceARN",
                    .priority = "Priority",
                    .fixed_rate = "FixedRate",
                    .reservoir_size = "ReservoirSize",
                    .host = "Host",
                    .service_name = "ServiceName",
                    .service_type = "ServiceType",
                    .http_method = "HTTPMethod",
                    .url_path = "URLPath",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampling_rule_update = "SamplingRuleUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sampling_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_sampling_rule };
        }
    },
    Response: type = struct {
        sampling_rule_record: ?SamplingRuleRecord = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampling_rule_record = "SamplingRuleRecord",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        Throttled,
    },
} = .{};

pub const SamplingRuleRecord = struct {
    sampling_rule: ?SamplingRule = null,
    created_at: ?i64 = null,
    modified_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sampling_rule = "SamplingRule",
            .created_at = "CreatedAt",
            .modified_at = "ModifiedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const SamplingRule = struct {
    rule_name: ?[]const u8 = null,
    rule_arn: ?[]const u8 = null,
    resource_arn: []const u8,
    priority: i64,
    fixed_rate: f64,
    reservoir_size: i64,
    service_name: []const u8,
    service_type: []const u8,
    host: []const u8,
    http_method: []const u8,
    url_path: []const u8,
    version: i64,
    attributes: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_name = "RuleName",
            .rule_arn = "RuleARN",
            .resource_arn = "ResourceARN",
            .priority = "Priority",
            .fixed_rate = "FixedRate",
            .reservoir_size = "ReservoirSize",
            .service_name = "ServiceName",
            .service_type = "ServiceType",
            .host = "Host",
            .http_method = "HTTPMethod",
            .url_path = "URLPath",
            .version = "Version",
            .attributes = "Attributes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attributes", field_name))
            return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
        return false;
    }
};

pub const Group = struct {
    group_name: ?[]const u8 = null,
    group_arn: ?[]const u8 = null,
    filter_expression: ?[]const u8 = null,
    insights_configuration: ?InsightsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
            .group_arn = "GroupARN",
            .filter_expression = "FilterExpression",
            .insights_configuration = "InsightsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightsConfiguration = struct {
    insights_enabled: ?bool = null,
    notifications_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insights_enabled = "InsightsEnabled",
            .notifications_enabled = "NotificationsEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePolicy = struct {
    policy_name: ?[]const u8 = null,
    policy_document: ?[]const u8 = null,
    policy_revision_id: ?[]const u8 = null,
    last_updated_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .policy_name = "PolicyName",
            .policy_document = "PolicyDocument",
            .policy_revision_id = "PolicyRevisionId",
            .last_updated_time = "LastUpdatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfig = struct {
    key_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_id = "KeyId",
            .status = "Status",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const RootCauseException = struct {
    name: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceId = struct {
    name: ?[]const u8 = null,
    names: ?[][]const u8 = null,
    account_id: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .names = "Names",
            .account_id = "AccountId",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const Service = struct {
    reference_id: ?i64 = null,
    name: ?[]const u8 = null,
    names: ?[][]const u8 = null,
    root: ?bool = null,
    account_id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    edges: ?[]Edge = null,
    summary_statistics: ?ServiceStatistics = null,
    duration_histogram: ?[]HistogramEntry = null,
    response_time_histogram: ?[]HistogramEntry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reference_id = "ReferenceId",
            .name = "Name",
            .names = "Names",
            .root = "Root",
            .account_id = "AccountId",
            .type = "Type",
            .state = "State",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .edges = "Edges",
            .summary_statistics = "SummaryStatistics",
            .duration_histogram = "DurationHistogram",
            .response_time_histogram = "ResponseTimeHistogram",
        };
        return @field(mappings, field_name);
    }
};

pub const HistogramEntry = struct {
    value: ?f64 = null,
    count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .count = "Count",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceStatistics = struct {
    ok_count: ?i64 = null,
    error_statistics: ?ErrorStatistics = null,
    fault_statistics: ?FaultStatistics = null,
    total_count: ?i64 = null,
    total_response_time: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ok_count = "OkCount",
            .error_statistics = "ErrorStatistics",
            .fault_statistics = "FaultStatistics",
            .total_count = "TotalCount",
            .total_response_time = "TotalResponseTime",
        };
        return @field(mappings, field_name);
    }
};

pub const FaultStatistics = struct {
    other_count: ?i64 = null,
    total_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .other_count = "OtherCount",
            .total_count = "TotalCount",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorStatistics = struct {
    throttle_count: ?i64 = null,
    other_count: ?i64 = null,
    total_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .throttle_count = "ThrottleCount",
            .other_count = "OtherCount",
            .total_count = "TotalCount",
        };
        return @field(mappings, field_name);
    }
};

pub const Edge = struct {
    reference_id: ?i64 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    summary_statistics: ?EdgeStatistics = null,
    response_time_histogram: ?[]HistogramEntry = null,
    aliases: ?[]Alias = null,
    edge_type: ?[]const u8 = null,
    received_event_age_histogram: ?[]HistogramEntry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reference_id = "ReferenceId",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .summary_statistics = "SummaryStatistics",
            .response_time_histogram = "ResponseTimeHistogram",
            .aliases = "Aliases",
            .edge_type = "EdgeType",
            .received_event_age_histogram = "ReceivedEventAgeHistogram",
        };
        return @field(mappings, field_name);
    }
};

pub const Alias = struct {
    name: ?[]const u8 = null,
    names: ?[][]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .names = "Names",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const EdgeStatistics = struct {
    ok_count: ?i64 = null,
    error_statistics: ?ErrorStatistics = null,
    fault_statistics: ?FaultStatistics = null,
    total_count: ?i64 = null,
    total_response_time: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ok_count = "OkCount",
            .error_statistics = "ErrorStatistics",
            .fault_statistics = "FaultStatistics",
            .total_count = "TotalCount",
            .total_response_time = "TotalResponseTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalousService = struct {
    service_id: ?ServiceId = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_id = "ServiceId",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestImpactStatistics = struct {
    fault_count: ?i64 = null,
    ok_count: ?i64 = null,
    total_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fault_count = "FaultCount",
            .ok_count = "OkCount",
            .total_count = "TotalCount",
        };
        return @field(mappings, field_name);
    }
};
