const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-07-09";
pub const sdk_id: []const u8 = "API Gateway";
pub const arn_namespace: ?[]const u8 = "apigateway";
pub const endpoint_prefix: []const u8 = "apigateway";
pub const sigv4_name: []const u8 = "apigateway";
pub const name: []const u8 = "BackplaneControlService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-07-09",
    sdk_id: []const u8 = "API Gateway",
    arn_namespace: ?[]const u8 = "apigateway",
    endpoint_prefix: []const u8 = "apigateway",
    sigv4_name: []const u8 = "apigateway",
    name: []const u8 = "BackplaneControlService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_api_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apikeys",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateApiKey",
    Request: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        enabled: ?bool = null,
        generate_distinct_id: ?bool = null,
        value: ?[]const u8 = null,
        stage_keys: ?[]struct {
            rest_api_id: ?[]const u8 = null,
            stage_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rest_api_id = "restApiId",
                    .stage_name = "stageName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        customer_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .enabled = "enabled",
                .generate_distinct_id = "generateDistinctId",
                .value = "value",
                .stage_keys = "stageKeys",
                .customer_id = "customerId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_api_key) } {
            return .{ .service_metadata = service_metadata, .action = create_api_key };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        value: ?[]const u8 = null,
        name: ?[]const u8 = null,
        customer_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        enabled: ?bool = null,
        created_date: ?i64 = null,
        last_updated_date: ?i64 = null,
        stage_keys: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .value = "value",
                .name = "name",
                .customer_id = "customerId",
                .description = "description",
                .enabled = "enabled",
                .created_date = "createdDate",
                .last_updated_date = "lastUpdatedDate",
                .stage_keys = "stageKeys",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_authorizer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis/{restApiId}/authorizers",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAuthorizer",
    Request: type = struct {
        rest_api_id: []const u8,
        name: []const u8,
        type: []const u8,
        provider_ar_ns: ?[][]const u8 = null,
        auth_type: ?[]const u8 = null,
        authorizer_uri: ?[]const u8 = null,
        authorizer_credentials: ?[]const u8 = null,
        identity_source: ?[]const u8 = null,
        identity_validation_expression: ?[]const u8 = null,
        authorizer_result_ttl_in_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .name = "name",
                .type = "type",
                .provider_ar_ns = "providerARNs",
                .auth_type = "authType",
                .authorizer_uri = "authorizerUri",
                .authorizer_credentials = "authorizerCredentials",
                .identity_source = "identitySource",
                .identity_validation_expression = "identityValidationExpression",
                .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = create_authorizer };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        type: ?[]const u8 = null,
        provider_ar_ns: ?[][]const u8 = null,
        auth_type: ?[]const u8 = null,
        authorizer_uri: ?[]const u8 = null,
        authorizer_credentials: ?[]const u8 = null,
        identity_source: ?[]const u8 = null,
        identity_validation_expression: ?[]const u8 = null,
        authorizer_result_ttl_in_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .type = "type",
                .provider_ar_ns = "providerARNs",
                .auth_type = "authType",
                .authorizer_uri = "authorizerUri",
                .authorizer_credentials = "authorizerCredentials",
                .identity_source = "identitySource",
                .identity_validation_expression = "identityValidationExpression",
                .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_base_path_mapping: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domainnames/{domainName}/basepathmappings",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateBasePathMapping",
    Request: type = struct {
        domain_name: []const u8,
        base_path: ?[]const u8 = null,
        rest_api_id: []const u8,
        stage: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .base_path = "basePath",
                .rest_api_id = "restApiId",
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_base_path_mapping) } {
            return .{ .service_metadata = service_metadata, .action = create_base_path_mapping };
        }
    },
    Response: type = struct {
        base_path: ?[]const u8 = null,
        rest_api_id: ?[]const u8 = null,
        stage: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .base_path = "basePath",
                .rest_api_id = "restApiId",
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_deployment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis/{restApiId}/deployments",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDeployment",
    Request: type = struct {
        rest_api_id: []const u8,
        stage_name: ?[]const u8 = null,
        stage_description: ?[]const u8 = null,
        description: ?[]const u8 = null,
        cache_cluster_enabled: ?bool = null,
        cache_cluster_size: ?[]const u8 = null,
        variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        canary_settings: ?struct {
            percent_traffic: ?f64 = null,
            stage_variable_overrides: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            use_stage_cache: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .percent_traffic = "percentTraffic",
                    .stage_variable_overrides = "stageVariableOverrides",
                    .use_stage_cache = "useStageCache",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "stage_variable_overrides", field_name))
                    return try serializeMap(self.stage_variable_overrides, self.fieldNameFor("stage_variable_overrides"), options, out_stream);
                return false;
            }
        } = null,
        tracing_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .stage_name = "stageName",
                .stage_description = "stageDescription",
                .description = "description",
                .cache_cluster_enabled = "cacheClusterEnabled",
                .cache_cluster_size = "cacheClusterSize",
                .variables = "variables",
                .canary_settings = "canarySettings",
                .tracing_enabled = "tracingEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "variables", field_name))
                return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_deployment) } {
            return .{ .service_metadata = service_metadata, .action = create_deployment };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?i64 = null,
        api_summary: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MethodSnapshot = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .description = "description",
                .created_date = "createdDate",
                .api_summary = "apiSummary",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "api_summary", field_name))
                return try serializeMap(self.api_summary, self.fieldNameFor("api_summary"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_documentation_part: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis/{restApiId}/documentation/parts",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDocumentationPart",
    Request: type = struct {
        rest_api_id: []const u8,
        location: DocumentationPartLocation,
        properties: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .location = "location",
                .properties = "properties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_documentation_part) } {
            return .{ .service_metadata = service_metadata, .action = create_documentation_part };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        location: ?DocumentationPartLocation = null,
        properties: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .location = "location",
                .properties = "properties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_documentation_version: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis/{restApiId}/documentation/versions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDocumentationVersion",
    Request: type = struct {
        rest_api_id: []const u8,
        documentation_version: []const u8,
        stage_name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .documentation_version = "documentationVersion",
                .stage_name = "stageName",
                .description = "description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_documentation_version) } {
            return .{ .service_metadata = service_metadata, .action = create_documentation_version };
        }
    },
    Response: type = struct {
        version: ?[]const u8 = null,
        created_date: ?i64 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version = "version",
                .created_date = "createdDate",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_domain_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domainnames",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDomainName",
    Request: type = struct {
        domain_name: []const u8,
        certificate_name: ?[]const u8 = null,
        certificate_body: ?[]const u8 = null,
        certificate_private_key: ?[]const u8 = null,
        certificate_chain: ?[]const u8 = null,
        certificate_arn: ?[]const u8 = null,
        regional_certificate_name: ?[]const u8 = null,
        regional_certificate_arn: ?[]const u8 = null,
        endpoint_configuration: ?EndpointConfiguration = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        security_policy: ?[]const u8 = null,
        mutual_tls_authentication: ?struct {
            truststore_uri: ?[]const u8 = null,
            truststore_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .truststore_uri = "truststoreUri",
                    .truststore_version = "truststoreVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        ownership_verification_certificate_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .certificate_name = "certificateName",
                .certificate_body = "certificateBody",
                .certificate_private_key = "certificatePrivateKey",
                .certificate_chain = "certificateChain",
                .certificate_arn = "certificateArn",
                .regional_certificate_name = "regionalCertificateName",
                .regional_certificate_arn = "regionalCertificateArn",
                .endpoint_configuration = "endpointConfiguration",
                .tags = "tags",
                .security_policy = "securityPolicy",
                .mutual_tls_authentication = "mutualTlsAuthentication",
                .ownership_verification_certificate_arn = "ownershipVerificationCertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_domain_name) } {
            return .{ .service_metadata = service_metadata, .action = create_domain_name };
        }
    },
    Response: type = struct {
        domain_name: ?[]const u8 = null,
        certificate_name: ?[]const u8 = null,
        certificate_arn: ?[]const u8 = null,
        certificate_upload_date: ?i64 = null,
        regional_domain_name: ?[]const u8 = null,
        regional_hosted_zone_id: ?[]const u8 = null,
        regional_certificate_name: ?[]const u8 = null,
        regional_certificate_arn: ?[]const u8 = null,
        distribution_domain_name: ?[]const u8 = null,
        distribution_hosted_zone_id: ?[]const u8 = null,
        endpoint_configuration: ?EndpointConfiguration = null,
        domain_name_status: ?[]const u8 = null,
        domain_name_status_message: ?[]const u8 = null,
        security_policy: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        mutual_tls_authentication: ?MutualTlsAuthentication = null,
        ownership_verification_certificate_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .certificate_name = "certificateName",
                .certificate_arn = "certificateArn",
                .certificate_upload_date = "certificateUploadDate",
                .regional_domain_name = "regionalDomainName",
                .regional_hosted_zone_id = "regionalHostedZoneId",
                .regional_certificate_name = "regionalCertificateName",
                .regional_certificate_arn = "regionalCertificateArn",
                .distribution_domain_name = "distributionDomainName",
                .distribution_hosted_zone_id = "distributionHostedZoneId",
                .endpoint_configuration = "endpointConfiguration",
                .domain_name_status = "domainNameStatus",
                .domain_name_status_message = "domainNameStatusMessage",
                .security_policy = "securityPolicy",
                .tags = "tags",
                .mutual_tls_authentication = "mutualTlsAuthentication",
                .ownership_verification_certificate_arn = "ownershipVerificationCertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_model: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis/{restApiId}/models",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateModel",
    Request: type = struct {
        rest_api_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        content_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .name = "name",
                .description = "description",
                .schema = "schema",
                .content_type = "contentType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model) } {
            return .{ .service_metadata = service_metadata, .action = create_model };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        content_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .schema = "schema",
                .content_type = "contentType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_request_validator: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis/{restApiId}/requestvalidators",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRequestValidator",
    Request: type = struct {
        rest_api_id: []const u8,
        name: ?[]const u8 = null,
        validate_request_body: ?bool = null,
        validate_request_parameters: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .name = "name",
                .validate_request_body = "validateRequestBody",
                .validate_request_parameters = "validateRequestParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_request_validator) } {
            return .{ .service_metadata = service_metadata, .action = create_request_validator };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        validate_request_body: ?bool = null,
        validate_request_parameters: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .validate_request_body = "validateRequestBody",
                .validate_request_parameters = "validateRequestParameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis/{restApiId}/resources/{parentId}",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateResource",
    Request: type = struct {
        rest_api_id: []const u8,
        parent_id: []const u8,
        path_part: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .parent_id = "parentId",
                .path_part = "pathPart",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource) } {
            return .{ .service_metadata = service_metadata, .action = create_resource };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        parent_id: ?[]const u8 = null,
        path_part: ?[]const u8 = null,
        path: ?[]const u8 = null,
        resource_methods: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Method = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .parent_id = "parentId",
                .path_part = "pathPart",
                .path = "path",
                .resource_methods = "resourceMethods",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "resource_methods", field_name))
                return try serializeMap(self.resource_methods, self.fieldNameFor("resource_methods"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_rest_api: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRestApi",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        version: ?[]const u8 = null,
        clone_from: ?[]const u8 = null,
        binary_media_types: ?[][]const u8 = null,
        minimum_compression_size: ?i64 = null,
        api_key_source: ?[]const u8 = null,
        endpoint_configuration: ?EndpointConfiguration = null,
        policy: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        disable_execute_api_endpoint: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .version = "version",
                .clone_from = "cloneFrom",
                .binary_media_types = "binaryMediaTypes",
                .minimum_compression_size = "minimumCompressionSize",
                .api_key_source = "apiKeySource",
                .endpoint_configuration = "endpointConfiguration",
                .policy = "policy",
                .tags = "tags",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rest_api) } {
            return .{ .service_metadata = service_metadata, .action = create_rest_api };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        warnings: ?[][]const u8 = null,
        binary_media_types: ?[][]const u8 = null,
        minimum_compression_size: ?i64 = null,
        api_key_source: ?[]const u8 = null,
        endpoint_configuration: ?EndpointConfiguration = null,
        policy: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        disable_execute_api_endpoint: ?bool = null,
        root_resource_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .created_date = "createdDate",
                .version = "version",
                .warnings = "warnings",
                .binary_media_types = "binaryMediaTypes",
                .minimum_compression_size = "minimumCompressionSize",
                .api_key_source = "apiKeySource",
                .endpoint_configuration = "endpointConfiguration",
                .policy = "policy",
                .tags = "tags",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .root_resource_id = "rootResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_stage: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis/{restApiId}/stages",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateStage",
    Request: type = struct {
        rest_api_id: []const u8,
        stage_name: []const u8,
        deployment_id: []const u8,
        description: ?[]const u8 = null,
        cache_cluster_enabled: ?bool = null,
        cache_cluster_size: ?[]const u8 = null,
        variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        documentation_version: ?[]const u8 = null,
        canary_settings: ?CanarySettings = null,
        tracing_enabled: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .stage_name = "stageName",
                .deployment_id = "deploymentId",
                .description = "description",
                .cache_cluster_enabled = "cacheClusterEnabled",
                .cache_cluster_size = "cacheClusterSize",
                .variables = "variables",
                .documentation_version = "documentationVersion",
                .canary_settings = "canarySettings",
                .tracing_enabled = "tracingEnabled",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "variables", field_name))
                return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_stage) } {
            return .{ .service_metadata = service_metadata, .action = create_stage };
        }
    },
    Response: type = struct {
        deployment_id: ?[]const u8 = null,
        client_certificate_id: ?[]const u8 = null,
        stage_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        cache_cluster_enabled: ?bool = null,
        cache_cluster_size: ?[]const u8 = null,
        cache_cluster_status: ?[]const u8 = null,
        method_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MethodSetting = null,
        } = null,
        variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        documentation_version: ?[]const u8 = null,
        access_log_settings: ?AccessLogSettings = null,
        canary_settings: ?CanarySettings = null,
        tracing_enabled: ?bool = null,
        web_acl_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        created_date: ?i64 = null,
        last_updated_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_id = "deploymentId",
                .client_certificate_id = "clientCertificateId",
                .stage_name = "stageName",
                .description = "description",
                .cache_cluster_enabled = "cacheClusterEnabled",
                .cache_cluster_size = "cacheClusterSize",
                .cache_cluster_status = "cacheClusterStatus",
                .method_settings = "methodSettings",
                .variables = "variables",
                .documentation_version = "documentationVersion",
                .access_log_settings = "accessLogSettings",
                .canary_settings = "canarySettings",
                .tracing_enabled = "tracingEnabled",
                .web_acl_arn = "webAclArn",
                .tags = "tags",
                .created_date = "createdDate",
                .last_updated_date = "lastUpdatedDate",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "method_settings", field_name))
                return try serializeMap(self.method_settings, self.fieldNameFor("method_settings"), options, out_stream);
            if (std.mem.eql(u8, "variables", field_name))
                return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_usage_plan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/usageplans",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateUsagePlan",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        api_stages: ?[]ApiStage = null,
        throttle: ?ThrottleSettings = null,
        quota: ?QuotaSettings = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .api_stages = "apiStages",
                .throttle = "throttle",
                .quota = "quota",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_usage_plan) } {
            return .{ .service_metadata = service_metadata, .action = create_usage_plan };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        api_stages: ?[]ApiStage = null,
        throttle: ?ThrottleSettings = null,
        quota: ?QuotaSettings = null,
        product_code: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .api_stages = "apiStages",
                .throttle = "throttle",
                .quota = "quota",
                .product_code = "productCode",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_usage_plan_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/usageplans/{usagePlanId}/keys",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateUsagePlanKey",
    Request: type = struct {
        usage_plan_id: []const u8,
        key_id: []const u8,
        key_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
                .key_id = "keyId",
                .key_type = "keyType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_usage_plan_key) } {
            return .{ .service_metadata = service_metadata, .action = create_usage_plan_key };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        type: ?[]const u8 = null,
        value: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .type = "type",
                .value = "value",
                .name = "name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_vpc_link: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/vpclinks",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateVpcLink",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        target_arns: [][]const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .target_arns = "targetArns",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vpc_link) } {
            return .{ .service_metadata = service_metadata, .action = create_vpc_link };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        target_arns: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .target_arns = "targetArns",
                .status = "status",
                .status_message = "statusMessage",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_api_key: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/apikeys/{apiKey}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteApiKey",
    Request: type = struct {
        api_key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_key = "apiKey",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_api_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_api_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_authorizer: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/authorizers/{authorizerId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteAuthorizer",
    Request: type = struct {
        rest_api_id: []const u8,
        authorizer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .authorizer_id = "authorizerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = delete_authorizer };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_base_path_mapping: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/domainnames/{domainName}/basepathmappings/{basePath}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteBasePathMapping",
    Request: type = struct {
        domain_name: []const u8,
        base_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .base_path = "basePath",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_base_path_mapping) } {
            return .{ .service_metadata = service_metadata, .action = delete_base_path_mapping };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_client_certificate: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/clientcertificates/{clientCertificateId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteClientCertificate",
    Request: type = struct {
        client_certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_certificate_id = "clientCertificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_client_certificate) } {
            return .{ .service_metadata = service_metadata, .action = delete_client_certificate };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_deployment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/deployments/{deploymentId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteDeployment",
    Request: type = struct {
        rest_api_id: []const u8,
        deployment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .deployment_id = "deploymentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_deployment) } {
            return .{ .service_metadata = service_metadata, .action = delete_deployment };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_documentation_part: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/documentation/parts/{documentationPartId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteDocumentationPart",
    Request: type = struct {
        rest_api_id: []const u8,
        documentation_part_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .documentation_part_id = "documentationPartId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_documentation_part) } {
            return .{ .service_metadata = service_metadata, .action = delete_documentation_part };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_documentation_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/documentation/versions/{documentationVersion}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteDocumentationVersion",
    Request: type = struct {
        rest_api_id: []const u8,
        documentation_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .documentation_version = "documentationVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_documentation_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_documentation_version };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_domain_name: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/domainnames/{domainName}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteDomainName",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_domain_name) } {
            return .{ .service_metadata = service_metadata, .action = delete_domain_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_gateway_response: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/gatewayresponses/{responseType}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteGatewayResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        response_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .response_type = "responseType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_gateway_response) } {
            return .{ .service_metadata = service_metadata, .action = delete_gateway_response };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_integration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/integration",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIntegration",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_integration) } {
            return .{ .service_metadata = service_metadata, .action = delete_integration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_integration_response: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/integration/responses/{statusCode}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIntegrationResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        status_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .status_code = "statusCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_integration_response) } {
            return .{ .service_metadata = service_metadata, .action = delete_integration_response };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_method: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMethod",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_method) } {
            return .{ .service_metadata = service_metadata, .action = delete_method };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_method_response: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/responses/{statusCode}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMethodResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        status_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .status_code = "statusCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_method_response) } {
            return .{ .service_metadata = service_metadata, .action = delete_method_response };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_model: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/models/{modelName}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteModel",
    Request: type = struct {
        rest_api_id: []const u8,
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .model_name = "modelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_model };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_request_validator: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/requestvalidators/{requestValidatorId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteRequestValidator",
    Request: type = struct {
        rest_api_id: []const u8,
        request_validator_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .request_validator_id = "requestValidatorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_request_validator) } {
            return .{ .service_metadata = service_metadata, .action = delete_request_validator };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/resources/{resourceId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteResource",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_rest_api: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteRestApi",
    Request: type = struct {
        rest_api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rest_api) } {
            return .{ .service_metadata = service_metadata, .action = delete_rest_api };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_stage: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/stages/{stageName}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteStage",
    Request: type = struct {
        rest_api_id: []const u8,
        stage_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .stage_name = "stageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stage) } {
            return .{ .service_metadata = service_metadata, .action = delete_stage };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_usage_plan: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/usageplans/{usagePlanId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteUsagePlan",
    Request: type = struct {
        usage_plan_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_usage_plan) } {
            return .{ .service_metadata = service_metadata, .action = delete_usage_plan };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_usage_plan_key: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/usageplans/{usagePlanId}/keys/{keyId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteUsagePlanKey",
    Request: type = struct {
        usage_plan_id: []const u8,
        key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
                .key_id = "keyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_usage_plan_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_usage_plan_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_vpc_link: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/vpclinks/{vpcLinkId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteVpcLink",
    Request: type = struct {
        vpc_link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_link_id = "vpcLinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vpc_link) } {
            return .{ .service_metadata = service_metadata, .action = delete_vpc_link };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const flush_stage_authorizers_cache: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/stages/{stageName}/cache/authorizers",
        .success_code = 202,
    };

    action_name: []const u8 = "FlushStageAuthorizersCache",
    Request: type = struct {
        rest_api_id: []const u8,
        stage_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .stage_name = "stageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(flush_stage_authorizers_cache) } {
            return .{ .service_metadata = service_metadata, .action = flush_stage_authorizers_cache };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const flush_stage_cache: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restapis/{restApiId}/stages/{stageName}/cache/data",
        .success_code = 202,
    };

    action_name: []const u8 = "FlushStageCache",
    Request: type = struct {
        rest_api_id: []const u8,
        stage_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .stage_name = "stageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(flush_stage_cache) } {
            return .{ .service_metadata = service_metadata, .action = flush_stage_cache };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const generate_client_certificate: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/clientcertificates",
        .success_code = 201,
    };

    action_name: []const u8 = "GenerateClientCertificate",
    Request: type = struct {
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(generate_client_certificate) } {
            return .{ .service_metadata = service_metadata, .action = generate_client_certificate };
        }
    },
    Response: type = struct {
        client_certificate_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        pem_encoded_certificate: ?[]const u8 = null,
        created_date: ?i64 = null,
        expiration_date: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_certificate_id = "clientCertificateId",
                .description = "description",
                .pem_encoded_certificate = "pemEncodedCertificate",
                .created_date = "createdDate",
                .expiration_date = "expirationDate",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/account",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account) } {
            return .{ .service_metadata = service_metadata, .action = get_account };
        }
    },
    Response: type = struct {
        cloudwatch_role_arn: ?[]const u8 = null,
        throttle_settings: ?ThrottleSettings = null,
        features: ?[][]const u8 = null,
        api_key_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloudwatch_role_arn = "cloudwatchRoleArn",
                .throttle_settings = "throttleSettings",
                .features = "features",
                .api_key_version = "apiKeyVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_api_key: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apikeys/{apiKey}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApiKey",
    Request: type = struct {
        api_key: []const u8,
        include_value: ?bool = null,

        pub const http_query = .{
            .include_value = "includeValue",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_key = "apiKey",
                .include_value = "includeValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_api_key) } {
            return .{ .service_metadata = service_metadata, .action = get_api_key };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        value: ?[]const u8 = null,
        name: ?[]const u8 = null,
        customer_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        enabled: ?bool = null,
        created_date: ?i64 = null,
        last_updated_date: ?i64 = null,
        stage_keys: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .value = "value",
                .name = "name",
                .customer_id = "customerId",
                .description = "description",
                .enabled = "enabled",
                .created_date = "createdDate",
                .last_updated_date = "lastUpdatedDate",
                .stage_keys = "stageKeys",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_api_keys: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/apikeys",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApiKeys",
    Request: type = struct {
        position: ?[]const u8 = null,
        limit: ?i64 = null,
        name_query: ?[]const u8 = null,
        customer_id: ?[]const u8 = null,
        include_values: ?bool = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
            .name_query = "name",
            .customer_id = "customerId",
            .include_values = "includeValues",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .position = "position",
                .limit = "limit",
                .name_query = "nameQuery",
                .customer_id = "customerId",
                .include_values = "includeValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_api_keys) } {
            return .{ .service_metadata = service_metadata, .action = get_api_keys };
        }
    },
    Response: type = struct {
        warnings: ?[][]const u8 = null,
        items: ?[]ApiKey = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .warnings = "warnings",
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_authorizer: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/authorizers/{authorizerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAuthorizer",
    Request: type = struct {
        rest_api_id: []const u8,
        authorizer_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .authorizer_id = "authorizerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = get_authorizer };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        type: ?[]const u8 = null,
        provider_ar_ns: ?[][]const u8 = null,
        auth_type: ?[]const u8 = null,
        authorizer_uri: ?[]const u8 = null,
        authorizer_credentials: ?[]const u8 = null,
        identity_source: ?[]const u8 = null,
        identity_validation_expression: ?[]const u8 = null,
        authorizer_result_ttl_in_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .type = "type",
                .provider_ar_ns = "providerARNs",
                .auth_type = "authType",
                .authorizer_uri = "authorizerUri",
                .authorizer_credentials = "authorizerCredentials",
                .identity_source = "identitySource",
                .identity_validation_expression = "identityValidationExpression",
                .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_authorizers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/authorizers",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAuthorizers",
    Request: type = struct {
        rest_api_id: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_authorizers) } {
            return .{ .service_metadata = service_metadata, .action = get_authorizers };
        }
    },
    Response: type = struct {
        items: ?[]Authorizer = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_base_path_mapping: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domainnames/{domainName}/basepathmappings/{basePath}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBasePathMapping",
    Request: type = struct {
        domain_name: []const u8,
        base_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .base_path = "basePath",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_base_path_mapping) } {
            return .{ .service_metadata = service_metadata, .action = get_base_path_mapping };
        }
    },
    Response: type = struct {
        base_path: ?[]const u8 = null,
        rest_api_id: ?[]const u8 = null,
        stage: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .base_path = "basePath",
                .rest_api_id = "restApiId",
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_base_path_mappings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domainnames/{domainName}/basepathmappings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBasePathMappings",
    Request: type = struct {
        domain_name: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_base_path_mappings) } {
            return .{ .service_metadata = service_metadata, .action = get_base_path_mappings };
        }
    },
    Response: type = struct {
        items: ?[]BasePathMapping = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_client_certificate: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clientcertificates/{clientCertificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetClientCertificate",
    Request: type = struct {
        client_certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_certificate_id = "clientCertificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_client_certificate) } {
            return .{ .service_metadata = service_metadata, .action = get_client_certificate };
        }
    },
    Response: type = struct {
        client_certificate_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        pem_encoded_certificate: ?[]const u8 = null,
        created_date: ?i64 = null,
        expiration_date: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_certificate_id = "clientCertificateId",
                .description = "description",
                .pem_encoded_certificate = "pemEncodedCertificate",
                .created_date = "createdDate",
                .expiration_date = "expirationDate",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_client_certificates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/clientcertificates",
        .success_code = 200,
    };

    action_name: []const u8 = "GetClientCertificates",
    Request: type = struct {
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_client_certificates) } {
            return .{ .service_metadata = service_metadata, .action = get_client_certificates };
        }
    },
    Response: type = struct {
        items: ?[]ClientCertificate = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_deployment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/deployments/{deploymentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeployment",
    Request: type = struct {
        rest_api_id: []const u8,
        deployment_id: []const u8,
        embed: ?[][]const u8 = null,

        pub const http_query = .{
            .embed = "embed",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .deployment_id = "deploymentId",
                .embed = "embed",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deployment) } {
            return .{ .service_metadata = service_metadata, .action = get_deployment };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?i64 = null,
        api_summary: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MethodSnapshot = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .description = "description",
                .created_date = "createdDate",
                .api_summary = "apiSummary",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "api_summary", field_name))
                return try serializeMap(self.api_summary, self.fieldNameFor("api_summary"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_deployments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/deployments",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeployments",
    Request: type = struct {
        rest_api_id: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_deployments) } {
            return .{ .service_metadata = service_metadata, .action = get_deployments };
        }
    },
    Response: type = struct {
        items: ?[]Deployment = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_documentation_part: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/documentation/parts/{documentationPartId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDocumentationPart",
    Request: type = struct {
        rest_api_id: []const u8,
        documentation_part_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .documentation_part_id = "documentationPartId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_documentation_part) } {
            return .{ .service_metadata = service_metadata, .action = get_documentation_part };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        location: ?DocumentationPartLocation = null,
        properties: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .location = "location",
                .properties = "properties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_documentation_parts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/documentation/parts",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDocumentationParts",
    Request: type = struct {
        rest_api_id: []const u8,
        type: ?[]const u8 = null,
        name_query: ?[]const u8 = null,
        path: ?[]const u8 = null,
        position: ?[]const u8 = null,
        limit: ?i64 = null,
        location_status: ?[]const u8 = null,

        pub const http_query = .{
            .type = "type",
            .name_query = "name",
            .path = "path",
            .position = "position",
            .limit = "limit",
            .location_status = "locationStatus",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .type = "type",
                .name_query = "nameQuery",
                .path = "path",
                .position = "position",
                .limit = "limit",
                .location_status = "locationStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_documentation_parts) } {
            return .{ .service_metadata = service_metadata, .action = get_documentation_parts };
        }
    },
    Response: type = struct {
        items: ?[]DocumentationPart = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_documentation_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/documentation/versions/{documentationVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDocumentationVersion",
    Request: type = struct {
        rest_api_id: []const u8,
        documentation_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .documentation_version = "documentationVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_documentation_version) } {
            return .{ .service_metadata = service_metadata, .action = get_documentation_version };
        }
    },
    Response: type = struct {
        version: ?[]const u8 = null,
        created_date: ?i64 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version = "version",
                .created_date = "createdDate",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_documentation_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/documentation/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDocumentationVersions",
    Request: type = struct {
        rest_api_id: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_documentation_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_documentation_versions };
        }
    },
    Response: type = struct {
        items: ?[]DocumentationVersion = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_domain_name: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domainnames/{domainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainName",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_name) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_name };
        }
    },
    Response: type = struct {
        domain_name: ?[]const u8 = null,
        certificate_name: ?[]const u8 = null,
        certificate_arn: ?[]const u8 = null,
        certificate_upload_date: ?i64 = null,
        regional_domain_name: ?[]const u8 = null,
        regional_hosted_zone_id: ?[]const u8 = null,
        regional_certificate_name: ?[]const u8 = null,
        regional_certificate_arn: ?[]const u8 = null,
        distribution_domain_name: ?[]const u8 = null,
        distribution_hosted_zone_id: ?[]const u8 = null,
        endpoint_configuration: ?EndpointConfiguration = null,
        domain_name_status: ?[]const u8 = null,
        domain_name_status_message: ?[]const u8 = null,
        security_policy: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        mutual_tls_authentication: ?MutualTlsAuthentication = null,
        ownership_verification_certificate_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .certificate_name = "certificateName",
                .certificate_arn = "certificateArn",
                .certificate_upload_date = "certificateUploadDate",
                .regional_domain_name = "regionalDomainName",
                .regional_hosted_zone_id = "regionalHostedZoneId",
                .regional_certificate_name = "regionalCertificateName",
                .regional_certificate_arn = "regionalCertificateArn",
                .distribution_domain_name = "distributionDomainName",
                .distribution_hosted_zone_id = "distributionHostedZoneId",
                .endpoint_configuration = "endpointConfiguration",
                .domain_name_status = "domainNameStatus",
                .domain_name_status_message = "domainNameStatusMessage",
                .security_policy = "securityPolicy",
                .tags = "tags",
                .mutual_tls_authentication = "mutualTlsAuthentication",
                .ownership_verification_certificate_arn = "ownershipVerificationCertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_domain_names: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domainnames",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomainNames",
    Request: type = struct {
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain_names) } {
            return .{ .service_metadata = service_metadata, .action = get_domain_names };
        }
    },
    Response: type = struct {
        items: ?[]DomainName = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_export: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/stages/{stageName}/exports/{exportType}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetExport",
    Request: type = struct {
        rest_api_id: []const u8,
        stage_name: []const u8,
        export_type: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        accepts: ?[]const u8 = null,
        pub const http_header = .{
            .accepts = "Accept",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .stage_name = "stageName",
                .export_type = "exportType",
                .parameters = "parameters",
                .accepts = "accepts",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_export) } {
            return .{ .service_metadata = service_metadata, .action = get_export };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        content_disposition: ?[]const u8 = null,
        body: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .content_disposition = "Content-Disposition",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .content_disposition = "contentDisposition",
                .body = "body",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_gateway_response: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/gatewayresponses/{responseType}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGatewayResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        response_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .response_type = "responseType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_gateway_response) } {
            return .{ .service_metadata = service_metadata, .action = get_gateway_response };
        }
    },
    Response: type = struct {
        response_type: ?[]const u8 = null,
        status_code: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        default_response: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .response_type = "responseType",
                .status_code = "statusCode",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .default_response = "defaultResponse",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_gateway_responses: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/gatewayresponses",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGatewayResponses",
    Request: type = struct {
        rest_api_id: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_gateway_responses) } {
            return .{ .service_metadata = service_metadata, .action = get_gateway_responses };
        }
    },
    Response: type = struct {
        items: ?[]GatewayResponse = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_integration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/integration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntegration",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_integration) } {
            return .{ .service_metadata = service_metadata, .action = get_integration };
        }
    },
    Response: type = struct {
        type: ?[]const u8 = null,
        http_method: ?[]const u8 = null,
        uri: ?[]const u8 = null,
        connection_type: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        credentials: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        passthrough_behavior: ?[]const u8 = null,
        content_handling: ?[]const u8 = null,
        timeout_in_millis: ?i64 = null,
        cache_namespace: ?[]const u8 = null,
        cache_key_parameters: ?[][]const u8 = null,
        integration_responses: ?[]struct {
            key: ?[]const u8 = null,
            value: ?IntegrationResponse = null,
        } = null,
        tls_config: ?TlsConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "type",
                .http_method = "httpMethod",
                .uri = "uri",
                .connection_type = "connectionType",
                .connection_id = "connectionId",
                .credentials = "credentials",
                .request_parameters = "requestParameters",
                .request_templates = "requestTemplates",
                .passthrough_behavior = "passthroughBehavior",
                .content_handling = "contentHandling",
                .timeout_in_millis = "timeoutInMillis",
                .cache_namespace = "cacheNamespace",
                .cache_key_parameters = "cacheKeyParameters",
                .integration_responses = "integrationResponses",
                .tls_config = "tlsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_templates", field_name))
                return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
            if (std.mem.eql(u8, "integration_responses", field_name))
                return try serializeMap(self.integration_responses, self.fieldNameFor("integration_responses"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_integration_response: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/integration/responses/{statusCode}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntegrationResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        status_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .status_code = "statusCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_integration_response) } {
            return .{ .service_metadata = service_metadata, .action = get_integration_response };
        }
    },
    Response: type = struct {
        status_code: ?[]const u8 = null,
        selection_pattern: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        content_handling: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
                .selection_pattern = "selectionPattern",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .content_handling = "contentHandling",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_method: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMethod",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_method) } {
            return .{ .service_metadata = service_metadata, .action = get_method };
        }
    },
    Response: type = struct {
        http_method: ?[]const u8 = null,
        authorization_type: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        api_key_required: ?bool = null,
        request_validator_id: ?[]const u8 = null,
        operation_name: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,
        request_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        method_responses: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MethodResponse = null,
        } = null,
        method_integration: ?Integration = null,
        authorization_scopes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .http_method = "httpMethod",
                .authorization_type = "authorizationType",
                .authorizer_id = "authorizerId",
                .api_key_required = "apiKeyRequired",
                .request_validator_id = "requestValidatorId",
                .operation_name = "operationName",
                .request_parameters = "requestParameters",
                .request_models = "requestModels",
                .method_responses = "methodResponses",
                .method_integration = "methodIntegration",
                .authorization_scopes = "authorizationScopes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_models", field_name))
                return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
            if (std.mem.eql(u8, "method_responses", field_name))
                return try serializeMap(self.method_responses, self.fieldNameFor("method_responses"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_method_response: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/responses/{statusCode}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMethodResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        status_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .status_code = "statusCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_method_response) } {
            return .{ .service_metadata = service_metadata, .action = get_method_response };
        }
    },
    Response: type = struct {
        status_code: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,
        response_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
                .response_parameters = "responseParameters",
                .response_models = "responseModels",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_models", field_name))
                return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_model: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/models/{modelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetModel",
    Request: type = struct {
        rest_api_id: []const u8,
        model_name: []const u8,
        flatten: ?bool = null,

        pub const http_query = .{
            .flatten = "flatten",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .model_name = "modelName",
                .flatten = "flatten",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_model) } {
            return .{ .service_metadata = service_metadata, .action = get_model };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        content_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .schema = "schema",
                .content_type = "contentType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_models: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/models",
        .success_code = 200,
    };

    action_name: []const u8 = "GetModels",
    Request: type = struct {
        rest_api_id: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_models) } {
            return .{ .service_metadata = service_metadata, .action = get_models };
        }
    },
    Response: type = struct {
        items: ?[]Model = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_model_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/models/{modelName}/default_template",
        .success_code = 200,
    };

    action_name: []const u8 = "GetModelTemplate",
    Request: type = struct {
        rest_api_id: []const u8,
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .model_name = "modelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_model_template) } {
            return .{ .service_metadata = service_metadata, .action = get_model_template };
        }
    },
    Response: type = struct {
        value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .value = "value",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_request_validator: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/requestvalidators/{requestValidatorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRequestValidator",
    Request: type = struct {
        rest_api_id: []const u8,
        request_validator_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .request_validator_id = "requestValidatorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_request_validator) } {
            return .{ .service_metadata = service_metadata, .action = get_request_validator };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        validate_request_body: ?bool = null,
        validate_request_parameters: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .validate_request_body = "validateRequestBody",
                .validate_request_parameters = "validateRequestParameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_request_validators: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/requestvalidators",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRequestValidators",
    Request: type = struct {
        rest_api_id: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_request_validators) } {
            return .{ .service_metadata = service_metadata, .action = get_request_validators };
        }
    },
    Response: type = struct {
        items: ?[]RequestValidator = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/resources/{resourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResource",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        embed: ?[][]const u8 = null,

        pub const http_query = .{
            .embed = "embed",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .embed = "embed",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource) } {
            return .{ .service_metadata = service_metadata, .action = get_resource };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        parent_id: ?[]const u8 = null,
        path_part: ?[]const u8 = null,
        path: ?[]const u8 = null,
        resource_methods: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Method = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .parent_id = "parentId",
                .path_part = "pathPart",
                .path = "path",
                .resource_methods = "resourceMethods",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "resource_methods", field_name))
                return try serializeMap(self.resource_methods, self.fieldNameFor("resource_methods"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_resources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/resources",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResources",
    Request: type = struct {
        rest_api_id: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,
        embed: ?[][]const u8 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
            .embed = "embed",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .position = "position",
                .limit = "limit",
                .embed = "embed",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resources) } {
            return .{ .service_metadata = service_metadata, .action = get_resources };
        }
    },
    Response: type = struct {
        items: ?[]Resource = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_rest_api: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRestApi",
    Request: type = struct {
        rest_api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rest_api) } {
            return .{ .service_metadata = service_metadata, .action = get_rest_api };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        warnings: ?[][]const u8 = null,
        binary_media_types: ?[][]const u8 = null,
        minimum_compression_size: ?i64 = null,
        api_key_source: ?[]const u8 = null,
        endpoint_configuration: ?EndpointConfiguration = null,
        policy: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        disable_execute_api_endpoint: ?bool = null,
        root_resource_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .created_date = "createdDate",
                .version = "version",
                .warnings = "warnings",
                .binary_media_types = "binaryMediaTypes",
                .minimum_compression_size = "minimumCompressionSize",
                .api_key_source = "apiKeySource",
                .endpoint_configuration = "endpointConfiguration",
                .policy = "policy",
                .tags = "tags",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .root_resource_id = "rootResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_rest_apis: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRestApis",
    Request: type = struct {
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rest_apis) } {
            return .{ .service_metadata = service_metadata, .action = get_rest_apis };
        }
    },
    Response: type = struct {
        items: ?[]RestApi = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_sdk: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/stages/{stageName}/sdks/{sdkType}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSdk",
    Request: type = struct {
        rest_api_id: []const u8,
        stage_name: []const u8,
        sdk_type: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .stage_name = "stageName",
                .sdk_type = "sdkType",
                .parameters = "parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sdk) } {
            return .{ .service_metadata = service_metadata, .action = get_sdk };
        }
    },
    Response: type = struct {
        content_type: ?[]const u8 = null,
        content_disposition: ?[]const u8 = null,
        body: ?[]const u8 = null,
        pub const http_header = .{
            .content_type = "Content-Type",
            .content_disposition = "Content-Disposition",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .content_type = "contentType",
                .content_disposition = "contentDisposition",
                .body = "body",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_sdk_type: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sdktypes/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSdkType",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sdk_type) } {
            return .{ .service_metadata = service_metadata, .action = get_sdk_type };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        friendly_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        configuration_properties: ?[]SdkConfigurationProperty = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .friendly_name = "friendlyName",
                .description = "description",
                .configuration_properties = "configurationProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_sdk_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sdktypes",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSdkTypes",
    Request: type = struct {
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sdk_types) } {
            return .{ .service_metadata = service_metadata, .action = get_sdk_types };
        }
    },
    Response: type = struct {
        items: ?[]SdkType = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_stage: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/stages/{stageName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStage",
    Request: type = struct {
        rest_api_id: []const u8,
        stage_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .stage_name = "stageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_stage) } {
            return .{ .service_metadata = service_metadata, .action = get_stage };
        }
    },
    Response: type = struct {
        deployment_id: ?[]const u8 = null,
        client_certificate_id: ?[]const u8 = null,
        stage_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        cache_cluster_enabled: ?bool = null,
        cache_cluster_size: ?[]const u8 = null,
        cache_cluster_status: ?[]const u8 = null,
        method_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MethodSetting = null,
        } = null,
        variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        documentation_version: ?[]const u8 = null,
        access_log_settings: ?AccessLogSettings = null,
        canary_settings: ?CanarySettings = null,
        tracing_enabled: ?bool = null,
        web_acl_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        created_date: ?i64 = null,
        last_updated_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_id = "deploymentId",
                .client_certificate_id = "clientCertificateId",
                .stage_name = "stageName",
                .description = "description",
                .cache_cluster_enabled = "cacheClusterEnabled",
                .cache_cluster_size = "cacheClusterSize",
                .cache_cluster_status = "cacheClusterStatus",
                .method_settings = "methodSettings",
                .variables = "variables",
                .documentation_version = "documentationVersion",
                .access_log_settings = "accessLogSettings",
                .canary_settings = "canarySettings",
                .tracing_enabled = "tracingEnabled",
                .web_acl_arn = "webAclArn",
                .tags = "tags",
                .created_date = "createdDate",
                .last_updated_date = "lastUpdatedDate",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "method_settings", field_name))
                return try serializeMap(self.method_settings, self.fieldNameFor("method_settings"), options, out_stream);
            if (std.mem.eql(u8, "variables", field_name))
                return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_stages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restapis/{restApiId}/stages",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStages",
    Request: type = struct {
        rest_api_id: []const u8,
        deployment_id: ?[]const u8 = null,

        pub const http_query = .{
            .deployment_id = "deploymentId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .deployment_id = "deploymentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_stages) } {
            return .{ .service_metadata = service_metadata, .action = get_stages };
        }
    },
    Response: type = struct {
        item: ?[]Stage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .item = "item",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTags",
    Request: type = struct {
        resource_arn: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_tags) } {
            return .{ .service_metadata = service_metadata, .action = get_tags };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_usage: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/usageplans/{usagePlanId}/usage",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUsage",
    Request: type = struct {
        usage_plan_id: []const u8,
        key_id: ?[]const u8 = null,
        start_date: []const u8,
        end_date: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .key_id = "keyId",
            .start_date = "startDate",
            .end_date = "endDate",
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
                .key_id = "keyId",
                .start_date = "startDate",
                .end_date = "endDate",
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_usage) } {
            return .{ .service_metadata = service_metadata, .action = get_usage };
        }
    },
    Response: type = struct {
        usage_plan_id: ?[]const u8 = null,
        start_date: ?[]const u8 = null,
        end_date: ?[]const u8 = null,
        items: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]i64 = null,
        } = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
                .start_date = "startDate",
                .end_date = "endDate",
                .items = "values",
                .position = "position",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "items", field_name))
                return try serializeMap(self.items, self.fieldNameFor("items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_usage_plan: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/usageplans/{usagePlanId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUsagePlan",
    Request: type = struct {
        usage_plan_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_usage_plan) } {
            return .{ .service_metadata = service_metadata, .action = get_usage_plan };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        api_stages: ?[]ApiStage = null,
        throttle: ?ThrottleSettings = null,
        quota: ?QuotaSettings = null,
        product_code: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .api_stages = "apiStages",
                .throttle = "throttle",
                .quota = "quota",
                .product_code = "productCode",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_usage_plan_key: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/usageplans/{usagePlanId}/keys/{keyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUsagePlanKey",
    Request: type = struct {
        usage_plan_id: []const u8,
        key_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
                .key_id = "keyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_usage_plan_key) } {
            return .{ .service_metadata = service_metadata, .action = get_usage_plan_key };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        type: ?[]const u8 = null,
        value: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .type = "type",
                .value = "value",
                .name = "name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_usage_plan_keys: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/usageplans/{usagePlanId}/keys",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUsagePlanKeys",
    Request: type = struct {
        usage_plan_id: []const u8,
        position: ?[]const u8 = null,
        limit: ?i64 = null,
        name_query: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
            .name_query = "name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
                .position = "position",
                .limit = "limit",
                .name_query = "nameQuery",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_usage_plan_keys) } {
            return .{ .service_metadata = service_metadata, .action = get_usage_plan_keys };
        }
    },
    Response: type = struct {
        items: ?[]UsagePlanKey = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_usage_plans: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/usageplans",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUsagePlans",
    Request: type = struct {
        position: ?[]const u8 = null,
        key_id: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .key_id = "keyId",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .position = "position",
                .key_id = "keyId",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_usage_plans) } {
            return .{ .service_metadata = service_metadata, .action = get_usage_plans };
        }
    },
    Response: type = struct {
        items: ?[]UsagePlan = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_vpc_link: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/vpclinks/{vpcLinkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVpcLink",
    Request: type = struct {
        vpc_link_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_link_id = "vpcLinkId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vpc_link) } {
            return .{ .service_metadata = service_metadata, .action = get_vpc_link };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        target_arns: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .target_arns = "targetArns",
                .status = "status",
                .status_message = "statusMessage",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const get_vpc_links: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/vpclinks",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVpcLinks",
    Request: type = struct {
        position: ?[]const u8 = null,
        limit: ?i64 = null,

        pub const http_query = .{
            .position = "position",
            .limit = "limit",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .position = "position",
                .limit = "limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_vpc_links) } {
            return .{ .service_metadata = service_metadata, .action = get_vpc_links };
        }
    },
    Response: type = struct {
        items: ?[]VpcLink = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "item",
                .position = "position",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const import_api_keys: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/apikeys?mode=import",
        .success_code = 201,
    };

    action_name: []const u8 = "ImportApiKeys",
    Request: type = struct {
        body: []const u8,
        format: []const u8,
        fail_on_warnings: ?bool = null,

        pub const http_query = .{
            .format = "format",
            .fail_on_warnings = "failonwarnings",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .body = "body",
                .format = "format",
                .fail_on_warnings = "failOnWarnings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_api_keys) } {
            return .{ .service_metadata = service_metadata, .action = import_api_keys };
        }
    },
    Response: type = struct {
        ids: ?[][]const u8 = null,
        warnings: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
                .warnings = "warnings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const import_documentation_parts: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restapis/{restApiId}/documentation/parts",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportDocumentationParts",
    Request: type = struct {
        rest_api_id: []const u8,
        mode: ?[]const u8 = null,
        fail_on_warnings: ?bool = null,
        body: []const u8,

        pub const http_query = .{
            .mode = "mode",
            .fail_on_warnings = "failonwarnings",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .mode = "mode",
                .fail_on_warnings = "failOnWarnings",
                .body = "body",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_documentation_parts) } {
            return .{ .service_metadata = service_metadata, .action = import_documentation_parts };
        }
    },
    Response: type = struct {
        ids: ?[][]const u8 = null,
        warnings: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ids = "ids",
                .warnings = "warnings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const import_rest_api: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis?mode=import",
        .success_code = 201,
    };

    action_name: []const u8 = "ImportRestApi",
    Request: type = struct {
        fail_on_warnings: ?bool = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        body: []const u8,

        pub const http_query = .{
            .fail_on_warnings = "failonwarnings",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fail_on_warnings = "failOnWarnings",
                .parameters = "parameters",
                .body = "body",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_rest_api) } {
            return .{ .service_metadata = service_metadata, .action = import_rest_api };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        warnings: ?[][]const u8 = null,
        binary_media_types: ?[][]const u8 = null,
        minimum_compression_size: ?i64 = null,
        api_key_source: ?[]const u8 = null,
        endpoint_configuration: ?EndpointConfiguration = null,
        policy: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        disable_execute_api_endpoint: ?bool = null,
        root_resource_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .created_date = "createdDate",
                .version = "version",
                .warnings = "warnings",
                .binary_media_types = "binaryMediaTypes",
                .minimum_compression_size = "minimumCompressionSize",
                .api_key_source = "apiKeySource",
                .endpoint_configuration = "endpointConfiguration",
                .policy = "policy",
                .tags = "tags",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .root_resource_id = "rootResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const put_gateway_response: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restapis/{restApiId}/gatewayresponses/{responseType}",
        .success_code = 201,
    };

    action_name: []const u8 = "PutGatewayResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        response_type: []const u8,
        status_code: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .response_type = "responseType",
                .status_code = "statusCode",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_gateway_response) } {
            return .{ .service_metadata = service_metadata, .action = put_gateway_response };
        }
    },
    Response: type = struct {
        response_type: ?[]const u8 = null,
        status_code: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        default_response: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .response_type = "responseType",
                .status_code = "statusCode",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .default_response = "defaultResponse",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const put_integration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/integration",
        .success_code = 201,
    };

    action_name: []const u8 = "PutIntegration",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        type: []const u8,
        integration_http_method: ?[]const u8 = null,
        uri: ?[]const u8 = null,
        connection_type: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        credentials: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        passthrough_behavior: ?[]const u8 = null,
        cache_namespace: ?[]const u8 = null,
        cache_key_parameters: ?[][]const u8 = null,
        content_handling: ?[]const u8 = null,
        timeout_in_millis: ?i64 = null,
        tls_config: ?TlsConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "requestHttpMethod",
                .type = "type",
                .integration_http_method = "httpMethod",
                .uri = "uri",
                .connection_type = "connectionType",
                .connection_id = "connectionId",
                .credentials = "credentials",
                .request_parameters = "requestParameters",
                .request_templates = "requestTemplates",
                .passthrough_behavior = "passthroughBehavior",
                .cache_namespace = "cacheNamespace",
                .cache_key_parameters = "cacheKeyParameters",
                .content_handling = "contentHandling",
                .timeout_in_millis = "timeoutInMillis",
                .tls_config = "tlsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_templates", field_name))
                return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_integration) } {
            return .{ .service_metadata = service_metadata, .action = put_integration };
        }
    },
    Response: type = struct {
        type: ?[]const u8 = null,
        http_method: ?[]const u8 = null,
        uri: ?[]const u8 = null,
        connection_type: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        credentials: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        passthrough_behavior: ?[]const u8 = null,
        content_handling: ?[]const u8 = null,
        timeout_in_millis: ?i64 = null,
        cache_namespace: ?[]const u8 = null,
        cache_key_parameters: ?[][]const u8 = null,
        integration_responses: ?[]struct {
            key: ?[]const u8 = null,
            value: ?IntegrationResponse = null,
        } = null,
        tls_config: ?TlsConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "type",
                .http_method = "httpMethod",
                .uri = "uri",
                .connection_type = "connectionType",
                .connection_id = "connectionId",
                .credentials = "credentials",
                .request_parameters = "requestParameters",
                .request_templates = "requestTemplates",
                .passthrough_behavior = "passthroughBehavior",
                .content_handling = "contentHandling",
                .timeout_in_millis = "timeoutInMillis",
                .cache_namespace = "cacheNamespace",
                .cache_key_parameters = "cacheKeyParameters",
                .integration_responses = "integrationResponses",
                .tls_config = "tlsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_templates", field_name))
                return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
            if (std.mem.eql(u8, "integration_responses", field_name))
                return try serializeMap(self.integration_responses, self.fieldNameFor("integration_responses"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const put_integration_response: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/integration/responses/{statusCode}",
        .success_code = 201,
    };

    action_name: []const u8 = "PutIntegrationResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        status_code: []const u8,
        selection_pattern: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        content_handling: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .status_code = "statusCode",
                .selection_pattern = "selectionPattern",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .content_handling = "contentHandling",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_integration_response) } {
            return .{ .service_metadata = service_metadata, .action = put_integration_response };
        }
    },
    Response: type = struct {
        status_code: ?[]const u8 = null,
        selection_pattern: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        content_handling: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
                .selection_pattern = "selectionPattern",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .content_handling = "contentHandling",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const put_method: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}",
        .success_code = 201,
    };

    action_name: []const u8 = "PutMethod",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        authorization_type: []const u8,
        authorizer_id: ?[]const u8 = null,
        api_key_required: ?bool = null,
        operation_name: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,
        request_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_validator_id: ?[]const u8 = null,
        authorization_scopes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .authorization_type = "authorizationType",
                .authorizer_id = "authorizerId",
                .api_key_required = "apiKeyRequired",
                .operation_name = "operationName",
                .request_parameters = "requestParameters",
                .request_models = "requestModels",
                .request_validator_id = "requestValidatorId",
                .authorization_scopes = "authorizationScopes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_models", field_name))
                return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_method) } {
            return .{ .service_metadata = service_metadata, .action = put_method };
        }
    },
    Response: type = struct {
        http_method: ?[]const u8 = null,
        authorization_type: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        api_key_required: ?bool = null,
        request_validator_id: ?[]const u8 = null,
        operation_name: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,
        request_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        method_responses: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MethodResponse = null,
        } = null,
        method_integration: ?Integration = null,
        authorization_scopes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .http_method = "httpMethod",
                .authorization_type = "authorizationType",
                .authorizer_id = "authorizerId",
                .api_key_required = "apiKeyRequired",
                .request_validator_id = "requestValidatorId",
                .operation_name = "operationName",
                .request_parameters = "requestParameters",
                .request_models = "requestModels",
                .method_responses = "methodResponses",
                .method_integration = "methodIntegration",
                .authorization_scopes = "authorizationScopes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_models", field_name))
                return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
            if (std.mem.eql(u8, "method_responses", field_name))
                return try serializeMap(self.method_responses, self.fieldNameFor("method_responses"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const put_method_response: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/responses/{statusCode}",
        .success_code = 201,
    };

    action_name: []const u8 = "PutMethodResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        status_code: []const u8,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,
        response_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .status_code = "statusCode",
                .response_parameters = "responseParameters",
                .response_models = "responseModels",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_models", field_name))
                return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_method_response) } {
            return .{ .service_metadata = service_metadata, .action = put_method_response };
        }
    },
    Response: type = struct {
        status_code: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,
        response_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
                .response_parameters = "responseParameters",
                .response_models = "responseModels",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_models", field_name))
                return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const put_rest_api: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restapis/{restApiId}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutRestApi",
    Request: type = struct {
        rest_api_id: []const u8,
        mode: ?[]const u8 = null,
        fail_on_warnings: ?bool = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        body: []const u8,

        pub const http_query = .{
            .mode = "mode",
            .fail_on_warnings = "failonwarnings",
        };

        pub const http_payload: []const u8 = "body";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .mode = "mode",
                .fail_on_warnings = "failOnWarnings",
                .parameters = "parameters",
                .body = "body",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_rest_api) } {
            return .{ .service_metadata = service_metadata, .action = put_rest_api };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        warnings: ?[][]const u8 = null,
        binary_media_types: ?[][]const u8 = null,
        minimum_compression_size: ?i64 = null,
        api_key_source: ?[]const u8 = null,
        endpoint_configuration: ?EndpointConfiguration = null,
        policy: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        disable_execute_api_endpoint: ?bool = null,
        root_resource_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .created_date = "createdDate",
                .version = "version",
                .warnings = "warnings",
                .binary_media_types = "binaryMediaTypes",
                .minimum_compression_size = "minimumCompressionSize",
                .api_key_source = "apiKeySource",
                .endpoint_configuration = "endpointConfiguration",
                .policy = "policy",
                .tags = "tags",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .root_resource_id = "rootResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const test_invoke_authorizer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis/{restApiId}/authorizers/{authorizerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "TestInvokeAuthorizer",
    Request: type = struct {
        rest_api_id: []const u8,
        authorizer_id: []const u8,
        headers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        multi_value_headers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        path_with_query_string: ?[]const u8 = null,
        body: ?[]const u8 = null,
        stage_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        additional_context: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .authorizer_id = "authorizerId",
                .headers = "headers",
                .multi_value_headers = "multiValueHeaders",
                .path_with_query_string = "pathWithQueryString",
                .body = "body",
                .stage_variables = "stageVariables",
                .additional_context = "additionalContext",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "headers", field_name))
                return try serializeMap(self.headers, self.fieldNameFor("headers"), options, out_stream);
            if (std.mem.eql(u8, "multi_value_headers", field_name))
                return try serializeMap(self.multi_value_headers, self.fieldNameFor("multi_value_headers"), options, out_stream);
            if (std.mem.eql(u8, "stage_variables", field_name))
                return try serializeMap(self.stage_variables, self.fieldNameFor("stage_variables"), options, out_stream);
            if (std.mem.eql(u8, "additional_context", field_name))
                return try serializeMap(self.additional_context, self.fieldNameFor("additional_context"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_invoke_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = test_invoke_authorizer };
        }
    },
    Response: type = struct {
        client_status: ?i64 = null,
        log: ?[]const u8 = null,
        latency: ?i64 = null,
        principal_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,
        authorization: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        claims: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_status = "clientStatus",
                .log = "log",
                .latency = "latency",
                .principal_id = "principalId",
                .policy = "policy",
                .authorization = "authorization",
                .claims = "claims",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "authorization", field_name))
                return try serializeMap(self.authorization, self.fieldNameFor("authorization"), options, out_stream);
            if (std.mem.eql(u8, "claims", field_name))
                return try serializeMap(self.claims, self.fieldNameFor("claims"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const test_invoke_method: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}",
        .success_code = 200,
    };

    action_name: []const u8 = "TestInvokeMethod",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        path_with_query_string: ?[]const u8 = null,
        body: ?[]const u8 = null,
        headers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        multi_value_headers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        client_certificate_id: ?[]const u8 = null,
        stage_variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .path_with_query_string = "pathWithQueryString",
                .body = "body",
                .headers = "headers",
                .multi_value_headers = "multiValueHeaders",
                .client_certificate_id = "clientCertificateId",
                .stage_variables = "stageVariables",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "headers", field_name))
                return try serializeMap(self.headers, self.fieldNameFor("headers"), options, out_stream);
            if (std.mem.eql(u8, "multi_value_headers", field_name))
                return try serializeMap(self.multi_value_headers, self.fieldNameFor("multi_value_headers"), options, out_stream);
            if (std.mem.eql(u8, "stage_variables", field_name))
                return try serializeMap(self.stage_variables, self.fieldNameFor("stage_variables"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_invoke_method) } {
            return .{ .service_metadata = service_metadata, .action = test_invoke_method };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        body: ?[]const u8 = null,
        headers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        multi_value_headers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        log: ?[]const u8 = null,
        latency: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .body = "body",
                .headers = "headers",
                .multi_value_headers = "multiValueHeaders",
                .log = "log",
                .latency = "latency",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "headers", field_name))
                return try serializeMap(self.headers, self.fieldNameFor("headers"), options, out_stream);
            if (std.mem.eql(u8, "multi_value_headers", field_name))
                return try serializeMap(self.multi_value_headers, self.fieldNameFor("multi_value_headers"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_account: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/account",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccount",
    Request: type = struct {
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account) } {
            return .{ .service_metadata = service_metadata, .action = update_account };
        }
    },
    Response: type = struct {
        cloudwatch_role_arn: ?[]const u8 = null,
        throttle_settings: ?ThrottleSettings = null,
        features: ?[][]const u8 = null,
        api_key_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloudwatch_role_arn = "cloudwatchRoleArn",
                .throttle_settings = "throttleSettings",
                .features = "features",
                .api_key_version = "apiKeyVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_api_key: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/apikeys/{apiKey}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApiKey",
    Request: type = struct {
        api_key: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_key = "apiKey",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_api_key) } {
            return .{ .service_metadata = service_metadata, .action = update_api_key };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        value: ?[]const u8 = null,
        name: ?[]const u8 = null,
        customer_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        enabled: ?bool = null,
        created_date: ?i64 = null,
        last_updated_date: ?i64 = null,
        stage_keys: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .value = "value",
                .name = "name",
                .customer_id = "customerId",
                .description = "description",
                .enabled = "enabled",
                .created_date = "createdDate",
                .last_updated_date = "lastUpdatedDate",
                .stage_keys = "stageKeys",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_authorizer: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/authorizers/{authorizerId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAuthorizer",
    Request: type = struct {
        rest_api_id: []const u8,
        authorizer_id: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .authorizer_id = "authorizerId",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_authorizer) } {
            return .{ .service_metadata = service_metadata, .action = update_authorizer };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        type: ?[]const u8 = null,
        provider_ar_ns: ?[][]const u8 = null,
        auth_type: ?[]const u8 = null,
        authorizer_uri: ?[]const u8 = null,
        authorizer_credentials: ?[]const u8 = null,
        identity_source: ?[]const u8 = null,
        identity_validation_expression: ?[]const u8 = null,
        authorizer_result_ttl_in_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .type = "type",
                .provider_ar_ns = "providerARNs",
                .auth_type = "authType",
                .authorizer_uri = "authorizerUri",
                .authorizer_credentials = "authorizerCredentials",
                .identity_source = "identitySource",
                .identity_validation_expression = "identityValidationExpression",
                .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_base_path_mapping: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/domainnames/{domainName}/basepathmappings/{basePath}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBasePathMapping",
    Request: type = struct {
        domain_name: []const u8,
        base_path: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .base_path = "basePath",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_base_path_mapping) } {
            return .{ .service_metadata = service_metadata, .action = update_base_path_mapping };
        }
    },
    Response: type = struct {
        base_path: ?[]const u8 = null,
        rest_api_id: ?[]const u8 = null,
        stage: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .base_path = "basePath",
                .rest_api_id = "restApiId",
                .stage = "stage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_client_certificate: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/clientcertificates/{clientCertificateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateClientCertificate",
    Request: type = struct {
        client_certificate_id: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_certificate_id = "clientCertificateId",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_client_certificate) } {
            return .{ .service_metadata = service_metadata, .action = update_client_certificate };
        }
    },
    Response: type = struct {
        client_certificate_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        pem_encoded_certificate: ?[]const u8 = null,
        created_date: ?i64 = null,
        expiration_date: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_certificate_id = "clientCertificateId",
                .description = "description",
                .pem_encoded_certificate = "pemEncodedCertificate",
                .created_date = "createdDate",
                .expiration_date = "expirationDate",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_deployment: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/deployments/{deploymentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDeployment",
    Request: type = struct {
        rest_api_id: []const u8,
        deployment_id: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .deployment_id = "deploymentId",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_deployment) } {
            return .{ .service_metadata = service_metadata, .action = update_deployment };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?i64 = null,
        api_summary: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?MethodSnapshot = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .description = "description",
                .created_date = "createdDate",
                .api_summary = "apiSummary",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "api_summary", field_name))
                return try serializeMap(self.api_summary, self.fieldNameFor("api_summary"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_documentation_part: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/documentation/parts/{documentationPartId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDocumentationPart",
    Request: type = struct {
        rest_api_id: []const u8,
        documentation_part_id: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .documentation_part_id = "documentationPartId",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_documentation_part) } {
            return .{ .service_metadata = service_metadata, .action = update_documentation_part };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        location: ?DocumentationPartLocation = null,
        properties: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .location = "location",
                .properties = "properties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_documentation_version: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/documentation/versions/{documentationVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDocumentationVersion",
    Request: type = struct {
        rest_api_id: []const u8,
        documentation_version: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .documentation_version = "documentationVersion",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_documentation_version) } {
            return .{ .service_metadata = service_metadata, .action = update_documentation_version };
        }
    },
    Response: type = struct {
        version: ?[]const u8 = null,
        created_date: ?i64 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .version = "version",
                .created_date = "createdDate",
                .description = "description",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_domain_name: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/domainnames/{domainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDomainName",
    Request: type = struct {
        domain_name: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_domain_name) } {
            return .{ .service_metadata = service_metadata, .action = update_domain_name };
        }
    },
    Response: type = struct {
        domain_name: ?[]const u8 = null,
        certificate_name: ?[]const u8 = null,
        certificate_arn: ?[]const u8 = null,
        certificate_upload_date: ?i64 = null,
        regional_domain_name: ?[]const u8 = null,
        regional_hosted_zone_id: ?[]const u8 = null,
        regional_certificate_name: ?[]const u8 = null,
        regional_certificate_arn: ?[]const u8 = null,
        distribution_domain_name: ?[]const u8 = null,
        distribution_hosted_zone_id: ?[]const u8 = null,
        endpoint_configuration: ?EndpointConfiguration = null,
        domain_name_status: ?[]const u8 = null,
        domain_name_status_message: ?[]const u8 = null,
        security_policy: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        mutual_tls_authentication: ?MutualTlsAuthentication = null,
        ownership_verification_certificate_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "domainName",
                .certificate_name = "certificateName",
                .certificate_arn = "certificateArn",
                .certificate_upload_date = "certificateUploadDate",
                .regional_domain_name = "regionalDomainName",
                .regional_hosted_zone_id = "regionalHostedZoneId",
                .regional_certificate_name = "regionalCertificateName",
                .regional_certificate_arn = "regionalCertificateArn",
                .distribution_domain_name = "distributionDomainName",
                .distribution_hosted_zone_id = "distributionHostedZoneId",
                .endpoint_configuration = "endpointConfiguration",
                .domain_name_status = "domainNameStatus",
                .domain_name_status_message = "domainNameStatusMessage",
                .security_policy = "securityPolicy",
                .tags = "tags",
                .mutual_tls_authentication = "mutualTlsAuthentication",
                .ownership_verification_certificate_arn = "ownershipVerificationCertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_gateway_response: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/gatewayresponses/{responseType}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGatewayResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        response_type: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .response_type = "responseType",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_gateway_response) } {
            return .{ .service_metadata = service_metadata, .action = update_gateway_response };
        }
    },
    Response: type = struct {
        response_type: ?[]const u8 = null,
        status_code: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        default_response: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .response_type = "responseType",
                .status_code = "statusCode",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .default_response = "defaultResponse",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_integration: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/integration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIntegration",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_integration) } {
            return .{ .service_metadata = service_metadata, .action = update_integration };
        }
    },
    Response: type = struct {
        type: ?[]const u8 = null,
        http_method: ?[]const u8 = null,
        uri: ?[]const u8 = null,
        connection_type: ?[]const u8 = null,
        connection_id: ?[]const u8 = null,
        credentials: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        request_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        passthrough_behavior: ?[]const u8 = null,
        content_handling: ?[]const u8 = null,
        timeout_in_millis: ?i64 = null,
        cache_namespace: ?[]const u8 = null,
        cache_key_parameters: ?[][]const u8 = null,
        integration_responses: ?[]struct {
            key: ?[]const u8 = null,
            value: ?IntegrationResponse = null,
        } = null,
        tls_config: ?TlsConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "type",
                .http_method = "httpMethod",
                .uri = "uri",
                .connection_type = "connectionType",
                .connection_id = "connectionId",
                .credentials = "credentials",
                .request_parameters = "requestParameters",
                .request_templates = "requestTemplates",
                .passthrough_behavior = "passthroughBehavior",
                .content_handling = "contentHandling",
                .timeout_in_millis = "timeoutInMillis",
                .cache_namespace = "cacheNamespace",
                .cache_key_parameters = "cacheKeyParameters",
                .integration_responses = "integrationResponses",
                .tls_config = "tlsConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_templates", field_name))
                return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
            if (std.mem.eql(u8, "integration_responses", field_name))
                return try serializeMap(self.integration_responses, self.fieldNameFor("integration_responses"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_integration_response: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/integration/responses/{statusCode}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIntegrationResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        status_code: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .status_code = "statusCode",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_integration_response) } {
            return .{ .service_metadata = service_metadata, .action = update_integration_response };
        }
    },
    Response: type = struct {
        status_code: ?[]const u8 = null,
        selection_pattern: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        response_templates: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        content_handling: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
                .selection_pattern = "selectionPattern",
                .response_parameters = "responseParameters",
                .response_templates = "responseTemplates",
                .content_handling = "contentHandling",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_templates", field_name))
                return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_method: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMethod",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_method) } {
            return .{ .service_metadata = service_metadata, .action = update_method };
        }
    },
    Response: type = struct {
        http_method: ?[]const u8 = null,
        authorization_type: ?[]const u8 = null,
        authorizer_id: ?[]const u8 = null,
        api_key_required: ?bool = null,
        request_validator_id: ?[]const u8 = null,
        operation_name: ?[]const u8 = null,
        request_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,
        request_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        method_responses: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MethodResponse = null,
        } = null,
        method_integration: ?Integration = null,
        authorization_scopes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .http_method = "httpMethod",
                .authorization_type = "authorizationType",
                .authorizer_id = "authorizerId",
                .api_key_required = "apiKeyRequired",
                .request_validator_id = "requestValidatorId",
                .operation_name = "operationName",
                .request_parameters = "requestParameters",
                .request_models = "requestModels",
                .method_responses = "methodResponses",
                .method_integration = "methodIntegration",
                .authorization_scopes = "authorizationScopes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "request_parameters", field_name))
                return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
            if (std.mem.eql(u8, "request_models", field_name))
                return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
            if (std.mem.eql(u8, "method_responses", field_name))
                return try serializeMap(self.method_responses, self.fieldNameFor("method_responses"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_method_response: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/resources/{resourceId}/methods/{httpMethod}/responses/{statusCode}",
        .success_code = 201,
    };

    action_name: []const u8 = "UpdateMethodResponse",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        http_method: []const u8,
        status_code: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .http_method = "httpMethod",
                .status_code = "statusCode",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_method_response) } {
            return .{ .service_metadata = service_metadata, .action = update_method_response };
        }
    },
    Response: type = struct {
        status_code: ?[]const u8 = null,
        response_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,
        response_models: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "statusCode",
                .response_parameters = "responseParameters",
                .response_models = "responseModels",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "response_parameters", field_name))
                return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
            if (std.mem.eql(u8, "response_models", field_name))
                return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_model: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/models/{modelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateModel",
    Request: type = struct {
        rest_api_id: []const u8,
        model_name: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .model_name = "modelName",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_model) } {
            return .{ .service_metadata = service_metadata, .action = update_model };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        content_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .schema = "schema",
                .content_type = "contentType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_request_validator: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/requestvalidators/{requestValidatorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRequestValidator",
    Request: type = struct {
        rest_api_id: []const u8,
        request_validator_id: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .request_validator_id = "requestValidatorId",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_request_validator) } {
            return .{ .service_metadata = service_metadata, .action = update_request_validator };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        validate_request_body: ?bool = null,
        validate_request_parameters: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .validate_request_body = "validateRequestBody",
                .validate_request_parameters = "validateRequestParameters",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_resource: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/resources/{resourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResource",
    Request: type = struct {
        rest_api_id: []const u8,
        resource_id: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .resource_id = "resourceId",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource) } {
            return .{ .service_metadata = service_metadata, .action = update_resource };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        parent_id: ?[]const u8 = null,
        path_part: ?[]const u8 = null,
        path: ?[]const u8 = null,
        resource_methods: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Method = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .parent_id = "parentId",
                .path_part = "pathPart",
                .path = "path",
                .resource_methods = "resourceMethods",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "resource_methods", field_name))
                return try serializeMap(self.resource_methods, self.fieldNameFor("resource_methods"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_rest_api: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRestApi",
    Request: type = struct {
        rest_api_id: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rest_api) } {
            return .{ .service_metadata = service_metadata, .action = update_rest_api };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        created_date: ?i64 = null,
        version: ?[]const u8 = null,
        warnings: ?[][]const u8 = null,
        binary_media_types: ?[][]const u8 = null,
        minimum_compression_size: ?i64 = null,
        api_key_source: ?[]const u8 = null,
        endpoint_configuration: ?EndpointConfiguration = null,
        policy: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        disable_execute_api_endpoint: ?bool = null,
        root_resource_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .created_date = "createdDate",
                .version = "version",
                .warnings = "warnings",
                .binary_media_types = "binaryMediaTypes",
                .minimum_compression_size = "minimumCompressionSize",
                .api_key_source = "apiKeySource",
                .endpoint_configuration = "endpointConfiguration",
                .policy = "policy",
                .tags = "tags",
                .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
                .root_resource_id = "rootResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_stage: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/restapis/{restApiId}/stages/{stageName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStage",
    Request: type = struct {
        rest_api_id: []const u8,
        stage_name: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rest_api_id = "restApiId",
                .stage_name = "stageName",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_stage) } {
            return .{ .service_metadata = service_metadata, .action = update_stage };
        }
    },
    Response: type = struct {
        deployment_id: ?[]const u8 = null,
        client_certificate_id: ?[]const u8 = null,
        stage_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        cache_cluster_enabled: ?bool = null,
        cache_cluster_size: ?[]const u8 = null,
        cache_cluster_status: ?[]const u8 = null,
        method_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MethodSetting = null,
        } = null,
        variables: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        documentation_version: ?[]const u8 = null,
        access_log_settings: ?AccessLogSettings = null,
        canary_settings: ?CanarySettings = null,
        tracing_enabled: ?bool = null,
        web_acl_arn: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        created_date: ?i64 = null,
        last_updated_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deployment_id = "deploymentId",
                .client_certificate_id = "clientCertificateId",
                .stage_name = "stageName",
                .description = "description",
                .cache_cluster_enabled = "cacheClusterEnabled",
                .cache_cluster_size = "cacheClusterSize",
                .cache_cluster_status = "cacheClusterStatus",
                .method_settings = "methodSettings",
                .variables = "variables",
                .documentation_version = "documentationVersion",
                .access_log_settings = "accessLogSettings",
                .canary_settings = "canarySettings",
                .tracing_enabled = "tracingEnabled",
                .web_acl_arn = "webAclArn",
                .tags = "tags",
                .created_date = "createdDate",
                .last_updated_date = "lastUpdatedDate",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "method_settings", field_name))
                return try serializeMap(self.method_settings, self.fieldNameFor("method_settings"), options, out_stream);
            if (std.mem.eql(u8, "variables", field_name))
                return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_usage: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/usageplans/{usagePlanId}/keys/{keyId}/usage",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUsage",
    Request: type = struct {
        usage_plan_id: []const u8,
        key_id: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
                .key_id = "keyId",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_usage) } {
            return .{ .service_metadata = service_metadata, .action = update_usage };
        }
    },
    Response: type = struct {
        usage_plan_id: ?[]const u8 = null,
        start_date: ?[]const u8 = null,
        end_date: ?[]const u8 = null,
        items: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]i64 = null,
        } = null,
        position: ?[]const u8 = null,

        pub const http_query = .{
            .position = "position",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
                .start_date = "startDate",
                .end_date = "endDate",
                .items = "values",
                .position = "position",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "items", field_name))
                return try serializeMap(self.items, self.fieldNameFor("items"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_usage_plan: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/usageplans/{usagePlanId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUsagePlan",
    Request: type = struct {
        usage_plan_id: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usage_plan_id = "usagePlanId",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_usage_plan) } {
            return .{ .service_metadata = service_metadata, .action = update_usage_plan };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        api_stages: ?[]ApiStage = null,
        throttle: ?ThrottleSettings = null,
        quota: ?QuotaSettings = null,
        product_code: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .api_stages = "apiStages",
                .throttle = "throttle",
                .quota = "quota",
                .product_code = "productCode",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_vpc_link: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/vpclinks/{vpcLinkId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVpcLink",
    Request: type = struct {
        vpc_link_id: []const u8,
        patch_operations: ?[]PatchOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vpc_link_id = "vpcLinkId",
                .patch_operations = "patchOperations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vpc_link) } {
            return .{ .service_metadata = service_metadata, .action = update_vpc_link };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        target_arns: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .name = "name",
                .description = "description",
                .target_arns = "targetArns",
                .status = "status",
                .status_message = "statusMessage",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        LimitExceeded,
        NotFound,
        TooManyRequests,
        Unauthorized,
    },
} = .{};

pub const PatchOperation = struct {
    op: ?[]const u8 = null,
    path: ?[]const u8 = null,
    value: ?[]const u8 = null,
    from: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .op = "op",
            .path = "path",
            .value = "value",
            .from = "from",
        };
        return @field(mappings, field_name);
    }
};

pub const QuotaSettings = struct {
    limit: ?i64 = null,
    offset: ?i64 = null,
    period: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .limit = "limit",
            .offset = "offset",
            .period = "period",
        };
        return @field(mappings, field_name);
    }
};

pub const ThrottleSettings = struct {
    burst_limit: ?i64 = null,
    rate_limit: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .burst_limit = "burstLimit",
            .rate_limit = "rateLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const ApiStage = struct {
    api_id: ?[]const u8 = null,
    stage: ?[]const u8 = null,
    throttle: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ThrottleSettings = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .api_id = "apiId",
            .stage = "stage",
            .throttle = "throttle",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "throttle", field_name))
            return try serializeMap(self.throttle, self.fieldNameFor("throttle"), options, out_stream);
        return false;
    }
};

pub const CanarySettings = struct {
    percent_traffic: ?f64 = null,
    deployment_id: ?[]const u8 = null,
    stage_variable_overrides: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    use_stage_cache: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .percent_traffic = "percentTraffic",
            .deployment_id = "deploymentId",
            .stage_variable_overrides = "stageVariableOverrides",
            .use_stage_cache = "useStageCache",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "stage_variable_overrides", field_name))
            return try serializeMap(self.stage_variable_overrides, self.fieldNameFor("stage_variable_overrides"), options, out_stream);
        return false;
    }
};

pub const AccessLogSettings = struct {
    format: ?[]const u8 = null,
    destination_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "format",
            .destination_arn = "destinationArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MethodSetting = struct {
    metrics_enabled: ?bool = null,
    logging_level: ?[]const u8 = null,
    data_trace_enabled: ?bool = null,
    throttling_burst_limit: ?i64 = null,
    throttling_rate_limit: ?f64 = null,
    caching_enabled: ?bool = null,
    cache_ttl_in_seconds: ?i64 = null,
    cache_data_encrypted: ?bool = null,
    require_authorization_for_cache_control: ?bool = null,
    unauthorized_cache_control_header_strategy: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metrics_enabled = "metricsEnabled",
            .logging_level = "loggingLevel",
            .data_trace_enabled = "dataTraceEnabled",
            .throttling_burst_limit = "throttlingBurstLimit",
            .throttling_rate_limit = "throttlingRateLimit",
            .caching_enabled = "cachingEnabled",
            .cache_ttl_in_seconds = "cacheTtlInSeconds",
            .cache_data_encrypted = "cacheDataEncrypted",
            .require_authorization_for_cache_control = "requireAuthorizationForCacheControl",
            .unauthorized_cache_control_header_strategy = "unauthorizedCacheControlHeaderStrategy",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointConfiguration = struct {
    types: ?[][]const u8 = null,
    vpc_endpoint_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .types = "types",
            .vpc_endpoint_ids = "vpcEndpointIds",
        };
        return @field(mappings, field_name);
    }
};

pub const Method = struct {
    http_method: ?[]const u8 = null,
    authorization_type: ?[]const u8 = null,
    authorizer_id: ?[]const u8 = null,
    api_key_required: ?bool = null,
    request_validator_id: ?[]const u8 = null,
    operation_name: ?[]const u8 = null,
    request_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?bool = null,
    } = null,
    request_models: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    method_responses: ?[]struct {
        key: ?[]const u8 = null,
        value: ?MethodResponse = null,
    } = null,
    method_integration: ?Integration = null,
    authorization_scopes: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .http_method = "httpMethod",
            .authorization_type = "authorizationType",
            .authorizer_id = "authorizerId",
            .api_key_required = "apiKeyRequired",
            .request_validator_id = "requestValidatorId",
            .operation_name = "operationName",
            .request_parameters = "requestParameters",
            .request_models = "requestModels",
            .method_responses = "methodResponses",
            .method_integration = "methodIntegration",
            .authorization_scopes = "authorizationScopes",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "request_parameters", field_name))
            return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
        if (std.mem.eql(u8, "request_models", field_name))
            return try serializeMap(self.request_models, self.fieldNameFor("request_models"), options, out_stream);
        if (std.mem.eql(u8, "method_responses", field_name))
            return try serializeMap(self.method_responses, self.fieldNameFor("method_responses"), options, out_stream);
        return false;
    }
};

pub const Integration = struct {
    type: ?[]const u8 = null,
    http_method: ?[]const u8 = null,
    uri: ?[]const u8 = null,
    connection_type: ?[]const u8 = null,
    connection_id: ?[]const u8 = null,
    credentials: ?[]const u8 = null,
    request_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    request_templates: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    passthrough_behavior: ?[]const u8 = null,
    content_handling: ?[]const u8 = null,
    timeout_in_millis: ?i64 = null,
    cache_namespace: ?[]const u8 = null,
    cache_key_parameters: ?[][]const u8 = null,
    integration_responses: ?[]struct {
        key: ?[]const u8 = null,
        value: ?IntegrationResponse = null,
    } = null,
    tls_config: ?TlsConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .http_method = "httpMethod",
            .uri = "uri",
            .connection_type = "connectionType",
            .connection_id = "connectionId",
            .credentials = "credentials",
            .request_parameters = "requestParameters",
            .request_templates = "requestTemplates",
            .passthrough_behavior = "passthroughBehavior",
            .content_handling = "contentHandling",
            .timeout_in_millis = "timeoutInMillis",
            .cache_namespace = "cacheNamespace",
            .cache_key_parameters = "cacheKeyParameters",
            .integration_responses = "integrationResponses",
            .tls_config = "tlsConfig",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "request_parameters", field_name))
            return try serializeMap(self.request_parameters, self.fieldNameFor("request_parameters"), options, out_stream);
        if (std.mem.eql(u8, "request_templates", field_name))
            return try serializeMap(self.request_templates, self.fieldNameFor("request_templates"), options, out_stream);
        if (std.mem.eql(u8, "integration_responses", field_name))
            return try serializeMap(self.integration_responses, self.fieldNameFor("integration_responses"), options, out_stream);
        return false;
    }
};

pub const TlsConfig = struct {
    insecure_skip_verification: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insecure_skip_verification = "insecureSkipVerification",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegrationResponse = struct {
    status_code: ?[]const u8 = null,
    selection_pattern: ?[]const u8 = null,
    response_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    response_templates: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    content_handling: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "statusCode",
            .selection_pattern = "selectionPattern",
            .response_parameters = "responseParameters",
            .response_templates = "responseTemplates",
            .content_handling = "contentHandling",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "response_parameters", field_name))
            return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
        if (std.mem.eql(u8, "response_templates", field_name))
            return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
        return false;
    }
};

pub const MethodResponse = struct {
    status_code: ?[]const u8 = null,
    response_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?bool = null,
    } = null,
    response_models: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status_code = "statusCode",
            .response_parameters = "responseParameters",
            .response_models = "responseModels",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "response_parameters", field_name))
            return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
        if (std.mem.eql(u8, "response_models", field_name))
            return try serializeMap(self.response_models, self.fieldNameFor("response_models"), options, out_stream);
        return false;
    }
};

pub const MutualTlsAuthentication = struct {
    truststore_uri: ?[]const u8 = null,
    truststore_version: ?[]const u8 = null,
    truststore_warnings: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .truststore_uri = "truststoreUri",
            .truststore_version = "truststoreVersion",
            .truststore_warnings = "truststoreWarnings",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentationPartLocation = struct {
    type: []const u8,
    path: ?[]const u8 = null,
    method: ?[]const u8 = null,
    status_code: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .path = "path",
            .method = "method",
            .status_code = "statusCode",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const MethodSnapshot = struct {
    authorization_type: ?[]const u8 = null,
    api_key_required: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authorization_type = "authorizationType",
            .api_key_required = "apiKeyRequired",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcLink = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    target_arns: ?[][]const u8 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .description = "description",
            .target_arns = "targetArns",
            .status = "status",
            .status_message = "statusMessage",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const UsagePlan = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    api_stages: ?[]ApiStage = null,
    throttle: ?ThrottleSettings = null,
    quota: ?QuotaSettings = null,
    product_code: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .description = "description",
            .api_stages = "apiStages",
            .throttle = "throttle",
            .quota = "quota",
            .product_code = "productCode",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const UsagePlanKey = struct {
    id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    value: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .type = "type",
            .value = "value",
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const Stage = struct {
    deployment_id: ?[]const u8 = null,
    client_certificate_id: ?[]const u8 = null,
    stage_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    cache_cluster_enabled: ?bool = null,
    cache_cluster_size: ?[]const u8 = null,
    cache_cluster_status: ?[]const u8 = null,
    method_settings: ?[]struct {
        key: ?[]const u8 = null,
        value: ?MethodSetting = null,
    } = null,
    variables: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    documentation_version: ?[]const u8 = null,
    access_log_settings: ?AccessLogSettings = null,
    canary_settings: ?CanarySettings = null,
    tracing_enabled: ?bool = null,
    web_acl_arn: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    created_date: ?i64 = null,
    last_updated_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .deployment_id = "deploymentId",
            .client_certificate_id = "clientCertificateId",
            .stage_name = "stageName",
            .description = "description",
            .cache_cluster_enabled = "cacheClusterEnabled",
            .cache_cluster_size = "cacheClusterSize",
            .cache_cluster_status = "cacheClusterStatus",
            .method_settings = "methodSettings",
            .variables = "variables",
            .documentation_version = "documentationVersion",
            .access_log_settings = "accessLogSettings",
            .canary_settings = "canarySettings",
            .tracing_enabled = "tracingEnabled",
            .web_acl_arn = "webAclArn",
            .tags = "tags",
            .created_date = "createdDate",
            .last_updated_date = "lastUpdatedDate",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "method_settings", field_name))
            return try serializeMap(self.method_settings, self.fieldNameFor("method_settings"), options, out_stream);
        if (std.mem.eql(u8, "variables", field_name))
            return try serializeMap(self.variables, self.fieldNameFor("variables"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const SdkType = struct {
    id: ?[]const u8 = null,
    friendly_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    configuration_properties: ?[]SdkConfigurationProperty = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .friendly_name = "friendlyName",
            .description = "description",
            .configuration_properties = "configurationProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const SdkConfigurationProperty = struct {
    name: ?[]const u8 = null,
    friendly_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    required: ?bool = null,
    default_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .friendly_name = "friendlyName",
            .description = "description",
            .required = "required",
            .default_value = "defaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const RestApi = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_date: ?i64 = null,
    version: ?[]const u8 = null,
    warnings: ?[][]const u8 = null,
    binary_media_types: ?[][]const u8 = null,
    minimum_compression_size: ?i64 = null,
    api_key_source: ?[]const u8 = null,
    endpoint_configuration: ?EndpointConfiguration = null,
    policy: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    disable_execute_api_endpoint: ?bool = null,
    root_resource_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .description = "description",
            .created_date = "createdDate",
            .version = "version",
            .warnings = "warnings",
            .binary_media_types = "binaryMediaTypes",
            .minimum_compression_size = "minimumCompressionSize",
            .api_key_source = "apiKeySource",
            .endpoint_configuration = "endpointConfiguration",
            .policy = "policy",
            .tags = "tags",
            .disable_execute_api_endpoint = "disableExecuteApiEndpoint",
            .root_resource_id = "rootResourceId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Resource = struct {
    id: ?[]const u8 = null,
    parent_id: ?[]const u8 = null,
    path_part: ?[]const u8 = null,
    path: ?[]const u8 = null,
    resource_methods: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Method = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .parent_id = "parentId",
            .path_part = "pathPart",
            .path = "path",
            .resource_methods = "resourceMethods",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "resource_methods", field_name))
            return try serializeMap(self.resource_methods, self.fieldNameFor("resource_methods"), options, out_stream);
        return false;
    }
};

pub const RequestValidator = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    validate_request_body: ?bool = null,
    validate_request_parameters: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .validate_request_body = "validateRequestBody",
            .validate_request_parameters = "validateRequestParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const Model = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    schema: ?[]const u8 = null,
    content_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .description = "description",
            .schema = "schema",
            .content_type = "contentType",
        };
        return @field(mappings, field_name);
    }
};

pub const GatewayResponse = struct {
    response_type: ?[]const u8 = null,
    status_code: ?[]const u8 = null,
    response_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    response_templates: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    default_response: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .response_type = "responseType",
            .status_code = "statusCode",
            .response_parameters = "responseParameters",
            .response_templates = "responseTemplates",
            .default_response = "defaultResponse",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "response_parameters", field_name))
            return try serializeMap(self.response_parameters, self.fieldNameFor("response_parameters"), options, out_stream);
        if (std.mem.eql(u8, "response_templates", field_name))
            return try serializeMap(self.response_templates, self.fieldNameFor("response_templates"), options, out_stream);
        return false;
    }
};

pub const DomainName = struct {
    domain_name: ?[]const u8 = null,
    certificate_name: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    certificate_upload_date: ?i64 = null,
    regional_domain_name: ?[]const u8 = null,
    regional_hosted_zone_id: ?[]const u8 = null,
    regional_certificate_name: ?[]const u8 = null,
    regional_certificate_arn: ?[]const u8 = null,
    distribution_domain_name: ?[]const u8 = null,
    distribution_hosted_zone_id: ?[]const u8 = null,
    endpoint_configuration: ?EndpointConfiguration = null,
    domain_name_status: ?[]const u8 = null,
    domain_name_status_message: ?[]const u8 = null,
    security_policy: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    mutual_tls_authentication: ?MutualTlsAuthentication = null,
    ownership_verification_certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "domainName",
            .certificate_name = "certificateName",
            .certificate_arn = "certificateArn",
            .certificate_upload_date = "certificateUploadDate",
            .regional_domain_name = "regionalDomainName",
            .regional_hosted_zone_id = "regionalHostedZoneId",
            .regional_certificate_name = "regionalCertificateName",
            .regional_certificate_arn = "regionalCertificateArn",
            .distribution_domain_name = "distributionDomainName",
            .distribution_hosted_zone_id = "distributionHostedZoneId",
            .endpoint_configuration = "endpointConfiguration",
            .domain_name_status = "domainNameStatus",
            .domain_name_status_message = "domainNameStatusMessage",
            .security_policy = "securityPolicy",
            .tags = "tags",
            .mutual_tls_authentication = "mutualTlsAuthentication",
            .ownership_verification_certificate_arn = "ownershipVerificationCertificateArn",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const DocumentationVersion = struct {
    version: ?[]const u8 = null,
    created_date: ?i64 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "version",
            .created_date = "createdDate",
            .description = "description",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentationPart = struct {
    id: ?[]const u8 = null,
    location: ?DocumentationPartLocation = null,
    properties: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .location = "location",
            .properties = "properties",
        };
        return @field(mappings, field_name);
    }
};

pub const Deployment = struct {
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    created_date: ?i64 = null,
    api_summary: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]struct {
            key: ?[]const u8 = null,
            value: ?MethodSnapshot = null,
        } = null,


    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "value", field_name))
            return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
        return false;
    }
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .description = "description",
            .created_date = "createdDate",
            .api_summary = "apiSummary",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "api_summary", field_name))
            return try serializeMap(self.api_summary, self.fieldNameFor("api_summary"), options, out_stream);
        return false;
    }
};

pub const ClientCertificate = struct {
    client_certificate_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    pem_encoded_certificate: ?[]const u8 = null,
    created_date: ?i64 = null,
    expiration_date: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_certificate_id = "clientCertificateId",
            .description = "description",
            .pem_encoded_certificate = "pemEncodedCertificate",
            .created_date = "createdDate",
            .expiration_date = "expirationDate",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const BasePathMapping = struct {
    base_path: ?[]const u8 = null,
    rest_api_id: ?[]const u8 = null,
    stage: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base_path = "basePath",
            .rest_api_id = "restApiId",
            .stage = "stage",
        };
        return @field(mappings, field_name);
    }
};

pub const Authorizer = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    provider_ar_ns: ?[][]const u8 = null,
    auth_type: ?[]const u8 = null,
    authorizer_uri: ?[]const u8 = null,
    authorizer_credentials: ?[]const u8 = null,
    identity_source: ?[]const u8 = null,
    identity_validation_expression: ?[]const u8 = null,
    authorizer_result_ttl_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .name = "name",
            .type = "type",
            .provider_ar_ns = "providerARNs",
            .auth_type = "authType",
            .authorizer_uri = "authorizerUri",
            .authorizer_credentials = "authorizerCredentials",
            .identity_source = "identitySource",
            .identity_validation_expression = "identityValidationExpression",
            .authorizer_result_ttl_in_seconds = "authorizerResultTtlInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const ApiKey = struct {
    id: ?[]const u8 = null,
    value: ?[]const u8 = null,
    name: ?[]const u8 = null,
    customer_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    enabled: ?bool = null,
    created_date: ?i64 = null,
    last_updated_date: ?i64 = null,
    stage_keys: ?[][]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .value = "value",
            .name = "name",
            .customer_id = "customerId",
            .description = "description",
            .enabled = "enabled",
            .created_date = "createdDate",
            .last_updated_date = "lastUpdatedDate",
            .stage_keys = "stageKeys",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};
