const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-15";
pub const sdk_id: []const u8 = "Backup";
pub const arn_namespace: ?[]const u8 = "backup";
pub const endpoint_prefix: []const u8 = "backup";
pub const sigv4_name: []const u8 = "backup";
pub const name: []const u8 = "CryoControllerUserManager";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-15",
    sdk_id: []const u8 = "Backup",
    arn_namespace: ?[]const u8 = "backup",
    endpoint_prefix: []const u8 = "backup",
    sigv4_name: []const u8 = "backup",
    name: []const u8 = "CryoControllerUserManager",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_legal_hold: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/legal-holds/{LegalHoldId}",
        .success_code = 201,
    };

    action_name: []const u8 = "CancelLegalHold",
    Request: type = struct {
        legal_hold_id: []const u8,
        cancel_description: []const u8,
        retain_record_in_days: ?i64 = null,

        pub const http_query = .{
            .cancel_description = "cancelDescription",
            .retain_record_in_days = "retainRecordInDays",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .legal_hold_id = "LegalHoldId",
                .cancel_description = "CancelDescription",
                .retain_record_in_days = "RetainRecordInDays",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_legal_hold) } {
            return .{ .service_metadata = service_metadata, .action = cancel_legal_hold };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidResourceState,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const create_backup_plan: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup/plans",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBackupPlan",
    Request: type = struct {
        backup_plan: BackupPlanInput,
        backup_plan_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        creator_request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan = "BackupPlan",
                .backup_plan_tags = "BackupPlanTags",
                .creator_request_id = "CreatorRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "backup_plan_tags", field_name))
                return try serializeMap(self.backup_plan_tags, self.fieldNameFor("backup_plan_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backup_plan) } {
            return .{ .service_metadata = service_metadata, .action = create_backup_plan };
        }
    },
    Response: type = struct {
        backup_plan_id: ?[]const u8 = null,
        backup_plan_arn: ?[]const u8 = null,
        creation_date: ?i64 = null,
        version_id: ?[]const u8 = null,
        advanced_backup_settings: ?[]AdvancedBackupSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
                .backup_plan_arn = "BackupPlanArn",
                .creation_date = "CreationDate",
                .version_id = "VersionId",
                .advanced_backup_settings = "AdvancedBackupSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const create_backup_selection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup/plans/{BackupPlanId}/selections",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBackupSelection",
    Request: type = struct {
        backup_plan_id: []const u8,
        backup_selection: BackupSelection,
        creator_request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
                .backup_selection = "BackupSelection",
                .creator_request_id = "CreatorRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backup_selection) } {
            return .{ .service_metadata = service_metadata, .action = create_backup_selection };
        }
    },
    Response: type = struct {
        selection_id: ?[]const u8 = null,
        backup_plan_id: ?[]const u8 = null,
        creation_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .selection_id = "SelectionId",
                .backup_plan_id = "BackupPlanId",
                .creation_date = "CreationDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const create_backup_vault: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup-vaults/{BackupVaultName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBackupVault",
    Request: type = struct {
        backup_vault_name: []const u8,
        backup_vault_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        encryption_key_arn: ?[]const u8 = null,
        creator_request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .backup_vault_tags = "BackupVaultTags",
                .encryption_key_arn = "EncryptionKeyArn",
                .creator_request_id = "CreatorRequestId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "backup_vault_tags", field_name))
                return try serializeMap(self.backup_vault_tags, self.fieldNameFor("backup_vault_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backup_vault) } {
            return .{ .service_metadata = service_metadata, .action = create_backup_vault };
        }
    },
    Response: type = struct {
        backup_vault_name: ?[]const u8 = null,
        backup_vault_arn: ?[]const u8 = null,
        creation_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .backup_vault_arn = "BackupVaultArn",
                .creation_date = "CreationDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const create_framework: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/frameworks",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFramework",
    Request: type = struct {
        framework_name: []const u8,
        framework_description: ?[]const u8 = null,
        framework_controls: []FrameworkControl,
        idempotency_token: ?[]const u8 = null,
        framework_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_name = "FrameworkName",
                .framework_description = "FrameworkDescription",
                .framework_controls = "FrameworkControls",
                .idempotency_token = "IdempotencyToken",
                .framework_tags = "FrameworkTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "framework_tags", field_name))
                return try serializeMap(self.framework_tags, self.fieldNameFor("framework_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_framework) } {
            return .{ .service_metadata = service_metadata, .action = create_framework };
        }
    },
    Response: type = struct {
        framework_name: ?[]const u8 = null,
        framework_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_name = "FrameworkName",
                .framework_arn = "FrameworkArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const create_legal_hold: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/legal-holds",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLegalHold",
    Request: type = struct {
        title: []const u8,
        description: []const u8,
        idempotency_token: ?[]const u8 = null,
        recovery_point_selection: ?RecoveryPointSelection = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .title = "Title",
                .description = "Description",
                .idempotency_token = "IdempotencyToken",
                .recovery_point_selection = "RecoveryPointSelection",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_legal_hold) } {
            return .{ .service_metadata = service_metadata, .action = create_legal_hold };
        }
    },
    Response: type = struct {
        title: ?[]const u8 = null,
        status: ?[]const u8 = null,
        description: ?[]const u8 = null,
        legal_hold_id: ?[]const u8 = null,
        legal_hold_arn: ?[]const u8 = null,
        creation_date: ?i64 = null,
        recovery_point_selection: ?RecoveryPointSelection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .title = "Title",
                .status = "Status",
                .description = "Description",
                .legal_hold_id = "LegalHoldId",
                .legal_hold_arn = "LegalHoldArn",
                .creation_date = "CreationDate",
                .recovery_point_selection = "RecoveryPointSelection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const create_logically_air_gapped_backup_vault: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/logically-air-gapped-backup-vaults/{BackupVaultName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLogicallyAirGappedBackupVault",
    Request: type = struct {
        backup_vault_name: []const u8,
        backup_vault_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        creator_request_id: ?[]const u8 = null,
        min_retention_days: i64,
        max_retention_days: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .backup_vault_tags = "BackupVaultTags",
                .creator_request_id = "CreatorRequestId",
                .min_retention_days = "MinRetentionDays",
                .max_retention_days = "MaxRetentionDays",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "backup_vault_tags", field_name))
                return try serializeMap(self.backup_vault_tags, self.fieldNameFor("backup_vault_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_logically_air_gapped_backup_vault) } {
            return .{ .service_metadata = service_metadata, .action = create_logically_air_gapped_backup_vault };
        }
    },
    Response: type = struct {
        backup_vault_name: ?[]const u8 = null,
        backup_vault_arn: ?[]const u8 = null,
        creation_date: ?i64 = null,
        vault_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .backup_vault_arn = "BackupVaultArn",
                .creation_date = "CreationDate",
                .vault_state = "VaultState",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidParameterValue,
        InvalidRequest,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const create_report_plan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/report-plans",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateReportPlan",
    Request: type = struct {
        report_plan_name: []const u8,
        report_plan_description: ?[]const u8 = null,
        report_delivery_channel: ReportDeliveryChannel,
        report_setting: ReportSetting,
        report_plan_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_plan_name = "ReportPlanName",
                .report_plan_description = "ReportPlanDescription",
                .report_delivery_channel = "ReportDeliveryChannel",
                .report_setting = "ReportSetting",
                .report_plan_tags = "ReportPlanTags",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "report_plan_tags", field_name))
                return try serializeMap(self.report_plan_tags, self.fieldNameFor("report_plan_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_report_plan) } {
            return .{ .service_metadata = service_metadata, .action = create_report_plan };
        }
    },
    Response: type = struct {
        report_plan_name: ?[]const u8 = null,
        report_plan_arn: ?[]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_plan_name = "ReportPlanName",
                .report_plan_arn = "ReportPlanArn",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const create_restore_testing_plan: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restore-testing/plans",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRestoreTestingPlan",
    Request: type = struct {
        creator_request_id: ?[]const u8 = null,
        restore_testing_plan: struct {
            recovery_point_selection: RestoreTestingRecoveryPointSelection,
            restore_testing_plan_name: []const u8,
            schedule_expression: []const u8,
            schedule_expression_timezone: ?[]const u8 = null,
            start_window_hours: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recovery_point_selection = "RecoveryPointSelection",
                    .restore_testing_plan_name = "RestoreTestingPlanName",
                    .schedule_expression = "ScheduleExpression",
                    .schedule_expression_timezone = "ScheduleExpressionTimezone",
                    .start_window_hours = "StartWindowHours",
                };
                return @field(mappings, field_name);
            }
        },
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creator_request_id = "CreatorRequestId",
                .restore_testing_plan = "RestoreTestingPlan",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_restore_testing_plan) } {
            return .{ .service_metadata = service_metadata, .action = create_restore_testing_plan };
        }
    },
    Response: type = struct {
        creation_time: i64,
        restore_testing_plan_arn: []const u8,
        restore_testing_plan_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "CreationTime",
                .restore_testing_plan_arn = "RestoreTestingPlanArn",
                .restore_testing_plan_name = "RestoreTestingPlanName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        Conflict,
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const create_restore_testing_selection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restore-testing/plans/{RestoreTestingPlanName}/selections",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRestoreTestingSelection",
    Request: type = struct {
        creator_request_id: ?[]const u8 = null,
        restore_testing_plan_name: []const u8,
        restore_testing_selection: struct {
            iam_role_arn: []const u8,
            protected_resource_arns: ?[][]const u8 = null,
            protected_resource_conditions: ?ProtectedResourceConditions = null,
            protected_resource_type: []const u8,
            restore_metadata_overrides: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            restore_testing_selection_name: []const u8,
            validation_window_hours: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .iam_role_arn = "IamRoleArn",
                    .protected_resource_arns = "ProtectedResourceArns",
                    .protected_resource_conditions = "ProtectedResourceConditions",
                    .protected_resource_type = "ProtectedResourceType",
                    .restore_metadata_overrides = "RestoreMetadataOverrides",
                    .restore_testing_selection_name = "RestoreTestingSelectionName",
                    .validation_window_hours = "ValidationWindowHours",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "restore_metadata_overrides", field_name))
                    return try serializeMap(self.restore_metadata_overrides, self.fieldNameFor("restore_metadata_overrides"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creator_request_id = "CreatorRequestId",
                .restore_testing_plan_name = "RestoreTestingPlanName",
                .restore_testing_selection = "RestoreTestingSelection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_restore_testing_selection) } {
            return .{ .service_metadata = service_metadata, .action = create_restore_testing_selection };
        }
    },
    Response: type = struct {
        creation_time: i64,
        restore_testing_plan_arn: []const u8,
        restore_testing_plan_name: []const u8,
        restore_testing_selection_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "CreationTime",
                .restore_testing_plan_arn = "RestoreTestingPlanArn",
                .restore_testing_plan_name = "RestoreTestingPlanName",
                .restore_testing_selection_name = "RestoreTestingSelectionName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_backup_plan: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/backup/plans/{BackupPlanId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackupPlan",
    Request: type = struct {
        backup_plan_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup_plan) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup_plan };
        }
    },
    Response: type = struct {
        backup_plan_id: ?[]const u8 = null,
        backup_plan_arn: ?[]const u8 = null,
        deletion_date: ?i64 = null,
        version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
                .backup_plan_arn = "BackupPlanArn",
                .deletion_date = "DeletionDate",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_backup_selection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/backup/plans/{BackupPlanId}/selections/{SelectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackupSelection",
    Request: type = struct {
        backup_plan_id: []const u8,
        selection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
                .selection_id = "SelectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup_selection) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup_selection };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_backup_vault: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/backup-vaults/{BackupVaultName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackupVault",
    Request: type = struct {
        backup_vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup_vault) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup_vault };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_backup_vault_access_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/backup-vaults/{BackupVaultName}/access-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackupVaultAccessPolicy",
    Request: type = struct {
        backup_vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup_vault_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup_vault_access_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_backup_vault_lock_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/backup-vaults/{BackupVaultName}/vault-lock",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackupVaultLockConfiguration",
    Request: type = struct {
        backup_vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup_vault_lock_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup_vault_lock_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_backup_vault_notifications: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/backup-vaults/{BackupVaultName}/notification-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBackupVaultNotifications",
    Request: type = struct {
        backup_vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup_vault_notifications) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup_vault_notifications };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_framework: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/audit/frameworks/{FrameworkName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFramework",
    Request: type = struct {
        framework_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_name = "FrameworkName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_framework) } {
            return .{ .service_metadata = service_metadata, .action = delete_framework };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_recovery_point: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/backup-vaults/{BackupVaultName}/recovery-points/{RecoveryPointArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRecoveryPoint",
    Request: type = struct {
        backup_vault_name: []const u8,
        recovery_point_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .recovery_point_arn = "RecoveryPointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_recovery_point) } {
            return .{ .service_metadata = service_metadata, .action = delete_recovery_point };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        InvalidResourceState,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_report_plan: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/audit/report-plans/{ReportPlanName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteReportPlan",
    Request: type = struct {
        report_plan_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_plan_name = "ReportPlanName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_report_plan) } {
            return .{ .service_metadata = service_metadata, .action = delete_report_plan };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_restore_testing_plan: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restore-testing/plans/{RestoreTestingPlanName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRestoreTestingPlan",
    Request: type = struct {
        restore_testing_plan_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_testing_plan_name = "RestoreTestingPlanName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_restore_testing_plan) } {
            return .{ .service_metadata = service_metadata, .action = delete_restore_testing_plan };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const delete_restore_testing_selection: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/restore-testing/plans/{RestoreTestingPlanName}/selections/{RestoreTestingSelectionName}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRestoreTestingSelection",
    Request: type = struct {
        restore_testing_plan_name: []const u8,
        restore_testing_selection_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_testing_plan_name = "RestoreTestingPlanName",
                .restore_testing_selection_name = "RestoreTestingSelectionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_restore_testing_selection) } {
            return .{ .service_metadata = service_metadata, .action = delete_restore_testing_selection };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_backup_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup-jobs/{BackupJobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBackupJob",
    Request: type = struct {
        backup_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_job_id = "BackupJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_backup_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_backup_job };
        }
    },
    Response: type = struct {
        account_id: ?[]const u8 = null,
        backup_job_id: ?[]const u8 = null,
        backup_vault_name: ?[]const u8 = null,
        backup_vault_arn: ?[]const u8 = null,
        recovery_point_arn: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        creation_date: ?i64 = null,
        completion_date: ?i64 = null,
        state: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        percent_done: ?[]const u8 = null,
        backup_size_in_bytes: ?i64 = null,
        iam_role_arn: ?[]const u8 = null,
        created_by: ?RecoveryPointCreator = null,
        resource_type: ?[]const u8 = null,
        bytes_transferred: ?i64 = null,
        expected_completion_date: ?i64 = null,
        start_by: ?i64 = null,
        backup_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        backup_type: ?[]const u8 = null,
        parent_job_id: ?[]const u8 = null,
        is_parent: ?bool = null,
        number_of_child_jobs: ?i64 = null,
        child_jobs_in_state: ?[]struct {
            key: ?[]const u8 = null,
            value: ?i64 = null,
        } = null,
        resource_name: ?[]const u8 = null,
        initiation_date: ?i64 = null,
        message_category: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .backup_job_id = "BackupJobId",
                .backup_vault_name = "BackupVaultName",
                .backup_vault_arn = "BackupVaultArn",
                .recovery_point_arn = "RecoveryPointArn",
                .resource_arn = "ResourceArn",
                .creation_date = "CreationDate",
                .completion_date = "CompletionDate",
                .state = "State",
                .status_message = "StatusMessage",
                .percent_done = "PercentDone",
                .backup_size_in_bytes = "BackupSizeInBytes",
                .iam_role_arn = "IamRoleArn",
                .created_by = "CreatedBy",
                .resource_type = "ResourceType",
                .bytes_transferred = "BytesTransferred",
                .expected_completion_date = "ExpectedCompletionDate",
                .start_by = "StartBy",
                .backup_options = "BackupOptions",
                .backup_type = "BackupType",
                .parent_job_id = "ParentJobId",
                .is_parent = "IsParent",
                .number_of_child_jobs = "NumberOfChildJobs",
                .child_jobs_in_state = "ChildJobsInState",
                .resource_name = "ResourceName",
                .initiation_date = "InitiationDate",
                .message_category = "MessageCategory",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "backup_options", field_name))
                return try serializeMap(self.backup_options, self.fieldNameFor("backup_options"), options, out_stream);
            if (std.mem.eql(u8, "child_jobs_in_state", field_name))
                return try serializeMap(self.child_jobs_in_state, self.fieldNameFor("child_jobs_in_state"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        DependencyFailure,
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_backup_vault: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup-vaults/{BackupVaultName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBackupVault",
    Request: type = struct {
        backup_vault_name: []const u8,
        backup_vault_account_id: ?[]const u8 = null,

        pub const http_query = .{
            .backup_vault_account_id = "backupVaultAccountId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .backup_vault_account_id = "BackupVaultAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_backup_vault) } {
            return .{ .service_metadata = service_metadata, .action = describe_backup_vault };
        }
    },
    Response: type = struct {
        backup_vault_name: ?[]const u8 = null,
        backup_vault_arn: ?[]const u8 = null,
        vault_type: ?[]const u8 = null,
        encryption_key_arn: ?[]const u8 = null,
        creation_date: ?i64 = null,
        creator_request_id: ?[]const u8 = null,
        number_of_recovery_points: ?i64 = null,
        locked: ?bool = null,
        min_retention_days: ?i64 = null,
        max_retention_days: ?i64 = null,
        lock_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .backup_vault_arn = "BackupVaultArn",
                .vault_type = "VaultType",
                .encryption_key_arn = "EncryptionKeyArn",
                .creation_date = "CreationDate",
                .creator_request_id = "CreatorRequestId",
                .number_of_recovery_points = "NumberOfRecoveryPoints",
                .locked = "Locked",
                .min_retention_days = "MinRetentionDays",
                .max_retention_days = "MaxRetentionDays",
                .lock_date = "LockDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_copy_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/copy-jobs/{CopyJobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCopyJob",
    Request: type = struct {
        copy_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .copy_job_id = "CopyJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_copy_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_copy_job };
        }
    },
    Response: type = struct {
        copy_job: ?CopyJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .copy_job = "CopyJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_framework: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/frameworks/{FrameworkName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFramework",
    Request: type = struct {
        framework_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_name = "FrameworkName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_framework) } {
            return .{ .service_metadata = service_metadata, .action = describe_framework };
        }
    },
    Response: type = struct {
        framework_name: ?[]const u8 = null,
        framework_arn: ?[]const u8 = null,
        framework_description: ?[]const u8 = null,
        framework_controls: ?[]FrameworkControl = null,
        creation_time: ?i64 = null,
        deployment_status: ?[]const u8 = null,
        framework_status: ?[]const u8 = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_name = "FrameworkName",
                .framework_arn = "FrameworkArn",
                .framework_description = "FrameworkDescription",
                .framework_controls = "FrameworkControls",
                .creation_time = "CreationTime",
                .deployment_status = "DeploymentStatus",
                .framework_status = "FrameworkStatus",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_global_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/global-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGlobalSettings",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_global_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_global_settings };
        }
    },
    Response: type = struct {
        global_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        last_update_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_settings = "GlobalSettings",
                .last_update_time = "LastUpdateTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "global_settings", field_name))
                return try serializeMap(self.global_settings, self.fieldNameFor("global_settings"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const describe_protected_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resources/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProtectedResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_protected_resource) } {
            return .{ .service_metadata = service_metadata, .action = describe_protected_resource };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        last_backup_time: ?i64 = null,
        resource_name: ?[]const u8 = null,
        last_backup_vault_arn: ?[]const u8 = null,
        last_recovery_point_arn: ?[]const u8 = null,
        latest_restore_execution_time_minutes: ?i64 = null,
        latest_restore_job_creation_date: ?i64 = null,
        latest_restore_recovery_point_creation_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_type = "ResourceType",
                .last_backup_time = "LastBackupTime",
                .resource_name = "ResourceName",
                .last_backup_vault_arn = "LastBackupVaultArn",
                .last_recovery_point_arn = "LastRecoveryPointArn",
                .latest_restore_execution_time_minutes = "LatestRestoreExecutionTimeMinutes",
                .latest_restore_job_creation_date = "LatestRestoreJobCreationDate",
                .latest_restore_recovery_point_creation_date = "LatestRestoreRecoveryPointCreationDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_recovery_point: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup-vaults/{BackupVaultName}/recovery-points/{RecoveryPointArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRecoveryPoint",
    Request: type = struct {
        backup_vault_name: []const u8,
        recovery_point_arn: []const u8,
        backup_vault_account_id: ?[]const u8 = null,

        pub const http_query = .{
            .backup_vault_account_id = "backupVaultAccountId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .recovery_point_arn = "RecoveryPointArn",
                .backup_vault_account_id = "BackupVaultAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_recovery_point) } {
            return .{ .service_metadata = service_metadata, .action = describe_recovery_point };
        }
    },
    Response: type = struct {
        recovery_point_arn: ?[]const u8 = null,
        backup_vault_name: ?[]const u8 = null,
        backup_vault_arn: ?[]const u8 = null,
        source_backup_vault_arn: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        created_by: ?RecoveryPointCreator = null,
        iam_role_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        creation_date: ?i64 = null,
        completion_date: ?i64 = null,
        backup_size_in_bytes: ?i64 = null,
        calculated_lifecycle: ?CalculatedLifecycle = null,
        lifecycle: ?Lifecycle = null,
        encryption_key_arn: ?[]const u8 = null,
        is_encrypted: ?bool = null,
        storage_class: ?[]const u8 = null,
        last_restore_time: ?i64 = null,
        parent_recovery_point_arn: ?[]const u8 = null,
        composite_member_identifier: ?[]const u8 = null,
        is_parent: ?bool = null,
        resource_name: ?[]const u8 = null,
        vault_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recovery_point_arn = "RecoveryPointArn",
                .backup_vault_name = "BackupVaultName",
                .backup_vault_arn = "BackupVaultArn",
                .source_backup_vault_arn = "SourceBackupVaultArn",
                .resource_arn = "ResourceArn",
                .resource_type = "ResourceType",
                .created_by = "CreatedBy",
                .iam_role_arn = "IamRoleArn",
                .status = "Status",
                .status_message = "StatusMessage",
                .creation_date = "CreationDate",
                .completion_date = "CompletionDate",
                .backup_size_in_bytes = "BackupSizeInBytes",
                .calculated_lifecycle = "CalculatedLifecycle",
                .lifecycle = "Lifecycle",
                .encryption_key_arn = "EncryptionKeyArn",
                .is_encrypted = "IsEncrypted",
                .storage_class = "StorageClass",
                .last_restore_time = "LastRestoreTime",
                .parent_recovery_point_arn = "ParentRecoveryPointArn",
                .composite_member_identifier = "CompositeMemberIdentifier",
                .is_parent = "IsParent",
                .resource_name = "ResourceName",
                .vault_type = "VaultType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_region_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/account-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRegionSettings",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_region_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_region_settings };
        }
    },
    Response: type = struct {
        resource_type_opt_in_preference: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,
        resource_type_management_preference: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type_opt_in_preference = "ResourceTypeOptInPreference",
                .resource_type_management_preference = "ResourceTypeManagementPreference",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "resource_type_opt_in_preference", field_name))
                return try serializeMap(self.resource_type_opt_in_preference, self.fieldNameFor("resource_type_opt_in_preference"), options, out_stream);
            if (std.mem.eql(u8, "resource_type_management_preference", field_name))
                return try serializeMap(self.resource_type_management_preference, self.fieldNameFor("resource_type_management_preference"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ServiceUnavailable,
    },
} = .{};
pub const describe_report_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/report-jobs/{ReportJobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeReportJob",
    Request: type = struct {
        report_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_job_id = "ReportJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_report_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_report_job };
        }
    },
    Response: type = struct {
        report_job: ?ReportJob = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_job = "ReportJob",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_report_plan: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/report-plans/{ReportPlanName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeReportPlan",
    Request: type = struct {
        report_plan_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_plan_name = "ReportPlanName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_report_plan) } {
            return .{ .service_metadata = service_metadata, .action = describe_report_plan };
        }
    },
    Response: type = struct {
        report_plan: ?ReportPlan = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_plan = "ReportPlan",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_restore_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-jobs/{RestoreJobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRestoreJob",
    Request: type = struct {
        restore_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_job_id = "RestoreJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_restore_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_restore_job };
        }
    },
    Response: type = struct {
        account_id: ?[]const u8 = null,
        restore_job_id: ?[]const u8 = null,
        recovery_point_arn: ?[]const u8 = null,
        creation_date: ?i64 = null,
        completion_date: ?i64 = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        percent_done: ?[]const u8 = null,
        backup_size_in_bytes: ?i64 = null,
        iam_role_arn: ?[]const u8 = null,
        expected_completion_time_minutes: ?i64 = null,
        created_resource_arn: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        recovery_point_creation_date: ?i64 = null,
        created_by: ?RestoreJobCreator = null,
        validation_status: ?[]const u8 = null,
        validation_status_message: ?[]const u8 = null,
        deletion_status: ?[]const u8 = null,
        deletion_status_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .restore_job_id = "RestoreJobId",
                .recovery_point_arn = "RecoveryPointArn",
                .creation_date = "CreationDate",
                .completion_date = "CompletionDate",
                .status = "Status",
                .status_message = "StatusMessage",
                .percent_done = "PercentDone",
                .backup_size_in_bytes = "BackupSizeInBytes",
                .iam_role_arn = "IamRoleArn",
                .expected_completion_time_minutes = "ExpectedCompletionTimeMinutes",
                .created_resource_arn = "CreatedResourceArn",
                .resource_type = "ResourceType",
                .recovery_point_creation_date = "RecoveryPointCreationDate",
                .created_by = "CreatedBy",
                .validation_status = "ValidationStatus",
                .validation_status_message = "ValidationStatusMessage",
                .deletion_status = "DeletionStatus",
                .deletion_status_message = "DeletionStatusMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DependencyFailure,
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const disassociate_recovery_point: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backup-vaults/{BackupVaultName}/recovery-points/{RecoveryPointArn}/disassociate",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateRecoveryPoint",
    Request: type = struct {
        backup_vault_name: []const u8,
        recovery_point_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .recovery_point_arn = "RecoveryPointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_recovery_point) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_recovery_point };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        InvalidResourceState,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const disassociate_recovery_point_from_parent: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/backup-vaults/{BackupVaultName}/recovery-points/{RecoveryPointArn}/parentAssociation",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateRecoveryPointFromParent",
    Request: type = struct {
        backup_vault_name: []const u8,
        recovery_point_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .recovery_point_arn = "RecoveryPointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_recovery_point_from_parent) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_recovery_point_from_parent };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const export_backup_plan_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup/plans/{BackupPlanId}/toTemplate",
        .success_code = 200,
    };

    action_name: []const u8 = "ExportBackupPlanTemplate",
    Request: type = struct {
        backup_plan_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_backup_plan_template) } {
            return .{ .service_metadata = service_metadata, .action = export_backup_plan_template };
        }
    },
    Response: type = struct {
        backup_plan_template_json: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_template_json = "BackupPlanTemplateJson",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_backup_plan: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup/plans/{BackupPlanId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackupPlan",
    Request: type = struct {
        backup_plan_id: []const u8,
        version_id: ?[]const u8 = null,

        pub const http_query = .{
            .version_id = "versionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backup_plan) } {
            return .{ .service_metadata = service_metadata, .action = get_backup_plan };
        }
    },
    Response: type = struct {
        backup_plan: ?BackupPlan = null,
        backup_plan_id: ?[]const u8 = null,
        backup_plan_arn: ?[]const u8 = null,
        version_id: ?[]const u8 = null,
        creator_request_id: ?[]const u8 = null,
        creation_date: ?i64 = null,
        deletion_date: ?i64 = null,
        last_execution_date: ?i64 = null,
        advanced_backup_settings: ?[]AdvancedBackupSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan = "BackupPlan",
                .backup_plan_id = "BackupPlanId",
                .backup_plan_arn = "BackupPlanArn",
                .version_id = "VersionId",
                .creator_request_id = "CreatorRequestId",
                .creation_date = "CreationDate",
                .deletion_date = "DeletionDate",
                .last_execution_date = "LastExecutionDate",
                .advanced_backup_settings = "AdvancedBackupSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_backup_plan_from_json: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backup/template/json/toPlan",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackupPlanFromJSON",
    Request: type = struct {
        backup_plan_template_json: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_template_json = "BackupPlanTemplateJson",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backup_plan_from_json) } {
            return .{ .service_metadata = service_metadata, .action = get_backup_plan_from_json };
        }
    },
    Response: type = struct {
        backup_plan: ?BackupPlan = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan = "BackupPlan",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        LimitExceeded,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const get_backup_plan_from_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup/template/plans/{BackupPlanTemplateId}/toPlan",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackupPlanFromTemplate",
    Request: type = struct {
        backup_plan_template_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_template_id = "BackupPlanTemplateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backup_plan_from_template) } {
            return .{ .service_metadata = service_metadata, .action = get_backup_plan_from_template };
        }
    },
    Response: type = struct {
        backup_plan_document: ?BackupPlan = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_document = "BackupPlanDocument",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_backup_selection: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup/plans/{BackupPlanId}/selections/{SelectionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackupSelection",
    Request: type = struct {
        backup_plan_id: []const u8,
        selection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
                .selection_id = "SelectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backup_selection) } {
            return .{ .service_metadata = service_metadata, .action = get_backup_selection };
        }
    },
    Response: type = struct {
        backup_selection: ?BackupSelection = null,
        selection_id: ?[]const u8 = null,
        backup_plan_id: ?[]const u8 = null,
        creation_date: ?i64 = null,
        creator_request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_selection = "BackupSelection",
                .selection_id = "SelectionId",
                .backup_plan_id = "BackupPlanId",
                .creation_date = "CreationDate",
                .creator_request_id = "CreatorRequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_backup_vault_access_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup-vaults/{BackupVaultName}/access-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackupVaultAccessPolicy",
    Request: type = struct {
        backup_vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backup_vault_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_backup_vault_access_policy };
        }
    },
    Response: type = struct {
        backup_vault_name: ?[]const u8 = null,
        backup_vault_arn: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .backup_vault_arn = "BackupVaultArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_backup_vault_notifications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup-vaults/{BackupVaultName}/notification-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBackupVaultNotifications",
    Request: type = struct {
        backup_vault_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_backup_vault_notifications) } {
            return .{ .service_metadata = service_metadata, .action = get_backup_vault_notifications };
        }
    },
    Response: type = struct {
        backup_vault_name: ?[]const u8 = null,
        backup_vault_arn: ?[]const u8 = null,
        sns_topic_arn: ?[]const u8 = null,
        backup_vault_events: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .backup_vault_arn = "BackupVaultArn",
                .sns_topic_arn = "SNSTopicArn",
                .backup_vault_events = "BackupVaultEvents",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_legal_hold: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/legal-holds/{LegalHoldId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLegalHold",
    Request: type = struct {
        legal_hold_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .legal_hold_id = "LegalHoldId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_legal_hold) } {
            return .{ .service_metadata = service_metadata, .action = get_legal_hold };
        }
    },
    Response: type = struct {
        title: ?[]const u8 = null,
        status: ?[]const u8 = null,
        description: ?[]const u8 = null,
        cancel_description: ?[]const u8 = null,
        legal_hold_id: ?[]const u8 = null,
        legal_hold_arn: ?[]const u8 = null,
        creation_date: ?i64 = null,
        cancellation_date: ?i64 = null,
        retain_record_until: ?i64 = null,
        recovery_point_selection: ?RecoveryPointSelection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .title = "Title",
                .status = "Status",
                .description = "Description",
                .cancel_description = "CancelDescription",
                .legal_hold_id = "LegalHoldId",
                .legal_hold_arn = "LegalHoldArn",
                .creation_date = "CreationDate",
                .cancellation_date = "CancellationDate",
                .retain_record_until = "RetainRecordUntil",
                .recovery_point_selection = "RecoveryPointSelection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_recovery_point_restore_metadata: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup-vaults/{BackupVaultName}/recovery-points/{RecoveryPointArn}/restore-metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecoveryPointRestoreMetadata",
    Request: type = struct {
        backup_vault_name: []const u8,
        recovery_point_arn: []const u8,
        backup_vault_account_id: ?[]const u8 = null,

        pub const http_query = .{
            .backup_vault_account_id = "backupVaultAccountId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .recovery_point_arn = "RecoveryPointArn",
                .backup_vault_account_id = "BackupVaultAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recovery_point_restore_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_recovery_point_restore_metadata };
        }
    },
    Response: type = struct {
        backup_vault_arn: ?[]const u8 = null,
        recovery_point_arn: ?[]const u8 = null,
        restore_metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        resource_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_arn = "BackupVaultArn",
                .recovery_point_arn = "RecoveryPointArn",
                .restore_metadata = "RestoreMetadata",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "restore_metadata", field_name))
                return try serializeMap(self.restore_metadata, self.fieldNameFor("restore_metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_restore_job_metadata: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-jobs/{RestoreJobId}/metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRestoreJobMetadata",
    Request: type = struct {
        restore_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_job_id = "RestoreJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_restore_job_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_restore_job_metadata };
        }
    },
    Response: type = struct {
        restore_job_id: ?[]const u8 = null,
        metadata: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_job_id = "RestoreJobId",
                .metadata = "Metadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_restore_testing_inferred_metadata: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-testing/inferred-metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRestoreTestingInferredMetadata",
    Request: type = struct {
        backup_vault_account_id: ?[]const u8 = null,
        backup_vault_name: []const u8,
        recovery_point_arn: []const u8,

        pub const http_query = .{
            .backup_vault_account_id = "BackupVaultAccountId",
            .backup_vault_name = "BackupVaultName",
            .recovery_point_arn = "RecoveryPointArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_account_id = "BackupVaultAccountId",
                .backup_vault_name = "BackupVaultName",
                .recovery_point_arn = "RecoveryPointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_restore_testing_inferred_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_restore_testing_inferred_metadata };
        }
    },
    Response: type = struct {
        inferred_metadata: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inferred_metadata = "InferredMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "inferred_metadata", field_name))
                return try serializeMap(self.inferred_metadata, self.fieldNameFor("inferred_metadata"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_restore_testing_plan: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-testing/plans/{RestoreTestingPlanName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRestoreTestingPlan",
    Request: type = struct {
        restore_testing_plan_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_testing_plan_name = "RestoreTestingPlanName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_restore_testing_plan) } {
            return .{ .service_metadata = service_metadata, .action = get_restore_testing_plan };
        }
    },
    Response: type = struct {
        restore_testing_plan: struct {
            creation_time: i64,
            creator_request_id: ?[]const u8 = null,
            last_execution_time: ?i64 = null,
            last_update_time: ?i64 = null,
            recovery_point_selection: RestoreTestingRecoveryPointSelection,
            restore_testing_plan_arn: []const u8,
            restore_testing_plan_name: []const u8,
            schedule_expression: []const u8,
            schedule_expression_timezone: ?[]const u8 = null,
            start_window_hours: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "CreationTime",
                    .creator_request_id = "CreatorRequestId",
                    .last_execution_time = "LastExecutionTime",
                    .last_update_time = "LastUpdateTime",
                    .recovery_point_selection = "RecoveryPointSelection",
                    .restore_testing_plan_arn = "RestoreTestingPlanArn",
                    .restore_testing_plan_name = "RestoreTestingPlanName",
                    .schedule_expression = "ScheduleExpression",
                    .schedule_expression_timezone = "ScheduleExpressionTimezone",
                    .start_window_hours = "StartWindowHours",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_testing_plan = "RestoreTestingPlan",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_restore_testing_selection: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-testing/plans/{RestoreTestingPlanName}/selections/{RestoreTestingSelectionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRestoreTestingSelection",
    Request: type = struct {
        restore_testing_plan_name: []const u8,
        restore_testing_selection_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_testing_plan_name = "RestoreTestingPlanName",
                .restore_testing_selection_name = "RestoreTestingSelectionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_restore_testing_selection) } {
            return .{ .service_metadata = service_metadata, .action = get_restore_testing_selection };
        }
    },
    Response: type = struct {
        restore_testing_selection: struct {
            creation_time: i64,
            creator_request_id: ?[]const u8 = null,
            iam_role_arn: []const u8,
            protected_resource_arns: ?[][]const u8 = null,
            protected_resource_conditions: ?ProtectedResourceConditions = null,
            protected_resource_type: []const u8,
            restore_metadata_overrides: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            restore_testing_plan_name: []const u8,
            restore_testing_selection_name: []const u8,
            validation_window_hours: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "CreationTime",
                    .creator_request_id = "CreatorRequestId",
                    .iam_role_arn = "IamRoleArn",
                    .protected_resource_arns = "ProtectedResourceArns",
                    .protected_resource_conditions = "ProtectedResourceConditions",
                    .protected_resource_type = "ProtectedResourceType",
                    .restore_metadata_overrides = "RestoreMetadataOverrides",
                    .restore_testing_plan_name = "RestoreTestingPlanName",
                    .restore_testing_selection_name = "RestoreTestingSelectionName",
                    .validation_window_hours = "ValidationWindowHours",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "restore_metadata_overrides", field_name))
                    return try serializeMap(self.restore_metadata_overrides, self.fieldNameFor("restore_metadata_overrides"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_testing_selection = "RestoreTestingSelection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const get_supported_resource_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/supported-resource-types",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSupportedResourceTypes",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_supported_resource_types) } {
            return .{ .service_metadata = service_metadata, .action = get_supported_resource_types };
        }
    },
    Response: type = struct {
        resource_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_types = "ResourceTypes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ServiceUnavailable,
    },
} = .{};
pub const list_backup_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBackupJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        by_resource_arn: ?[]const u8 = null,
        by_state: ?[]const u8 = null,
        by_backup_vault_name: ?[]const u8 = null,
        by_created_before: ?i64 = null,
        by_created_after: ?i64 = null,
        by_resource_type: ?[]const u8 = null,
        by_account_id: ?[]const u8 = null,
        by_complete_after: ?i64 = null,
        by_complete_before: ?i64 = null,
        by_parent_job_id: ?[]const u8 = null,
        by_message_category: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .by_resource_arn = "resourceArn",
            .by_state = "state",
            .by_backup_vault_name = "backupVaultName",
            .by_created_before = "createdBefore",
            .by_created_after = "createdAfter",
            .by_resource_type = "resourceType",
            .by_account_id = "accountId",
            .by_complete_after = "completeAfter",
            .by_complete_before = "completeBefore",
            .by_parent_job_id = "parentJobId",
            .by_message_category = "messageCategory",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .by_resource_arn = "ByResourceArn",
                .by_state = "ByState",
                .by_backup_vault_name = "ByBackupVaultName",
                .by_created_before = "ByCreatedBefore",
                .by_created_after = "ByCreatedAfter",
                .by_resource_type = "ByResourceType",
                .by_account_id = "ByAccountId",
                .by_complete_after = "ByCompleteAfter",
                .by_complete_before = "ByCompleteBefore",
                .by_parent_job_id = "ByParentJobId",
                .by_message_category = "ByMessageCategory",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_backup_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_backup_jobs };
        }
    },
    Response: type = struct {
        backup_jobs: ?[]struct {
            account_id: ?[]const u8 = null,
            backup_job_id: ?[]const u8 = null,
            backup_vault_name: ?[]const u8 = null,
            backup_vault_arn: ?[]const u8 = null,
            recovery_point_arn: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            creation_date: ?i64 = null,
            completion_date: ?i64 = null,
            state: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            percent_done: ?[]const u8 = null,
            backup_size_in_bytes: ?i64 = null,
            iam_role_arn: ?[]const u8 = null,
            created_by: ?RecoveryPointCreator = null,
            expected_completion_date: ?i64 = null,
            start_by: ?i64 = null,
            resource_type: ?[]const u8 = null,
            bytes_transferred: ?i64 = null,
            backup_options: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            backup_type: ?[]const u8 = null,
            parent_job_id: ?[]const u8 = null,
            is_parent: ?bool = null,
            resource_name: ?[]const u8 = null,
            initiation_date: ?i64 = null,
            message_category: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "AccountId",
                    .backup_job_id = "BackupJobId",
                    .backup_vault_name = "BackupVaultName",
                    .backup_vault_arn = "BackupVaultArn",
                    .recovery_point_arn = "RecoveryPointArn",
                    .resource_arn = "ResourceArn",
                    .creation_date = "CreationDate",
                    .completion_date = "CompletionDate",
                    .state = "State",
                    .status_message = "StatusMessage",
                    .percent_done = "PercentDone",
                    .backup_size_in_bytes = "BackupSizeInBytes",
                    .iam_role_arn = "IamRoleArn",
                    .created_by = "CreatedBy",
                    .expected_completion_date = "ExpectedCompletionDate",
                    .start_by = "StartBy",
                    .resource_type = "ResourceType",
                    .bytes_transferred = "BytesTransferred",
                    .backup_options = "BackupOptions",
                    .backup_type = "BackupType",
                    .parent_job_id = "ParentJobId",
                    .is_parent = "IsParent",
                    .resource_name = "ResourceName",
                    .initiation_date = "InitiationDate",
                    .message_category = "MessageCategory",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "backup_options", field_name))
                    return try serializeMap(self.backup_options, self.fieldNameFor("backup_options"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_jobs = "BackupJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_backup_job_summaries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/backup-job-summaries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBackupJobSummaries",
    Request: type = struct {
        account_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        message_category: ?[]const u8 = null,
        aggregation_period: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .account_id = "AccountId",
            .state = "State",
            .resource_type = "ResourceType",
            .message_category = "MessageCategory",
            .aggregation_period = "AggregationPeriod",
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .state = "State",
                .resource_type = "ResourceType",
                .message_category = "MessageCategory",
                .aggregation_period = "AggregationPeriod",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_backup_job_summaries) } {
            return .{ .service_metadata = service_metadata, .action = list_backup_job_summaries };
        }
    },
    Response: type = struct {
        backup_job_summaries: ?[]struct {
            region: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            message_category: ?[]const u8 = null,
            count: ?i64 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region = "Region",
                    .account_id = "AccountId",
                    .state = "State",
                    .resource_type = "ResourceType",
                    .message_category = "MessageCategory",
                    .count = "Count",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        aggregation_period: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_job_summaries = "BackupJobSummaries",
                .aggregation_period = "AggregationPeriod",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_backup_plans: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup/plans",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBackupPlans",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        include_deleted: ?bool = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .include_deleted = "includeDeleted",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .include_deleted = "IncludeDeleted",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_backup_plans) } {
            return .{ .service_metadata = service_metadata, .action = list_backup_plans };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        backup_plans_list: ?[]BackupPlansListMember = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .backup_plans_list = "BackupPlansList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_backup_plan_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup/template/plans",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBackupPlanTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_backup_plan_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_backup_plan_templates };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        backup_plan_templates_list: ?[]struct {
            backup_plan_template_id: ?[]const u8 = null,
            backup_plan_template_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .backup_plan_template_id = "BackupPlanTemplateId",
                    .backup_plan_template_name = "BackupPlanTemplateName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .backup_plan_templates_list = "BackupPlanTemplatesList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_backup_plan_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup/plans/{BackupPlanId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBackupPlanVersions",
    Request: type = struct {
        backup_plan_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_backup_plan_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_backup_plan_versions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        backup_plan_versions_list: ?[]BackupPlansListMember = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .backup_plan_versions_list = "BackupPlanVersionsList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_backup_selections: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup/plans/{BackupPlanId}/selections",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBackupSelections",
    Request: type = struct {
        backup_plan_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_backup_selections) } {
            return .{ .service_metadata = service_metadata, .action = list_backup_selections };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        backup_selections_list: ?[]struct {
            selection_id: ?[]const u8 = null,
            selection_name: ?[]const u8 = null,
            backup_plan_id: ?[]const u8 = null,
            creation_date: ?i64 = null,
            creator_request_id: ?[]const u8 = null,
            iam_role_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .selection_id = "SelectionId",
                    .selection_name = "SelectionName",
                    .backup_plan_id = "BackupPlanId",
                    .creation_date = "CreationDate",
                    .creator_request_id = "CreatorRequestId",
                    .iam_role_arn = "IamRoleArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .backup_selections_list = "BackupSelectionsList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_backup_vaults: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup-vaults",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBackupVaults",
    Request: type = struct {
        by_vault_type: ?[]const u8 = null,
        by_shared: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .by_vault_type = "vaultType",
            .by_shared = "shared",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .by_vault_type = "ByVaultType",
                .by_shared = "ByShared",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_backup_vaults) } {
            return .{ .service_metadata = service_metadata, .action = list_backup_vaults };
        }
    },
    Response: type = struct {
        backup_vault_list: ?[]struct {
            backup_vault_name: ?[]const u8 = null,
            backup_vault_arn: ?[]const u8 = null,
            creation_date: ?i64 = null,
            encryption_key_arn: ?[]const u8 = null,
            creator_request_id: ?[]const u8 = null,
            number_of_recovery_points: ?i64 = null,
            locked: ?bool = null,
            min_retention_days: ?i64 = null,
            max_retention_days: ?i64 = null,
            lock_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .backup_vault_name = "BackupVaultName",
                    .backup_vault_arn = "BackupVaultArn",
                    .creation_date = "CreationDate",
                    .encryption_key_arn = "EncryptionKeyArn",
                    .creator_request_id = "CreatorRequestId",
                    .number_of_recovery_points = "NumberOfRecoveryPoints",
                    .locked = "Locked",
                    .min_retention_days = "MinRetentionDays",
                    .max_retention_days = "MaxRetentionDays",
                    .lock_date = "LockDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_list = "BackupVaultList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_copy_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/copy-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCopyJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        by_resource_arn: ?[]const u8 = null,
        by_state: ?[]const u8 = null,
        by_created_before: ?i64 = null,
        by_created_after: ?i64 = null,
        by_resource_type: ?[]const u8 = null,
        by_destination_vault_arn: ?[]const u8 = null,
        by_account_id: ?[]const u8 = null,
        by_complete_before: ?i64 = null,
        by_complete_after: ?i64 = null,
        by_parent_job_id: ?[]const u8 = null,
        by_message_category: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .by_resource_arn = "resourceArn",
            .by_state = "state",
            .by_created_before = "createdBefore",
            .by_created_after = "createdAfter",
            .by_resource_type = "resourceType",
            .by_destination_vault_arn = "destinationVaultArn",
            .by_account_id = "accountId",
            .by_complete_before = "completeBefore",
            .by_complete_after = "completeAfter",
            .by_parent_job_id = "parentJobId",
            .by_message_category = "messageCategory",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .by_resource_arn = "ByResourceArn",
                .by_state = "ByState",
                .by_created_before = "ByCreatedBefore",
                .by_created_after = "ByCreatedAfter",
                .by_resource_type = "ByResourceType",
                .by_destination_vault_arn = "ByDestinationVaultArn",
                .by_account_id = "ByAccountId",
                .by_complete_before = "ByCompleteBefore",
                .by_complete_after = "ByCompleteAfter",
                .by_parent_job_id = "ByParentJobId",
                .by_message_category = "ByMessageCategory",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_copy_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_copy_jobs };
        }
    },
    Response: type = struct {
        copy_jobs: ?[]CopyJob = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .copy_jobs = "CopyJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_copy_job_summaries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/copy-job-summaries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListCopyJobSummaries",
    Request: type = struct {
        account_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        message_category: ?[]const u8 = null,
        aggregation_period: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .account_id = "AccountId",
            .state = "State",
            .resource_type = "ResourceType",
            .message_category = "MessageCategory",
            .aggregation_period = "AggregationPeriod",
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .state = "State",
                .resource_type = "ResourceType",
                .message_category = "MessageCategory",
                .aggregation_period = "AggregationPeriod",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_copy_job_summaries) } {
            return .{ .service_metadata = service_metadata, .action = list_copy_job_summaries };
        }
    },
    Response: type = struct {
        copy_job_summaries: ?[]struct {
            region: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            message_category: ?[]const u8 = null,
            count: ?i64 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region = "Region",
                    .account_id = "AccountId",
                    .state = "State",
                    .resource_type = "ResourceType",
                    .message_category = "MessageCategory",
                    .count = "Count",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        aggregation_period: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .copy_job_summaries = "CopyJobSummaries",
                .aggregation_period = "AggregationPeriod",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_frameworks: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/frameworks",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFrameworks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_frameworks) } {
            return .{ .service_metadata = service_metadata, .action = list_frameworks };
        }
    },
    Response: type = struct {
        frameworks: ?[]struct {
            framework_name: ?[]const u8 = null,
            framework_arn: ?[]const u8 = null,
            framework_description: ?[]const u8 = null,
            number_of_controls: ?i64 = null,
            creation_time: ?i64 = null,
            deployment_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .framework_name = "FrameworkName",
                    .framework_arn = "FrameworkArn",
                    .framework_description = "FrameworkDescription",
                    .number_of_controls = "NumberOfControls",
                    .creation_time = "CreationTime",
                    .deployment_status = "DeploymentStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .frameworks = "Frameworks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_legal_holds: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/legal-holds",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLegalHolds",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_legal_holds) } {
            return .{ .service_metadata = service_metadata, .action = list_legal_holds };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        legal_holds: ?[]struct {
            title: ?[]const u8 = null,
            status: ?[]const u8 = null,
            description: ?[]const u8 = null,
            legal_hold_id: ?[]const u8 = null,
            legal_hold_arn: ?[]const u8 = null,
            creation_date: ?i64 = null,
            cancellation_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .title = "Title",
                    .status = "Status",
                    .description = "Description",
                    .legal_hold_id = "LegalHoldId",
                    .legal_hold_arn = "LegalHoldArn",
                    .creation_date = "CreationDate",
                    .cancellation_date = "CancellationDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .legal_holds = "LegalHolds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_protected_resources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProtectedResources",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_protected_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_protected_resources };
        }
    },
    Response: type = struct {
        results: ?[]ProtectedResource = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_protected_resources_by_backup_vault: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup-vaults/{BackupVaultName}/resources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProtectedResourcesByBackupVault",
    Request: type = struct {
        backup_vault_name: []const u8,
        backup_vault_account_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .backup_vault_account_id = "backupVaultAccountId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .backup_vault_account_id = "BackupVaultAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_protected_resources_by_backup_vault) } {
            return .{ .service_metadata = service_metadata, .action = list_protected_resources_by_backup_vault };
        }
    },
    Response: type = struct {
        results: ?[]ProtectedResource = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_recovery_points_by_backup_vault: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/backup-vaults/{BackupVaultName}/recovery-points",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecoveryPointsByBackupVault",
    Request: type = struct {
        backup_vault_name: []const u8,
        backup_vault_account_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        by_resource_arn: ?[]const u8 = null,
        by_resource_type: ?[]const u8 = null,
        by_backup_plan_id: ?[]const u8 = null,
        by_created_before: ?i64 = null,
        by_created_after: ?i64 = null,
        by_parent_recovery_point_arn: ?[]const u8 = null,

        pub const http_query = .{
            .backup_vault_account_id = "backupVaultAccountId",
            .next_token = "nextToken",
            .max_results = "maxResults",
            .by_resource_arn = "resourceArn",
            .by_resource_type = "resourceType",
            .by_backup_plan_id = "backupPlanId",
            .by_created_before = "createdBefore",
            .by_created_after = "createdAfter",
            .by_parent_recovery_point_arn = "parentRecoveryPointArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .backup_vault_account_id = "BackupVaultAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .by_resource_arn = "ByResourceArn",
                .by_resource_type = "ByResourceType",
                .by_backup_plan_id = "ByBackupPlanId",
                .by_created_before = "ByCreatedBefore",
                .by_created_after = "ByCreatedAfter",
                .by_parent_recovery_point_arn = "ByParentRecoveryPointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recovery_points_by_backup_vault) } {
            return .{ .service_metadata = service_metadata, .action = list_recovery_points_by_backup_vault };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recovery_points: ?[]struct {
            recovery_point_arn: ?[]const u8 = null,
            backup_vault_name: ?[]const u8 = null,
            backup_vault_arn: ?[]const u8 = null,
            source_backup_vault_arn: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            created_by: ?RecoveryPointCreator = null,
            iam_role_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            creation_date: ?i64 = null,
            completion_date: ?i64 = null,
            backup_size_in_bytes: ?i64 = null,
            calculated_lifecycle: ?CalculatedLifecycle = null,
            lifecycle: ?Lifecycle = null,
            encryption_key_arn: ?[]const u8 = null,
            is_encrypted: ?bool = null,
            last_restore_time: ?i64 = null,
            parent_recovery_point_arn: ?[]const u8 = null,
            composite_member_identifier: ?[]const u8 = null,
            is_parent: ?bool = null,
            resource_name: ?[]const u8 = null,
            vault_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recovery_point_arn = "RecoveryPointArn",
                    .backup_vault_name = "BackupVaultName",
                    .backup_vault_arn = "BackupVaultArn",
                    .source_backup_vault_arn = "SourceBackupVaultArn",
                    .resource_arn = "ResourceArn",
                    .resource_type = "ResourceType",
                    .created_by = "CreatedBy",
                    .iam_role_arn = "IamRoleArn",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .creation_date = "CreationDate",
                    .completion_date = "CompletionDate",
                    .backup_size_in_bytes = "BackupSizeInBytes",
                    .calculated_lifecycle = "CalculatedLifecycle",
                    .lifecycle = "Lifecycle",
                    .encryption_key_arn = "EncryptionKeyArn",
                    .is_encrypted = "IsEncrypted",
                    .last_restore_time = "LastRestoreTime",
                    .parent_recovery_point_arn = "ParentRecoveryPointArn",
                    .composite_member_identifier = "CompositeMemberIdentifier",
                    .is_parent = "IsParent",
                    .resource_name = "ResourceName",
                    .vault_type = "VaultType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .recovery_points = "RecoveryPoints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_recovery_points_by_legal_hold: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/legal-holds/{LegalHoldId}/recovery-points",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecoveryPointsByLegalHold",
    Request: type = struct {
        legal_hold_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .legal_hold_id = "LegalHoldId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recovery_points_by_legal_hold) } {
            return .{ .service_metadata = service_metadata, .action = list_recovery_points_by_legal_hold };
        }
    },
    Response: type = struct {
        recovery_points: ?[]struct {
            recovery_point_arn: ?[]const u8 = null,
            resource_arn: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            backup_vault_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recovery_point_arn = "RecoveryPointArn",
                    .resource_arn = "ResourceArn",
                    .resource_type = "ResourceType",
                    .backup_vault_name = "BackupVaultName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recovery_points = "RecoveryPoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_recovery_points_by_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resources/{ResourceArn}/recovery-points",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecoveryPointsByResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recovery_points_by_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_recovery_points_by_resource };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recovery_points: ?[]struct {
            recovery_point_arn: ?[]const u8 = null,
            creation_date: ?i64 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            encryption_key_arn: ?[]const u8 = null,
            backup_size_bytes: ?i64 = null,
            backup_vault_name: ?[]const u8 = null,
            is_parent: ?bool = null,
            parent_recovery_point_arn: ?[]const u8 = null,
            resource_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recovery_point_arn = "RecoveryPointArn",
                    .creation_date = "CreationDate",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .encryption_key_arn = "EncryptionKeyArn",
                    .backup_size_bytes = "BackupSizeBytes",
                    .backup_vault_name = "BackupVaultName",
                    .is_parent = "IsParent",
                    .parent_recovery_point_arn = "ParentRecoveryPointArn",
                    .resource_name = "ResourceName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .recovery_points = "RecoveryPoints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_report_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/report-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReportJobs",
    Request: type = struct {
        by_report_plan_name: ?[]const u8 = null,
        by_creation_before: ?i64 = null,
        by_creation_after: ?i64 = null,
        by_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .by_report_plan_name = "ReportPlanName",
            .by_creation_before = "CreationBefore",
            .by_creation_after = "CreationAfter",
            .by_status = "Status",
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .by_report_plan_name = "ByReportPlanName",
                .by_creation_before = "ByCreationBefore",
                .by_creation_after = "ByCreationAfter",
                .by_status = "ByStatus",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_report_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_report_jobs };
        }
    },
    Response: type = struct {
        report_jobs: ?[]ReportJob = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_jobs = "ReportJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_report_plans: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/report-plans",
        .success_code = 200,
    };

    action_name: []const u8 = "ListReportPlans",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_report_plans) } {
            return .{ .service_metadata = service_metadata, .action = list_report_plans };
        }
    },
    Response: type = struct {
        report_plans: ?[]ReportPlan = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_plans = "ReportPlans",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_restore_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRestoreJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        by_account_id: ?[]const u8 = null,
        by_resource_type: ?[]const u8 = null,
        by_created_before: ?i64 = null,
        by_created_after: ?i64 = null,
        by_status: ?[]const u8 = null,
        by_complete_before: ?i64 = null,
        by_complete_after: ?i64 = null,
        by_restore_testing_plan_arn: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .by_account_id = "accountId",
            .by_resource_type = "resourceType",
            .by_created_before = "createdBefore",
            .by_created_after = "createdAfter",
            .by_status = "status",
            .by_complete_before = "completeBefore",
            .by_complete_after = "completeAfter",
            .by_restore_testing_plan_arn = "restoreTestingPlanArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .by_account_id = "ByAccountId",
                .by_resource_type = "ByResourceType",
                .by_created_before = "ByCreatedBefore",
                .by_created_after = "ByCreatedAfter",
                .by_status = "ByStatus",
                .by_complete_before = "ByCompleteBefore",
                .by_complete_after = "ByCompleteAfter",
                .by_restore_testing_plan_arn = "ByRestoreTestingPlanArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_restore_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_restore_jobs };
        }
    },
    Response: type = struct {
        restore_jobs: ?[]RestoreJobsListMember = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_jobs = "RestoreJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_restore_jobs_by_protected_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resources/{ResourceArn}/restore-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRestoreJobsByProtectedResource",
    Request: type = struct {
        resource_arn: []const u8,
        by_status: ?[]const u8 = null,
        by_recovery_point_creation_date_after: ?i64 = null,
        by_recovery_point_creation_date_before: ?i64 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .by_status = "status",
            .by_recovery_point_creation_date_after = "recoveryPointCreationDateAfter",
            .by_recovery_point_creation_date_before = "recoveryPointCreationDateBefore",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .by_status = "ByStatus",
                .by_recovery_point_creation_date_after = "ByRecoveryPointCreationDateAfter",
                .by_recovery_point_creation_date_before = "ByRecoveryPointCreationDateBefore",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_restore_jobs_by_protected_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_restore_jobs_by_protected_resource };
        }
    },
    Response: type = struct {
        restore_jobs: ?[]RestoreJobsListMember = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_jobs = "RestoreJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_restore_job_summaries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/audit/restore-job-summaries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRestoreJobSummaries",
    Request: type = struct {
        account_id: ?[]const u8 = null,
        state: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        aggregation_period: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .account_id = "AccountId",
            .state = "State",
            .resource_type = "ResourceType",
            .aggregation_period = "AggregationPeriod",
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .state = "State",
                .resource_type = "ResourceType",
                .aggregation_period = "AggregationPeriod",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_restore_job_summaries) } {
            return .{ .service_metadata = service_metadata, .action = list_restore_job_summaries };
        }
    },
    Response: type = struct {
        restore_job_summaries: ?[]struct {
            region: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            resource_type: ?[]const u8 = null,
            count: ?i64 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .region = "Region",
                    .account_id = "AccountId",
                    .state = "State",
                    .resource_type = "ResourceType",
                    .count = "Count",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        aggregation_period: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_job_summaries = "RestoreJobSummaries",
                .aggregation_period = "AggregationPeriod",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_restore_testing_plans: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-testing/plans",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRestoreTestingPlans",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_restore_testing_plans) } {
            return .{ .service_metadata = service_metadata, .action = list_restore_testing_plans };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        restore_testing_plans: []struct {
            creation_time: i64,
            last_execution_time: ?i64 = null,
            last_update_time: ?i64 = null,
            restore_testing_plan_arn: []const u8,
            restore_testing_plan_name: []const u8,
            schedule_expression: []const u8,
            schedule_expression_timezone: ?[]const u8 = null,
            start_window_hours: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "CreationTime",
                    .last_execution_time = "LastExecutionTime",
                    .last_update_time = "LastUpdateTime",
                    .restore_testing_plan_arn = "RestoreTestingPlanArn",
                    .restore_testing_plan_name = "RestoreTestingPlanName",
                    .schedule_expression = "ScheduleExpression",
                    .schedule_expression_timezone = "ScheduleExpressionTimezone",
                    .start_window_hours = "StartWindowHours",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .restore_testing_plans = "RestoreTestingPlans",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const list_restore_testing_selections: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/restore-testing/plans/{RestoreTestingPlanName}/selections",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRestoreTestingSelections",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        restore_testing_plan_name: []const u8,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .restore_testing_plan_name = "RestoreTestingPlanName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_restore_testing_selections) } {
            return .{ .service_metadata = service_metadata, .action = list_restore_testing_selections };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        restore_testing_selections: []struct {
            creation_time: i64,
            iam_role_arn: []const u8,
            protected_resource_type: []const u8,
            restore_testing_plan_name: []const u8,
            restore_testing_selection_name: []const u8,
            validation_window_hours: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "CreationTime",
                    .iam_role_arn = "IamRoleArn",
                    .protected_resource_type = "ProtectedResourceType",
                    .restore_testing_plan_name = "RestoreTestingPlanName",
                    .restore_testing_selection_name = "RestoreTestingSelectionName",
                    .validation_window_hours = "ValidationWindowHours",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .restore_testing_selections = "RestoreTestingSelections",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTags",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const put_backup_vault_access_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup-vaults/{BackupVaultName}/access-policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBackupVaultAccessPolicy",
    Request: type = struct {
        backup_vault_name: []const u8,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_backup_vault_access_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_backup_vault_access_policy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const put_backup_vault_lock_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup-vaults/{BackupVaultName}/vault-lock",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBackupVaultLockConfiguration",
    Request: type = struct {
        backup_vault_name: []const u8,
        min_retention_days: ?i64 = null,
        max_retention_days: ?i64 = null,
        changeable_for_days: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .min_retention_days = "MinRetentionDays",
                .max_retention_days = "MaxRetentionDays",
                .changeable_for_days = "ChangeableForDays",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_backup_vault_lock_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_backup_vault_lock_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const put_backup_vault_notifications: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup-vaults/{BackupVaultName}/notification-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBackupVaultNotifications",
    Request: type = struct {
        backup_vault_name: []const u8,
        sns_topic_arn: []const u8,
        backup_vault_events: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .sns_topic_arn = "SNSTopicArn",
                .backup_vault_events = "BackupVaultEvents",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_backup_vault_notifications) } {
            return .{ .service_metadata = service_metadata, .action = put_backup_vault_notifications };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const put_restore_validation_result: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restore-jobs/{RestoreJobId}/validations",
        .success_code = 204,
    };

    action_name: []const u8 = "PutRestoreValidationResult",
    Request: type = struct {
        restore_job_id: []const u8,
        validation_status: []const u8,
        validation_status_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_job_id = "RestoreJobId",
                .validation_status = "ValidationStatus",
                .validation_status_message = "ValidationStatusMessage",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_restore_validation_result) } {
            return .{ .service_metadata = service_metadata, .action = put_restore_validation_result };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const start_backup_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/backup-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "StartBackupJob",
    Request: type = struct {
        backup_vault_name: []const u8,
        resource_arn: []const u8,
        iam_role_arn: []const u8,
        idempotency_token: ?[]const u8 = null,
        start_window_minutes: ?i64 = null,
        complete_window_minutes: ?i64 = null,
        lifecycle: ?Lifecycle = null,
        recovery_point_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        backup_options: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .resource_arn = "ResourceArn",
                .iam_role_arn = "IamRoleArn",
                .idempotency_token = "IdempotencyToken",
                .start_window_minutes = "StartWindowMinutes",
                .complete_window_minutes = "CompleteWindowMinutes",
                .lifecycle = "Lifecycle",
                .recovery_point_tags = "RecoveryPointTags",
                .backup_options = "BackupOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "recovery_point_tags", field_name))
                return try serializeMap(self.recovery_point_tags, self.fieldNameFor("recovery_point_tags"), options, out_stream);
            if (std.mem.eql(u8, "backup_options", field_name))
                return try serializeMap(self.backup_options, self.fieldNameFor("backup_options"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_backup_job) } {
            return .{ .service_metadata = service_metadata, .action = start_backup_job };
        }
    },
    Response: type = struct {
        backup_job_id: ?[]const u8 = null,
        recovery_point_arn: ?[]const u8 = null,
        creation_date: ?i64 = null,
        is_parent: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_job_id = "BackupJobId",
                .recovery_point_arn = "RecoveryPointArn",
                .creation_date = "CreationDate",
                .is_parent = "IsParent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        LimitExceeded,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const start_copy_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/copy-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "StartCopyJob",
    Request: type = struct {
        recovery_point_arn: []const u8,
        source_backup_vault_name: []const u8,
        destination_backup_vault_arn: []const u8,
        iam_role_arn: []const u8,
        idempotency_token: ?[]const u8 = null,
        lifecycle: ?Lifecycle = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recovery_point_arn = "RecoveryPointArn",
                .source_backup_vault_name = "SourceBackupVaultName",
                .destination_backup_vault_arn = "DestinationBackupVaultArn",
                .iam_role_arn = "IamRoleArn",
                .idempotency_token = "IdempotencyToken",
                .lifecycle = "Lifecycle",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_copy_job) } {
            return .{ .service_metadata = service_metadata, .action = start_copy_job };
        }
    },
    Response: type = struct {
        copy_job_id: ?[]const u8 = null,
        creation_date: ?i64 = null,
        is_parent: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .copy_job_id = "CopyJobId",
                .creation_date = "CreationDate",
                .is_parent = "IsParent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        LimitExceeded,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const start_report_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/audit/report-jobs/{ReportPlanName}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartReportJob",
    Request: type = struct {
        report_plan_name: []const u8,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_plan_name = "ReportPlanName",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_report_job) } {
            return .{ .service_metadata = service_metadata, .action = start_report_job };
        }
    },
    Response: type = struct {
        report_job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_job_id = "ReportJobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const start_restore_job: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restore-jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "StartRestoreJob",
    Request: type = struct {
        recovery_point_arn: []const u8,
        metadata: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },
        iam_role_arn: ?[]const u8 = null,
        idempotency_token: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,
        copy_source_tags_to_restored_resource: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recovery_point_arn = "RecoveryPointArn",
                .metadata = "Metadata",
                .iam_role_arn = "IamRoleArn",
                .idempotency_token = "IdempotencyToken",
                .resource_type = "ResourceType",
                .copy_source_tags_to_restored_resource = "CopySourceTagsToRestoredResource",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata", field_name))
                return try serializeMap(self.metadata, self.fieldNameFor("metadata"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_restore_job) } {
            return .{ .service_metadata = service_metadata, .action = start_restore_job };
        }
    },
    Response: type = struct {
        restore_job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_job_id = "RestoreJobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const stop_backup_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backup-jobs/{BackupJobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "StopBackupJob",
    Request: type = struct {
        backup_job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_job_id = "BackupJobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_backup_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_backup_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/untag/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_key_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_key_list = "TagKeyList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const update_backup_plan: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backup/plans/{BackupPlanId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBackupPlan",
    Request: type = struct {
        backup_plan_id: []const u8,
        backup_plan: BackupPlanInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
                .backup_plan = "BackupPlan",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_backup_plan) } {
            return .{ .service_metadata = service_metadata, .action = update_backup_plan };
        }
    },
    Response: type = struct {
        backup_plan_id: ?[]const u8 = null,
        backup_plan_arn: ?[]const u8 = null,
        creation_date: ?i64 = null,
        version_id: ?[]const u8 = null,
        advanced_backup_settings: ?[]AdvancedBackupSetting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_plan_id = "BackupPlanId",
                .backup_plan_arn = "BackupPlanArn",
                .creation_date = "CreationDate",
                .version_id = "VersionId",
                .advanced_backup_settings = "AdvancedBackupSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const update_framework: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/audit/frameworks/{FrameworkName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFramework",
    Request: type = struct {
        framework_name: []const u8,
        framework_description: ?[]const u8 = null,
        framework_controls: ?[]FrameworkControl = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_name = "FrameworkName",
                .framework_description = "FrameworkDescription",
                .framework_controls = "FrameworkControls",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_framework) } {
            return .{ .service_metadata = service_metadata, .action = update_framework };
        }
    },
    Response: type = struct {
        framework_name: ?[]const u8 = null,
        framework_arn: ?[]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .framework_name = "FrameworkName",
                .framework_arn = "FrameworkArn",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        Conflict,
        InvalidParameterValue,
        LimitExceeded,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const update_global_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/global-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGlobalSettings",
    Request: type = struct {
        global_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .global_settings = "GlobalSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "global_settings", field_name))
                return try serializeMap(self.global_settings, self.fieldNameFor("global_settings"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_global_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_global_settings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const update_recovery_point_lifecycle: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/backup-vaults/{BackupVaultName}/recovery-points/{RecoveryPointArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRecoveryPointLifecycle",
    Request: type = struct {
        backup_vault_name: []const u8,
        recovery_point_arn: []const u8,
        lifecycle: ?Lifecycle = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_name = "BackupVaultName",
                .recovery_point_arn = "RecoveryPointArn",
                .lifecycle = "Lifecycle",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_recovery_point_lifecycle) } {
            return .{ .service_metadata = service_metadata, .action = update_recovery_point_lifecycle };
        }
    },
    Response: type = struct {
        backup_vault_arn: ?[]const u8 = null,
        recovery_point_arn: ?[]const u8 = null,
        lifecycle: ?Lifecycle = null,
        calculated_lifecycle: ?CalculatedLifecycle = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_vault_arn = "BackupVaultArn",
                .recovery_point_arn = "RecoveryPointArn",
                .lifecycle = "Lifecycle",
                .calculated_lifecycle = "CalculatedLifecycle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValue,
        InvalidRequest,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const update_region_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/account-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRegionSettings",
    Request: type = struct {
        resource_type_opt_in_preference: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,
        resource_type_management_preference: ?[]struct {
            key: ?[]const u8 = null,
            value: ?bool = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_type_opt_in_preference = "ResourceTypeOptInPreference",
                .resource_type_management_preference = "ResourceTypeManagementPreference",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "resource_type_opt_in_preference", field_name))
                return try serializeMap(self.resource_type_opt_in_preference, self.fieldNameFor("resource_type_opt_in_preference"), options, out_stream);
            if (std.mem.eql(u8, "resource_type_management_preference", field_name))
                return try serializeMap(self.resource_type_management_preference, self.fieldNameFor("resource_type_management_preference"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_region_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_region_settings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidParameterValue,
        MissingParameterValue,
        ServiceUnavailable,
    },
} = .{};
pub const update_report_plan: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/audit/report-plans/{ReportPlanName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateReportPlan",
    Request: type = struct {
        report_plan_name: []const u8,
        report_plan_description: ?[]const u8 = null,
        report_delivery_channel: ?ReportDeliveryChannel = null,
        report_setting: ?ReportSetting = null,
        idempotency_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_plan_name = "ReportPlanName",
                .report_plan_description = "ReportPlanDescription",
                .report_delivery_channel = "ReportDeliveryChannel",
                .report_setting = "ReportSetting",
                .idempotency_token = "IdempotencyToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_report_plan) } {
            return .{ .service_metadata = service_metadata, .action = update_report_plan };
        }
    },
    Response: type = struct {
        report_plan_name: ?[]const u8 = null,
        report_plan_arn: ?[]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_plan_name = "ReportPlanName",
                .report_plan_arn = "ReportPlanArn",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const update_restore_testing_plan: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restore-testing/plans/{RestoreTestingPlanName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRestoreTestingPlan",
    Request: type = struct {
        restore_testing_plan: struct {
            recovery_point_selection: ?RestoreTestingRecoveryPointSelection = null,
            schedule_expression: ?[]const u8 = null,
            schedule_expression_timezone: ?[]const u8 = null,
            start_window_hours: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recovery_point_selection = "RecoveryPointSelection",
                    .schedule_expression = "ScheduleExpression",
                    .schedule_expression_timezone = "ScheduleExpressionTimezone",
                    .start_window_hours = "StartWindowHours",
                };
                return @field(mappings, field_name);
            }
        },
        restore_testing_plan_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_testing_plan = "RestoreTestingPlan",
                .restore_testing_plan_name = "RestoreTestingPlanName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_restore_testing_plan) } {
            return .{ .service_metadata = service_metadata, .action = update_restore_testing_plan };
        }
    },
    Response: type = struct {
        creation_time: i64,
        restore_testing_plan_arn: []const u8,
        restore_testing_plan_name: []const u8,
        update_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "CreationTime",
                .restore_testing_plan_arn = "RestoreTestingPlanArn",
                .restore_testing_plan_name = "RestoreTestingPlanName",
                .update_time = "UpdateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const update_restore_testing_selection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/restore-testing/plans/{RestoreTestingPlanName}/selections/{RestoreTestingSelectionName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRestoreTestingSelection",
    Request: type = struct {
        restore_testing_plan_name: []const u8,
        restore_testing_selection: struct {
            iam_role_arn: ?[]const u8 = null,
            protected_resource_arns: ?[][]const u8 = null,
            protected_resource_conditions: ?ProtectedResourceConditions = null,
            restore_metadata_overrides: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            validation_window_hours: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .iam_role_arn = "IamRoleArn",
                    .protected_resource_arns = "ProtectedResourceArns",
                    .protected_resource_conditions = "ProtectedResourceConditions",
                    .restore_metadata_overrides = "RestoreMetadataOverrides",
                    .validation_window_hours = "ValidationWindowHours",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "restore_metadata_overrides", field_name))
                    return try serializeMap(self.restore_metadata_overrides, self.fieldNameFor("restore_metadata_overrides"), options, out_stream);
                return false;
            }
        },
        restore_testing_selection_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .restore_testing_plan_name = "RestoreTestingPlanName",
                .restore_testing_selection = "RestoreTestingSelection",
                .restore_testing_selection_name = "RestoreTestingSelectionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_restore_testing_selection) } {
            return .{ .service_metadata = service_metadata, .action = update_restore_testing_selection };
        }
    },
    Response: type = struct {
        creation_time: i64,
        restore_testing_plan_arn: []const u8,
        restore_testing_plan_name: []const u8,
        restore_testing_selection_name: []const u8,
        update_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "CreationTime",
                .restore_testing_plan_arn = "RestoreTestingPlanArn",
                .restore_testing_plan_name = "RestoreTestingPlanName",
                .restore_testing_selection_name = "RestoreTestingSelectionName",
                .update_time = "UpdateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InvalidParameterValue,
        MissingParameterValue,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};

pub const ProtectedResourceConditions = struct {
    string_equals: ?[]KeyValue = null,
    string_not_equals: ?[]KeyValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_equals = "StringEquals",
            .string_not_equals = "StringNotEquals",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyValue = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RestoreTestingRecoveryPointSelection = struct {
    algorithm: ?[]const u8 = null,
    exclude_vaults: ?[][]const u8 = null,
    include_vaults: ?[][]const u8 = null,
    recovery_point_types: ?[][]const u8 = null,
    selection_window_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .algorithm = "Algorithm",
            .exclude_vaults = "ExcludeVaults",
            .include_vaults = "IncludeVaults",
            .recovery_point_types = "RecoveryPointTypes",
            .selection_window_days = "SelectionWindowDays",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportSetting = struct {
    report_template: []const u8,
    framework_arns: ?[][]const u8 = null,
    number_of_frameworks: ?i64 = null,
    accounts: ?[][]const u8 = null,
    organization_units: ?[][]const u8 = null,
    regions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report_template = "ReportTemplate",
            .framework_arns = "FrameworkArns",
            .number_of_frameworks = "NumberOfFrameworks",
            .accounts = "Accounts",
            .organization_units = "OrganizationUnits",
            .regions = "Regions",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportDeliveryChannel = struct {
    s3_bucket_name: []const u8,
    s3_key_prefix: ?[]const u8 = null,
    formats: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "S3BucketName",
            .s3_key_prefix = "S3KeyPrefix",
            .formats = "Formats",
        };
        return @field(mappings, field_name);
    }
};

pub const CalculatedLifecycle = struct {
    move_to_cold_storage_at: ?i64 = null,
    delete_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .move_to_cold_storage_at = "MoveToColdStorageAt",
            .delete_at = "DeleteAt",
        };
        return @field(mappings, field_name);
    }
};

pub const Lifecycle = struct {
    move_to_cold_storage_after_days: ?i64 = null,
    delete_after_days: ?i64 = null,
    opt_in_to_archive_for_supported_resources: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .move_to_cold_storage_after_days = "MoveToColdStorageAfterDays",
            .delete_after_days = "DeleteAfterDays",
            .opt_in_to_archive_for_supported_resources = "OptInToArchiveForSupportedResources",
        };
        return @field(mappings, field_name);
    }
};

pub const FrameworkControl = struct {
    control_name: []const u8,
    control_input_parameters: ?[]ControlInputParameter = null,
    control_scope: ?ControlScope = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .control_name = "ControlName",
            .control_input_parameters = "ControlInputParameters",
            .control_scope = "ControlScope",
        };
        return @field(mappings, field_name);
    }
};

pub const ControlScope = struct {
    compliance_resource_ids: ?[][]const u8 = null,
    compliance_resource_types: ?[][]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .compliance_resource_ids = "ComplianceResourceIds",
            .compliance_resource_types = "ComplianceResourceTypes",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ControlInputParameter = struct {
    parameter_name: ?[]const u8 = null,
    parameter_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_name = "ParameterName",
            .parameter_value = "ParameterValue",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedBackupSetting = struct {
    resource_type: ?[]const u8 = null,
    backup_options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "ResourceType",
            .backup_options = "BackupOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "backup_options", field_name))
            return try serializeMap(self.backup_options, self.fieldNameFor("backup_options"), options, out_stream);
        return false;
    }
};

pub const BackupPlanInput = struct {
    backup_plan_name: []const u8,
    rules: []BackupRuleInput,
    advanced_backup_settings: ?[]AdvancedBackupSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_plan_name = "BackupPlanName",
            .rules = "Rules",
            .advanced_backup_settings = "AdvancedBackupSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const BackupRuleInput = struct {
    rule_name: []const u8,
    target_backup_vault_name: []const u8,
    schedule_expression: ?[]const u8 = null,
    start_window_minutes: ?i64 = null,
    completion_window_minutes: ?i64 = null,
    lifecycle: ?Lifecycle = null,
    recovery_point_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    copy_actions: ?[]CopyAction = null,
    enable_continuous_backup: ?bool = null,
    schedule_expression_timezone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_name = "RuleName",
            .target_backup_vault_name = "TargetBackupVaultName",
            .schedule_expression = "ScheduleExpression",
            .start_window_minutes = "StartWindowMinutes",
            .completion_window_minutes = "CompletionWindowMinutes",
            .lifecycle = "Lifecycle",
            .recovery_point_tags = "RecoveryPointTags",
            .copy_actions = "CopyActions",
            .enable_continuous_backup = "EnableContinuousBackup",
            .schedule_expression_timezone = "ScheduleExpressionTimezone",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "recovery_point_tags", field_name))
            return try serializeMap(self.recovery_point_tags, self.fieldNameFor("recovery_point_tags"), options, out_stream);
        return false;
    }
};

pub const CopyAction = struct {
    lifecycle: ?Lifecycle = null,
    destination_backup_vault_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lifecycle = "Lifecycle",
            .destination_backup_vault_arn = "DestinationBackupVaultArn",
        };
        return @field(mappings, field_name);
    }
};

pub const RestoreJobsListMember = struct {
    account_id: ?[]const u8 = null,
    restore_job_id: ?[]const u8 = null,
    recovery_point_arn: ?[]const u8 = null,
    creation_date: ?i64 = null,
    completion_date: ?i64 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    percent_done: ?[]const u8 = null,
    backup_size_in_bytes: ?i64 = null,
    iam_role_arn: ?[]const u8 = null,
    expected_completion_time_minutes: ?i64 = null,
    created_resource_arn: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    recovery_point_creation_date: ?i64 = null,
    created_by: ?RestoreJobCreator = null,
    validation_status: ?[]const u8 = null,
    validation_status_message: ?[]const u8 = null,
    deletion_status: ?[]const u8 = null,
    deletion_status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .restore_job_id = "RestoreJobId",
            .recovery_point_arn = "RecoveryPointArn",
            .creation_date = "CreationDate",
            .completion_date = "CompletionDate",
            .status = "Status",
            .status_message = "StatusMessage",
            .percent_done = "PercentDone",
            .backup_size_in_bytes = "BackupSizeInBytes",
            .iam_role_arn = "IamRoleArn",
            .expected_completion_time_minutes = "ExpectedCompletionTimeMinutes",
            .created_resource_arn = "CreatedResourceArn",
            .resource_type = "ResourceType",
            .recovery_point_creation_date = "RecoveryPointCreationDate",
            .created_by = "CreatedBy",
            .validation_status = "ValidationStatus",
            .validation_status_message = "ValidationStatusMessage",
            .deletion_status = "DeletionStatus",
            .deletion_status_message = "DeletionStatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const RestoreJobCreator = struct {
    restore_testing_plan_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .restore_testing_plan_arn = "RestoreTestingPlanArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportPlan = struct {
    report_plan_arn: ?[]const u8 = null,
    report_plan_name: ?[]const u8 = null,
    report_plan_description: ?[]const u8 = null,
    report_setting: ?ReportSetting = null,
    report_delivery_channel: ?ReportDeliveryChannel = null,
    deployment_status: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_attempted_execution_time: ?i64 = null,
    last_successful_execution_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report_plan_arn = "ReportPlanArn",
            .report_plan_name = "ReportPlanName",
            .report_plan_description = "ReportPlanDescription",
            .report_setting = "ReportSetting",
            .report_delivery_channel = "ReportDeliveryChannel",
            .deployment_status = "DeploymentStatus",
            .creation_time = "CreationTime",
            .last_attempted_execution_time = "LastAttemptedExecutionTime",
            .last_successful_execution_time = "LastSuccessfulExecutionTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportJob = struct {
    report_job_id: ?[]const u8 = null,
    report_plan_arn: ?[]const u8 = null,
    report_template: ?[]const u8 = null,
    creation_time: ?i64 = null,
    completion_time: ?i64 = null,
    status: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    report_destination: ?ReportDestination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report_job_id = "ReportJobId",
            .report_plan_arn = "ReportPlanArn",
            .report_template = "ReportTemplate",
            .creation_time = "CreationTime",
            .completion_time = "CompletionTime",
            .status = "Status",
            .status_message = "StatusMessage",
            .report_destination = "ReportDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const ReportDestination = struct {
    s3_bucket_name: ?[]const u8 = null,
    s3_keys: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "S3BucketName",
            .s3_keys = "S3Keys",
        };
        return @field(mappings, field_name);
    }
};

pub const RecoveryPointCreator = struct {
    backup_plan_id: ?[]const u8 = null,
    backup_plan_arn: ?[]const u8 = null,
    backup_plan_version: ?[]const u8 = null,
    backup_rule_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_plan_id = "BackupPlanId",
            .backup_plan_arn = "BackupPlanArn",
            .backup_plan_version = "BackupPlanVersion",
            .backup_rule_id = "BackupRuleId",
        };
        return @field(mappings, field_name);
    }
};

pub const ProtectedResource = struct {
    resource_arn: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,
    last_backup_time: ?i64 = null,
    resource_name: ?[]const u8 = null,
    last_backup_vault_arn: ?[]const u8 = null,
    last_recovery_point_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .resource_type = "ResourceType",
            .last_backup_time = "LastBackupTime",
            .resource_name = "ResourceName",
            .last_backup_vault_arn = "LastBackupVaultArn",
            .last_recovery_point_arn = "LastRecoveryPointArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CopyJob = struct {
    account_id: ?[]const u8 = null,
    copy_job_id: ?[]const u8 = null,
    source_backup_vault_arn: ?[]const u8 = null,
    source_recovery_point_arn: ?[]const u8 = null,
    destination_backup_vault_arn: ?[]const u8 = null,
    destination_recovery_point_arn: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    creation_date: ?i64 = null,
    completion_date: ?i64 = null,
    state: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    backup_size_in_bytes: ?i64 = null,
    iam_role_arn: ?[]const u8 = null,
    created_by: ?RecoveryPointCreator = null,
    resource_type: ?[]const u8 = null,
    parent_job_id: ?[]const u8 = null,
    is_parent: ?bool = null,
    composite_member_identifier: ?[]const u8 = null,
    number_of_child_jobs: ?i64 = null,
    child_jobs_in_state: ?[]struct {
        key: ?[]const u8 = null,
        value: ?i64 = null,
    } = null,
    resource_name: ?[]const u8 = null,
    message_category: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .account_id = "AccountId",
            .copy_job_id = "CopyJobId",
            .source_backup_vault_arn = "SourceBackupVaultArn",
            .source_recovery_point_arn = "SourceRecoveryPointArn",
            .destination_backup_vault_arn = "DestinationBackupVaultArn",
            .destination_recovery_point_arn = "DestinationRecoveryPointArn",
            .resource_arn = "ResourceArn",
            .creation_date = "CreationDate",
            .completion_date = "CompletionDate",
            .state = "State",
            .status_message = "StatusMessage",
            .backup_size_in_bytes = "BackupSizeInBytes",
            .iam_role_arn = "IamRoleArn",
            .created_by = "CreatedBy",
            .resource_type = "ResourceType",
            .parent_job_id = "ParentJobId",
            .is_parent = "IsParent",
            .composite_member_identifier = "CompositeMemberIdentifier",
            .number_of_child_jobs = "NumberOfChildJobs",
            .child_jobs_in_state = "ChildJobsInState",
            .resource_name = "ResourceName",
            .message_category = "MessageCategory",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "child_jobs_in_state", field_name))
            return try serializeMap(self.child_jobs_in_state, self.fieldNameFor("child_jobs_in_state"), options, out_stream);
        return false;
    }
};

pub const BackupPlansListMember = struct {
    backup_plan_arn: ?[]const u8 = null,
    backup_plan_id: ?[]const u8 = null,
    creation_date: ?i64 = null,
    deletion_date: ?i64 = null,
    version_id: ?[]const u8 = null,
    backup_plan_name: ?[]const u8 = null,
    creator_request_id: ?[]const u8 = null,
    last_execution_date: ?i64 = null,
    advanced_backup_settings: ?[]AdvancedBackupSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_plan_arn = "BackupPlanArn",
            .backup_plan_id = "BackupPlanId",
            .creation_date = "CreationDate",
            .deletion_date = "DeletionDate",
            .version_id = "VersionId",
            .backup_plan_name = "BackupPlanName",
            .creator_request_id = "CreatorRequestId",
            .last_execution_date = "LastExecutionDate",
            .advanced_backup_settings = "AdvancedBackupSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const RecoveryPointSelection = struct {
    vault_names: ?[][]const u8 = null,
    resource_identifiers: ?[][]const u8 = null,
    date_range: ?DateRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vault_names = "VaultNames",
            .resource_identifiers = "ResourceIdentifiers",
            .date_range = "DateRange",
        };
        return @field(mappings, field_name);
    }
};

pub const DateRange = struct {
    from_date: i64,
    to_date: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_date = "FromDate",
            .to_date = "ToDate",
        };
        return @field(mappings, field_name);
    }
};

pub const BackupSelection = struct {
    selection_name: []const u8,
    iam_role_arn: []const u8,
    resources: ?[][]const u8 = null,
    list_of_tags: ?[]Condition = null,
    not_resources: ?[][]const u8 = null,
    conditions: ?Conditions = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selection_name = "SelectionName",
            .iam_role_arn = "IamRoleArn",
            .resources = "Resources",
            .list_of_tags = "ListOfTags",
            .not_resources = "NotResources",
            .conditions = "Conditions",
        };
        return @field(mappings, field_name);
    }
};

pub const Conditions = struct {
    string_equals: ?[]ConditionParameter = null,
    string_not_equals: ?[]ConditionParameter = null,
    string_like: ?[]ConditionParameter = null,
    string_not_like: ?[]ConditionParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_equals = "StringEquals",
            .string_not_equals = "StringNotEquals",
            .string_like = "StringLike",
            .string_not_like = "StringNotLike",
        };
        return @field(mappings, field_name);
    }
};

pub const ConditionParameter = struct {
    condition_key: ?[]const u8 = null,
    condition_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition_key = "ConditionKey",
            .condition_value = "ConditionValue",
        };
        return @field(mappings, field_name);
    }
};

pub const Condition = struct {
    condition_type: []const u8,
    condition_key: []const u8,
    condition_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition_type = "ConditionType",
            .condition_key = "ConditionKey",
            .condition_value = "ConditionValue",
        };
        return @field(mappings, field_name);
    }
};

pub const BackupPlan = struct {
    backup_plan_name: []const u8,
    rules: []BackupRule,
    advanced_backup_settings: ?[]AdvancedBackupSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_plan_name = "BackupPlanName",
            .rules = "Rules",
            .advanced_backup_settings = "AdvancedBackupSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const BackupRule = struct {
    rule_name: []const u8,
    target_backup_vault_name: []const u8,
    schedule_expression: ?[]const u8 = null,
    start_window_minutes: ?i64 = null,
    completion_window_minutes: ?i64 = null,
    lifecycle: ?Lifecycle = null,
    recovery_point_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    rule_id: ?[]const u8 = null,
    copy_actions: ?[]CopyAction = null,
    enable_continuous_backup: ?bool = null,
    schedule_expression_timezone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_name = "RuleName",
            .target_backup_vault_name = "TargetBackupVaultName",
            .schedule_expression = "ScheduleExpression",
            .start_window_minutes = "StartWindowMinutes",
            .completion_window_minutes = "CompletionWindowMinutes",
            .lifecycle = "Lifecycle",
            .recovery_point_tags = "RecoveryPointTags",
            .rule_id = "RuleId",
            .copy_actions = "CopyActions",
            .enable_continuous_backup = "EnableContinuousBackup",
            .schedule_expression_timezone = "ScheduleExpressionTimezone",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "recovery_point_tags", field_name))
            return try serializeMap(self.recovery_point_tags, self.fieldNameFor("recovery_point_tags"), options, out_stream);
        return false;
    }
};
