const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-05-01";
pub const sdk_id: []const u8 = "Chime";
pub const arn_namespace: ?[]const u8 = "chime";
pub const endpoint_prefix: []const u8 = "chime";
pub const sigv4_name: []const u8 = "chime";
pub const name: []const u8 = "UCBuzzConsoleService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-05-01",
    sdk_id: []const u8 = "Chime",
    arn_namespace: ?[]const u8 = "chime",
    endpoint_prefix: []const u8 = "chime",
    sigv4_name: []const u8 = "chime",
    name: []const u8 = "UCBuzzConsoleService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_phone_numbers_with_voice_connector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}?operation=associate-phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociatePhoneNumbersWithVoiceConnector",
    Request: type = struct {
        voice_connector_id: []const u8,
        e164_phone_numbers: [][]const u8,
        force_associate: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .e164_phone_numbers = "E164PhoneNumbers",
                .force_associate = "ForceAssociate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_phone_numbers_with_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = associate_phone_numbers_with_voice_connector };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const associate_phone_numbers_with_voice_connector_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connector-groups/{VoiceConnectorGroupId}?operation=associate-phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociatePhoneNumbersWithVoiceConnectorGroup",
    Request: type = struct {
        voice_connector_group_id: []const u8,
        e164_phone_numbers: [][]const u8,
        force_associate: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group_id = "VoiceConnectorGroupId",
                .e164_phone_numbers = "E164PhoneNumbers",
                .force_associate = "ForceAssociate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_phone_numbers_with_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = associate_phone_numbers_with_voice_connector_group };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const associate_phone_number_with_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/users/{UserId}?operation=associate-phone-number",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociatePhoneNumberWithUser",
    Request: type = struct {
        account_id: []const u8,
        user_id: []const u8,
        e164_phone_number: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_id = "UserId",
                .e164_phone_number = "E164PhoneNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_phone_number_with_user) } {
            return .{ .service_metadata = service_metadata, .action = associate_phone_number_with_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const associate_signin_delegate_groups_with_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}?operation=associate-signin-delegate-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateSigninDelegateGroupsWithAccount",
    Request: type = struct {
        account_id: []const u8,
        signin_delegate_groups: []SigninDelegateGroup,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .signin_delegate_groups = "SigninDelegateGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_signin_delegate_groups_with_account) } {
            return .{ .service_metadata = service_metadata, .action = associate_signin_delegate_groups_with_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_create_attendee: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/attendees?operation=batch-create",
        .success_code = 201,
    };

    action_name: []const u8 = "BatchCreateAttendee",
    Request: type = struct {
        meeting_id: []const u8,
        attendees: []CreateAttendeeRequestItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .attendees = "Attendees",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_attendee) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_attendee };
        }
    },
    Response: type = struct {
        attendees: ?[]Attendee = null,
        errors: ?[]CreateAttendeeError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attendees = "Attendees",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_create_channel_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/memberships?operation=batch-create",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchCreateChannelMembership",
    Request: type = struct {
        channel_arn: []const u8,
        type: ?[]const u8 = null,
        member_arns: [][]const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .type = "Type",
                .member_arns = "MemberArns",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_channel_membership) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_channel_membership };
        }
    },
    Response: type = struct {
        batch_channel_memberships: ?struct {
            invited_by: ?Identity = null,
            type: ?[]const u8 = null,
            members: ?[]Identity = null,
            channel_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .invited_by = "InvitedBy",
                    .type = "Type",
                    .members = "Members",
                    .channel_arn = "ChannelArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]struct {
            member_arn: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member_arn = "MemberArn",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_channel_memberships = "BatchChannelMemberships",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_create_room_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/rooms/{RoomId}/memberships?operation=batch-create",
        .success_code = 201,
    };

    action_name: []const u8 = "BatchCreateRoomMembership",
    Request: type = struct {
        account_id: []const u8,
        room_id: []const u8,
        membership_item_list: []struct {
            member_id: ?[]const u8 = null,
            role: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member_id = "MemberId",
                    .role = "Role",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .room_id = "RoomId",
                .membership_item_list = "MembershipItemList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_room_membership) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_room_membership };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            member_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member_id = "MemberId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_delete_phone_number: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-numbers?operation=batch-delete",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDeletePhoneNumber",
    Request: type = struct {
        phone_number_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_ids = "PhoneNumberIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_phone_number };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_suspend_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/users?operation=suspend",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchSuspendUser",
    Request: type = struct {
        account_id: []const u8,
        user_id_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_id_list = "UserIdList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_suspend_user) } {
            return .{ .service_metadata = service_metadata, .action = batch_suspend_user };
        }
    },
    Response: type = struct {
        user_errors: ?[]UserError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_errors = "UserErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_unsuspend_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/users?operation=unsuspend",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUnsuspendUser",
    Request: type = struct {
        account_id: []const u8,
        user_id_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_id_list = "UserIdList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_unsuspend_user) } {
            return .{ .service_metadata = service_metadata, .action = batch_unsuspend_user };
        }
    },
    Response: type = struct {
        user_errors: ?[]UserError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_errors = "UserErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_update_phone_number: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-numbers?operation=batch-update",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdatePhoneNumber",
    Request: type = struct {
        update_phone_number_request_items: []struct {
            phone_number_id: []const u8,
            product_type: ?[]const u8 = null,
            calling_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .phone_number_id = "PhoneNumberId",
                    .product_type = "ProductType",
                    .calling_name = "CallingName",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_phone_number_request_items = "UpdatePhoneNumberRequestItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_phone_number };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const batch_update_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateUser",
    Request: type = struct {
        account_id: []const u8,
        update_user_request_items: []struct {
            user_id: []const u8,
            license_type: ?[]const u8 = null,
            user_type: ?[]const u8 = null,
            alexa_for_business_metadata: ?AlexaForBusinessMetadata = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_id = "UserId",
                    .license_type = "LicenseType",
                    .user_type = "UserType",
                    .alexa_for_business_metadata = "AlexaForBusinessMetadata",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .update_user_request_items = "UpdateUserRequestItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_user) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_user };
        }
    },
    Response: type = struct {
        user_errors: ?[]UserError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_errors = "UserErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAccount",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_account) } {
            return .{ .service_metadata = service_metadata, .action = create_account };
        }
    },
    Response: type = struct {
        account: ?Account = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account = "Account",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_app_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/app-instances",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAppInstance",
    Request: type = struct {
        name: []const u8,
        metadata: ?[]const u8 = null,
        client_request_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .metadata = "Metadata",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_app_instance };
        }
    },
    Response: type = struct {
        app_instance_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_app_instance_admin: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/app-instances/{AppInstanceArn}/admins",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAppInstanceAdmin",
    Request: type = struct {
        app_instance_admin_arn: []const u8,
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_admin_arn = "AppInstanceAdminArn",
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_instance_admin) } {
            return .{ .service_metadata = service_metadata, .action = create_app_instance_admin };
        }
    },
    Response: type = struct {
        app_instance_admin: ?Identity = null,
        app_instance_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_admin = "AppInstanceAdmin",
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_app_instance_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/app-instance-users",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAppInstanceUser",
    Request: type = struct {
        app_instance_arn: []const u8,
        app_instance_user_id: []const u8,
        name: []const u8,
        metadata: ?[]const u8 = null,
        client_request_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .app_instance_user_id = "AppInstanceUserId",
                .name = "Name",
                .metadata = "Metadata",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = create_app_instance_user };
        }
    },
    Response: type = struct {
        app_instance_user_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_attendee: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/attendees",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateAttendee",
    Request: type = struct {
        meeting_id: []const u8,
        external_user_id: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .external_user_id = "ExternalUserId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_attendee) } {
            return .{ .service_metadata = service_metadata, .action = create_attendee };
        }
    },
    Response: type = struct {
        attendee: ?Attendee = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attendee = "Attendee",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_bot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/bots",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateBot",
    Request: type = struct {
        account_id: []const u8,
        display_name: []const u8,
        domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .display_name = "DisplayName",
                .domain = "Domain",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot) } {
            return .{ .service_metadata = service_metadata, .action = create_bot };
        }
    },
    Response: type = struct {
        bot: ?Bot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot = "Bot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannel",
    Request: type = struct {
        app_instance_arn: []const u8,
        name: []const u8,
        mode: ?[]const u8 = null,
        privacy: ?[]const u8 = null,
        metadata: ?[]const u8 = null,
        client_request_token: []const u8,
        tags: ?[]Tag = null,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .name = "Name",
                .mode = "Mode",
                .privacy = "Privacy",
                .metadata = "Metadata",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel) } {
            return .{ .service_metadata = service_metadata, .action = create_channel };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_channel_ban: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/bans",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannelBan",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel_ban) } {
            return .{ .service_metadata = service_metadata, .action = create_channel_ban };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        member: ?Identity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member = "Member",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_channel_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/memberships",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannelMembership",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        type: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .type = "Type",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel_membership) } {
            return .{ .service_metadata = service_metadata, .action = create_channel_membership };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        member: ?Identity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member = "Member",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_channel_moderator: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/moderators",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateChannelModerator",
    Request: type = struct {
        channel_arn: []const u8,
        channel_moderator_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_moderator_arn = "ChannelModeratorArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel_moderator) } {
            return .{ .service_metadata = service_metadata, .action = create_channel_moderator };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        channel_moderator: ?Identity = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_moderator = "ChannelModerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_media_capture_pipeline: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/media-capture-pipelines",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMediaCapturePipeline",
    Request: type = struct {
        source_type: []const u8,
        source_arn: []const u8,
        sink_type: []const u8,
        sink_arn: []const u8,
        client_request_token: ?[]const u8 = null,
        chime_sdk_meeting_configuration: ?ChimeSdkMeetingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_type = "SourceType",
                .source_arn = "SourceArn",
                .sink_type = "SinkType",
                .sink_arn = "SinkArn",
                .client_request_token = "ClientRequestToken",
                .chime_sdk_meeting_configuration = "ChimeSdkMeetingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_media_capture_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_media_capture_pipeline };
        }
    },
    Response: type = struct {
        media_capture_pipeline: ?MediaCapturePipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_capture_pipeline = "MediaCapturePipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_meeting: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMeeting",
    Request: type = struct {
        client_request_token: []const u8,
        external_meeting_id: ?[]const u8 = null,
        meeting_host_id: ?[]const u8 = null,
        media_region: ?[]const u8 = null,
        tags: ?[]Tag = null,
        notifications_configuration: ?MeetingNotificationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .external_meeting_id = "ExternalMeetingId",
                .meeting_host_id = "MeetingHostId",
                .media_region = "MediaRegion",
                .tags = "Tags",
                .notifications_configuration = "NotificationsConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_meeting) } {
            return .{ .service_metadata = service_metadata, .action = create_meeting };
        }
    },
    Response: type = struct {
        meeting: ?Meeting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting = "Meeting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_meeting_dial_out: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/dial-outs",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMeetingDialOut",
    Request: type = struct {
        meeting_id: []const u8,
        from_phone_number: []const u8,
        to_phone_number: []const u8,
        join_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .from_phone_number = "FromPhoneNumber",
                .to_phone_number = "ToPhoneNumber",
                .join_token = "JoinToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_meeting_dial_out) } {
            return .{ .service_metadata = service_metadata, .action = create_meeting_dial_out };
        }
    },
    Response: type = struct {
        transaction_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transaction_id = "TransactionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_meeting_with_attendees: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings?operation=create-attendees",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateMeetingWithAttendees",
    Request: type = struct {
        client_request_token: []const u8,
        external_meeting_id: ?[]const u8 = null,
        meeting_host_id: ?[]const u8 = null,
        media_region: ?[]const u8 = null,
        tags: ?[]Tag = null,
        notifications_configuration: ?MeetingNotificationConfiguration = null,
        attendees: ?[]CreateAttendeeRequestItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .external_meeting_id = "ExternalMeetingId",
                .meeting_host_id = "MeetingHostId",
                .media_region = "MediaRegion",
                .tags = "Tags",
                .notifications_configuration = "NotificationsConfiguration",
                .attendees = "Attendees",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_meeting_with_attendees) } {
            return .{ .service_metadata = service_metadata, .action = create_meeting_with_attendees };
        }
    },
    Response: type = struct {
        meeting: ?Meeting = null,
        attendees: ?[]Attendee = null,
        errors: ?[]CreateAttendeeError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting = "Meeting",
                .attendees = "Attendees",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_phone_number_order: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-number-orders",
        .success_code = 201,
    };

    action_name: []const u8 = "CreatePhoneNumberOrder",
    Request: type = struct {
        product_type: []const u8,
        e164_phone_numbers: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_type = "ProductType",
                .e164_phone_numbers = "E164PhoneNumbers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_phone_number_order) } {
            return .{ .service_metadata = service_metadata, .action = create_phone_number_order };
        }
    },
    Response: type = struct {
        phone_number_order: ?PhoneNumberOrder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_order = "PhoneNumberOrder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_proxy_session: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/proxy-sessions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateProxySession",
    Request: type = struct {
        voice_connector_id: []const u8,
        participant_phone_numbers: [][]const u8,
        name: ?[]const u8 = null,
        expiry_minutes: ?i64 = null,
        capabilities: [][]const u8,
        number_selection_behavior: ?[]const u8 = null,
        geo_match_level: ?[]const u8 = null,
        geo_match_params: ?GeoMatchParams = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .participant_phone_numbers = "ParticipantPhoneNumbers",
                .name = "Name",
                .expiry_minutes = "ExpiryMinutes",
                .capabilities = "Capabilities",
                .number_selection_behavior = "NumberSelectionBehavior",
                .geo_match_level = "GeoMatchLevel",
                .geo_match_params = "GeoMatchParams",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_proxy_session) } {
            return .{ .service_metadata = service_metadata, .action = create_proxy_session };
        }
    },
    Response: type = struct {
        proxy_session: ?ProxySession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy_session = "ProxySession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_room: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/rooms",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRoom",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_room) } {
            return .{ .service_metadata = service_metadata, .action = create_room };
        }
    },
    Response: type = struct {
        room: ?Room = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .room = "Room",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_room_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/rooms/{RoomId}/memberships",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateRoomMembership",
    Request: type = struct {
        account_id: []const u8,
        room_id: []const u8,
        member_id: []const u8,
        role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .room_id = "RoomId",
                .member_id = "MemberId",
                .role = "Role",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_room_membership) } {
            return .{ .service_metadata = service_metadata, .action = create_room_membership };
        }
    },
    Response: type = struct {
        room_membership: ?RoomMembership = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .room_membership = "RoomMembership",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_sip_media_application: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sip-media-applications",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSipMediaApplication",
    Request: type = struct {
        aws_region: []const u8,
        name: []const u8,
        endpoints: []SipMediaApplicationEndpoint,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_region = "AwsRegion",
                .name = "Name",
                .endpoints = "Endpoints",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sip_media_application) } {
            return .{ .service_metadata = service_metadata, .action = create_sip_media_application };
        }
    },
    Response: type = struct {
        sip_media_application: ?SipMediaApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application = "SipMediaApplication",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_sip_media_application_call: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sip-media-applications/{SipMediaApplicationId}/calls",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSipMediaApplicationCall",
    Request: type = struct {
        from_phone_number: []const u8,
        to_phone_number: []const u8,
        sip_media_application_id: []const u8,
        sip_headers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .from_phone_number = "FromPhoneNumber",
                .to_phone_number = "ToPhoneNumber",
                .sip_media_application_id = "SipMediaApplicationId",
                .sip_headers = "SipHeaders",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "sip_headers", field_name))
                return try serializeMap(self.sip_headers, self.fieldNameFor("sip_headers"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sip_media_application_call) } {
            return .{ .service_metadata = service_metadata, .action = create_sip_media_application_call };
        }
    },
    Response: type = struct {
        sip_media_application_call: ?SipMediaApplicationCall = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_call = "SipMediaApplicationCall",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_sip_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sip-rules",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateSipRule",
    Request: type = struct {
        name: []const u8,
        trigger_type: []const u8,
        trigger_value: []const u8,
        disabled: ?bool = null,
        target_applications: []SipRuleTargetApplication,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .trigger_type = "TriggerType",
                .trigger_value = "TriggerValue",
                .disabled = "Disabled",
                .target_applications = "TargetApplications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_sip_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_sip_rule };
        }
    },
    Response: type = struct {
        sip_rule: ?SipRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule = "SipRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Conflict,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/users?operation=create",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        account_id: []const u8,
        username: ?[]const u8 = null,
        email: ?[]const u8 = null,
        user_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .username = "Username",
                .email = "Email",
                .user_type = "UserType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_voice_connector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateVoiceConnector",
    Request: type = struct {
        name: []const u8,
        aws_region: ?[]const u8 = null,
        require_encryption: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .aws_region = "AwsRegion",
                .require_encryption = "RequireEncryption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = create_voice_connector };
        }
    },
    Response: type = struct {
        voice_connector: ?VoiceConnector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector = "VoiceConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const create_voice_connector_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connector-groups",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateVoiceConnectorGroup",
    Request: type = struct {
        name: []const u8,
        voice_connector_items: ?[]VoiceConnectorItem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .voice_connector_items = "VoiceConnectorItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = create_voice_connector_group };
        }
    },
    Response: type = struct {
        voice_connector_group: ?VoiceConnectorGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group = "VoiceConnectorGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_account: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AccountId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAccount",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_account) } {
            return .{ .service_metadata = service_metadata, .action = delete_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
        UnprocessableEntity,
    },
} = .{};
pub const delete_app_instance: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/app-instances/{AppInstanceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAppInstance",
    Request: type = struct {
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_instance };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_app_instance_admin: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/app-instances/{AppInstanceArn}/admins/{AppInstanceAdminArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAppInstanceAdmin",
    Request: type = struct {
        app_instance_admin_arn: []const u8,
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_admin_arn = "AppInstanceAdminArn",
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_instance_admin) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_instance_admin };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_app_instance_streaming_configurations: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/app-instances/{AppInstanceArn}/streaming-configurations",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAppInstanceStreamingConfigurations",
    Request: type = struct {
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_instance_streaming_configurations) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_instance_streaming_configurations };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_app_instance_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/app-instance-users/{AppInstanceUserArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAppInstanceUser",
    Request: type = struct {
        app_instance_user_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_instance_user };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_attendee: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/meetings/{MeetingId}/attendees/{AttendeeId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteAttendee",
    Request: type = struct {
        meeting_id: []const u8,
        attendee_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .attendee_id = "AttendeeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_attendee) } {
            return .{ .service_metadata = service_metadata, .action = delete_attendee };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannel",
    Request: type = struct {
        channel_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel_ban: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}/bans/{MemberArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannelBan",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel_ban) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel_ban };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel_membership: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}/memberships/{MemberArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannelMembership",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel_membership) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel_membership };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel_message: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}/messages/{MessageId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannelMessage",
    Request: type = struct {
        channel_arn: []const u8,
        message_id: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel_message) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel_message };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_channel_moderator: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{ChannelArn}/moderators/{ChannelModeratorArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteChannelModerator",
    Request: type = struct {
        channel_arn: []const u8,
        channel_moderator_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_moderator_arn = "ChannelModeratorArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel_moderator) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel_moderator };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_events_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AccountId}/bots/{BotId}/events-configuration",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteEventsConfiguration",
    Request: type = struct {
        account_id: []const u8,
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bot_id = "BotId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_events_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_events_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        UnauthorizedClient,
    },
} = .{};
pub const delete_media_capture_pipeline: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/media-capture-pipelines/{MediaPipelineId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMediaCapturePipeline",
    Request: type = struct {
        media_pipeline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_pipeline_id = "MediaPipelineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_media_capture_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_media_capture_pipeline };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_meeting: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/meetings/{MeetingId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteMeeting",
    Request: type = struct {
        meeting_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_meeting) } {
            return .{ .service_metadata = service_metadata, .action = delete_meeting };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_phone_number: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/phone-numbers/{PhoneNumberId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeletePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = delete_phone_number };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_proxy_session: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/proxy-sessions/{ProxySessionId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteProxySession",
    Request: type = struct {
        voice_connector_id: []const u8,
        proxy_session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .proxy_session_id = "ProxySessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_proxy_session) } {
            return .{ .service_metadata = service_metadata, .action = delete_proxy_session };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_room: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AccountId}/rooms/{RoomId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRoom",
    Request: type = struct {
        account_id: []const u8,
        room_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .room_id = "RoomId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_room) } {
            return .{ .service_metadata = service_metadata, .action = delete_room };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_room_membership: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AccountId}/rooms/{RoomId}/memberships/{MemberId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteRoomMembership",
    Request: type = struct {
        account_id: []const u8,
        room_id: []const u8,
        member_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .room_id = "RoomId",
                .member_id = "MemberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_room_membership) } {
            return .{ .service_metadata = service_metadata, .action = delete_room_membership };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_sip_media_application: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sip-media-applications/{SipMediaApplicationId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSipMediaApplication",
    Request: type = struct {
        sip_media_application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sip_media_application) } {
            return .{ .service_metadata = service_metadata, .action = delete_sip_media_application };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_sip_rule: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sip-rules/{SipRuleId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSipRule",
    Request: type = struct {
        sip_rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule_id = "SipRuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_sip_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_sip_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnector",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_emergency_calling_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/emergency-calling-configuration",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorEmergencyCallingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_emergency_calling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_emergency_calling_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connector-groups/{VoiceConnectorGroupId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorGroup",
    Request: type = struct {
        voice_connector_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group_id = "VoiceConnectorGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_origination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/origination",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorOrigination",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_origination) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_origination };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_proxy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/programmable-numbers/proxy",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorProxy",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_proxy) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_proxy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_streaming_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/streaming-configuration",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorStreamingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_streaming_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_streaming_configuration };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_termination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorTermination",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_termination) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_termination };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const delete_voice_connector_termination_credentials: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination/credentials?operation=delete",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteVoiceConnectorTerminationCredentials",
    Request: type = struct {
        voice_connector_id: []const u8,
        usernames: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .usernames = "Usernames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_voice_connector_termination_credentials) } {
            return .{ .service_metadata = service_metadata, .action = delete_voice_connector_termination_credentials };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_app_instance: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances/{AppInstanceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppInstance",
    Request: type = struct {
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_instance) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_instance };
        }
    },
    Response: type = struct {
        app_instance: ?struct {
            app_instance_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            metadata: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_arn = "AppInstanceArn",
                    .name = "Name",
                    .metadata = "Metadata",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance = "AppInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_app_instance_admin: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances/{AppInstanceArn}/admins/{AppInstanceAdminArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppInstanceAdmin",
    Request: type = struct {
        app_instance_admin_arn: []const u8,
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_admin_arn = "AppInstanceAdminArn",
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_instance_admin) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_instance_admin };
        }
    },
    Response: type = struct {
        app_instance_admin: ?struct {
            admin: ?Identity = null,
            app_instance_arn: ?[]const u8 = null,
            created_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .admin = "Admin",
                    .app_instance_arn = "AppInstanceArn",
                    .created_timestamp = "CreatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_admin = "AppInstanceAdmin",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_app_instance_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instance-users/{AppInstanceUserArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAppInstanceUser",
    Request: type = struct {
        app_instance_user_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_instance_user };
        }
    },
    Response: type = struct {
        app_instance_user: ?struct {
            app_instance_user_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            metadata: ?[]const u8 = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_user_arn = "AppInstanceUserArn",
                    .name = "Name",
                    .created_timestamp = "CreatedTimestamp",
                    .metadata = "Metadata",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user = "AppInstanceUser",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannel",
    Request: type = struct {
        channel_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel };
        }
    },
    Response: type = struct {
        channel: ?struct {
            name: ?[]const u8 = null,
            channel_arn: ?[]const u8 = null,
            mode: ?[]const u8 = null,
            privacy: ?[]const u8 = null,
            metadata: ?[]const u8 = null,
            created_by: ?Identity = null,
            created_timestamp: ?i64 = null,
            last_message_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .channel_arn = "ChannelArn",
                    .mode = "Mode",
                    .privacy = "Privacy",
                    .metadata = "Metadata",
                    .created_by = "CreatedBy",
                    .created_timestamp = "CreatedTimestamp",
                    .last_message_timestamp = "LastMessageTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "Channel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_ban: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/bans/{MemberArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelBan",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_ban) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_ban };
        }
    },
    Response: type = struct {
        channel_ban: ?struct {
            member: ?Identity = null,
            channel_arn: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            created_by: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member = "Member",
                    .channel_arn = "ChannelArn",
                    .created_timestamp = "CreatedTimestamp",
                    .created_by = "CreatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_ban = "ChannelBan",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_membership: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/memberships/{MemberArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelMembership",
    Request: type = struct {
        channel_arn: []const u8,
        member_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .member_arn = "MemberArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_membership) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_membership };
        }
    },
    Response: type = struct {
        channel_membership: ?struct {
            invited_by: ?Identity = null,
            type: ?[]const u8 = null,
            member: ?Identity = null,
            channel_arn: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .invited_by = "InvitedBy",
                    .type = "Type",
                    .member = "Member",
                    .channel_arn = "ChannelArn",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_membership = "ChannelMembership",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_membership_for_app_instance_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}?scope=app-instance-user-membership",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelMembershipForAppInstanceUser",
    Request: type = struct {
        channel_arn: []const u8,
        app_instance_user_arn: []const u8,
        chime_bearer: ?[]const u8 = null,

        pub const http_query = .{
            .app_instance_user_arn = "app-instance-user-arn",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .app_instance_user_arn = "AppInstanceUserArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_membership_for_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_membership_for_app_instance_user };
        }
    },
    Response: type = struct {
        channel_membership: ?ChannelMembershipForAppInstanceUserSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_membership = "ChannelMembership",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_moderated_by_app_instance_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}?scope=app-instance-user-moderated-channel",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelModeratedByAppInstanceUser",
    Request: type = struct {
        channel_arn: []const u8,
        app_instance_user_arn: []const u8,
        chime_bearer: ?[]const u8 = null,

        pub const http_query = .{
            .app_instance_user_arn = "app-instance-user-arn",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .app_instance_user_arn = "AppInstanceUserArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_moderated_by_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_moderated_by_app_instance_user };
        }
    },
    Response: type = struct {
        channel: ?ChannelModeratedByAppInstanceUserSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "Channel",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const describe_channel_moderator: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/moderators/{ChannelModeratorArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannelModerator",
    Request: type = struct {
        channel_arn: []const u8,
        channel_moderator_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_moderator_arn = "ChannelModeratorArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel_moderator) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel_moderator };
        }
    },
    Response: type = struct {
        channel_moderator: ?struct {
            moderator: ?Identity = null,
            channel_arn: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            created_by: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .moderator = "Moderator",
                    .channel_arn = "ChannelArn",
                    .created_timestamp = "CreatedTimestamp",
                    .created_by = "CreatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_moderator = "ChannelModerator",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const disassociate_phone_number_from_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/users/{UserId}?operation=disassociate-phone-number",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociatePhoneNumberFromUser",
    Request: type = struct {
        account_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_phone_number_from_user) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_phone_number_from_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const disassociate_phone_numbers_from_voice_connector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}?operation=disassociate-phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociatePhoneNumbersFromVoiceConnector",
    Request: type = struct {
        voice_connector_id: []const u8,
        e164_phone_numbers: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .e164_phone_numbers = "E164PhoneNumbers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_phone_numbers_from_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_phone_numbers_from_voice_connector };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const disassociate_phone_numbers_from_voice_connector_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connector-groups/{VoiceConnectorGroupId}?operation=disassociate-phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociatePhoneNumbersFromVoiceConnectorGroup",
    Request: type = struct {
        voice_connector_group_id: []const u8,
        e164_phone_numbers: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group_id = "VoiceConnectorGroupId",
                .e164_phone_numbers = "E164PhoneNumbers",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_phone_numbers_from_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_phone_numbers_from_voice_connector_group };
        }
    },
    Response: type = struct {
        phone_number_errors: ?[]PhoneNumberError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_errors = "PhoneNumberErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const disassociate_signin_delegate_groups_from_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}?operation=disassociate-signin-delegate-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateSigninDelegateGroupsFromAccount",
    Request: type = struct {
        account_id: []const u8,
        group_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .group_names = "GroupNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_signin_delegate_groups_from_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_signin_delegate_groups_from_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccount",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account) } {
            return .{ .service_metadata = service_metadata, .action = get_account };
        }
    },
    Response: type = struct {
        account: ?Account = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account = "Account",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_account_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccountSettings",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_account_settings };
        }
    },
    Response: type = struct {
        account_settings: ?AccountSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_settings = "AccountSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_app_instance_retention_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances/{AppInstanceArn}/retention-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAppInstanceRetentionSettings",
    Request: type = struct {
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app_instance_retention_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_app_instance_retention_settings };
        }
    },
    Response: type = struct {
        app_instance_retention_settings: ?AppInstanceRetentionSettings = null,
        initiate_deletion_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_retention_settings = "AppInstanceRetentionSettings",
                .initiate_deletion_timestamp = "InitiateDeletionTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_app_instance_streaming_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances/{AppInstanceArn}/streaming-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAppInstanceStreamingConfigurations",
    Request: type = struct {
        app_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_app_instance_streaming_configurations) } {
            return .{ .service_metadata = service_metadata, .action = get_app_instance_streaming_configurations };
        }
    },
    Response: type = struct {
        app_instance_streaming_configurations: ?[]AppInstanceStreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_streaming_configurations = "AppInstanceStreamingConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_attendee: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/meetings/{MeetingId}/attendees/{AttendeeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAttendee",
    Request: type = struct {
        meeting_id: []const u8,
        attendee_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .attendee_id = "AttendeeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_attendee) } {
            return .{ .service_metadata = service_metadata, .action = get_attendee };
        }
    },
    Response: type = struct {
        attendee: ?Attendee = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attendee = "Attendee",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_bot: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/bots/{BotId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBot",
    Request: type = struct {
        account_id: []const u8,
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bot_id = "BotId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bot) } {
            return .{ .service_metadata = service_metadata, .action = get_bot };
        }
    },
    Response: type = struct {
        bot: ?Bot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot = "Bot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_channel_message: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/messages/{MessageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChannelMessage",
    Request: type = struct {
        channel_arn: []const u8,
        message_id: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_channel_message) } {
            return .{ .service_metadata = service_metadata, .action = get_channel_message };
        }
    },
    Response: type = struct {
        channel_message: ?struct {
            channel_arn: ?[]const u8 = null,
            message_id: ?[]const u8 = null,
            content: ?[]const u8 = null,
            metadata: ?[]const u8 = null,
            type: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_edited_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            sender: ?Identity = null,
            redacted: ?bool = null,
            persistence: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .channel_arn = "ChannelArn",
                    .message_id = "MessageId",
                    .content = "Content",
                    .metadata = "Metadata",
                    .type = "Type",
                    .created_timestamp = "CreatedTimestamp",
                    .last_edited_timestamp = "LastEditedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .sender = "Sender",
                    .redacted = "Redacted",
                    .persistence = "Persistence",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_message = "ChannelMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_events_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/bots/{BotId}/events-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEventsConfiguration",
    Request: type = struct {
        account_id: []const u8,
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bot_id = "BotId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_events_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_events_configuration };
        }
    },
    Response: type = struct {
        events_configuration: ?EventsConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events_configuration = "EventsConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        UnauthorizedClient,
    },
} = .{};
pub const get_global_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGlobalSettings",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_global_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_global_settings };
        }
    },
    Response: type = struct {
        business_calling: ?BusinessCallingSettings = null,
        voice_connector: ?VoiceConnectorSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .business_calling = "BusinessCalling",
                .voice_connector = "VoiceConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_media_capture_pipeline: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/media-capture-pipelines/{MediaPipelineId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMediaCapturePipeline",
    Request: type = struct {
        media_pipeline_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_pipeline_id = "MediaPipelineId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_media_capture_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = get_media_capture_pipeline };
        }
    },
    Response: type = struct {
        media_capture_pipeline: ?MediaCapturePipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_capture_pipeline = "MediaCapturePipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_meeting: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/meetings/{MeetingId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMeeting",
    Request: type = struct {
        meeting_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_meeting) } {
            return .{ .service_metadata = service_metadata, .action = get_meeting };
        }
    },
    Response: type = struct {
        meeting: ?Meeting = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting = "Meeting",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_messaging_session_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/endpoints/messaging-session",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMessagingSessionEndpoint",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_messaging_session_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_messaging_session_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?struct {
            url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .url = "Url",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "Endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_phone_number: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-numbers/{PhoneNumberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = get_phone_number };
        }
    },
    Response: type = struct {
        phone_number: ?PhoneNumber = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "PhoneNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_phone_number_order: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-number-orders/{PhoneNumberOrderId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPhoneNumberOrder",
    Request: type = struct {
        phone_number_order_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_order_id = "PhoneNumberOrderId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_phone_number_order) } {
            return .{ .service_metadata = service_metadata, .action = get_phone_number_order };
        }
    },
    Response: type = struct {
        phone_number_order: ?PhoneNumberOrder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_order = "PhoneNumberOrder",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_phone_number_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/settings/phone-number",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPhoneNumberSettings",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_phone_number_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_phone_number_settings };
        }
    },
    Response: type = struct {
        calling_name: ?[]const u8 = null,
        calling_name_updated_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calling_name = "CallingName",
                .calling_name_updated_timestamp = "CallingNameUpdatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_proxy_session: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/proxy-sessions/{ProxySessionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProxySession",
    Request: type = struct {
        voice_connector_id: []const u8,
        proxy_session_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .proxy_session_id = "ProxySessionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_proxy_session) } {
            return .{ .service_metadata = service_metadata, .action = get_proxy_session };
        }
    },
    Response: type = struct {
        proxy_session: ?ProxySession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy_session = "ProxySession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_retention_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/retention-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRetentionSettings",
    Request: type = struct {
        account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_retention_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_retention_settings };
        }
    },
    Response: type = struct {
        retention_settings: ?RetentionSettings = null,
        initiate_deletion_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retention_settings = "RetentionSettings",
                .initiate_deletion_timestamp = "InitiateDeletionTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_room: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/rooms/{RoomId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRoom",
    Request: type = struct {
        account_id: []const u8,
        room_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .room_id = "RoomId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_room) } {
            return .{ .service_metadata = service_metadata, .action = get_room };
        }
    },
    Response: type = struct {
        room: ?Room = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .room = "Room",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_sip_media_application: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-media-applications/{SipMediaApplicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSipMediaApplication",
    Request: type = struct {
        sip_media_application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sip_media_application) } {
            return .{ .service_metadata = service_metadata, .action = get_sip_media_application };
        }
    },
    Response: type = struct {
        sip_media_application: ?SipMediaApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application = "SipMediaApplication",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_sip_media_application_logging_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-media-applications/{SipMediaApplicationId}/logging-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSipMediaApplicationLoggingConfiguration",
    Request: type = struct {
        sip_media_application_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sip_media_application_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_sip_media_application_logging_configuration };
        }
    },
    Response: type = struct {
        sip_media_application_logging_configuration: ?SipMediaApplicationLoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_logging_configuration = "SipMediaApplicationLoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_sip_rule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-rules/{SipRuleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSipRule",
    Request: type = struct {
        sip_rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule_id = "SipRuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sip_rule) } {
            return .{ .service_metadata = service_metadata, .action = get_sip_rule };
        }
    },
    Response: type = struct {
        sip_rule: ?SipRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule = "SipRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/users/{UserId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUser",
    Request: type = struct {
        account_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user) } {
            return .{ .service_metadata = service_metadata, .action = get_user };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_user_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/users/{UserId}/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "GetUserSettings",
    Request: type = struct {
        account_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_user_settings };
        }
    },
    Response: type = struct {
        user_settings: ?UserSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_settings = "UserSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnector",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector };
        }
    },
    Response: type = struct {
        voice_connector: ?VoiceConnector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector = "VoiceConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_emergency_calling_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/emergency-calling-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorEmergencyCallingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_emergency_calling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_emergency_calling_configuration };
        }
    },
    Response: type = struct {
        emergency_calling_configuration: ?EmergencyCallingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .emergency_calling_configuration = "EmergencyCallingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connector-groups/{VoiceConnectorGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorGroup",
    Request: type = struct {
        voice_connector_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group_id = "VoiceConnectorGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_group };
        }
    },
    Response: type = struct {
        voice_connector_group: ?VoiceConnectorGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group = "VoiceConnectorGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_logging_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/logging-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorLoggingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_origination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/origination",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorOrigination",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_origination) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_origination };
        }
    },
    Response: type = struct {
        origination: ?Origination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination = "Origination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_proxy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/programmable-numbers/proxy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorProxy",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_proxy) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_proxy };
        }
    },
    Response: type = struct {
        proxy: ?Proxy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy = "Proxy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_streaming_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/streaming-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorStreamingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_streaming_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_streaming_configuration };
        }
    },
    Response: type = struct {
        streaming_configuration: ?StreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_configuration = "StreamingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_termination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorTermination",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_termination) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_termination };
        }
    },
    Response: type = struct {
        termination: ?Termination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .termination = "Termination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const get_voice_connector_termination_health: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination/health",
        .success_code = 200,
    };

    action_name: []const u8 = "GetVoiceConnectorTerminationHealth",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_voice_connector_termination_health) } {
            return .{ .service_metadata = service_metadata, .action = get_voice_connector_termination_health };
        }
    },
    Response: type = struct {
        termination_health: ?struct {
            timestamp: ?i64 = null,
            source: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .source = "Source",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .termination_health = "TerminationHealth",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const invite_users: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/users?operation=add",
        .success_code = 201,
    };

    action_name: []const u8 = "InviteUsers",
    Request: type = struct {
        account_id: []const u8,
        user_email_list: [][]const u8,
        user_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_email_list = "UserEmailList",
                .user_type = "UserType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(invite_users) } {
            return .{ .service_metadata = service_metadata, .action = invite_users };
        }
    },
    Response: type = struct {
        invites: ?[]struct {
            invite_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            email_address: ?[]const u8 = null,
            email_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .invite_id = "InviteId",
                    .status = "Status",
                    .email_address = "EmailAddress",
                    .email_status = "EmailStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .invites = "Invites",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_accounts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccounts",
    Request: type = struct {
        name: ?[]const u8 = null,
        user_email: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .name = "name",
            .user_email = "user-email",
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .user_email = "UserEmail",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_accounts };
        }
    },
    Response: type = struct {
        accounts: ?[]Account = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .accounts = "Accounts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_app_instance_admins: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances/{AppInstanceArn}/admins",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppInstanceAdmins",
    Request: type = struct {
        app_instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_instance_admins) } {
            return .{ .service_metadata = service_metadata, .action = list_app_instance_admins };
        }
    },
    Response: type = struct {
        app_instance_arn: ?[]const u8 = null,
        app_instance_admins: ?[]struct {
            admin: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .admin = "Admin",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .app_instance_admins = "AppInstanceAdmins",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_app_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppInstances",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_app_instances };
        }
    },
    Response: type = struct {
        app_instances: ?[]struct {
            app_instance_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            metadata: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_arn = "AppInstanceArn",
                    .name = "Name",
                    .metadata = "Metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instances = "AppInstances",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_app_instance_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/app-instance-users",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAppInstanceUsers",
    Request: type = struct {
        app_instance_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .app_instance_arn = "app-instance-arn",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_instance_users) } {
            return .{ .service_metadata = service_metadata, .action = list_app_instance_users };
        }
    },
    Response: type = struct {
        app_instance_arn: ?[]const u8 = null,
        app_instance_users: ?[]struct {
            app_instance_user_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            metadata: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_instance_user_arn = "AppInstanceUserArn",
                    .name = "Name",
                    .metadata = "Metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .app_instance_users = "AppInstanceUsers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_attendees: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/meetings/{MeetingId}/attendees",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAttendees",
    Request: type = struct {
        meeting_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_attendees) } {
            return .{ .service_metadata = service_metadata, .action = list_attendees };
        }
    },
    Response: type = struct {
        attendees: ?[]Attendee = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attendees = "Attendees",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_attendee_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/meetings/{MeetingId}/attendees/{AttendeeId}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAttendeeTags",
    Request: type = struct {
        meeting_id: []const u8,
        attendee_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .attendee_id = "AttendeeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_attendee_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_attendee_tags };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_bots: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/bots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBots",
    Request: type = struct {
        account_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bots) } {
            return .{ .service_metadata = service_metadata, .action = list_bots };
        }
    },
    Response: type = struct {
        bots: ?[]Bot = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bots = "Bots",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_bans: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/bans",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelBans",
    Request: type = struct {
        channel_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_bans) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_bans };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        channel_bans: ?[]struct {
            member: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member = "Member",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .next_token = "NextToken",
                .channel_bans = "ChannelBans",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_memberships: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/memberships",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelMemberships",
    Request: type = struct {
        channel_arn: []const u8,
        type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: ?[]const u8 = null,

        pub const http_query = .{
            .type = "type",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .type = "Type",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_memberships) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_memberships };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        channel_memberships: ?[]struct {
            member: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .member = "Member",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .channel_memberships = "ChannelMemberships",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_memberships_for_app_instance_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels?scope=app-instance-user-memberships",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelMembershipsForAppInstanceUser",
    Request: type = struct {
        app_instance_user_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: ?[]const u8 = null,

        pub const http_query = .{
            .app_instance_user_arn = "app-instance-user-arn",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_memberships_for_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_memberships_for_app_instance_user };
        }
    },
    Response: type = struct {
        channel_memberships: ?[]ChannelMembershipForAppInstanceUserSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_memberships = "ChannelMemberships",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_messages: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/messages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelMessages",
    Request: type = struct {
        channel_arn: []const u8,
        sort_order: ?[]const u8 = null,
        not_before: ?i64 = null,
        not_after: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: ?[]const u8 = null,

        pub const http_query = .{
            .sort_order = "sort-order",
            .not_before = "not-before",
            .not_after = "not-after",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .sort_order = "SortOrder",
                .not_before = "NotBefore",
                .not_after = "NotAfter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_messages) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_messages };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        channel_messages: ?[]struct {
            message_id: ?[]const u8 = null,
            content: ?[]const u8 = null,
            metadata: ?[]const u8 = null,
            type: ?[]const u8 = null,
            created_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            last_edited_timestamp: ?i64 = null,
            sender: ?Identity = null,
            redacted: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "MessageId",
                    .content = "Content",
                    .metadata = "Metadata",
                    .type = "Type",
                    .created_timestamp = "CreatedTimestamp",
                    .last_updated_timestamp = "LastUpdatedTimestamp",
                    .last_edited_timestamp = "LastEditedTimestamp",
                    .sender = "Sender",
                    .redacted = "Redacted",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .next_token = "NextToken",
                .channel_messages = "ChannelMessages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channel_moderators: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels/{ChannelArn}/moderators",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelModerators",
    Request: type = struct {
        channel_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channel_moderators) } {
            return .{ .service_metadata = service_metadata, .action = list_channel_moderators };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        channel_moderators: ?[]struct {
            moderator: ?Identity = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .moderator = "Moderator",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .next_token = "NextToken",
                .channel_moderators = "ChannelModerators",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannels",
    Request: type = struct {
        app_instance_arn: []const u8,
        privacy: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: ?[]const u8 = null,

        pub const http_query = .{
            .app_instance_arn = "app-instance-arn",
            .privacy = "privacy",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .privacy = "Privacy",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_channels };
        }
    },
    Response: type = struct {
        channels: ?[]ChannelSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "Channels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_channels_moderated_by_app_instance_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels?scope=app-instance-user-moderated-channels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannelsModeratedByAppInstanceUser",
    Request: type = struct {
        app_instance_user_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        chime_bearer: ?[]const u8 = null,

        pub const http_query = .{
            .app_instance_user_arn = "app-instance-user-arn",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels_moderated_by_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = list_channels_moderated_by_app_instance_user };
        }
    },
    Response: type = struct {
        channels: ?[]ChannelModeratedByAppInstanceUserSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "Channels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_media_capture_pipelines: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/media-capture-pipelines",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMediaCapturePipelines",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_media_capture_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_media_capture_pipelines };
        }
    },
    Response: type = struct {
        media_capture_pipelines: ?[]MediaCapturePipeline = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .media_capture_pipelines = "MediaCapturePipelines",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_meetings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/meetings",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMeetings",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_meetings) } {
            return .{ .service_metadata = service_metadata, .action = list_meetings };
        }
    },
    Response: type = struct {
        meetings: ?[]Meeting = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meetings = "Meetings",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_meeting_tags: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/meetings/{MeetingId}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListMeetingTags",
    Request: type = struct {
        meeting_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_meeting_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_meeting_tags };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_phone_number_orders: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-number-orders",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPhoneNumberOrders",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_phone_number_orders) } {
            return .{ .service_metadata = service_metadata, .action = list_phone_number_orders };
        }
    },
    Response: type = struct {
        phone_number_orders: ?[]PhoneNumberOrder = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_orders = "PhoneNumberOrders",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_phone_numbers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPhoneNumbers",
    Request: type = struct {
        status: ?[]const u8 = null,
        product_type: ?[]const u8 = null,
        filter_name: ?[]const u8 = null,
        filter_value: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .status = "status",
            .product_type = "product-type",
            .filter_name = "filter-name",
            .filter_value = "filter-value",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .product_type = "ProductType",
                .filter_name = "FilterName",
                .filter_value = "FilterValue",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_phone_numbers) } {
            return .{ .service_metadata = service_metadata, .action = list_phone_numbers };
        }
    },
    Response: type = struct {
        phone_numbers: ?[]PhoneNumber = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_numbers = "PhoneNumbers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_proxy_sessions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/proxy-sessions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProxySessions",
    Request: type = struct {
        voice_connector_id: []const u8,
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .status = "status",
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .status = "Status",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_proxy_sessions) } {
            return .{ .service_metadata = service_metadata, .action = list_proxy_sessions };
        }
    },
    Response: type = struct {
        proxy_sessions: ?[]ProxySession = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy_sessions = "ProxySessions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_room_memberships: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/rooms/{RoomId}/memberships",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRoomMemberships",
    Request: type = struct {
        account_id: []const u8,
        room_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .room_id = "RoomId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_room_memberships) } {
            return .{ .service_metadata = service_metadata, .action = list_room_memberships };
        }
    },
    Response: type = struct {
        room_memberships: ?[]RoomMembership = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .room_memberships = "RoomMemberships",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_rooms: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/rooms",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRooms",
    Request: type = struct {
        account_id: []const u8,
        member_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .member_id = "member-id",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .member_id = "MemberId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rooms) } {
            return .{ .service_metadata = service_metadata, .action = list_rooms };
        }
    },
    Response: type = struct {
        rooms: ?[]Room = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rooms = "Rooms",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_sip_media_applications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-media-applications",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSipMediaApplications",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sip_media_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_sip_media_applications };
        }
    },
    Response: type = struct {
        sip_media_applications: ?[]SipMediaApplication = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_applications = "SipMediaApplications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_sip_rules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sip-rules",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSipRules",
    Request: type = struct {
        sip_media_application_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .sip_media_application_id = "sip-media-application",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_sip_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_sip_rules };
        }
    },
    Response: type = struct {
        sip_rules: ?[]SipRule = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rules = "SipRules",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_supported_phone_number_countries: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-number-countries",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSupportedPhoneNumberCountries",
    Request: type = struct {
        product_type: []const u8,

        pub const http_query = .{
            .product_type = "product-type",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .product_type = "ProductType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_supported_phone_number_countries) } {
            return .{ .service_metadata = service_metadata, .action = list_supported_phone_number_countries };
        }
    },
    Response: type = struct {
        phone_number_countries: ?[]struct {
            country_code: ?[]const u8 = null,
            supported_phone_number_types: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .country_code = "CountryCode",
                    .supported_phone_number_types = "SupportedPhoneNumberTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_countries = "PhoneNumberCountries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        UnauthorizedClient,
    },
} = .{};
pub const list_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AccountId}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        account_id: []const u8,
        user_email: ?[]const u8 = null,
        user_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .user_email = "user-email",
            .user_type = "user-type",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_email = "UserEmail",
                .user_type = "UserType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        users: ?[]User = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_voice_connector_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connector-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVoiceConnectorGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_voice_connector_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_voice_connector_groups };
        }
    },
    Response: type = struct {
        voice_connector_groups: ?[]VoiceConnectorGroup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_groups = "VoiceConnectorGroups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_voice_connectors: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVoiceConnectors",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_voice_connectors) } {
            return .{ .service_metadata = service_metadata, .action = list_voice_connectors };
        }
    },
    Response: type = struct {
        voice_connectors: ?[]VoiceConnector = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connectors = "VoiceConnectors",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const list_voice_connector_termination_credentials: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination/credentials",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVoiceConnectorTerminationCredentials",
    Request: type = struct {
        voice_connector_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_voice_connector_termination_credentials) } {
            return .{ .service_metadata = service_metadata, .action = list_voice_connector_termination_credentials };
        }
    },
    Response: type = struct {
        usernames: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .usernames = "Usernames",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const logout_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/users/{UserId}?operation=logout",
        .success_code = 204,
    };

    action_name: []const u8 = "LogoutUser",
    Request: type = struct {
        account_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(logout_user) } {
            return .{ .service_metadata = service_metadata, .action = logout_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_app_instance_retention_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instances/{AppInstanceArn}/retention-settings",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAppInstanceRetentionSettings",
    Request: type = struct {
        app_instance_arn: []const u8,
        app_instance_retention_settings: AppInstanceRetentionSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .app_instance_retention_settings = "AppInstanceRetentionSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_app_instance_retention_settings) } {
            return .{ .service_metadata = service_metadata, .action = put_app_instance_retention_settings };
        }
    },
    Response: type = struct {
        app_instance_retention_settings: ?AppInstanceRetentionSettings = null,
        initiate_deletion_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_retention_settings = "AppInstanceRetentionSettings",
                .initiate_deletion_timestamp = "InitiateDeletionTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_app_instance_streaming_configurations: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instances/{AppInstanceArn}/streaming-configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAppInstanceStreamingConfigurations",
    Request: type = struct {
        app_instance_arn: []const u8,
        app_instance_streaming_configurations: []AppInstanceStreamingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .app_instance_streaming_configurations = "AppInstanceStreamingConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_app_instance_streaming_configurations) } {
            return .{ .service_metadata = service_metadata, .action = put_app_instance_streaming_configurations };
        }
    },
    Response: type = struct {
        app_instance_streaming_configurations: ?[]AppInstanceStreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_streaming_configurations = "AppInstanceStreamingConfigurations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_events_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AccountId}/bots/{BotId}/events-configuration",
        .success_code = 201,
    };

    action_name: []const u8 = "PutEventsConfiguration",
    Request: type = struct {
        account_id: []const u8,
        bot_id: []const u8,
        outbound_events_https_endpoint: ?[]const u8 = null,
        lambda_function_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bot_id = "BotId",
                .outbound_events_https_endpoint = "OutboundEventsHTTPSEndpoint",
                .lambda_function_arn = "LambdaFunctionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_events_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_events_configuration };
        }
    },
    Response: type = struct {
        events_configuration: ?EventsConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events_configuration = "EventsConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        UnauthorizedClient,
    },
} = .{};
pub const put_retention_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AccountId}/retention-settings",
        .success_code = 204,
    };

    action_name: []const u8 = "PutRetentionSettings",
    Request: type = struct {
        account_id: []const u8,
        retention_settings: RetentionSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .retention_settings = "RetentionSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_retention_settings) } {
            return .{ .service_metadata = service_metadata, .action = put_retention_settings };
        }
    },
    Response: type = struct {
        retention_settings: ?RetentionSettings = null,
        initiate_deletion_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .retention_settings = "RetentionSettings",
                .initiate_deletion_timestamp = "InitiateDeletionTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_sip_media_application_logging_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sip-media-applications/{SipMediaApplicationId}/logging-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutSipMediaApplicationLoggingConfiguration",
    Request: type = struct {
        sip_media_application_id: []const u8,
        sip_media_application_logging_configuration: ?SipMediaApplicationLoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
                .sip_media_application_logging_configuration = "SipMediaApplicationLoggingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_sip_media_application_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_sip_media_application_logging_configuration };
        }
    },
    Response: type = struct {
        sip_media_application_logging_configuration: ?SipMediaApplicationLoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_logging_configuration = "SipMediaApplicationLoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_emergency_calling_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/emergency-calling-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorEmergencyCallingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,
        emergency_calling_configuration: EmergencyCallingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .emergency_calling_configuration = "EmergencyCallingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_emergency_calling_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_emergency_calling_configuration };
        }
    },
    Response: type = struct {
        emergency_calling_configuration: ?EmergencyCallingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .emergency_calling_configuration = "EmergencyCallingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_logging_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/logging-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorLoggingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,
        logging_configuration: LoggingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_origination: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/origination",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorOrigination",
    Request: type = struct {
        voice_connector_id: []const u8,
        origination: Origination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .origination = "Origination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_origination) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_origination };
        }
    },
    Response: type = struct {
        origination: ?Origination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origination = "Origination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_proxy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/programmable-numbers/proxy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorProxy",
    Request: type = struct {
        voice_connector_id: []const u8,
        default_session_expiry_minutes: i64,
        phone_number_pool_countries: [][]const u8,
        fall_back_phone_number: ?[]const u8 = null,
        disabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .default_session_expiry_minutes = "DefaultSessionExpiryMinutes",
                .phone_number_pool_countries = "PhoneNumberPoolCountries",
                .fall_back_phone_number = "FallBackPhoneNumber",
                .disabled = "Disabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_proxy) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_proxy };
        }
    },
    Response: type = struct {
        proxy: ?Proxy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy = "Proxy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_streaming_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/streaming-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorStreamingConfiguration",
    Request: type = struct {
        voice_connector_id: []const u8,
        streaming_configuration: StreamingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .streaming_configuration = "StreamingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_streaming_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_streaming_configuration };
        }
    },
    Response: type = struct {
        streaming_configuration: ?StreamingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_configuration = "StreamingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_termination: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination",
        .success_code = 200,
    };

    action_name: []const u8 = "PutVoiceConnectorTermination",
    Request: type = struct {
        voice_connector_id: []const u8,
        termination: Termination,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .termination = "Termination",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_termination) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_termination };
        }
    },
    Response: type = struct {
        termination: ?Termination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .termination = "Termination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const put_voice_connector_termination_credentials: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/termination/credentials?operation=put",
        .success_code = 204,
    };

    action_name: []const u8 = "PutVoiceConnectorTerminationCredentials",
    Request: type = struct {
        voice_connector_id: []const u8,
        credentials: ?[]struct {
            username: ?[]const u8 = null,
            password: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .username = "Username",
                    .password = "Password",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .credentials = "Credentials",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_voice_connector_termination_credentials) } {
            return .{ .service_metadata = service_metadata, .action = put_voice_connector_termination_credentials };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const redact_channel_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/messages/{MessageId}?operation=redact",
        .success_code = 200,
    };

    action_name: []const u8 = "RedactChannelMessage",
    Request: type = struct {
        channel_arn: []const u8,
        message_id: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(redact_channel_message) } {
            return .{ .service_metadata = service_metadata, .action = redact_channel_message };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const redact_conversation_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/conversations/{ConversationId}/messages/{MessageId}?operation=redact",
        .success_code = 200,
    };

    action_name: []const u8 = "RedactConversationMessage",
    Request: type = struct {
        account_id: []const u8,
        conversation_id: []const u8,
        message_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .conversation_id = "ConversationId",
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(redact_conversation_message) } {
            return .{ .service_metadata = service_metadata, .action = redact_conversation_message };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const redact_room_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/rooms/{RoomId}/messages/{MessageId}?operation=redact",
        .success_code = 200,
    };

    action_name: []const u8 = "RedactRoomMessage",
    Request: type = struct {
        account_id: []const u8,
        room_id: []const u8,
        message_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .room_id = "RoomId",
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(redact_room_message) } {
            return .{ .service_metadata = service_metadata, .action = redact_room_message };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const regenerate_security_token: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/bots/{BotId}?operation=regenerate-security-token",
        .success_code = 200,
    };

    action_name: []const u8 = "RegenerateSecurityToken",
    Request: type = struct {
        account_id: []const u8,
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bot_id = "BotId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(regenerate_security_token) } {
            return .{ .service_metadata = service_metadata, .action = regenerate_security_token };
        }
    },
    Response: type = struct {
        bot: ?Bot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot = "Bot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const reset_personal_pin: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/users/{UserId}?operation=reset-personal-pin",
        .success_code = 200,
    };

    action_name: []const u8 = "ResetPersonalPIN",
    Request: type = struct {
        account_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_personal_pin) } {
            return .{ .service_metadata = service_metadata, .action = reset_personal_pin };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const restore_phone_number: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-numbers/{PhoneNumberId}?operation=restore",
        .success_code = 200,
    };

    action_name: []const u8 = "RestorePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = restore_phone_number };
        }
    },
    Response: type = struct {
        phone_number: ?PhoneNumber = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "PhoneNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const search_available_phone_numbers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/search?type=phone-numbers",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchAvailablePhoneNumbers",
    Request: type = struct {
        area_code: ?[]const u8 = null,
        city: ?[]const u8 = null,
        country: ?[]const u8 = null,
        state: ?[]const u8 = null,
        toll_free_prefix: ?[]const u8 = null,
        phone_number_type: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .area_code = "area-code",
            .city = "city",
            .country = "country",
            .state = "state",
            .toll_free_prefix = "toll-free-prefix",
            .phone_number_type = "phone-number-type",
            .max_results = "max-results",
            .next_token = "next-token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .area_code = "AreaCode",
                .city = "City",
                .country = "Country",
                .state = "State",
                .toll_free_prefix = "TollFreePrefix",
                .phone_number_type = "PhoneNumberType",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_available_phone_numbers) } {
            return .{ .service_metadata = service_metadata, .action = search_available_phone_numbers };
        }
    },
    Response: type = struct {
        e164_phone_numbers: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .e164_phone_numbers = "E164PhoneNumbers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const send_channel_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels/{ChannelArn}/messages",
        .success_code = 201,
    };

    action_name: []const u8 = "SendChannelMessage",
    Request: type = struct {
        channel_arn: []const u8,
        content: []const u8,
        type: []const u8,
        persistence: []const u8,
        metadata: ?[]const u8 = null,
        client_request_token: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .content = "Content",
                .type = "Type",
                .persistence = "Persistence",
                .metadata = "Metadata",
                .client_request_token = "ClientRequestToken",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_channel_message) } {
            return .{ .service_metadata = service_metadata, .action = send_channel_message };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const start_meeting_transcription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/transcription?operation=start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartMeetingTranscription",
    Request: type = struct {
        meeting_id: []const u8,
        transcription_configuration: struct {
            engine_transcribe_settings: ?struct {
                language_code: ?[]const u8 = null,
                vocabulary_filter_method: ?[]const u8 = null,
                vocabulary_filter_name: ?[]const u8 = null,
                vocabulary_name: ?[]const u8 = null,
                region: ?[]const u8 = null,
                enable_partial_results_stabilization: ?bool = null,
                partial_results_stability: ?[]const u8 = null,
                content_identification_type: ?[]const u8 = null,
                content_redaction_type: ?[]const u8 = null,
                pii_entity_types: ?[]const u8 = null,
                language_model_name: ?[]const u8 = null,
                identify_language: ?bool = null,
                language_options: ?[]const u8 = null,
                preferred_language: ?[]const u8 = null,
                vocabulary_names: ?[]const u8 = null,
                vocabulary_filter_names: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .language_code = "LanguageCode",
                        .vocabulary_filter_method = "VocabularyFilterMethod",
                        .vocabulary_filter_name = "VocabularyFilterName",
                        .vocabulary_name = "VocabularyName",
                        .region = "Region",
                        .enable_partial_results_stabilization = "EnablePartialResultsStabilization",
                        .partial_results_stability = "PartialResultsStability",
                        .content_identification_type = "ContentIdentificationType",
                        .content_redaction_type = "ContentRedactionType",
                        .pii_entity_types = "PiiEntityTypes",
                        .language_model_name = "LanguageModelName",
                        .identify_language = "IdentifyLanguage",
                        .language_options = "LanguageOptions",
                        .preferred_language = "PreferredLanguage",
                        .vocabulary_names = "VocabularyNames",
                        .vocabulary_filter_names = "VocabularyFilterNames",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            engine_transcribe_medical_settings: ?struct {
                language_code: []const u8,
                specialty: []const u8,
                type: []const u8,
                vocabulary_name: ?[]const u8 = null,
                region: ?[]const u8 = null,
                content_identification_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .language_code = "LanguageCode",
                        .specialty = "Specialty",
                        .type = "Type",
                        .vocabulary_name = "VocabularyName",
                        .region = "Region",
                        .content_identification_type = "ContentIdentificationType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine_transcribe_settings = "EngineTranscribeSettings",
                    .engine_transcribe_medical_settings = "EngineTranscribeMedicalSettings",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .transcription_configuration = "TranscriptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_meeting_transcription) } {
            return .{ .service_metadata = service_metadata, .action = start_meeting_transcription };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
        UnprocessableEntity,
    },
} = .{};
pub const stop_meeting_transcription: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/transcription?operation=stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopMeetingTranscription",
    Request: type = struct {
        meeting_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_meeting_transcription) } {
            return .{ .service_metadata = service_metadata, .action = stop_meeting_transcription };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
        UnprocessableEntity,
    },
} = .{};
pub const tag_attendee: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/attendees/{AttendeeId}/tags?operation=add",
        .success_code = 204,
    };

    action_name: []const u8 = "TagAttendee",
    Request: type = struct {
        meeting_id: []const u8,
        attendee_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .attendee_id = "AttendeeId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_attendee) } {
            return .{ .service_metadata = service_metadata, .action = tag_attendee };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const tag_meeting: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/tags?operation=add",
        .success_code = 204,
    };

    action_name: []const u8 = "TagMeeting",
    Request: type = struct {
        meeting_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_meeting) } {
            return .{ .service_metadata = service_metadata, .action = tag_meeting };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=tag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        UnauthorizedClient,
    },
} = .{};
pub const untag_attendee: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/attendees/{AttendeeId}/tags?operation=delete",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagAttendee",
    Request: type = struct {
        meeting_id: []const u8,
        attendee_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .attendee_id = "AttendeeId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_attendee) } {
            return .{ .service_metadata = service_metadata, .action = untag_attendee };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const untag_meeting: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/meetings/{MeetingId}/tags?operation=delete",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagMeeting",
    Request: type = struct {
        meeting_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .meeting_id = "MeetingId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_meeting) } {
            return .{ .service_metadata = service_metadata, .action = untag_meeting };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags?operation=untag-resource",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        UnauthorizedClient,
    },
} = .{};
pub const update_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccount",
    Request: type = struct {
        account_id: []const u8,
        name: ?[]const u8 = null,
        default_license: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .default_license = "DefaultLicense",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account) } {
            return .{ .service_metadata = service_metadata, .action = update_account };
        }
    },
    Response: type = struct {
        account: ?Account = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account = "Account",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_account_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AccountId}/settings",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateAccountSettings",
    Request: type = struct {
        account_id: []const u8,
        account_settings: AccountSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .account_settings = "AccountSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_account_settings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_app_instance: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instances/{AppInstanceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAppInstance",
    Request: type = struct {
        app_instance_arn: []const u8,
        name: []const u8,
        metadata: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
                .name = "Name",
                .metadata = "Metadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_instance) } {
            return .{ .service_metadata = service_metadata, .action = update_app_instance };
        }
    },
    Response: type = struct {
        app_instance_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_arn = "AppInstanceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_app_instance_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/app-instance-users/{AppInstanceUserArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAppInstanceUser",
    Request: type = struct {
        app_instance_user_arn: []const u8,
        name: []const u8,
        metadata: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
                .name = "Name",
                .metadata = "Metadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_instance_user) } {
            return .{ .service_metadata = service_metadata, .action = update_app_instance_user };
        }
    },
    Response: type = struct {
        app_instance_user_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_instance_user_arn = "AppInstanceUserArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_bot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/bots/{BotId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBot",
    Request: type = struct {
        account_id: []const u8,
        bot_id: []const u8,
        disabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bot_id = "BotId",
                .disabled = "Disabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bot) } {
            return .{ .service_metadata = service_metadata, .action = update_bot };
        }
    },
    Response: type = struct {
        bot: ?Bot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot = "Bot",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{ChannelArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannel",
    Request: type = struct {
        channel_arn: []const u8,
        name: []const u8,
        mode: []const u8,
        metadata: ?[]const u8 = null,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .name = "Name",
                .mode = "Mode",
                .metadata = "Metadata",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_channel };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_channel_message: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{ChannelArn}/messages/{MessageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannelMessage",
    Request: type = struct {
        channel_arn: []const u8,
        message_id: []const u8,
        content: ?[]const u8 = null,
        metadata: ?[]const u8 = null,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
                .content = "Content",
                .metadata = "Metadata",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel_message) } {
            return .{ .service_metadata = service_metadata, .action = update_channel_message };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_channel_read_marker: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels/{ChannelArn}/readMarker",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannelReadMarker",
    Request: type = struct {
        channel_arn: []const u8,
        chime_bearer: ?[]const u8 = null,
        pub const http_header = .{
            .chime_bearer = "x-amz-chime-bearer",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
                .chime_bearer = "ChimeBearer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel_read_marker) } {
            return .{ .service_metadata = service_metadata, .action = update_channel_read_marker };
        }
    },
    Response: type = struct {
        channel_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_arn = "ChannelArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_global_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/settings",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateGlobalSettings",
    Request: type = struct {
        business_calling: ?BusinessCallingSettings = null,
        voice_connector: ?VoiceConnectorSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .business_calling = "BusinessCalling",
                .voice_connector = "VoiceConnector",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_global_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_global_settings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_phone_number: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-numbers/{PhoneNumberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,
        product_type: ?[]const u8 = null,
        calling_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .product_type = "ProductType",
                .calling_name = "CallingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = update_phone_number };
        }
    },
    Response: type = struct {
        phone_number: ?PhoneNumber = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number = "PhoneNumber",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_phone_number_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/settings/phone-number",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdatePhoneNumberSettings",
    Request: type = struct {
        calling_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .calling_name = "CallingName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_phone_number_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_phone_number_settings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_proxy_session: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/voice-connectors/{VoiceConnectorId}/proxy-sessions/{ProxySessionId}",
        .success_code = 201,
    };

    action_name: []const u8 = "UpdateProxySession",
    Request: type = struct {
        voice_connector_id: []const u8,
        proxy_session_id: []const u8,
        capabilities: [][]const u8,
        expiry_minutes: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .proxy_session_id = "ProxySessionId",
                .capabilities = "Capabilities",
                .expiry_minutes = "ExpiryMinutes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_proxy_session) } {
            return .{ .service_metadata = service_metadata, .action = update_proxy_session };
        }
    },
    Response: type = struct {
        proxy_session: ?ProxySession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proxy_session = "ProxySession",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_room: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/rooms/{RoomId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoom",
    Request: type = struct {
        account_id: []const u8,
        room_id: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .room_id = "RoomId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_room) } {
            return .{ .service_metadata = service_metadata, .action = update_room };
        }
    },
    Response: type = struct {
        room: ?Room = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .room = "Room",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_room_membership: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/rooms/{RoomId}/memberships/{MemberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoomMembership",
    Request: type = struct {
        account_id: []const u8,
        room_id: []const u8,
        member_id: []const u8,
        role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .room_id = "RoomId",
                .member_id = "MemberId",
                .role = "Role",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_room_membership) } {
            return .{ .service_metadata = service_metadata, .action = update_room_membership };
        }
    },
    Response: type = struct {
        room_membership: ?RoomMembership = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .room_membership = "RoomMembership",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_sip_media_application: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sip-media-applications/{SipMediaApplicationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSipMediaApplication",
    Request: type = struct {
        sip_media_application_id: []const u8,
        name: ?[]const u8 = null,
        endpoints: ?[]SipMediaApplicationEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
                .name = "Name",
                .endpoints = "Endpoints",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sip_media_application) } {
            return .{ .service_metadata = service_metadata, .action = update_sip_media_application };
        }
    },
    Response: type = struct {
        sip_media_application: ?SipMediaApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application = "SipMediaApplication",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_sip_media_application_call: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sip-media-applications/{SipMediaApplicationId}/calls/{TransactionId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateSipMediaApplicationCall",
    Request: type = struct {
        sip_media_application_id: []const u8,
        transaction_id: []const u8,
        arguments: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_id = "SipMediaApplicationId",
                .transaction_id = "TransactionId",
                .arguments = "Arguments",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "arguments", field_name))
                return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sip_media_application_call) } {
            return .{ .service_metadata = service_metadata, .action = update_sip_media_application_call };
        }
    },
    Response: type = struct {
        sip_media_application_call: ?SipMediaApplicationCall = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_media_application_call = "SipMediaApplicationCall",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_sip_rule: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sip-rules/{SipRuleId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateSipRule",
    Request: type = struct {
        sip_rule_id: []const u8,
        name: []const u8,
        disabled: ?bool = null,
        target_applications: ?[]SipRuleTargetApplication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule_id = "SipRuleId",
                .name = "Name",
                .disabled = "Disabled",
                .target_applications = "TargetApplications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_sip_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_sip_rule };
        }
    },
    Response: type = struct {
        sip_rule: ?SipRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sip_rule = "SipRule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ResourceLimitExceeded,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AccountId}/users/{UserId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        account_id: []const u8,
        user_id: []const u8,
        license_type: ?[]const u8 = null,
        user_type: ?[]const u8 = null,
        alexa_for_business_metadata: ?AlexaForBusinessMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_id = "UserId",
                .license_type = "LicenseType",
                .user_type = "UserType",
                .alexa_for_business_metadata = "AlexaForBusinessMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {
        user: ?User = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_user_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AccountId}/users/{UserId}/settings",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateUserSettings",
    Request: type = struct {
        account_id: []const u8,
        user_id: []const u8,
        user_settings: UserSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .user_id = "UserId",
                .user_settings = "UserSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_user_settings };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_voice_connector: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connectors/{VoiceConnectorId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVoiceConnector",
    Request: type = struct {
        voice_connector_id: []const u8,
        name: []const u8,
        require_encryption: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_id = "VoiceConnectorId",
                .name = "Name",
                .require_encryption = "RequireEncryption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_voice_connector) } {
            return .{ .service_metadata = service_metadata, .action = update_voice_connector };
        }
    },
    Response: type = struct {
        voice_connector: ?VoiceConnector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector = "VoiceConnector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const update_voice_connector_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/voice-connector-groups/{VoiceConnectorGroupId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateVoiceConnectorGroup",
    Request: type = struct {
        voice_connector_group_id: []const u8,
        name: []const u8,
        voice_connector_items: []VoiceConnectorItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group_id = "VoiceConnectorGroupId",
                .name = "Name",
                .voice_connector_items = "VoiceConnectorItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_voice_connector_group) } {
            return .{ .service_metadata = service_metadata, .action = update_voice_connector_group };
        }
    },
    Response: type = struct {
        voice_connector_group: ?VoiceConnectorGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .voice_connector_group = "VoiceConnectorGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};
pub const validate_e911_address: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/emergency-calling/address",
        .success_code = 202,
    };

    action_name: []const u8 = "ValidateE911Address",
    Request: type = struct {
        aws_account_id: []const u8,
        street_number: []const u8,
        street_info: []const u8,
        city: []const u8,
        state: []const u8,
        country: []const u8,
        postal_code: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .street_number = "StreetNumber",
                .street_info = "StreetInfo",
                .city = "City",
                .state = "State",
                .country = "Country",
                .postal_code = "PostalCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(validate_e911_address) } {
            return .{ .service_metadata = service_metadata, .action = validate_e911_address };
        }
    },
    Response: type = struct {
        validation_result: ?i64 = null,
        address_external_id: ?[]const u8 = null,
        address: ?struct {
            street_name: ?[]const u8 = null,
            street_suffix: ?[]const u8 = null,
            post_directional: ?[]const u8 = null,
            pre_directional: ?[]const u8 = null,
            street_number: ?[]const u8 = null,
            city: ?[]const u8 = null,
            state: ?[]const u8 = null,
            postal_code: ?[]const u8 = null,
            postal_code_plus4: ?[]const u8 = null,
            country: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .street_name = "streetName",
                    .street_suffix = "streetSuffix",
                    .post_directional = "postDirectional",
                    .pre_directional = "preDirectional",
                    .street_number = "streetNumber",
                    .city = "city",
                    .state = "state",
                    .postal_code = "postalCode",
                    .postal_code_plus4 = "postalCodePlus4",
                    .country = "country",
                };
                return @field(mappings, field_name);
            }
        } = null,
        candidate_address_list: ?[]struct {
            street_info: ?[]const u8 = null,
            street_number: ?[]const u8 = null,
            city: ?[]const u8 = null,
            state: ?[]const u8 = null,
            postal_code: ?[]const u8 = null,
            postal_code_plus4: ?[]const u8 = null,
            country: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .street_info = "streetInfo",
                    .street_number = "streetNumber",
                    .city = "city",
                    .state = "state",
                    .postal_code = "postalCode",
                    .postal_code_plus4 = "postalCodePlus4",
                    .country = "country",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .validation_result = "ValidationResult",
                .address_external_id = "AddressExternalId",
                .address = "Address",
                .candidate_address_list = "CandidateAddressList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        NotFound,
        ServiceFailure,
        ServiceUnavailable,
        ThrottledClient,
        UnauthorizedClient,
    },
} = .{};

pub const VoiceConnectorGroup = struct {
    voice_connector_group_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    voice_connector_items: ?[]VoiceConnectorItem = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    voice_connector_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_connector_group_id = "VoiceConnectorGroupId",
            .name = "Name",
            .voice_connector_items = "VoiceConnectorItems",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .voice_connector_group_arn = "VoiceConnectorGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceConnectorItem = struct {
    voice_connector_id: []const u8,
    priority: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_connector_id = "VoiceConnectorId",
            .priority = "Priority",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceConnector = struct {
    voice_connector_id: ?[]const u8 = null,
    aws_region: ?[]const u8 = null,
    name: ?[]const u8 = null,
    outbound_host_name: ?[]const u8 = null,
    require_encryption: ?bool = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    voice_connector_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_connector_id = "VoiceConnectorId",
            .aws_region = "AwsRegion",
            .name = "Name",
            .outbound_host_name = "OutboundHostName",
            .require_encryption = "RequireEncryption",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .voice_connector_arn = "VoiceConnectorArn",
        };
        return @field(mappings, field_name);
    }
};

pub const UserSettings = struct {
    telephony: TelephonySettings,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .telephony = "Telephony",
        };
        return @field(mappings, field_name);
    }
};

pub const TelephonySettings = struct {
    inbound_calling: bool,
    outbound_calling: bool,
    sms: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inbound_calling = "InboundCalling",
            .outbound_calling = "OutboundCalling",
            .sms = "SMS",
        };
        return @field(mappings, field_name);
    }
};

pub const User = struct {
    user_id: []const u8,
    account_id: ?[]const u8 = null,
    primary_email: ?[]const u8 = null,
    primary_provisioned_number: ?[]const u8 = null,
    display_name: ?[]const u8 = null,
    license_type: ?[]const u8 = null,
    user_type: ?[]const u8 = null,
    user_registration_status: ?[]const u8 = null,
    user_invitation_status: ?[]const u8 = null,
    registered_on: ?i64 = null,
    invited_on: ?i64 = null,
    alexa_for_business_metadata: ?AlexaForBusinessMetadata = null,
    personal_pin: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_id = "UserId",
            .account_id = "AccountId",
            .primary_email = "PrimaryEmail",
            .primary_provisioned_number = "PrimaryProvisionedNumber",
            .display_name = "DisplayName",
            .license_type = "LicenseType",
            .user_type = "UserType",
            .user_registration_status = "UserRegistrationStatus",
            .user_invitation_status = "UserInvitationStatus",
            .registered_on = "RegisteredOn",
            .invited_on = "InvitedOn",
            .alexa_for_business_metadata = "AlexaForBusinessMetadata",
            .personal_pin = "PersonalPIN",
        };
        return @field(mappings, field_name);
    }
};

pub const AlexaForBusinessMetadata = struct {
    is_alexa_for_business_enabled: ?bool = null,
    alexa_for_business_room_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_alexa_for_business_enabled = "IsAlexaForBusinessEnabled",
            .alexa_for_business_room_arn = "AlexaForBusinessRoomArn",
        };
        return @field(mappings, field_name);
    }
};

pub const SipRule = struct {
    sip_rule_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    disabled: ?bool = null,
    trigger_type: ?[]const u8 = null,
    trigger_value: ?[]const u8 = null,
    target_applications: ?[]SipRuleTargetApplication = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sip_rule_id = "SipRuleId",
            .name = "Name",
            .disabled = "Disabled",
            .trigger_type = "TriggerType",
            .trigger_value = "TriggerValue",
            .target_applications = "TargetApplications",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const SipRuleTargetApplication = struct {
    sip_media_application_id: ?[]const u8 = null,
    priority: ?i64 = null,
    aws_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sip_media_application_id = "SipMediaApplicationId",
            .priority = "Priority",
            .aws_region = "AwsRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const SipMediaApplicationCall = struct {
    transaction_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transaction_id = "TransactionId",
        };
        return @field(mappings, field_name);
    }
};

pub const SipMediaApplication = struct {
    sip_media_application_id: ?[]const u8 = null,
    aws_region: ?[]const u8 = null,
    name: ?[]const u8 = null,
    endpoints: ?[]SipMediaApplicationEndpoint = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sip_media_application_id = "SipMediaApplicationId",
            .aws_region = "AwsRegion",
            .name = "Name",
            .endpoints = "Endpoints",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const SipMediaApplicationEndpoint = struct {
    lambda_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_arn = "LambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const RoomMembership = struct {
    room_id: ?[]const u8 = null,
    member: ?Member = null,
    role: ?[]const u8 = null,
    invited_by: ?[]const u8 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .room_id = "RoomId",
            .member = "Member",
            .role = "Role",
            .invited_by = "InvitedBy",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const Member = struct {
    member_id: ?[]const u8 = null,
    member_type: ?[]const u8 = null,
    email: ?[]const u8 = null,
    full_name: ?[]const u8 = null,
    account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .member_id = "MemberId",
            .member_type = "MemberType",
            .email = "Email",
            .full_name = "FullName",
            .account_id = "AccountId",
        };
        return @field(mappings, field_name);
    }
};

pub const Room = struct {
    room_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    account_id: ?[]const u8 = null,
    created_by: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .room_id = "RoomId",
            .name = "Name",
            .account_id = "AccountId",
            .created_by = "CreatedBy",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const ProxySession = struct {
    voice_connector_id: ?[]const u8 = null,
    proxy_session_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    expiry_minutes: ?i64 = null,
    capabilities: ?[][]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    ended_timestamp: ?i64 = null,
    participants: ?[]Participant = null,
    number_selection_behavior: ?[]const u8 = null,
    geo_match_level: ?[]const u8 = null,
    geo_match_params: ?GeoMatchParams = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_connector_id = "VoiceConnectorId",
            .proxy_session_id = "ProxySessionId",
            .name = "Name",
            .status = "Status",
            .expiry_minutes = "ExpiryMinutes",
            .capabilities = "Capabilities",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .ended_timestamp = "EndedTimestamp",
            .participants = "Participants",
            .number_selection_behavior = "NumberSelectionBehavior",
            .geo_match_level = "GeoMatchLevel",
            .geo_match_params = "GeoMatchParams",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoMatchParams = struct {
    country: []const u8,
    area_code: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .country = "Country",
            .area_code = "AreaCode",
        };
        return @field(mappings, field_name);
    }
};

pub const Participant = struct {
    phone_number: ?[]const u8 = null,
    proxy_phone_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_number = "PhoneNumber",
            .proxy_phone_number = "ProxyPhoneNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumber = struct {
    phone_number_id: ?[]const u8 = null,
    e164_phone_number: ?[]const u8 = null,
    country: ?[]const u8 = null,
    type: ?[]const u8 = null,
    product_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    capabilities: ?PhoneNumberCapabilities = null,
    associations: ?[]PhoneNumberAssociation = null,
    calling_name: ?[]const u8 = null,
    calling_name_status: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    deletion_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_number_id = "PhoneNumberId",
            .e164_phone_number = "E164PhoneNumber",
            .country = "Country",
            .type = "Type",
            .product_type = "ProductType",
            .status = "Status",
            .capabilities = "Capabilities",
            .associations = "Associations",
            .calling_name = "CallingName",
            .calling_name_status = "CallingNameStatus",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .deletion_timestamp = "DeletionTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberAssociation = struct {
    value: ?[]const u8 = null,
    name: ?[]const u8 = null,
    associated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .name = "Name",
            .associated_timestamp = "AssociatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberCapabilities = struct {
    inbound_call: ?bool = null,
    outbound_call: ?bool = null,
    inbound_sms: ?bool = null,
    outbound_sms: ?bool = null,
    inbound_mms: ?bool = null,
    outbound_mms: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inbound_call = "InboundCall",
            .outbound_call = "OutboundCall",
            .inbound_sms = "InboundSMS",
            .outbound_sms = "OutboundSMS",
            .inbound_mms = "InboundMMS",
            .outbound_mms = "OutboundMMS",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceConnectorSettings = struct {
    cdr_bucket: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cdr_bucket = "CdrBucket",
        };
        return @field(mappings, field_name);
    }
};

pub const BusinessCallingSettings = struct {
    cdr_bucket: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cdr_bucket = "CdrBucket",
        };
        return @field(mappings, field_name);
    }
};

pub const Bot = struct {
    bot_id: ?[]const u8 = null,
    user_id: ?[]const u8 = null,
    display_name: ?[]const u8 = null,
    bot_type: ?[]const u8 = null,
    disabled: ?bool = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    bot_email: ?[]const u8 = null,
    security_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "BotId",
            .user_id = "UserId",
            .display_name = "DisplayName",
            .bot_type = "BotType",
            .disabled = "Disabled",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .bot_email = "BotEmail",
            .security_token = "SecurityToken",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountSettings = struct {
    disable_remote_control: ?bool = null,
    enable_dial_out: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disable_remote_control = "DisableRemoteControl",
            .enable_dial_out = "EnableDialOut",
        };
        return @field(mappings, field_name);
    }
};

pub const Account = struct {
    aws_account_id: []const u8,
    account_id: []const u8,
    name: []const u8,
    account_type: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    default_license: ?[]const u8 = null,
    supported_licenses: ?[][]const u8 = null,
    account_status: ?[]const u8 = null,
    signin_delegate_groups: ?[]SigninDelegateGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_account_id = "AwsAccountId",
            .account_id = "AccountId",
            .name = "Name",
            .account_type = "AccountType",
            .created_timestamp = "CreatedTimestamp",
            .default_license = "DefaultLicense",
            .supported_licenses = "SupportedLicenses",
            .account_status = "AccountStatus",
            .signin_delegate_groups = "SigninDelegateGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const SigninDelegateGroup = struct {
    group_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group_name = "GroupName",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Termination = struct {
    cps_limit: ?i64 = null,
    default_phone_number: ?[]const u8 = null,
    calling_regions: ?[][]const u8 = null,
    cidr_allowed_list: ?[][]const u8 = null,
    disabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cps_limit = "CpsLimit",
            .default_phone_number = "DefaultPhoneNumber",
            .calling_regions = "CallingRegions",
            .cidr_allowed_list = "CidrAllowedList",
            .disabled = "Disabled",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingConfiguration = struct {
    data_retention_in_hours: i64,
    disabled: ?bool = null,
    streaming_notification_targets: ?[]StreamingNotificationTarget = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_retention_in_hours = "DataRetentionInHours",
            .disabled = "Disabled",
            .streaming_notification_targets = "StreamingNotificationTargets",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingNotificationTarget = struct {
    notification_target: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notification_target = "NotificationTarget",
        };
        return @field(mappings, field_name);
    }
};

pub const Proxy = struct {
    default_session_expiry_minutes: ?i64 = null,
    disabled: ?bool = null,
    fall_back_phone_number: ?[]const u8 = null,
    phone_number_countries: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_session_expiry_minutes = "DefaultSessionExpiryMinutes",
            .disabled = "Disabled",
            .fall_back_phone_number = "FallBackPhoneNumber",
            .phone_number_countries = "PhoneNumberCountries",
        };
        return @field(mappings, field_name);
    }
};

pub const Origination = struct {
    routes: ?[]OriginationRoute = null,
    disabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .routes = "Routes",
            .disabled = "Disabled",
        };
        return @field(mappings, field_name);
    }
};

pub const OriginationRoute = struct {
    host: ?[]const u8 = null,
    port: ?i64 = null,
    protocol: ?[]const u8 = null,
    priority: ?i64 = null,
    weight: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .protocol = "Protocol",
            .priority = "Priority",
            .weight = "Weight",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingConfiguration = struct {
    enable_sip_logs: ?bool = null,
    enable_media_metric_logs: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_sip_logs = "EnableSIPLogs",
            .enable_media_metric_logs = "EnableMediaMetricLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const EmergencyCallingConfiguration = struct {
    dnis: ?[]DNISEmergencyCallingConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dnis = "DNIS",
        };
        return @field(mappings, field_name);
    }
};

pub const DNISEmergencyCallingConfiguration = struct {
    emergency_phone_number: []const u8,
    test_phone_number: ?[]const u8 = null,
    calling_country: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .emergency_phone_number = "EmergencyPhoneNumber",
            .test_phone_number = "TestPhoneNumber",
            .calling_country = "CallingCountry",
        };
        return @field(mappings, field_name);
    }
};

pub const SipMediaApplicationLoggingConfiguration = struct {
    enable_sip_media_application_message_logs: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_sip_media_application_message_logs = "EnableSipMediaApplicationMessageLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const RetentionSettings = struct {
    room_retention_settings: ?RoomRetentionSettings = null,
    conversation_retention_settings: ?ConversationRetentionSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .room_retention_settings = "RoomRetentionSettings",
            .conversation_retention_settings = "ConversationRetentionSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const ConversationRetentionSettings = struct {
    retention_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .retention_days = "RetentionDays",
        };
        return @field(mappings, field_name);
    }
};

pub const RoomRetentionSettings = struct {
    retention_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .retention_days = "RetentionDays",
        };
        return @field(mappings, field_name);
    }
};

pub const EventsConfiguration = struct {
    bot_id: ?[]const u8 = null,
    outbound_events_https_endpoint: ?[]const u8 = null,
    lambda_function_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "BotId",
            .outbound_events_https_endpoint = "OutboundEventsHTTPSEndpoint",
            .lambda_function_arn = "LambdaFunctionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AppInstanceStreamingConfiguration = struct {
    app_instance_data_type: []const u8,
    resource_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_instance_data_type = "AppInstanceDataType",
            .resource_arn = "ResourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AppInstanceRetentionSettings = struct {
    channel_retention_settings: ?ChannelRetentionSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_retention_settings = "ChannelRetentionSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelRetentionSettings = struct {
    retention_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .retention_days = "RetentionDays",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberOrder = struct {
    phone_number_order_id: ?[]const u8 = null,
    product_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    ordered_phone_numbers: ?[]OrderedPhoneNumber = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_number_order_id = "PhoneNumberOrderId",
            .product_type = "ProductType",
            .status = "Status",
            .ordered_phone_numbers = "OrderedPhoneNumbers",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const OrderedPhoneNumber = struct {
    e164_phone_number: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .e164_phone_number = "E164PhoneNumber",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const Meeting = struct {
    meeting_id: ?[]const u8 = null,
    external_meeting_id: ?[]const u8 = null,
    media_placement: ?MediaPlacement = null,
    media_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .meeting_id = "MeetingId",
            .external_meeting_id = "ExternalMeetingId",
            .media_placement = "MediaPlacement",
            .media_region = "MediaRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaPlacement = struct {
    audio_host_url: ?[]const u8 = null,
    audio_fallback_url: ?[]const u8 = null,
    screen_data_url: ?[]const u8 = null,
    screen_sharing_url: ?[]const u8 = null,
    screen_viewing_url: ?[]const u8 = null,
    signaling_url: ?[]const u8 = null,
    turn_control_url: ?[]const u8 = null,
    event_ingestion_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio_host_url = "AudioHostUrl",
            .audio_fallback_url = "AudioFallbackUrl",
            .screen_data_url = "ScreenDataUrl",
            .screen_sharing_url = "ScreenSharingUrl",
            .screen_viewing_url = "ScreenViewingUrl",
            .signaling_url = "SignalingUrl",
            .turn_control_url = "TurnControlUrl",
            .event_ingestion_url = "EventIngestionUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaCapturePipeline = struct {
    media_pipeline_id: ?[]const u8 = null,
    source_type: ?[]const u8 = null,
    source_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    sink_type: ?[]const u8 = null,
    sink_arn: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    updated_timestamp: ?i64 = null,
    chime_sdk_meeting_configuration: ?ChimeSdkMeetingConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .media_pipeline_id = "MediaPipelineId",
            .source_type = "SourceType",
            .source_arn = "SourceArn",
            .status = "Status",
            .sink_type = "SinkType",
            .sink_arn = "SinkArn",
            .created_timestamp = "CreatedTimestamp",
            .updated_timestamp = "UpdatedTimestamp",
            .chime_sdk_meeting_configuration = "ChimeSdkMeetingConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ChimeSdkMeetingConfiguration = struct {
    source_configuration: ?SourceConfiguration = null,
    artifacts_configuration: ?ArtifactsConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_configuration = "SourceConfiguration",
            .artifacts_configuration = "ArtifactsConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const ArtifactsConfiguration = struct {
    audio: AudioArtifactsConfiguration,
    video: VideoArtifactsConfiguration,
    content: ContentArtifactsConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .audio = "Audio",
            .video = "Video",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const ContentArtifactsConfiguration = struct {
    state: []const u8,
    mux_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .mux_type = "MuxType",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoArtifactsConfiguration = struct {
    state: []const u8,
    mux_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .mux_type = "MuxType",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioArtifactsConfiguration = struct {
    mux_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mux_type = "MuxType",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceConfiguration = struct {
    selected_video_streams: ?SelectedVideoStreams = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_video_streams = "SelectedVideoStreams",
        };
        return @field(mappings, field_name);
    }
};

pub const SelectedVideoStreams = struct {
    attendee_ids: ?[][]const u8 = null,
    external_user_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attendee_ids = "AttendeeIds",
            .external_user_ids = "ExternalUserIds",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelModeratedByAppInstanceUserSummary = struct {
    channel_summary: ?ChannelSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_summary = "ChannelSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelSummary = struct {
    name: ?[]const u8 = null,
    channel_arn: ?[]const u8 = null,
    mode: ?[]const u8 = null,
    privacy: ?[]const u8 = null,
    metadata: ?[]const u8 = null,
    last_message_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .channel_arn = "ChannelArn",
            .mode = "Mode",
            .privacy = "Privacy",
            .metadata = "Metadata",
            .last_message_timestamp = "LastMessageTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const Identity = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelMembershipForAppInstanceUserSummary = struct {
    channel_summary: ?ChannelSummary = null,
    app_instance_user_membership_summary: ?AppInstanceUserMembershipSummary = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_summary = "ChannelSummary",
            .app_instance_user_membership_summary = "AppInstanceUserMembershipSummary",
        };
        return @field(mappings, field_name);
    }
};

pub const AppInstanceUserMembershipSummary = struct {
    type: ?[]const u8 = null,
    read_marker_timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .read_marker_timestamp = "ReadMarkerTimestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const Attendee = struct {
    external_user_id: ?[]const u8 = null,
    attendee_id: ?[]const u8 = null,
    join_token: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_user_id = "ExternalUserId",
            .attendee_id = "AttendeeId",
            .join_token = "JoinToken",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberError = struct {
    phone_number_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_number_id = "PhoneNumberId",
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateAttendeeError = struct {
    external_user_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_user_id = "ExternalUserId",
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateAttendeeRequestItem = struct {
    external_user_id: []const u8,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .external_user_id = "ExternalUserId",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const MeetingNotificationConfiguration = struct {
    sns_topic_arn: ?[]const u8 = null,
    sqs_queue_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_topic_arn = "SnsTopicArn",
            .sqs_queue_arn = "SqsQueueArn",
        };
        return @field(mappings, field_name);
    }
};

pub const UserError = struct {
    user_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_id = "UserId",
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};
