const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-08-08";
pub const sdk_id: []const u8 = "Connect";
pub const arn_namespace: ?[]const u8 = "connect";
pub const endpoint_prefix: []const u8 = "connect";
pub const sigv4_name: []const u8 = "connect";
pub const name: []const u8 = "AmazonConnectService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-08-08",
    sdk_id: []const u8 = "Connect",
    arn_namespace: ?[]const u8 = "connect",
    endpoint_prefix: []const u8 = "connect",
    sigv4_name: []const u8 = "connect",
    name: []const u8 = "AmazonConnectService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const activate_evaluation_form: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/evaluation-forms/{InstanceId}/{EvaluationFormId}/activate",
        .success_code = 200,
    };

    action_name: []const u8 = "ActivateEvaluationForm",
    Request: type = struct {
        instance_id: []const u8,
        evaluation_form_id: []const u8,
        evaluation_form_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .evaluation_form_id = "EvaluationFormId",
                .evaluation_form_version = "EvaluationFormVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(activate_evaluation_form) } {
            return .{ .service_metadata = service_metadata, .action = activate_evaluation_form };
        }
    },
    Response: type = struct {
        evaluation_form_id: []const u8,
        evaluation_form_arn: []const u8,
        evaluation_form_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_form_id = "EvaluationFormId",
                .evaluation_form_arn = "EvaluationFormArn",
                .evaluation_form_version = "EvaluationFormVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_analytics_data_set: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/analytics-data/instance/{InstanceId}/association",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateAnalyticsDataSet",
    Request: type = struct {
        instance_id: []const u8,
        data_set_id: []const u8,
        target_account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .data_set_id = "DataSetId",
                .target_account_id = "TargetAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_analytics_data_set) } {
            return .{ .service_metadata = service_metadata, .action = associate_analytics_data_set };
        }
    },
    Response: type = struct {
        data_set_id: ?[]const u8 = null,
        target_account_id: ?[]const u8 = null,
        resource_share_id: ?[]const u8 = null,
        resource_share_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .target_account_id = "TargetAccountId",
                .resource_share_id = "ResourceShareId",
                .resource_share_arn = "ResourceShareArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_approved_origin: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/approved-origin",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateApprovedOrigin",
    Request: type = struct {
        instance_id: []const u8,
        origin: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .origin = "Origin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_approved_origin) } {
            return .{ .service_metadata = service_metadata, .action = associate_approved_origin };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const associate_bot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/bot",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateBot",
    Request: type = struct {
        instance_id: []const u8,
        lex_bot: ?LexBot = null,
        lex_v2_bot: ?LexV2Bot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .lex_bot = "LexBot",
                .lex_v2_bot = "LexV2Bot",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_bot) } {
            return .{ .service_metadata = service_metadata, .action = associate_bot };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        LimitExceeded,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const associate_default_vocabulary: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/default-vocabulary/{InstanceId}/{LanguageCode}",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateDefaultVocabulary",
    Request: type = struct {
        instance_id: []const u8,
        language_code: []const u8,
        vocabulary_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .language_code = "LanguageCode",
                .vocabulary_id = "VocabularyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_default_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = associate_default_vocabulary };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_flow: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/flow-associations/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateFlow",
    Request: type = struct {
        instance_id: []const u8,
        resource_id: []const u8,
        flow_id: []const u8,
        resource_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .resource_id = "ResourceId",
                .flow_id = "FlowId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_flow) } {
            return .{ .service_metadata = service_metadata, .action = associate_flow };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_instance_storage_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/storage-config",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateInstanceStorageConfig",
    Request: type = struct {
        instance_id: []const u8,
        resource_type: []const u8,
        storage_config: InstanceStorageConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .resource_type = "ResourceType",
                .storage_config = "StorageConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_instance_storage_config) } {
            return .{ .service_metadata = service_metadata, .action = associate_instance_storage_config };
        }
    },
    Response: type = struct {
        association_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_lambda_function: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/lambda-function",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateLambdaFunction",
    Request: type = struct {
        instance_id: []const u8,
        function_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .function_arn = "FunctionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_lambda_function) } {
            return .{ .service_metadata = service_metadata, .action = associate_lambda_function };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const associate_lex_bot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/lex-bot",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateLexBot",
    Request: type = struct {
        instance_id: []const u8,
        lex_bot: LexBot,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .lex_bot = "LexBot",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_lex_bot) } {
            return .{ .service_metadata = service_metadata, .action = associate_lex_bot };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const associate_phone_number_contact_flow: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/phone-number/{PhoneNumberId}/contact-flow",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociatePhoneNumberContactFlow",
    Request: type = struct {
        phone_number_id: []const u8,
        instance_id: []const u8,
        contact_flow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_phone_number_contact_flow) } {
            return .{ .service_metadata = service_metadata, .action = associate_phone_number_contact_flow };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_queue_quick_connects: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/associate-quick-connects",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateQueueQuickConnects",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        quick_connect_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .quick_connect_ids = "QuickConnectIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_queue_quick_connects) } {
            return .{ .service_metadata = service_metadata, .action = associate_queue_quick_connects };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_routing_profile_queues: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/associate-queues",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateRoutingProfileQueues",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        queue_configs: []RoutingProfileQueueConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .queue_configs = "QueueConfigs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_routing_profile_queues) } {
            return .{ .service_metadata = service_metadata, .action = associate_routing_profile_queues };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_security_key: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/security-key",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateSecurityKey",
    Request: type = struct {
        instance_id: []const u8,
        key: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .key = "Key",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_security_key) } {
            return .{ .service_metadata = service_metadata, .action = associate_security_key };
        }
    },
    Response: type = struct {
        association_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const associate_traffic_distribution_group_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/traffic-distribution-group/{TrafficDistributionGroupId}/user",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateTrafficDistributionGroupUser",
    Request: type = struct {
        traffic_distribution_group_id: []const u8,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_distribution_group_id = "TrafficDistributionGroupId",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_traffic_distribution_group_user) } {
            return .{ .service_metadata = service_metadata, .action = associate_traffic_distribution_group_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const associate_user_proficiencies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/associate-proficiencies",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateUserProficiencies",
    Request: type = struct {
        instance_id: []const u8,
        user_id: []const u8,
        user_proficiencies: []UserProficiency,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .user_id = "UserId",
                .user_proficiencies = "UserProficiencies",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_user_proficiencies) } {
            return .{ .service_metadata = service_metadata, .action = associate_user_proficiencies };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const batch_associate_analytics_data_set: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/analytics-data/instance/{InstanceId}/associations",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchAssociateAnalyticsDataSet",
    Request: type = struct {
        instance_id: []const u8,
        data_set_ids: [][]const u8,
        target_account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .data_set_ids = "DataSetIds",
                .target_account_id = "TargetAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_associate_analytics_data_set) } {
            return .{ .service_metadata = service_metadata, .action = batch_associate_analytics_data_set };
        }
    },
    Response: type = struct {
        created: ?[]AnalyticsDataAssociationResult = null,
        errors: ?[]ErrorResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created = "Created",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const batch_disassociate_analytics_data_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/analytics-data/instance/{InstanceId}/associations",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDisassociateAnalyticsDataSet",
    Request: type = struct {
        instance_id: []const u8,
        data_set_ids: [][]const u8,
        target_account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .data_set_ids = "DataSetIds",
                .target_account_id = "TargetAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_disassociate_analytics_data_set) } {
            return .{ .service_metadata = service_metadata, .action = batch_disassociate_analytics_data_set };
        }
    },
    Response: type = struct {
        deleted: ?[][]const u8 = null,
        errors: ?[]ErrorResult = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deleted = "Deleted",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const batch_get_flow_association: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/flow-associations-batch/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchGetFlowAssociation",
    Request: type = struct {
        instance_id: []const u8,
        resource_ids: [][]const u8,
        resource_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .resource_ids = "ResourceIds",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_flow_association) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_flow_association };
        }
    },
    Response: type = struct {
        flow_association_summary_list: ?[]FlowAssociationSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_association_summary_list = "FlowAssociationSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const batch_put_contact: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact/batch/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchPutContact",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        instance_id: []const u8,
        contact_data_request_list: []struct {
            system_endpoint: ?Endpoint = null,
            customer_endpoint: ?Endpoint = null,
            request_identifier: ?[]const u8 = null,
            queue_id: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            campaign: ?struct {
                campaign_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .campaign_id = "CampaignId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .system_endpoint = "SystemEndpoint",
                    .customer_endpoint = "CustomerEndpoint",
                    .request_identifier = "RequestIdentifier",
                    .queue_id = "QueueId",
                    .attributes = "Attributes",
                    .campaign = "Campaign",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .instance_id = "InstanceId",
                .contact_data_request_list = "ContactDataRequestList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_put_contact) } {
            return .{ .service_metadata = service_metadata, .action = batch_put_contact };
        }
    },
    Response: type = struct {
        successful_request_list: ?[]struct {
            request_identifier: ?[]const u8 = null,
            contact_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .request_identifier = "RequestIdentifier",
                    .contact_id = "ContactId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        failed_request_list: ?[]struct {
            request_identifier: ?[]const u8 = null,
            failure_reason_code: ?[]const u8 = null,
            failure_reason_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .request_identifier = "RequestIdentifier",
                    .failure_reason_code = "FailureReasonCode",
                    .failure_reason_message = "FailureReasonMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_request_list = "SuccessfulRequestList",
                .failed_request_list = "FailedRequestList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Idempotency,
        InternalService,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const claim_phone_number: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-number/claim",
        .success_code = 200,
    };

    action_name: []const u8 = "ClaimPhoneNumber",
    Request: type = struct {
        target_arn: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        phone_number: []const u8,
        phone_number_description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "TargetArn",
                .instance_id = "InstanceId",
                .phone_number = "PhoneNumber",
                .phone_number_description = "PhoneNumberDescription",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(claim_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = claim_phone_number };
        }
    },
    Response: type = struct {
        phone_number_id: ?[]const u8 = null,
        phone_number_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .phone_number_arn = "PhoneNumberArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Idempotency,
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_agent_status: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/agent-status/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAgentStatus",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        state: []const u8,
        display_order: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .state = "State",
                .display_order = "DisplayOrder",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_agent_status) } {
            return .{ .service_metadata = service_metadata, .action = create_agent_status };
        }
    },
    Response: type = struct {
        agent_status_arn: ?[]const u8 = null,
        agent_status_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_status_arn = "AgentStatusARN",
                .agent_status_id = "AgentStatusId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_contact_flow: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact-flows/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateContactFlow",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        type: []const u8,
        description: ?[]const u8 = null,
        content: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .type = "Type",
                .description = "Description",
                .content = "Content",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_contact_flow) } {
            return .{ .service_metadata = service_metadata, .action = create_contact_flow };
        }
    },
    Response: type = struct {
        contact_flow_id: ?[]const u8 = null,
        contact_flow_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_flow_id = "ContactFlowId",
                .contact_flow_arn = "ContactFlowArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidContactFlow,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_contact_flow_module: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact-flow-modules/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateContactFlowModule",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        content: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .content = "Content",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_contact_flow_module) } {
            return .{ .service_metadata = service_metadata, .action = create_contact_flow_module };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DuplicateResource,
        Idempotency,
        InternalService,
        InvalidContactFlowModule,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_evaluation_form: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/evaluation-forms/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEvaluationForm",
    Request: type = struct {
        instance_id: []const u8,
        title: []const u8,
        description: ?[]const u8 = null,
        items: []EvaluationFormItem,
        scoring_strategy: ?EvaluationFormScoringStrategy = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .title = "Title",
                .description = "Description",
                .items = "Items",
                .scoring_strategy = "ScoringStrategy",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_evaluation_form) } {
            return .{ .service_metadata = service_metadata, .action = create_evaluation_form };
        }
    },
    Response: type = struct {
        evaluation_form_id: []const u8,
        evaluation_form_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_form_id = "EvaluationFormId",
                .evaluation_form_arn = "EvaluationFormArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_hours_of_operation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/hours-of-operations/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateHoursOfOperation",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        time_zone: []const u8,
        config: []HoursOfOperationConfig,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .time_zone = "TimeZone",
                .config = "Config",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_hours_of_operation) } {
            return .{ .service_metadata = service_metadata, .action = create_hours_of_operation };
        }
    },
    Response: type = struct {
        hours_of_operation_id: ?[]const u8 = null,
        hours_of_operation_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hours_of_operation_id = "HoursOfOperationId",
                .hours_of_operation_arn = "HoursOfOperationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_instance: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateInstance",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        identity_management_type: []const u8,
        instance_alias: ?[]const u8 = null,
        directory_id: ?[]const u8 = null,
        inbound_calls_enabled: bool,
        outbound_calls_enabled: bool,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .identity_management_type = "IdentityManagementType",
                .instance_alias = "InstanceAlias",
                .directory_id = "DirectoryId",
                .inbound_calls_enabled = "InboundCallsEnabled",
                .outbound_calls_enabled = "OutboundCallsEnabled",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_instance };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_integration_association: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/integration-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIntegrationAssociation",
    Request: type = struct {
        instance_id: []const u8,
        integration_type: []const u8,
        integration_arn: []const u8,
        source_application_url: ?[]const u8 = null,
        source_application_name: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_type = "IntegrationType",
                .integration_arn = "IntegrationArn",
                .source_application_url = "SourceApplicationUrl",
                .source_application_name = "SourceApplicationName",
                .source_type = "SourceType",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_integration_association) } {
            return .{ .service_metadata = service_metadata, .action = create_integration_association };
        }
    },
    Response: type = struct {
        integration_association_id: ?[]const u8 = null,
        integration_association_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .integration_association_id = "IntegrationAssociationId",
                .integration_association_arn = "IntegrationAssociationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_participant: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/create-participant",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateParticipant",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        client_token: ?[]const u8 = null,
        participant_details: struct {
            participant_role: ?[]const u8 = null,
            display_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .participant_role = "ParticipantRole",
                    .display_name = "DisplayName",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .client_token = "ClientToken",
                .participant_details = "ParticipantDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_participant) } {
            return .{ .service_metadata = service_metadata, .action = create_participant };
        }
    },
    Response: type = struct {
        participant_credentials: ?struct {
            participant_token: ?[]const u8 = null,
            expiry: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .participant_token = "ParticipantToken",
                    .expiry = "Expiry",
                };
                return @field(mappings, field_name);
            }
        } = null,
        participant_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .participant_credentials = "ParticipantCredentials",
                .participant_id = "ParticipantId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_persistent_contact_association: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/persistent-contact-association/{InstanceId}/{InitialContactId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePersistentContactAssociation",
    Request: type = struct {
        instance_id: []const u8,
        initial_contact_id: []const u8,
        rehydration_type: []const u8,
        source_contact_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .initial_contact_id = "InitialContactId",
                .rehydration_type = "RehydrationType",
                .source_contact_id = "SourceContactId",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_persistent_contact_association) } {
            return .{ .service_metadata = service_metadata, .action = create_persistent_contact_association };
        }
    },
    Response: type = struct {
        continued_from_contact_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .continued_from_contact_id = "ContinuedFromContactId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_predefined_attribute: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/predefined-attributes/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePredefinedAttribute",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        values: PredefinedAttributeValues,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .values = "Values",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_predefined_attribute) } {
            return .{ .service_metadata = service_metadata, .action = create_predefined_attribute };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_prompt: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/prompts/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreatePrompt",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        s3_uri: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .s3_uri = "S3Uri",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_prompt) } {
            return .{ .service_metadata = service_metadata, .action = create_prompt };
        }
    },
    Response: type = struct {
        prompt_arn: ?[]const u8 = null,
        prompt_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prompt_arn = "PromptARN",
                .prompt_id = "PromptId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        Throttling,
    },
} = .{};
pub const create_queue: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/queues/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateQueue",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        outbound_caller_config: ?OutboundCallerConfig = null,
        hours_of_operation_id: []const u8,
        max_contacts: ?i64 = null,
        quick_connect_ids: ?[][]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .outbound_caller_config = "OutboundCallerConfig",
                .hours_of_operation_id = "HoursOfOperationId",
                .max_contacts = "MaxContacts",
                .quick_connect_ids = "QuickConnectIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_queue) } {
            return .{ .service_metadata = service_metadata, .action = create_queue };
        }
    },
    Response: type = struct {
        queue_arn: ?[]const u8 = null,
        queue_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_arn = "QueueArn",
                .queue_id = "QueueId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_quick_connect: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/quick-connects/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateQuickConnect",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        quick_connect_config: QuickConnectConfig,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .quick_connect_config = "QuickConnectConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_quick_connect) } {
            return .{ .service_metadata = service_metadata, .action = create_quick_connect };
        }
    },
    Response: type = struct {
        quick_connect_arn: ?[]const u8 = null,
        quick_connect_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .quick_connect_arn = "QuickConnectARN",
                .quick_connect_id = "QuickConnectId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_routing_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/routing-profiles/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRoutingProfile",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: []const u8,
        default_outbound_queue_id: []const u8,
        queue_configs: ?[]RoutingProfileQueueConfig = null,
        media_concurrencies: []MediaConcurrency,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        agent_availability_timer: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .default_outbound_queue_id = "DefaultOutboundQueueId",
                .queue_configs = "QueueConfigs",
                .media_concurrencies = "MediaConcurrencies",
                .tags = "Tags",
                .agent_availability_timer = "AgentAvailabilityTimer",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_routing_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_routing_profile };
        }
    },
    Response: type = struct {
        routing_profile_arn: ?[]const u8 = null,
        routing_profile_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_profile_arn = "RoutingProfileArn",
                .routing_profile_id = "RoutingProfileId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_rule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/rules/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateRule",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        trigger_event_source: RuleTriggerEventSource,
        function: []const u8,
        actions: []RuleAction,
        publish_status: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .trigger_event_source = "TriggerEventSource",
                .function = "Function",
                .actions = "Actions",
                .publish_status = "PublishStatus",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rule) } {
            return .{ .service_metadata = service_metadata, .action = create_rule };
        }
    },
    Response: type = struct {
        rule_arn: []const u8,
        rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_arn = "RuleArn",
                .rule_id = "RuleId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_security_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/security-profiles/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSecurityProfile",
    Request: type = struct {
        security_profile_name: []const u8,
        description: ?[]const u8 = null,
        permissions: ?[][]const u8 = null,
        instance_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        allowed_access_control_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tag_restricted_resources: ?[][]const u8 = null,
        applications: ?[]Application = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_name = "SecurityProfileName",
                .description = "Description",
                .permissions = "Permissions",
                .instance_id = "InstanceId",
                .tags = "Tags",
                .allowed_access_control_tags = "AllowedAccessControlTags",
                .tag_restricted_resources = "TagRestrictedResources",
                .applications = "Applications",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "allowed_access_control_tags", field_name))
                return try serializeMap(self.allowed_access_control_tags, self.fieldNameFor("allowed_access_control_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_security_profile };
        }
    },
    Response: type = struct {
        security_profile_id: ?[]const u8 = null,
        security_profile_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_id = "SecurityProfileId",
                .security_profile_arn = "SecurityProfileArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_task_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/task/template",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTaskTemplate",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        contact_flow_id: ?[]const u8 = null,
        constraints: ?TaskTemplateConstraints = null,
        defaults: ?TaskTemplateDefaults = null,
        status: ?[]const u8 = null,
        fields: []TaskTemplateField,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .contact_flow_id = "ContactFlowId",
                .constraints = "Constraints",
                .defaults = "Defaults",
                .status = "Status",
                .fields = "Fields",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_task_template) } {
            return .{ .service_metadata = service_metadata, .action = create_task_template };
        }
    },
    Response: type = struct {
        id: []const u8,
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        PropertyValidation,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_traffic_distribution_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/traffic-distribution-group",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTrafficDistributionGroup",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        instance_id: []const u8,
        client_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .instance_id = "InstanceId",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_traffic_distribution_group) } {
            return .{ .service_metadata = service_metadata, .action = create_traffic_distribution_group };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ResourceNotReady,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_use_case: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/instance/{InstanceId}/integration-associations/{IntegrationAssociationId}/use-cases",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUseCase",
    Request: type = struct {
        instance_id: []const u8,
        integration_association_id: []const u8,
        use_case_type: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_association_id = "IntegrationAssociationId",
                .use_case_type = "UseCaseType",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_use_case) } {
            return .{ .service_metadata = service_metadata, .action = create_use_case };
        }
    },
    Response: type = struct {
        use_case_id: ?[]const u8 = null,
        use_case_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .use_case_id = "UseCaseId",
                .use_case_arn = "UseCaseArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/users/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        username: []const u8,
        password: ?[]const u8 = null,
        identity_info: ?UserIdentityInfo = null,
        phone_config: UserPhoneConfig,
        directory_user_id: ?[]const u8 = null,
        security_profile_ids: [][]const u8,
        routing_profile_id: []const u8,
        hierarchy_group_id: ?[]const u8 = null,
        instance_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .username = "Username",
                .password = "Password",
                .identity_info = "IdentityInfo",
                .phone_config = "PhoneConfig",
                .directory_user_id = "DirectoryUserId",
                .security_profile_ids = "SecurityProfileIds",
                .routing_profile_id = "RoutingProfileId",
                .hierarchy_group_id = "HierarchyGroupId",
                .instance_id = "InstanceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        user_id: ?[]const u8 = null,
        user_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .user_arn = "UserArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_user_hierarchy_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/user-hierarchy-groups/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUserHierarchyGroup",
    Request: type = struct {
        name: []const u8,
        parent_group_id: ?[]const u8 = null,
        instance_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .parent_group_id = "ParentGroupId",
                .instance_id = "InstanceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_hierarchy_group) } {
            return .{ .service_metadata = service_metadata, .action = create_user_hierarchy_group };
        }
    },
    Response: type = struct {
        hierarchy_group_id: ?[]const u8 = null,
        hierarchy_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_group_id = "HierarchyGroupId",
                .hierarchy_group_arn = "HierarchyGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_view: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/views/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateView",
    Request: type = struct {
        instance_id: []const u8,
        client_token: ?[]const u8 = null,
        status: []const u8,
        content: ViewInputContent,
        description: ?[]const u8 = null,
        name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .client_token = "ClientToken",
                .status = "Status",
                .content = "Content",
                .description = "Description",
                .name = "Name",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_view) } {
            return .{ .service_metadata = service_metadata, .action = create_view };
        }
    },
    Response: type = struct {
        view: ?View = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .view = "View",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        ServiceQuotaExceeded,
        TooManyRequests,
    },
} = .{};
pub const create_view_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/views/{InstanceId}/{ViewId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateViewVersion",
    Request: type = struct {
        instance_id: []const u8,
        view_id: []const u8,
        version_description: ?[]const u8 = null,
        view_content_sha256: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .view_id = "ViewId",
                .version_description = "VersionDescription",
                .view_content_sha256 = "ViewContentSha256",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_view_version) } {
            return .{ .service_metadata = service_metadata, .action = create_view_version };
        }
    },
    Response: type = struct {
        view: ?View = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .view = "View",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        ServiceQuotaExceeded,
        TooManyRequests,
    },
} = .{};
pub const create_vocabulary: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/vocabulary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateVocabulary",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        instance_id: []const u8,
        vocabulary_name: []const u8,
        language_code: []const u8,
        content: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "ClientToken",
                .instance_id = "InstanceId",
                .vocabulary_name = "VocabularyName",
                .language_code = "LanguageCode",
                .content = "Content",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = create_vocabulary };
        }
    },
    Response: type = struct {
        vocabulary_arn: []const u8,
        vocabulary_id: []const u8,
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_arn = "VocabularyArn",
                .vocabulary_id = "VocabularyId",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const deactivate_evaluation_form: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/evaluation-forms/{InstanceId}/{EvaluationFormId}/deactivate",
        .success_code = 200,
    };

    action_name: []const u8 = "DeactivateEvaluationForm",
    Request: type = struct {
        instance_id: []const u8,
        evaluation_form_id: []const u8,
        evaluation_form_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .evaluation_form_id = "EvaluationFormId",
                .evaluation_form_version = "EvaluationFormVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deactivate_evaluation_form) } {
            return .{ .service_metadata = service_metadata, .action = deactivate_evaluation_form };
        }
    },
    Response: type = struct {
        evaluation_form_id: []const u8,
        evaluation_form_arn: []const u8,
        evaluation_form_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_form_id = "EvaluationFormId",
                .evaluation_form_arn = "EvaluationFormArn",
                .evaluation_form_version = "EvaluationFormVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_contact_evaluation: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/contact-evaluations/{InstanceId}/{EvaluationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteContactEvaluation",
    Request: type = struct {
        instance_id: []const u8,
        evaluation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .evaluation_id = "EvaluationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_contact_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = delete_contact_evaluation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_contact_flow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/contact-flows/{InstanceId}/{ContactFlowId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteContactFlow",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_contact_flow) } {
            return .{ .service_metadata = service_metadata, .action = delete_contact_flow };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_contact_flow_module: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/contact-flow-modules/{InstanceId}/{ContactFlowModuleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteContactFlowModule",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_module_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_module_id = "ContactFlowModuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_contact_flow_module) } {
            return .{ .service_metadata = service_metadata, .action = delete_contact_flow_module };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_evaluation_form: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/evaluation-forms/{InstanceId}/{EvaluationFormId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEvaluationForm",
    Request: type = struct {
        instance_id: []const u8,
        evaluation_form_id: []const u8,
        evaluation_form_version: ?i64 = null,

        pub const http_query = .{
            .evaluation_form_version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .evaluation_form_id = "EvaluationFormId",
                .evaluation_form_version = "EvaluationFormVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_evaluation_form) } {
            return .{ .service_metadata = service_metadata, .action = delete_evaluation_form };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_hours_of_operation: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/hours-of-operations/{InstanceId}/{HoursOfOperationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteHoursOfOperation",
    Request: type = struct {
        instance_id: []const u8,
        hours_of_operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .hours_of_operation_id = "HoursOfOperationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_hours_of_operation) } {
            return .{ .service_metadata = service_metadata, .action = delete_hours_of_operation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_instance: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInstance",
    Request: type = struct {
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_instance };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const delete_integration_association: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/integration-associations/{IntegrationAssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteIntegrationAssociation",
    Request: type = struct {
        instance_id: []const u8,
        integration_association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_association_id = "IntegrationAssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_integration_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_integration_association };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_predefined_attribute: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/predefined-attributes/{InstanceId}/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePredefinedAttribute",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_predefined_attribute) } {
            return .{ .service_metadata = service_metadata, .action = delete_predefined_attribute };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_prompt: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/prompts/{InstanceId}/{PromptId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePrompt",
    Request: type = struct {
        instance_id: []const u8,
        prompt_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .prompt_id = "PromptId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_prompt) } {
            return .{ .service_metadata = service_metadata, .action = delete_prompt };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_queue: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/queues/{InstanceId}/{QueueId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteQueue",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_queue) } {
            return .{ .service_metadata = service_metadata, .action = delete_queue };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_quick_connect: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/quick-connects/{InstanceId}/{QuickConnectId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteQuickConnect",
    Request: type = struct {
        instance_id: []const u8,
        quick_connect_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .quick_connect_id = "QuickConnectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_quick_connect) } {
            return .{ .service_metadata = service_metadata, .action = delete_quick_connect };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_routing_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRoutingProfile",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_routing_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_routing_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_rule: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/rules/{InstanceId}/{RuleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRule",
    Request: type = struct {
        instance_id: []const u8,
        rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .rule_id = "RuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rule) } {
            return .{ .service_metadata = service_metadata, .action = delete_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_security_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/security-profiles/{InstanceId}/{SecurityProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSecurityProfile",
    Request: type = struct {
        instance_id: []const u8,
        security_profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .security_profile_id = "SecurityProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_security_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_task_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/task/template/{TaskTemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTaskTemplate",
    Request: type = struct {
        instance_id: []const u8,
        task_template_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .task_template_id = "TaskTemplateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_task_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_task_template };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_traffic_distribution_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/traffic-distribution-group/{TrafficDistributionGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTrafficDistributionGroup",
    Request: type = struct {
        traffic_distribution_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_distribution_group_id = "TrafficDistributionGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_traffic_distribution_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_traffic_distribution_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceInUse,
        Throttling,
    },
} = .{};
pub const delete_use_case: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/integration-associations/{IntegrationAssociationId}/use-cases/{UseCaseId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUseCase",
    Request: type = struct {
        instance_id: []const u8,
        integration_association_id: []const u8,
        use_case_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_association_id = "IntegrationAssociationId",
                .use_case_id = "UseCaseId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_use_case) } {
            return .{ .service_metadata = service_metadata, .action = delete_use_case };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/users/{InstanceId}/{UserId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        instance_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_user_hierarchy_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/user-hierarchy-groups/{InstanceId}/{HierarchyGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUserHierarchyGroup",
    Request: type = struct {
        hierarchy_group_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_group_id = "HierarchyGroupId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_hierarchy_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_hierarchy_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_view: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/views/{InstanceId}/{ViewId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteView",
    Request: type = struct {
        instance_id: []const u8,
        view_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .view_id = "ViewId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_view) } {
            return .{ .service_metadata = service_metadata, .action = delete_view };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_view_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/views/{InstanceId}/{ViewId}/versions/{ViewVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteViewVersion",
    Request: type = struct {
        instance_id: []const u8,
        view_id: []const u8,
        view_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .view_id = "ViewId",
                .view_version = "ViewVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_view_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_view_version };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_vocabulary: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/vocabulary-remove/{InstanceId}/{VocabularyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteVocabulary",
    Request: type = struct {
        instance_id: []const u8,
        vocabulary_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .vocabulary_id = "VocabularyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = delete_vocabulary };
        }
    },
    Response: type = struct {
        vocabulary_arn: []const u8,
        vocabulary_id: []const u8,
        state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_arn = "VocabularyArn",
                .vocabulary_id = "VocabularyId",
                .state = "State",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_agent_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/agent-status/{InstanceId}/{AgentStatusId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAgentStatus",
    Request: type = struct {
        instance_id: []const u8,
        agent_status_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .agent_status_id = "AgentStatusId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_agent_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_agent_status };
        }
    },
    Response: type = struct {
        agent_status: ?struct {
            agent_status_arn: ?[]const u8 = null,
            agent_status_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            type: ?[]const u8 = null,
            display_order: ?i64 = null,
            state: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .agent_status_arn = "AgentStatusARN",
                    .agent_status_id = "AgentStatusId",
                    .name = "Name",
                    .description = "Description",
                    .type = "Type",
                    .display_order = "DisplayOrder",
                    .state = "State",
                    .tags = "Tags",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_status = "AgentStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_contact: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contacts/{InstanceId}/{ContactId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeContact",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_contact) } {
            return .{ .service_metadata = service_metadata, .action = describe_contact };
        }
    },
    Response: type = struct {
        contact: ?struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            initial_contact_id: ?[]const u8 = null,
            previous_contact_id: ?[]const u8 = null,
            initiation_method: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            channel: ?[]const u8 = null,
            queue_info: ?struct {
                id: ?[]const u8 = null,
                enqueue_timestamp: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .enqueue_timestamp = "EnqueueTimestamp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            agent_info: ?struct {
                id: ?[]const u8 = null,
                connected_to_agent_timestamp: ?i64 = null,
                agent_pause_duration_in_seconds: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .connected_to_agent_timestamp = "ConnectedToAgentTimestamp",
                        .agent_pause_duration_in_seconds = "AgentPauseDurationInSeconds",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            initiation_timestamp: ?i64 = null,
            disconnect_timestamp: ?i64 = null,
            last_update_timestamp: ?i64 = null,
            last_paused_timestamp: ?i64 = null,
            last_resumed_timestamp: ?i64 = null,
            total_pause_count: ?i64 = null,
            total_pause_duration_in_seconds: ?i64 = null,
            scheduled_timestamp: ?i64 = null,
            related_contact_id: ?[]const u8 = null,
            wisdom_info: ?struct {
                session_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .session_arn = "SessionArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            queue_time_adjustment_seconds: ?i64 = null,
            queue_priority: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .initial_contact_id = "InitialContactId",
                    .previous_contact_id = "PreviousContactId",
                    .initiation_method = "InitiationMethod",
                    .name = "Name",
                    .description = "Description",
                    .channel = "Channel",
                    .queue_info = "QueueInfo",
                    .agent_info = "AgentInfo",
                    .initiation_timestamp = "InitiationTimestamp",
                    .disconnect_timestamp = "DisconnectTimestamp",
                    .last_update_timestamp = "LastUpdateTimestamp",
                    .last_paused_timestamp = "LastPausedTimestamp",
                    .last_resumed_timestamp = "LastResumedTimestamp",
                    .total_pause_count = "TotalPauseCount",
                    .total_pause_duration_in_seconds = "TotalPauseDurationInSeconds",
                    .scheduled_timestamp = "ScheduledTimestamp",
                    .related_contact_id = "RelatedContactId",
                    .wisdom_info = "WisdomInfo",
                    .queue_time_adjustment_seconds = "QueueTimeAdjustmentSeconds",
                    .queue_priority = "QueuePriority",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact = "Contact",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_contact_evaluation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact-evaluations/{InstanceId}/{EvaluationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeContactEvaluation",
    Request: type = struct {
        instance_id: []const u8,
        evaluation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .evaluation_id = "EvaluationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_contact_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = describe_contact_evaluation };
        }
    },
    Response: type = struct {
        evaluation: struct {
            evaluation_id: []const u8,
            evaluation_arn: []const u8,
            metadata: struct {
                contact_id: []const u8,
                evaluator_arn: []const u8,
                contact_agent_id: ?[]const u8 = null,
                score: ?EvaluationScore = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .contact_id = "ContactId",
                        .evaluator_arn = "EvaluatorArn",
                        .contact_agent_id = "ContactAgentId",
                        .score = "Score",
                    };
                    return @field(mappings, field_name);
                }
            },
            answers: []struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    value: ?EvaluationAnswerData = null,
                    system_suggested_value: ?EvaluationAnswerData = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .value = "Value",
                            .system_suggested_value = "SystemSuggestedValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
            },
            notes: []struct {
                key: ?[]const u8 = null,
                value: ?EvaluationNote = null,
            },
            status: []const u8,
            scores: ?[]struct {
                key: ?[]const u8 = null,
                value: ?EvaluationScore = null,
            } = null,
            created_time: i64,
            last_modified_time: i64,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_id = "EvaluationId",
                    .evaluation_arn = "EvaluationArn",
                    .metadata = "Metadata",
                    .answers = "Answers",
                    .notes = "Notes",
                    .status = "Status",
                    .scores = "Scores",
                    .created_time = "CreatedTime",
                    .last_modified_time = "LastModifiedTime",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "answers", field_name))
                    return try serializeMap(self.answers, self.fieldNameFor("answers"), options, out_stream);
                if (std.mem.eql(u8, "notes", field_name))
                    return try serializeMap(self.notes, self.fieldNameFor("notes"), options, out_stream);
                if (std.mem.eql(u8, "scores", field_name))
                    return try serializeMap(self.scores, self.fieldNameFor("scores"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },
        evaluation_form: struct {
            evaluation_form_version: i64,
            evaluation_form_id: []const u8,
            evaluation_form_arn: []const u8,
            title: []const u8,
            description: ?[]const u8 = null,
            items: []EvaluationFormItem,
            scoring_strategy: ?EvaluationFormScoringStrategy = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_form_version = "EvaluationFormVersion",
                    .evaluation_form_id = "EvaluationFormId",
                    .evaluation_form_arn = "EvaluationFormArn",
                    .title = "Title",
                    .description = "Description",
                    .items = "Items",
                    .scoring_strategy = "ScoringStrategy",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation = "Evaluation",
                .evaluation_form = "EvaluationForm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_contact_flow: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact-flows/{InstanceId}/{ContactFlowId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeContactFlow",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_contact_flow) } {
            return .{ .service_metadata = service_metadata, .action = describe_contact_flow };
        }
    },
    Response: type = struct {
        contact_flow: ?struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            description: ?[]const u8 = null,
            content: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .name = "Name",
                    .type = "Type",
                    .state = "State",
                    .description = "Description",
                    .content = "Content",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_flow = "ContactFlow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ContactFlowNotPublished,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_contact_flow_module: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact-flow-modules/{InstanceId}/{ContactFlowModuleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeContactFlowModule",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_module_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_module_id = "ContactFlowModuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_contact_flow_module) } {
            return .{ .service_metadata = service_metadata, .action = describe_contact_flow_module };
        }
    },
    Response: type = struct {
        contact_flow_module: ?struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            content: ?[]const u8 = null,
            description: ?[]const u8 = null,
            state: ?[]const u8 = null,
            status: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .name = "Name",
                    .content = "Content",
                    .description = "Description",
                    .state = "State",
                    .status = "Status",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_flow_module = "ContactFlowModule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_evaluation_form: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/evaluation-forms/{InstanceId}/{EvaluationFormId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeEvaluationForm",
    Request: type = struct {
        instance_id: []const u8,
        evaluation_form_id: []const u8,
        evaluation_form_version: ?i64 = null,

        pub const http_query = .{
            .evaluation_form_version = "version",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .evaluation_form_id = "EvaluationFormId",
                .evaluation_form_version = "EvaluationFormVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_evaluation_form) } {
            return .{ .service_metadata = service_metadata, .action = describe_evaluation_form };
        }
    },
    Response: type = struct {
        evaluation_form: struct {
            evaluation_form_id: []const u8,
            evaluation_form_version: i64,
            locked: bool,
            evaluation_form_arn: []const u8,
            title: []const u8,
            description: ?[]const u8 = null,
            status: []const u8,
            items: []EvaluationFormItem,
            scoring_strategy: ?EvaluationFormScoringStrategy = null,
            created_time: i64,
            created_by: []const u8,
            last_modified_time: i64,
            last_modified_by: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_form_id = "EvaluationFormId",
                    .evaluation_form_version = "EvaluationFormVersion",
                    .locked = "Locked",
                    .evaluation_form_arn = "EvaluationFormArn",
                    .title = "Title",
                    .description = "Description",
                    .status = "Status",
                    .items = "Items",
                    .scoring_strategy = "ScoringStrategy",
                    .created_time = "CreatedTime",
                    .created_by = "CreatedBy",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_by = "LastModifiedBy",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_form = "EvaluationForm",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_hours_of_operation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/hours-of-operations/{InstanceId}/{HoursOfOperationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeHoursOfOperation",
    Request: type = struct {
        instance_id: []const u8,
        hours_of_operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .hours_of_operation_id = "HoursOfOperationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hours_of_operation) } {
            return .{ .service_metadata = service_metadata, .action = describe_hours_of_operation };
        }
    },
    Response: type = struct {
        hours_of_operation: ?HoursOfOperation = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hours_of_operation = "HoursOfOperation",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_instance: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInstance",
    Request: type = struct {
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance };
        }
    },
    Response: type = struct {
        instance: ?struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            identity_management_type: ?[]const u8 = null,
            instance_alias: ?[]const u8 = null,
            created_time: ?i64 = null,
            service_role: ?[]const u8 = null,
            instance_status: ?[]const u8 = null,
            status_reason: ?struct {
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .message = "Message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            inbound_calls_enabled: ?bool = null,
            outbound_calls_enabled: ?bool = null,
            instance_access_url: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .identity_management_type = "IdentityManagementType",
                    .instance_alias = "InstanceAlias",
                    .created_time = "CreatedTime",
                    .service_role = "ServiceRole",
                    .instance_status = "InstanceStatus",
                    .status_reason = "StatusReason",
                    .inbound_calls_enabled = "InboundCallsEnabled",
                    .outbound_calls_enabled = "OutboundCallsEnabled",
                    .instance_access_url = "InstanceAccessUrl",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance = "Instance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const describe_instance_attribute: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/attribute/{AttributeType}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInstanceAttribute",
    Request: type = struct {
        instance_id: []const u8,
        attribute_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .attribute_type = "AttributeType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_attribute };
        }
    },
    Response: type = struct {
        attribute: ?Attribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attribute = "Attribute",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_instance_storage_config: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/storage-config/{AssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInstanceStorageConfig",
    Request: type = struct {
        instance_id: []const u8,
        association_id: []const u8,
        resource_type: []const u8,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .association_id = "AssociationId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_storage_config) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_storage_config };
        }
    },
    Response: type = struct {
        storage_config: ?InstanceStorageConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_config = "StorageConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_phone_number: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-number/{PhoneNumberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = describe_phone_number };
        }
    },
    Response: type = struct {
        claimed_phone_number_summary: ?struct {
            phone_number_id: ?[]const u8 = null,
            phone_number_arn: ?[]const u8 = null,
            phone_number: ?[]const u8 = null,
            phone_number_country_code: ?[]const u8 = null,
            phone_number_type: ?[]const u8 = null,
            phone_number_description: ?[]const u8 = null,
            target_arn: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            phone_number_status: ?struct {
                status: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status = "Status",
                        .message = "Message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            source_phone_number_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .phone_number_id = "PhoneNumberId",
                    .phone_number_arn = "PhoneNumberArn",
                    .phone_number = "PhoneNumber",
                    .phone_number_country_code = "PhoneNumberCountryCode",
                    .phone_number_type = "PhoneNumberType",
                    .phone_number_description = "PhoneNumberDescription",
                    .target_arn = "TargetArn",
                    .instance_id = "InstanceId",
                    .tags = "Tags",
                    .phone_number_status = "PhoneNumberStatus",
                    .source_phone_number_arn = "SourcePhoneNumberArn",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .claimed_phone_number_summary = "ClaimedPhoneNumberSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_predefined_attribute: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/predefined-attributes/{InstanceId}/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePredefinedAttribute",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_predefined_attribute) } {
            return .{ .service_metadata = service_metadata, .action = describe_predefined_attribute };
        }
    },
    Response: type = struct {
        predefined_attribute: ?PredefinedAttribute = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predefined_attribute = "PredefinedAttribute",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_prompt: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prompts/{InstanceId}/{PromptId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribePrompt",
    Request: type = struct {
        instance_id: []const u8,
        prompt_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .prompt_id = "PromptId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_prompt) } {
            return .{ .service_metadata = service_metadata, .action = describe_prompt };
        }
    },
    Response: type = struct {
        prompt: ?Prompt = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prompt = "Prompt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_queue: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/queues/{InstanceId}/{QueueId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeQueue",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_queue) } {
            return .{ .service_metadata = service_metadata, .action = describe_queue };
        }
    },
    Response: type = struct {
        queue: ?Queue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue = "Queue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_quick_connect: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/quick-connects/{InstanceId}/{QuickConnectId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeQuickConnect",
    Request: type = struct {
        instance_id: []const u8,
        quick_connect_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .quick_connect_id = "QuickConnectId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_quick_connect) } {
            return .{ .service_metadata = service_metadata, .action = describe_quick_connect };
        }
    },
    Response: type = struct {
        quick_connect: ?QuickConnect = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .quick_connect = "QuickConnect",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_routing_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRoutingProfile",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_routing_profile) } {
            return .{ .service_metadata = service_metadata, .action = describe_routing_profile };
        }
    },
    Response: type = struct {
        routing_profile: ?RoutingProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_profile = "RoutingProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_rule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rules/{InstanceId}/{RuleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeRule",
    Request: type = struct {
        instance_id: []const u8,
        rule_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .rule_id = "RuleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_rule) } {
            return .{ .service_metadata = service_metadata, .action = describe_rule };
        }
    },
    Response: type = struct {
        rule: struct {
            name: []const u8,
            rule_id: []const u8,
            rule_arn: []const u8,
            trigger_event_source: RuleTriggerEventSource,
            function: []const u8,
            actions: []RuleAction,
            publish_status: []const u8,
            created_time: i64,
            last_updated_time: i64,
            last_updated_by: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .rule_id = "RuleId",
                    .rule_arn = "RuleArn",
                    .trigger_event_source = "TriggerEventSource",
                    .function = "Function",
                    .actions = "Actions",
                    .publish_status = "PublishStatus",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .last_updated_by = "LastUpdatedBy",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule = "Rule",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_security_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/security-profiles/{InstanceId}/{SecurityProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSecurityProfile",
    Request: type = struct {
        security_profile_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_id = "SecurityProfileId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = describe_security_profile };
        }
    },
    Response: type = struct {
        security_profile: ?struct {
            id: ?[]const u8 = null,
            organization_resource_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            security_profile_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            allowed_access_control_tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            tag_restricted_resources: ?[][]const u8 = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .organization_resource_id = "OrganizationResourceId",
                    .arn = "Arn",
                    .security_profile_name = "SecurityProfileName",
                    .description = "Description",
                    .tags = "Tags",
                    .allowed_access_control_tags = "AllowedAccessControlTags",
                    .tag_restricted_resources = "TagRestrictedResources",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                if (std.mem.eql(u8, "allowed_access_control_tags", field_name))
                    return try serializeMap(self.allowed_access_control_tags, self.fieldNameFor("allowed_access_control_tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile = "SecurityProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_traffic_distribution_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/traffic-distribution-group/{TrafficDistributionGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTrafficDistributionGroup",
    Request: type = struct {
        traffic_distribution_group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_distribution_group_id = "TrafficDistributionGroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_traffic_distribution_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_traffic_distribution_group };
        }
    },
    Response: type = struct {
        traffic_distribution_group: ?struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            instance_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            is_default: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .description = "Description",
                    .instance_arn = "InstanceArn",
                    .status = "Status",
                    .tags = "Tags",
                    .is_default = "IsDefault",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_distribution_group = "TrafficDistributionGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/users/{InstanceId}/{UserId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUser",
    Request: type = struct {
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_user };
        }
    },
    Response: type = struct {
        user: ?struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            username: ?[]const u8 = null,
            identity_info: ?UserIdentityInfo = null,
            phone_config: ?UserPhoneConfig = null,
            directory_user_id: ?[]const u8 = null,
            security_profile_ids: ?[][]const u8 = null,
            routing_profile_id: ?[]const u8 = null,
            hierarchy_group_id: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .username = "Username",
                    .identity_info = "IdentityInfo",
                    .phone_config = "PhoneConfig",
                    .directory_user_id = "DirectoryUserId",
                    .security_profile_ids = "SecurityProfileIds",
                    .routing_profile_id = "RoutingProfileId",
                    .hierarchy_group_id = "HierarchyGroupId",
                    .tags = "Tags",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_user_hierarchy_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user-hierarchy-groups/{InstanceId}/{HierarchyGroupId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUserHierarchyGroup",
    Request: type = struct {
        hierarchy_group_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_group_id = "HierarchyGroupId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_hierarchy_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_hierarchy_group };
        }
    },
    Response: type = struct {
        hierarchy_group: ?struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            level_id: ?[]const u8 = null,
            hierarchy_path: ?struct {
                level_one: ?HierarchyGroupSummary = null,
                level_two: ?HierarchyGroupSummary = null,
                level_three: ?HierarchyGroupSummary = null,
                level_four: ?HierarchyGroupSummary = null,
                level_five: ?HierarchyGroupSummary = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .level_one = "LevelOne",
                        .level_two = "LevelTwo",
                        .level_three = "LevelThree",
                        .level_four = "LevelFour",
                        .level_five = "LevelFive",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .level_id = "LevelId",
                    .hierarchy_path = "HierarchyPath",
                    .tags = "Tags",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_group = "HierarchyGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_user_hierarchy_structure: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user-hierarchy-structure/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUserHierarchyStructure",
    Request: type = struct {
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_hierarchy_structure) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_hierarchy_structure };
        }
    },
    Response: type = struct {
        hierarchy_structure: ?struct {
            level_one: ?HierarchyLevel = null,
            level_two: ?HierarchyLevel = null,
            level_three: ?HierarchyLevel = null,
            level_four: ?HierarchyLevel = null,
            level_five: ?HierarchyLevel = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .level_one = "LevelOne",
                    .level_two = "LevelTwo",
                    .level_three = "LevelThree",
                    .level_four = "LevelFour",
                    .level_five = "LevelFive",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_structure = "HierarchyStructure",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_view: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/views/{InstanceId}/{ViewId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeView",
    Request: type = struct {
        instance_id: []const u8,
        view_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .view_id = "ViewId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_view) } {
            return .{ .service_metadata = service_metadata, .action = describe_view };
        }
    },
    Response: type = struct {
        view: ?View = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .view = "View",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const describe_vocabulary: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/vocabulary/{InstanceId}/{VocabularyId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeVocabulary",
    Request: type = struct {
        instance_id: []const u8,
        vocabulary_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .vocabulary_id = "VocabularyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vocabulary) } {
            return .{ .service_metadata = service_metadata, .action = describe_vocabulary };
        }
    },
    Response: type = struct {
        vocabulary: struct {
            name: []const u8,
            id: []const u8,
            arn: []const u8,
            language_code: []const u8,
            state: []const u8,
            last_modified_time: i64,
            failure_reason: ?[]const u8 = null,
            content: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .arn = "Arn",
                    .language_code = "LanguageCode",
                    .state = "State",
                    .last_modified_time = "LastModifiedTime",
                    .failure_reason = "FailureReason",
                    .content = "Content",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary = "Vocabulary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_analytics_data_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/analytics-data/instance/{InstanceId}/association",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateAnalyticsDataSet",
    Request: type = struct {
        instance_id: []const u8,
        data_set_id: []const u8,
        target_account_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .data_set_id = "DataSetId",
                .target_account_id = "TargetAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_analytics_data_set) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_analytics_data_set };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_approved_origin: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/approved-origin",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateApprovedOrigin",
    Request: type = struct {
        instance_id: []const u8,
        origin: []const u8,

        pub const http_query = .{
            .origin = "origin",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .origin = "Origin",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_approved_origin) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_approved_origin };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_bot: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/instance/{InstanceId}/bot",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateBot",
    Request: type = struct {
        instance_id: []const u8,
        lex_bot: ?LexBot = null,
        lex_v2_bot: ?LexV2Bot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .lex_bot = "LexBot",
                .lex_v2_bot = "LexV2Bot",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_bot) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_bot };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_flow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/flow-associations/{InstanceId}/{ResourceId}/{ResourceType}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateFlow",
    Request: type = struct {
        instance_id: []const u8,
        resource_id: []const u8,
        resource_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_flow) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_flow };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_instance_storage_config: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/storage-config/{AssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateInstanceStorageConfig",
    Request: type = struct {
        instance_id: []const u8,
        association_id: []const u8,
        resource_type: []const u8,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .association_id = "AssociationId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_instance_storage_config) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_instance_storage_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_lambda_function: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/lambda-function",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateLambdaFunction",
    Request: type = struct {
        instance_id: []const u8,
        function_arn: []const u8,

        pub const http_query = .{
            .function_arn = "functionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .function_arn = "FunctionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_lambda_function) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_lambda_function };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_lex_bot: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/lex-bot",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateLexBot",
    Request: type = struct {
        instance_id: []const u8,
        bot_name: []const u8,
        lex_region: []const u8,

        pub const http_query = .{
            .bot_name = "botName",
            .lex_region = "lexRegion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .bot_name = "BotName",
                .lex_region = "LexRegion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_lex_bot) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_lex_bot };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_phone_number_contact_flow: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/phone-number/{PhoneNumberId}/contact-flow",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociatePhoneNumberContactFlow",
    Request: type = struct {
        phone_number_id: []const u8,
        instance_id: []const u8,

        pub const http_query = .{
            .instance_id = "instanceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_phone_number_contact_flow) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_phone_number_contact_flow };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_queue_quick_connects: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/disassociate-quick-connects",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateQueueQuickConnects",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        quick_connect_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .quick_connect_ids = "QuickConnectIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_queue_quick_connects) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_queue_quick_connects };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_routing_profile_queues: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/disassociate-queues",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateRoutingProfileQueues",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        queue_references: []RoutingProfileQueueReference,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .queue_references = "QueueReferences",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_routing_profile_queues) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_routing_profile_queues };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_security_key: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/instance/{InstanceId}/security-key/{AssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateSecurityKey",
    Request: type = struct {
        instance_id: []const u8,
        association_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .association_id = "AssociationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_security_key) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_security_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_traffic_distribution_group_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/traffic-distribution-group/{TrafficDistributionGroupId}/user",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateTrafficDistributionGroupUser",
    Request: type = struct {
        traffic_distribution_group_id: []const u8,
        user_id: []const u8,
        instance_id: []const u8,

        pub const http_query = .{
            .user_id = "UserId",
            .instance_id = "InstanceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_distribution_group_id = "TrafficDistributionGroupId",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_traffic_distribution_group_user) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_traffic_distribution_group_user };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const disassociate_user_proficiencies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/disassociate-proficiencies",
        .success_code = 200,
    };

    action_name: []const u8 = "DisassociateUserProficiencies",
    Request: type = struct {
        instance_id: []const u8,
        user_id: []const u8,
        user_proficiencies: []struct {
            attribute_name: []const u8,
            attribute_value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_name = "AttributeName",
                    .attribute_value = "AttributeValue",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .user_id = "UserId",
                .user_proficiencies = "UserProficiencies",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_user_proficiencies) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_user_proficiencies };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const dismiss_user_contact: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/contact",
        .success_code = 200,
    };

    action_name: []const u8 = "DismissUserContact",
    Request: type = struct {
        user_id: []const u8,
        instance_id: []const u8,
        contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(dismiss_user_contact) } {
            return .{ .service_metadata = service_metadata, .action = dismiss_user_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_contact_attributes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact/attributes/{InstanceId}/{InitialContactId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetContactAttributes",
    Request: type = struct {
        instance_id: []const u8,
        initial_contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .initial_contact_id = "InitialContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_contact_attributes) } {
            return .{ .service_metadata = service_metadata, .action = get_contact_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const get_current_metric_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/metrics/current/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCurrentMetricData",
    Request: type = struct {
        instance_id: []const u8,
        filters: Filters,
        groupings: ?[][]const u8 = null,
        current_metrics: []CurrentMetric,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sort_criteria: ?[]struct {
            sort_by_metric: ?[]const u8 = null,
            sort_order: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sort_by_metric = "SortByMetric",
                    .sort_order = "SortOrder",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .filters = "Filters",
                .groupings = "Groupings",
                .current_metrics = "CurrentMetrics",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sort_criteria = "SortCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_current_metric_data) } {
            return .{ .service_metadata = service_metadata, .action = get_current_metric_data };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        metric_results: ?[]struct {
            dimensions: ?Dimensions = null,
            collections: ?[]struct {
                metric: ?CurrentMetric = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metric = "Metric",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dimensions = "Dimensions",
                    .collections = "Collections",
                };
                return @field(mappings, field_name);
            }
        } = null,
        data_snapshot_time: ?i64 = null,
        approximate_total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .metric_results = "MetricResults",
                .data_snapshot_time = "DataSnapshotTime",
                .approximate_total_count = "ApproximateTotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_current_user_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/metrics/userdata/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCurrentUserData",
    Request: type = struct {
        instance_id: []const u8,
        filters: struct {
            queues: ?[][]const u8 = null,
            contact_filter: ?struct {
                contact_states: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .contact_states = "ContactStates",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            routing_profiles: ?[][]const u8 = null,
            agents: ?[][]const u8 = null,
            user_hierarchy_groups: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .queues = "Queues",
                    .contact_filter = "ContactFilter",
                    .routing_profiles = "RoutingProfiles",
                    .agents = "Agents",
                    .user_hierarchy_groups = "UserHierarchyGroups",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_current_user_data) } {
            return .{ .service_metadata = service_metadata, .action = get_current_user_data };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        user_data_list: ?[]struct {
            user: ?struct {
                id: ?[]const u8 = null,
                arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .arn = "Arn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            routing_profile: ?RoutingProfileReference = null,
            hierarchy_path: ?struct {
                level_one: ?HierarchyGroupSummaryReference = null,
                level_two: ?HierarchyGroupSummaryReference = null,
                level_three: ?HierarchyGroupSummaryReference = null,
                level_four: ?HierarchyGroupSummaryReference = null,
                level_five: ?HierarchyGroupSummaryReference = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .level_one = "LevelOne",
                        .level_two = "LevelTwo",
                        .level_three = "LevelThree",
                        .level_four = "LevelFour",
                        .level_five = "LevelFive",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            status: ?struct {
                status_start_timestamp: ?i64 = null,
                status_arn: ?[]const u8 = null,
                status_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status_start_timestamp = "StatusStartTimestamp",
                        .status_arn = "StatusArn",
                        .status_name = "StatusName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            available_slots_by_channel: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            max_slots_by_channel: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            active_slots_by_channel: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,
            contacts: ?[]struct {
                contact_id: ?[]const u8 = null,
                channel: ?[]const u8 = null,
                initiation_method: ?[]const u8 = null,
                agent_contact_state: ?[]const u8 = null,
                state_start_timestamp: ?i64 = null,
                connected_to_agent_timestamp: ?i64 = null,
                queue: ?QueueReference = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .contact_id = "ContactId",
                        .channel = "Channel",
                        .initiation_method = "InitiationMethod",
                        .agent_contact_state = "AgentContactState",
                        .state_start_timestamp = "StateStartTimestamp",
                        .connected_to_agent_timestamp = "ConnectedToAgentTimestamp",
                        .queue = "Queue",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            next_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user = "User",
                    .routing_profile = "RoutingProfile",
                    .hierarchy_path = "HierarchyPath",
                    .status = "Status",
                    .available_slots_by_channel = "AvailableSlotsByChannel",
                    .max_slots_by_channel = "MaxSlotsByChannel",
                    .active_slots_by_channel = "ActiveSlotsByChannel",
                    .contacts = "Contacts",
                    .next_status = "NextStatus",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "available_slots_by_channel", field_name))
                    return try serializeMap(self.available_slots_by_channel, self.fieldNameFor("available_slots_by_channel"), options, out_stream);
                if (std.mem.eql(u8, "max_slots_by_channel", field_name))
                    return try serializeMap(self.max_slots_by_channel, self.fieldNameFor("max_slots_by_channel"), options, out_stream);
                if (std.mem.eql(u8, "active_slots_by_channel", field_name))
                    return try serializeMap(self.active_slots_by_channel, self.fieldNameFor("active_slots_by_channel"), options, out_stream);
                return false;
            }
        } = null,
        approximate_total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .user_data_list = "UserDataList",
                .approximate_total_count = "ApproximateTotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_federation_token: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user/federate/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFederationToken",
    Request: type = struct {
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_federation_token) } {
            return .{ .service_metadata = service_metadata, .action = get_federation_token };
        }
    },
    Response: type = struct {
        credentials: ?struct {
            access_token: ?[]const u8 = null,
            access_token_expiration: ?i64 = null,
            refresh_token: ?[]const u8 = null,
            refresh_token_expiration: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_token = "AccessToken",
                    .access_token_expiration = "AccessTokenExpiration",
                    .refresh_token = "RefreshToken",
                    .refresh_token_expiration = "RefreshTokenExpiration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sign_in_url: ?[]const u8 = null,
        user_arn: ?[]const u8 = null,
        user_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .credentials = "Credentials",
                .sign_in_url = "SignInUrl",
                .user_arn = "UserArn",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        UserNotFound,
    },
} = .{};
pub const get_flow_association: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/flow-associations/{InstanceId}/{ResourceId}/{ResourceType}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFlowAssociation",
    Request: type = struct {
        instance_id: []const u8,
        resource_id: []const u8,
        resource_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .resource_id = "ResourceId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_flow_association) } {
            return .{ .service_metadata = service_metadata, .action = get_flow_association };
        }
    },
    Response: type = struct {
        resource_id: ?[]const u8 = null,
        flow_id: ?[]const u8 = null,
        resource_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .flow_id = "FlowId",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_metric_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/metrics/historical/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMetricData",
    Request: type = struct {
        instance_id: []const u8,
        start_time: i64,
        end_time: i64,
        filters: Filters,
        groupings: ?[][]const u8 = null,
        historical_metrics: []HistoricalMetric,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .filters = "Filters",
                .groupings = "Groupings",
                .historical_metrics = "HistoricalMetrics",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_metric_data) } {
            return .{ .service_metadata = service_metadata, .action = get_metric_data };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        metric_results: ?[]struct {
            dimensions: ?Dimensions = null,
            collections: ?[]struct {
                metric: ?HistoricalMetric = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metric = "Metric",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dimensions = "Dimensions",
                    .collections = "Collections",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .metric_results = "MetricResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_metric_data_v2: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/metrics/data",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMetricDataV2",
    Request: type = struct {
        resource_arn: []const u8,
        start_time: i64,
        end_time: i64,
        interval: ?struct {
            time_zone: ?[]const u8 = null,
            interval_period: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .time_zone = "TimeZone",
                    .interval_period = "IntervalPeriod",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: []struct {
            filter_key: ?[]const u8 = null,
            filter_values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .filter_key = "FilterKey",
                    .filter_values = "FilterValues",
                };
                return @field(mappings, field_name);
            }
        },
        groupings: ?[][]const u8 = null,
        metrics: []MetricV2,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .interval = "Interval",
                .filters = "Filters",
                .groupings = "Groupings",
                .metrics = "Metrics",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_metric_data_v2) } {
            return .{ .service_metadata = service_metadata, .action = get_metric_data_v2 };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        metric_results: ?[]struct {
            dimensions: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            metric_interval: ?struct {
                interval: ?[]const u8 = null,
                start_time: ?i64 = null,
                end_time: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .interval = "Interval",
                        .start_time = "StartTime",
                        .end_time = "EndTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            collections: ?[]struct {
                metric: ?MetricV2 = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metric = "Metric",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dimensions = "Dimensions",
                    .metric_interval = "MetricInterval",
                    .collections = "Collections",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "dimensions", field_name))
                    return try serializeMap(self.dimensions, self.fieldNameFor("dimensions"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .metric_results = "MetricResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_prompt_file: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prompts/{InstanceId}/{PromptId}/file",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPromptFile",
    Request: type = struct {
        instance_id: []const u8,
        prompt_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .prompt_id = "PromptId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_prompt_file) } {
            return .{ .service_metadata = service_metadata, .action = get_prompt_file };
        }
    },
    Response: type = struct {
        prompt_presigned_url: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        last_modified_region: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prompt_presigned_url = "PromptPresignedUrl",
                .last_modified_time = "LastModifiedTime",
                .last_modified_region = "LastModifiedRegion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_task_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/task/template/{TaskTemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTaskTemplate",
    Request: type = struct {
        instance_id: []const u8,
        task_template_id: []const u8,
        snapshot_version: ?[]const u8 = null,

        pub const http_query = .{
            .snapshot_version = "snapshotVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .task_template_id = "TaskTemplateId",
                .snapshot_version = "SnapshotVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_task_template) } {
            return .{ .service_metadata = service_metadata, .action = get_task_template };
        }
    },
    Response: type = struct {
        instance_id: ?[]const u8 = null,
        id: []const u8,
        arn: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        contact_flow_id: ?[]const u8 = null,
        constraints: ?TaskTemplateConstraints = null,
        defaults: ?TaskTemplateDefaults = null,
        fields: ?[]TaskTemplateField = null,
        status: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        created_time: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .id = "Id",
                .arn = "Arn",
                .name = "Name",
                .description = "Description",
                .contact_flow_id = "ContactFlowId",
                .constraints = "Constraints",
                .defaults = "Defaults",
                .fields = "Fields",
                .status = "Status",
                .last_modified_time = "LastModifiedTime",
                .created_time = "CreatedTime",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_traffic_distribution: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/traffic-distribution/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetTrafficDistribution",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_traffic_distribution) } {
            return .{ .service_metadata = service_metadata, .action = get_traffic_distribution };
        }
    },
    Response: type = struct {
        telephony_config: ?TelephonyConfig = null,
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        sign_in_config: ?SignInConfig = null,
        agent_config: ?AgentConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .telephony_config = "TelephonyConfig",
                .id = "Id",
                .arn = "Arn",
                .sign_in_config = "SignInConfig",
                .agent_config = "AgentConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const import_phone_number: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-number/import",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportPhoneNumber",
    Request: type = struct {
        instance_id: []const u8,
        source_phone_number_arn: []const u8,
        phone_number_description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .source_phone_number_arn = "SourcePhoneNumberArn",
                .phone_number_description = "PhoneNumberDescription",
                .tags = "Tags",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = import_phone_number };
        }
    },
    Response: type = struct {
        phone_number_id: ?[]const u8 = null,
        phone_number_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .phone_number_arn = "PhoneNumberArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Idempotency,
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_agent_statuses: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/agent-status/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAgentStatuses",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        agent_status_types: ?[][]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .agent_status_types = "AgentStatusTypes",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .agent_status_types = "AgentStatusTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_agent_statuses) } {
            return .{ .service_metadata = service_metadata, .action = list_agent_statuses };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        agent_status_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .type = "Type",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .agent_status_summary_list = "AgentStatusSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_analytics_data_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/analytics-data/instance/{InstanceId}/association",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnalyticsDataAssociations",
    Request: type = struct {
        instance_id: []const u8,
        data_set_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .data_set_id = "DataSetId",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .data_set_id = "DataSetId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_analytics_data_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_analytics_data_associations };
        }
    },
    Response: type = struct {
        results: ?[]AnalyticsDataAssociationResult = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_approved_origins: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/approved-origins",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApprovedOrigins",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_approved_origins) } {
            return .{ .service_metadata = service_metadata, .action = list_approved_origins };
        }
    },
    Response: type = struct {
        origins: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .origins = "Origins",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_bots: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/bots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBots",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        lex_version: []const u8,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .lex_version = "lexVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .lex_version = "LexVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bots) } {
            return .{ .service_metadata = service_metadata, .action = list_bots };
        }
    },
    Response: type = struct {
        lex_bots: ?[]struct {
            lex_bot: ?LexBot = null,
            lex_v2_bot: ?LexV2Bot = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lex_bot = "LexBot",
                    .lex_v2_bot = "LexV2Bot",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lex_bots = "LexBots",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_contact_evaluations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact-evaluations/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListContactEvaluations",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .contact_id = "contactId",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contact_evaluations) } {
            return .{ .service_metadata = service_metadata, .action = list_contact_evaluations };
        }
    },
    Response: type = struct {
        evaluation_summary_list: []struct {
            evaluation_id: []const u8,
            evaluation_arn: []const u8,
            evaluation_form_title: []const u8,
            evaluation_form_id: []const u8,
            status: []const u8,
            evaluator_arn: []const u8,
            score: ?EvaluationScore = null,
            created_time: i64,
            last_modified_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_id = "EvaluationId",
                    .evaluation_arn = "EvaluationArn",
                    .evaluation_form_title = "EvaluationFormTitle",
                    .evaluation_form_id = "EvaluationFormId",
                    .status = "Status",
                    .evaluator_arn = "EvaluatorArn",
                    .score = "Score",
                    .created_time = "CreatedTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_summary_list = "EvaluationSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_contact_flow_modules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact-flow-modules-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListContactFlowModules",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        contact_flow_module_state: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .contact_flow_module_state = "state",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .contact_flow_module_state = "ContactFlowModuleState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contact_flow_modules) } {
            return .{ .service_metadata = service_metadata, .action = list_contact_flow_modules };
        }
    },
    Response: type = struct {
        contact_flow_modules_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .state = "State",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_flow_modules_summary_list = "ContactFlowModulesSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_contact_flows: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact-flows-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListContactFlows",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_types: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .contact_flow_types = "contactFlowTypes",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_types = "ContactFlowTypes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contact_flows) } {
            return .{ .service_metadata = service_metadata, .action = list_contact_flows };
        }
    },
    Response: type = struct {
        contact_flow_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            contact_flow_type: ?[]const u8 = null,
            contact_flow_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .contact_flow_type = "ContactFlowType",
                    .contact_flow_state = "ContactFlowState",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_flow_summary_list = "ContactFlowSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_contact_references: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/contact/references/{InstanceId}/{ContactId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListContactReferences",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        reference_types: [][]const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .reference_types = "referenceTypes",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .reference_types = "ReferenceTypes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contact_references) } {
            return .{ .service_metadata = service_metadata, .action = list_contact_references };
        }
    },
    Response: type = struct {
        reference_summary_list: ?[]union {
            url: ?struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            },
            attachment: ?struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .value = "Value",
                        .status = "Status",
                    };
                    return @field(mappings, field_name);
                }
            },
            string: ?struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            },
            number: ?struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            },
            date: ?struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            },
            email: ?struct {
                name: ?[]const u8 = null,
                value: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .url = "Url",
                    .attachment = "Attachment",
                    .string = "String",
                    .number = "Number",
                    .date = "Date",
                    .email = "Email",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reference_summary_list = "ReferenceSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_default_vocabularies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/default-vocabulary-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDefaultVocabularies",
    Request: type = struct {
        instance_id: []const u8,
        language_code: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .language_code = "LanguageCode",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_default_vocabularies) } {
            return .{ .service_metadata = service_metadata, .action = list_default_vocabularies };
        }
    },
    Response: type = struct {
        default_vocabulary_list: []struct {
            instance_id: []const u8,
            language_code: []const u8,
            vocabulary_id: []const u8,
            vocabulary_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_id = "InstanceId",
                    .language_code = "LanguageCode",
                    .vocabulary_id = "VocabularyId",
                    .vocabulary_name = "VocabularyName",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .default_vocabulary_list = "DefaultVocabularyList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_evaluation_forms: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/evaluation-forms/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEvaluationForms",
    Request: type = struct {
        instance_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_evaluation_forms) } {
            return .{ .service_metadata = service_metadata, .action = list_evaluation_forms };
        }
    },
    Response: type = struct {
        evaluation_form_summary_list: []struct {
            evaluation_form_id: []const u8,
            evaluation_form_arn: []const u8,
            title: []const u8,
            created_time: i64,
            created_by: []const u8,
            last_modified_time: i64,
            last_modified_by: []const u8,
            last_activated_time: ?i64 = null,
            last_activated_by: ?[]const u8 = null,
            latest_version: i64,
            active_version: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_form_id = "EvaluationFormId",
                    .evaluation_form_arn = "EvaluationFormArn",
                    .title = "Title",
                    .created_time = "CreatedTime",
                    .created_by = "CreatedBy",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_by = "LastModifiedBy",
                    .last_activated_time = "LastActivatedTime",
                    .last_activated_by = "LastActivatedBy",
                    .latest_version = "LatestVersion",
                    .active_version = "ActiveVersion",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_form_summary_list = "EvaluationFormSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_evaluation_form_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/evaluation-forms/{InstanceId}/{EvaluationFormId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEvaluationFormVersions",
    Request: type = struct {
        instance_id: []const u8,
        evaluation_form_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .evaluation_form_id = "EvaluationFormId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_evaluation_form_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_evaluation_form_versions };
        }
    },
    Response: type = struct {
        evaluation_form_version_summary_list: []struct {
            evaluation_form_arn: []const u8,
            evaluation_form_id: []const u8,
            evaluation_form_version: i64,
            locked: bool,
            status: []const u8,
            created_time: i64,
            created_by: []const u8,
            last_modified_time: i64,
            last_modified_by: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .evaluation_form_arn = "EvaluationFormArn",
                    .evaluation_form_id = "EvaluationFormId",
                    .evaluation_form_version = "EvaluationFormVersion",
                    .locked = "Locked",
                    .status = "Status",
                    .created_time = "CreatedTime",
                    .created_by = "CreatedBy",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_by = "LastModifiedBy",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_form_version_summary_list = "EvaluationFormVersionSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_flow_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/flow-associations-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFlowAssociations",
    Request: type = struct {
        instance_id: []const u8,
        resource_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .resource_type = "ResourceType",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .resource_type = "ResourceType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_flow_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_flow_associations };
        }
    },
    Response: type = struct {
        flow_association_summary_list: ?[]FlowAssociationSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_association_summary_list = "FlowAssociationSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_hours_of_operations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/hours-of-operations-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListHoursOfOperations",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hours_of_operations) } {
            return .{ .service_metadata = service_metadata, .action = list_hours_of_operations };
        }
    },
    Response: type = struct {
        hours_of_operation_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hours_of_operation_summary_list = "HoursOfOperationSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_instance_attributes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInstanceAttributes",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instance_attributes) } {
            return .{ .service_metadata = service_metadata, .action = list_instance_attributes };
        }
    },
    Response: type = struct {
        attributes: ?[]Attribute = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_instances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInstances",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_instances };
        }
    },
    Response: type = struct {
        instance_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            identity_management_type: ?[]const u8 = null,
            instance_alias: ?[]const u8 = null,
            created_time: ?i64 = null,
            service_role: ?[]const u8 = null,
            instance_status: ?[]const u8 = null,
            inbound_calls_enabled: ?bool = null,
            outbound_calls_enabled: ?bool = null,
            instance_access_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .identity_management_type = "IdentityManagementType",
                    .instance_alias = "InstanceAlias",
                    .created_time = "CreatedTime",
                    .service_role = "ServiceRole",
                    .instance_status = "InstanceStatus",
                    .inbound_calls_enabled = "InboundCallsEnabled",
                    .outbound_calls_enabled = "OutboundCallsEnabled",
                    .instance_access_url = "InstanceAccessUrl",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_summary_list = "InstanceSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
    },
} = .{};
pub const list_instance_storage_configs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/storage-configs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInstanceStorageConfigs",
    Request: type = struct {
        instance_id: []const u8,
        resource_type: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .resource_type = "resourceType",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .resource_type = "ResourceType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_instance_storage_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_instance_storage_configs };
        }
    },
    Response: type = struct {
        storage_configs: ?[]InstanceStorageConfig = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_configs = "StorageConfigs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_integration_associations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/integration-associations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIntegrationAssociations",
    Request: type = struct {
        instance_id: []const u8,
        integration_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        integration_arn: ?[]const u8 = null,

        pub const http_query = .{
            .integration_type = "integrationType",
            .next_token = "nextToken",
            .max_results = "maxResults",
            .integration_arn = "integrationArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_type = "IntegrationType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .integration_arn = "IntegrationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_integration_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_integration_associations };
        }
    },
    Response: type = struct {
        integration_association_summary_list: ?[]struct {
            integration_association_id: ?[]const u8 = null,
            integration_association_arn: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            integration_type: ?[]const u8 = null,
            integration_arn: ?[]const u8 = null,
            source_application_url: ?[]const u8 = null,
            source_application_name: ?[]const u8 = null,
            source_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .integration_association_id = "IntegrationAssociationId",
                    .integration_association_arn = "IntegrationAssociationArn",
                    .instance_id = "InstanceId",
                    .integration_type = "IntegrationType",
                    .integration_arn = "IntegrationArn",
                    .source_application_url = "SourceApplicationUrl",
                    .source_application_name = "SourceApplicationName",
                    .source_type = "SourceType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .integration_association_summary_list = "IntegrationAssociationSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_lambda_functions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/lambda-functions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLambdaFunctions",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lambda_functions) } {
            return .{ .service_metadata = service_metadata, .action = list_lambda_functions };
        }
    },
    Response: type = struct {
        lambda_functions: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lambda_functions = "LambdaFunctions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_lex_bots: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/lex-bots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLexBots",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_lex_bots) } {
            return .{ .service_metadata = service_metadata, .action = list_lex_bots };
        }
    },
    Response: type = struct {
        lex_bots: ?[]LexBot = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lex_bots = "LexBots",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_phone_numbers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/phone-numbers-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPhoneNumbers",
    Request: type = struct {
        instance_id: []const u8,
        phone_number_types: ?[][]const u8 = null,
        phone_number_country_codes: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .phone_number_types = "phoneNumberTypes",
            .phone_number_country_codes = "phoneNumberCountryCodes",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .phone_number_types = "PhoneNumberTypes",
                .phone_number_country_codes = "PhoneNumberCountryCodes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_phone_numbers) } {
            return .{ .service_metadata = service_metadata, .action = list_phone_numbers };
        }
    },
    Response: type = struct {
        phone_number_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            phone_number: ?[]const u8 = null,
            phone_number_type: ?[]const u8 = null,
            phone_number_country_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .phone_number = "PhoneNumber",
                    .phone_number_type = "PhoneNumberType",
                    .phone_number_country_code = "PhoneNumberCountryCode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_summary_list = "PhoneNumberSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_phone_numbers_v2: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-number/list",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPhoneNumbersV2",
    Request: type = struct {
        target_arn: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        phone_number_country_codes: ?[][]const u8 = null,
        phone_number_types: ?[][]const u8 = null,
        phone_number_prefix: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "TargetArn",
                .instance_id = "InstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .phone_number_country_codes = "PhoneNumberCountryCodes",
                .phone_number_types = "PhoneNumberTypes",
                .phone_number_prefix = "PhoneNumberPrefix",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_phone_numbers_v2) } {
            return .{ .service_metadata = service_metadata, .action = list_phone_numbers_v2 };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        list_phone_numbers_summary_list: ?[]struct {
            phone_number_id: ?[]const u8 = null,
            phone_number_arn: ?[]const u8 = null,
            phone_number: ?[]const u8 = null,
            phone_number_country_code: ?[]const u8 = null,
            phone_number_type: ?[]const u8 = null,
            target_arn: ?[]const u8 = null,
            instance_id: ?[]const u8 = null,
            phone_number_description: ?[]const u8 = null,
            source_phone_number_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .phone_number_id = "PhoneNumberId",
                    .phone_number_arn = "PhoneNumberArn",
                    .phone_number = "PhoneNumber",
                    .phone_number_country_code = "PhoneNumberCountryCode",
                    .phone_number_type = "PhoneNumberType",
                    .target_arn = "TargetArn",
                    .instance_id = "InstanceId",
                    .phone_number_description = "PhoneNumberDescription",
                    .source_phone_number_arn = "SourcePhoneNumberArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .list_phone_numbers_summary_list = "ListPhoneNumbersSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_predefined_attributes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/predefined-attributes/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPredefinedAttributes",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_predefined_attributes) } {
            return .{ .service_metadata = service_metadata, .action = list_predefined_attributes };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        predefined_attribute_summary_list: ?[]struct {
            name: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .predefined_attribute_summary_list = "PredefinedAttributeSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_prompts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/prompts-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPrompts",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_prompts) } {
            return .{ .service_metadata = service_metadata, .action = list_prompts };
        }
    },
    Response: type = struct {
        prompt_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prompt_summary_list = "PromptSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_queue_quick_connects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/queues/{InstanceId}/{QueueId}/quick-connects",
        .success_code = 200,
    };

    action_name: []const u8 = "ListQueueQuickConnects",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_queue_quick_connects) } {
            return .{ .service_metadata = service_metadata, .action = list_queue_quick_connects };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        quick_connect_summary_list: ?[]QuickConnectSummary = null,
        last_modified_time: ?i64 = null,
        last_modified_region: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .quick_connect_summary_list = "QuickConnectSummaryList",
                .last_modified_time = "LastModifiedTime",
                .last_modified_region = "LastModifiedRegion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_queues: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/queues-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListQueues",
    Request: type = struct {
        instance_id: []const u8,
        queue_types: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .queue_types = "queueTypes",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_types = "QueueTypes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_queues) } {
            return .{ .service_metadata = service_metadata, .action = list_queues };
        }
    },
    Response: type = struct {
        queue_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            queue_type: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .queue_type = "QueueType",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queue_summary_list = "QueueSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_quick_connects: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/quick-connects/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListQuickConnects",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        quick_connect_types: ?[][]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .quick_connect_types = "QuickConnectTypes",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .quick_connect_types = "QuickConnectTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_quick_connects) } {
            return .{ .service_metadata = service_metadata, .action = list_quick_connects };
        }
    },
    Response: type = struct {
        quick_connect_summary_list: ?[]QuickConnectSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .quick_connect_summary_list = "QuickConnectSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_realtime_contact_analysis_segments_v2: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/list-real-time-analysis-segments-v2/{InstanceId}/{ContactId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRealtimeContactAnalysisSegmentsV2",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        output_type: []const u8,
        segment_types: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .output_type = "OutputType",
                .segment_types = "SegmentTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_realtime_contact_analysis_segments_v2) } {
            return .{ .service_metadata = service_metadata, .action = list_realtime_contact_analysis_segments_v2 };
        }
    },
    Response: type = struct {
        channel: []const u8,
        status: []const u8,
        segments: []union {
            transcript: ?struct {
                id: []const u8,
                participant_id: []const u8,
                participant_role: []const u8,
                display_name: ?[]const u8 = null,
                content: []const u8,
                content_type: ?[]const u8 = null,
                time: RealTimeContactAnalysisTimeData,
                redaction: ?struct {
                    character_offsets: ?[]RealTimeContactAnalysisCharacterInterval = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .character_offsets = "CharacterOffsets",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                sentiment: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .participant_id = "ParticipantId",
                        .participant_role = "ParticipantRole",
                        .display_name = "DisplayName",
                        .content = "Content",
                        .content_type = "ContentType",
                        .time = "Time",
                        .redaction = "Redaction",
                        .sentiment = "Sentiment",
                    };
                    return @field(mappings, field_name);
                }
            },
            categories: ?struct {
                matched_details: []struct {
                    key: ?[]const u8 = null,
                    value: ?struct {
                        points_of_interest: []struct {
                            transcript_items: ?[]struct {
                                id: []const u8,
                                character_offsets: ?RealTimeContactAnalysisCharacterInterval = null,

                                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                    const mappings = .{
                                        .id = "Id",
                                        .character_offsets = "CharacterOffsets",
                                    };
                                    return @field(mappings, field_name);
                                }
                            } = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .transcript_items = "TranscriptItems",
                                };
                                return @field(mappings, field_name);
                            }
                        },

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .points_of_interest = "PointsOfInterest",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .matched_details = "MatchedDetails",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "matched_details", field_name))
                        return try serializeMap(self.matched_details, self.fieldNameFor("matched_details"), options, out_stream);
                    return false;
                }
            },
            issues: ?struct {
                issues_detected: []struct {
                    transcript_items: []struct {
                        content: ?[]const u8 = null,
                        id: []const u8,
                        character_offsets: ?RealTimeContactAnalysisCharacterInterval = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .content = "Content",
                                .id = "Id",
                                .character_offsets = "CharacterOffsets",
                            };
                            return @field(mappings, field_name);
                        }
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .transcript_items = "TranscriptItems",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .issues_detected = "IssuesDetected",
                    };
                    return @field(mappings, field_name);
                }
            },
            event: ?struct {
                id: []const u8,
                participant_id: ?[]const u8 = null,
                participant_role: ?[]const u8 = null,
                display_name: ?[]const u8 = null,
                event_type: []const u8,
                time: RealTimeContactAnalysisTimeData,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .participant_id = "ParticipantId",
                        .participant_role = "ParticipantRole",
                        .display_name = "DisplayName",
                        .event_type = "EventType",
                        .time = "Time",
                    };
                    return @field(mappings, field_name);
                }
            },
            attachments: ?struct {
                id: []const u8,
                participant_id: []const u8,
                participant_role: []const u8,
                display_name: ?[]const u8 = null,
                attachments: []struct {
                    attachment_name: []const u8,
                    content_type: ?[]const u8 = null,
                    attachment_id: []const u8,
                    status: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .attachment_name = "AttachmentName",
                            .content_type = "ContentType",
                            .attachment_id = "AttachmentId",
                            .status = "Status",
                        };
                        return @field(mappings, field_name);
                    }
                },
                time: RealTimeContactAnalysisTimeData,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .participant_id = "ParticipantId",
                        .participant_role = "ParticipantRole",
                        .display_name = "DisplayName",
                        .attachments = "Attachments",
                        .time = "Time",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transcript = "Transcript",
                    .categories = "Categories",
                    .issues = "Issues",
                    .event = "Event",
                    .attachments = "Attachments",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel = "Channel",
                .status = "Status",
                .segments = "Segments",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        OutputTypeNotFound,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_routing_profile_queues: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/queues",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRoutingProfileQueues",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_routing_profile_queues) } {
            return .{ .service_metadata = service_metadata, .action = list_routing_profile_queues };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        routing_profile_queue_config_summary_list: ?[]struct {
            queue_id: []const u8,
            queue_arn: []const u8,
            queue_name: []const u8,
            priority: i64,
            delay: i64,
            channel: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .queue_id = "QueueId",
                    .queue_arn = "QueueArn",
                    .queue_name = "QueueName",
                    .priority = "Priority",
                    .delay = "Delay",
                    .channel = "Channel",
                };
                return @field(mappings, field_name);
            }
        } = null,
        last_modified_time: ?i64 = null,
        last_modified_region: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .routing_profile_queue_config_summary_list = "RoutingProfileQueueConfigSummaryList",
                .last_modified_time = "LastModifiedTime",
                .last_modified_region = "LastModifiedRegion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_routing_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/routing-profiles-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRoutingProfiles",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_routing_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_routing_profiles };
        }
    },
    Response: type = struct {
        routing_profile_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_profile_summary_list = "RoutingProfileSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_rules: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/rules/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRules",
    Request: type = struct {
        instance_id: []const u8,
        publish_status: ?[]const u8 = null,
        event_source_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .publish_status = "publishStatus",
            .event_source_name = "eventSourceName",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .publish_status = "PublishStatus",
                .event_source_name = "EventSourceName",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rules) } {
            return .{ .service_metadata = service_metadata, .action = list_rules };
        }
    },
    Response: type = struct {
        rule_summary_list: []struct {
            name: []const u8,
            rule_id: []const u8,
            rule_arn: []const u8,
            event_source_name: []const u8,
            publish_status: []const u8,
            action_summaries: []struct {
                action_type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action_type = "ActionType",
                    };
                    return @field(mappings, field_name);
                }
            },
            created_time: i64,
            last_updated_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .rule_id = "RuleId",
                    .rule_arn = "RuleArn",
                    .event_source_name = "EventSourceName",
                    .publish_status = "PublishStatus",
                    .action_summaries = "ActionSummaries",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_summary_list = "RuleSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_security_keys: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/security-keys",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSecurityKeys",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_security_keys };
        }
    },
    Response: type = struct {
        security_keys: ?[]struct {
            association_id: ?[]const u8 = null,
            key: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .association_id = "AssociationId",
                    .key = "Key",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_keys = "SecurityKeys",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_security_profile_applications: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/security-profiles-applications/{InstanceId}/{SecurityProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSecurityProfileApplications",
    Request: type = struct {
        security_profile_id: []const u8,
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_id = "SecurityProfileId",
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_profile_applications) } {
            return .{ .service_metadata = service_metadata, .action = list_security_profile_applications };
        }
    },
    Response: type = struct {
        applications: ?[]Application = null,
        next_token: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        last_modified_region: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .applications = "Applications",
                .next_token = "NextToken",
                .last_modified_time = "LastModifiedTime",
                .last_modified_region = "LastModifiedRegion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_security_profile_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/security-profiles-permissions/{InstanceId}/{SecurityProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSecurityProfilePermissions",
    Request: type = struct {
        security_profile_id: []const u8,
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_id = "SecurityProfileId",
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_profile_permissions) } {
            return .{ .service_metadata = service_metadata, .action = list_security_profile_permissions };
        }
    },
    Response: type = struct {
        permissions: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        last_modified_region: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .permissions = "Permissions",
                .next_token = "NextToken",
                .last_modified_time = "LastModifiedTime",
                .last_modified_region = "LastModifiedRegion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_security_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/security-profiles-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSecurityProfiles",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_security_profiles };
        }
    },
    Response: type = struct {
        security_profile_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_summary_list = "SecurityProfileSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_task_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/task/template",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTaskTemplates",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
            .status = "status",
            .name = "name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status = "Status",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_task_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_task_templates };
        }
    },
    Response: type = struct {
        task_templates: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .description = "Description",
                    .status = "Status",
                    .last_modified_time = "LastModifiedTime",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_templates = "TaskTemplates",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_traffic_distribution_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/traffic-distribution-groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTrafficDistributionGroups",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .instance_id = "instanceId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_traffic_distribution_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_traffic_distribution_groups };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        traffic_distribution_group_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            instance_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            is_default: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .instance_arn = "InstanceArn",
                    .status = "Status",
                    .is_default = "IsDefault",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .traffic_distribution_group_summary_list = "TrafficDistributionGroupSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const list_traffic_distribution_group_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/traffic-distribution-group/{TrafficDistributionGroupId}/user",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTrafficDistributionGroupUsers",
    Request: type = struct {
        traffic_distribution_group_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .traffic_distribution_group_id = "TrafficDistributionGroupId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_traffic_distribution_group_users) } {
            return .{ .service_metadata = service_metadata, .action = list_traffic_distribution_group_users };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        traffic_distribution_group_user_summary_list: ?[]struct {
            user_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_id = "UserId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .traffic_distribution_group_user_summary_list = "TrafficDistributionGroupUserSummaryList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_use_cases: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/instance/{InstanceId}/integration-associations/{IntegrationAssociationId}/use-cases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUseCases",
    Request: type = struct {
        instance_id: []const u8,
        integration_association_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .integration_association_id = "IntegrationAssociationId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_use_cases) } {
            return .{ .service_metadata = service_metadata, .action = list_use_cases };
        }
    },
    Response: type = struct {
        use_case_summary_list: ?[]struct {
            use_case_id: ?[]const u8 = null,
            use_case_arn: ?[]const u8 = null,
            use_case_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .use_case_id = "UseCaseId",
                    .use_case_arn = "UseCaseArn",
                    .use_case_type = "UseCaseType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .use_case_summary_list = "UseCaseSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_user_hierarchy_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/user-hierarchy-groups-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUserHierarchyGroups",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_hierarchy_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_user_hierarchy_groups };
        }
    },
    Response: type = struct {
        user_hierarchy_group_summary_list: ?[]HierarchyGroupSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_hierarchy_group_summary_list = "UserHierarchyGroupSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_user_proficiencies: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/users/{InstanceId}/{UserId}/proficiencies",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUserProficiencies",
    Request: type = struct {
        instance_id: []const u8,
        user_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .user_id = "UserId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_proficiencies) } {
            return .{ .service_metadata = service_metadata, .action = list_user_proficiencies };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        user_proficiency_list: ?[]UserProficiency = null,
        last_modified_time: ?i64 = null,
        last_modified_region: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .user_proficiency_list = "UserProficiencyList",
                .last_modified_time = "LastModifiedTime",
                .last_modified_region = "LastModifiedRegion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/users-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        user_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            username: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            last_modified_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .username = "Username",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_region = "LastModifiedRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_summary_list = "UserSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_views: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/views/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListViews",
    Request: type = struct {
        instance_id: []const u8,
        type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .type = "type",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .type = "Type",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_views) } {
            return .{ .service_metadata = service_metadata, .action = list_views };
        }
    },
    Response: type = struct {
        views_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .name = "Name",
                    .type = "Type",
                    .status = "Status",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .views_summary_list = "ViewsSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const list_view_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/views/{InstanceId}/{ViewId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListViewVersions",
    Request: type = struct {
        instance_id: []const u8,
        view_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .view_id = "ViewId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_view_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_view_versions };
        }
    },
    Response: type = struct {
        view_version_summary_list: ?[]struct {
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            version: ?i64 = null,
            version_description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .arn = "Arn",
                    .description = "Description",
                    .name = "Name",
                    .type = "Type",
                    .version = "Version",
                    .version_description = "VersionDescription",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .view_version_summary_list = "ViewVersionSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const monitor_contact: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/monitor",
        .success_code = 200,
    };

    action_name: []const u8 = "MonitorContact",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        user_id: []const u8,
        allowed_monitor_capabilities: ?[][]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .user_id = "UserId",
                .allowed_monitor_capabilities = "AllowedMonitorCapabilities",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(monitor_contact) } {
            return .{ .service_metadata = service_metadata, .action = monitor_contact };
        }
    },
    Response: type = struct {
        contact_id: ?[]const u8 = null,
        contact_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .contact_arn = "ContactArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Idempotency,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const pause_contact: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/pause",
        .success_code = 200,
    };

    action_name: []const u8 = "PauseContact",
    Request: type = struct {
        contact_id: []const u8,
        instance_id: []const u8,
        contact_flow_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(pause_contact) } {
            return .{ .service_metadata = service_metadata, .action = pause_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_user_status: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/users/{InstanceId}/{UserId}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "PutUserStatus",
    Request: type = struct {
        user_id: []const u8,
        instance_id: []const u8,
        agent_status_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_id = "UserId",
                .instance_id = "InstanceId",
                .agent_status_id = "AgentStatusId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_user_status) } {
            return .{ .service_metadata = service_metadata, .action = put_user_status };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const release_phone_number: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/phone-number/{PhoneNumberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ReleasePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,
        client_token: ?[]const u8 = null,

        pub const http_query = .{
            .client_token = "clientToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(release_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = release_phone_number };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Idempotency,
        InternalService,
        InvalidParameter,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const replicate_instance: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/instance/{InstanceId}/replicate",
        .success_code = 200,
    };

    action_name: []const u8 = "ReplicateInstance",
    Request: type = struct {
        instance_id: []const u8,
        replica_region: []const u8,
        client_token: ?[]const u8 = null,
        replica_alias: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .replica_region = "ReplicaRegion",
                .client_token = "ClientToken",
                .replica_alias = "ReplicaAlias",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(replicate_instance) } {
            return .{ .service_metadata = service_metadata, .action = replicate_instance };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        ResourceNotReady,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const resume_contact: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/resume",
        .success_code = 200,
    };

    action_name: []const u8 = "ResumeContact",
    Request: type = struct {
        contact_id: []const u8,
        instance_id: []const u8,
        contact_flow_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_contact) } {
            return .{ .service_metadata = service_metadata, .action = resume_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const resume_contact_recording: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/resume-recording",
        .success_code = 200,
    };

    action_name: []const u8 = "ResumeContactRecording",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        initial_contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .initial_contact_id = "InitialContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_contact_recording) } {
            return .{ .service_metadata = service_metadata, .action = resume_contact_recording };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const search_available_phone_numbers: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/phone-number/search-available",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchAvailablePhoneNumbers",
    Request: type = struct {
        target_arn: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        phone_number_country_code: []const u8,
        phone_number_type: []const u8,
        phone_number_prefix: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .target_arn = "TargetArn",
                .instance_id = "InstanceId",
                .phone_number_country_code = "PhoneNumberCountryCode",
                .phone_number_type = "PhoneNumberType",
                .phone_number_prefix = "PhoneNumberPrefix",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_available_phone_numbers) } {
            return .{ .service_metadata = service_metadata, .action = search_available_phone_numbers };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        available_numbers_list: ?[]struct {
            phone_number: ?[]const u8 = null,
            phone_number_country_code: ?[]const u8 = null,
            phone_number_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .phone_number = "PhoneNumber",
                    .phone_number_country_code = "PhoneNumberCountryCode",
                    .phone_number_type = "PhoneNumberType",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .available_numbers_list = "AvailableNumbersList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        Throttling,
    },
} = .{};
pub const search_contacts: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/search-contacts",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchContacts",
    Request: type = struct {
        instance_id: []const u8,
        time_range: struct {
            type: []const u8,
            start_time: i64,
            end_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        },
        search_criteria: ?struct {
            agent_ids: ?[][]const u8 = null,
            agent_hierarchy_groups: ?struct {
                l1_ids: ?[][]const u8 = null,
                l2_ids: ?[][]const u8 = null,
                l3_ids: ?[][]const u8 = null,
                l4_ids: ?[][]const u8 = null,
                l5_ids: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .l1_ids = "L1Ids",
                        .l2_ids = "L2Ids",
                        .l3_ids = "L3Ids",
                        .l4_ids = "L4Ids",
                        .l5_ids = "L5Ids",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            channels: ?[][]const u8 = null,
            contact_analysis: ?struct {
                transcript: ?struct {
                    criteria: []struct {
                        participant_role: []const u8,
                        search_text: [][]const u8,
                        match_type: []const u8,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .participant_role = "ParticipantRole",
                                .search_text = "SearchText",
                                .match_type = "MatchType",
                            };
                            return @field(mappings, field_name);
                        }
                    },
                    match_type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .criteria = "Criteria",
                            .match_type = "MatchType",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .transcript = "Transcript",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            initiation_methods: ?[][]const u8 = null,
            queue_ids: ?[][]const u8 = null,
            searchable_contact_attributes: ?struct {
                criteria: []struct {
                    key: []const u8,
                    values: [][]const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .key = "Key",
                            .values = "Values",
                        };
                        return @field(mappings, field_name);
                    }
                },
                match_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .criteria = "Criteria",
                        .match_type = "MatchType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .agent_ids = "AgentIds",
                    .agent_hierarchy_groups = "AgentHierarchyGroups",
                    .channels = "Channels",
                    .contact_analysis = "ContactAnalysis",
                    .initiation_methods = "InitiationMethods",
                    .queue_ids = "QueueIds",
                    .searchable_contact_attributes = "SearchableContactAttributes",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort: ?struct {
            field_name: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field_name = "FieldName",
                    .order = "Order",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .time_range = "TimeRange",
                .search_criteria = "SearchCriteria",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort = "Sort",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_contacts) } {
            return .{ .service_metadata = service_metadata, .action = search_contacts };
        }
    },
    Response: type = struct {
        contacts: []struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            initial_contact_id: ?[]const u8 = null,
            previous_contact_id: ?[]const u8 = null,
            initiation_method: ?[]const u8 = null,
            channel: ?[]const u8 = null,
            queue_info: ?struct {
                id: ?[]const u8 = null,
                enqueue_timestamp: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .enqueue_timestamp = "EnqueueTimestamp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            agent_info: ?struct {
                id: ?[]const u8 = null,
                connected_to_agent_timestamp: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .id = "Id",
                        .connected_to_agent_timestamp = "ConnectedToAgentTimestamp",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            initiation_timestamp: ?i64 = null,
            disconnect_timestamp: ?i64 = null,
            scheduled_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .initial_contact_id = "InitialContactId",
                    .previous_contact_id = "PreviousContactId",
                    .initiation_method = "InitiationMethod",
                    .channel = "Channel",
                    .queue_info = "QueueInfo",
                    .agent_info = "AgentInfo",
                    .initiation_timestamp = "InitiationTimestamp",
                    .disconnect_timestamp = "DisconnectTimestamp",
                    .scheduled_timestamp = "ScheduledTimestamp",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contacts = "Contacts",
                .next_token = "NextToken",
                .total_count = "TotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_hours_of_operations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/search-hours-of-operations",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchHoursOfOperations",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        search_filter: ?struct {
            tag_filter: ?ControlPlaneTagFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_filter = "TagFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        search_criteria: ?HoursOfOperationSearchCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .search_filter = "SearchFilter",
                .search_criteria = "SearchCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_hours_of_operations) } {
            return .{ .service_metadata = service_metadata, .action = search_hours_of_operations };
        }
    },
    Response: type = struct {
        hours_of_operations: ?[]HoursOfOperation = null,
        next_token: ?[]const u8 = null,
        approximate_total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hours_of_operations = "HoursOfOperations",
                .next_token = "NextToken",
                .approximate_total_count = "ApproximateTotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_predefined_attributes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/search-predefined-attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchPredefinedAttributes",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        search_criteria: ?PredefinedAttributeSearchCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .search_criteria = "SearchCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_predefined_attributes) } {
            return .{ .service_metadata = service_metadata, .action = search_predefined_attributes };
        }
    },
    Response: type = struct {
        predefined_attributes: ?[]PredefinedAttribute = null,
        next_token: ?[]const u8 = null,
        approximate_total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predefined_attributes = "PredefinedAttributes",
                .next_token = "NextToken",
                .approximate_total_count = "ApproximateTotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_prompts: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/search-prompts",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchPrompts",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        search_filter: ?struct {
            tag_filter: ?ControlPlaneTagFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_filter = "TagFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        search_criteria: ?PromptSearchCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .search_filter = "SearchFilter",
                .search_criteria = "SearchCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_prompts) } {
            return .{ .service_metadata = service_metadata, .action = search_prompts };
        }
    },
    Response: type = struct {
        prompts: ?[]Prompt = null,
        next_token: ?[]const u8 = null,
        approximate_total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prompts = "Prompts",
                .next_token = "NextToken",
                .approximate_total_count = "ApproximateTotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_queues: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/search-queues",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchQueues",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        search_filter: ?struct {
            tag_filter: ?ControlPlaneTagFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_filter = "TagFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        search_criteria: ?QueueSearchCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .search_filter = "SearchFilter",
                .search_criteria = "SearchCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_queues) } {
            return .{ .service_metadata = service_metadata, .action = search_queues };
        }
    },
    Response: type = struct {
        queues: ?[]Queue = null,
        next_token: ?[]const u8 = null,
        approximate_total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .queues = "Queues",
                .next_token = "NextToken",
                .approximate_total_count = "ApproximateTotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_quick_connects: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/search-quick-connects",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchQuickConnects",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        search_filter: ?struct {
            tag_filter: ?ControlPlaneTagFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_filter = "TagFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        search_criteria: ?QuickConnectSearchCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .search_filter = "SearchFilter",
                .search_criteria = "SearchCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_quick_connects) } {
            return .{ .service_metadata = service_metadata, .action = search_quick_connects };
        }
    },
    Response: type = struct {
        quick_connects: ?[]QuickConnect = null,
        next_token: ?[]const u8 = null,
        approximate_total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .quick_connects = "QuickConnects",
                .next_token = "NextToken",
                .approximate_total_count = "ApproximateTotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_resource_tags: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/search-resource-tags",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchResourceTags",
    Request: type = struct {
        instance_id: []const u8,
        resource_types: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        search_criteria: ?struct {
            tag_search_condition: ?struct {
                tag_key: ?[]const u8 = null,
                tag_value: ?[]const u8 = null,
                tag_key_comparison_type: ?[]const u8 = null,
                tag_value_comparison_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .tag_key = "tagKey",
                        .tag_value = "tagValue",
                        .tag_key_comparison_type = "tagKeyComparisonType",
                        .tag_value_comparison_type = "tagValueComparisonType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_search_condition = "TagSearchCondition",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .resource_types = "ResourceTypes",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .search_criteria = "SearchCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_resource_tags) } {
            return .{ .service_metadata = service_metadata, .action = search_resource_tags };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "key",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        MaximumResultReturned,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_routing_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/search-routing-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchRoutingProfiles",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        search_filter: ?struct {
            tag_filter: ?ControlPlaneTagFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_filter = "TagFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        search_criteria: ?RoutingProfileSearchCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .search_filter = "SearchFilter",
                .search_criteria = "SearchCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_routing_profiles) } {
            return .{ .service_metadata = service_metadata, .action = search_routing_profiles };
        }
    },
    Response: type = struct {
        routing_profiles: ?[]RoutingProfile = null,
        next_token: ?[]const u8 = null,
        approximate_total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_profiles = "RoutingProfiles",
                .next_token = "NextToken",
                .approximate_total_count = "ApproximateTotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_security_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/search-security-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchSecurityProfiles",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        search_criteria: ?SecurityProfileSearchCriteria = null,
        search_filter: ?struct {
            tag_filter: ?ControlPlaneTagFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_filter = "TagFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .search_criteria = "SearchCriteria",
                .search_filter = "SearchFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_security_profiles) } {
            return .{ .service_metadata = service_metadata, .action = search_security_profiles };
        }
    },
    Response: type = struct {
        security_profiles: ?[]struct {
            id: ?[]const u8 = null,
            organization_resource_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            security_profile_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .organization_resource_id = "OrganizationResourceId",
                    .arn = "Arn",
                    .security_profile_name = "SecurityProfileName",
                    .description = "Description",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,
        approximate_total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profiles = "SecurityProfiles",
                .next_token = "NextToken",
                .approximate_total_count = "ApproximateTotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_users: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/search-users",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchUsers",
    Request: type = struct {
        instance_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        search_filter: ?struct {
            tag_filter: ?ControlPlaneTagFilter = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_filter = "TagFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        search_criteria: ?UserSearchCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .search_filter = "SearchFilter",
                .search_criteria = "SearchCriteria",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_users) } {
            return .{ .service_metadata = service_metadata, .action = search_users };
        }
    },
    Response: type = struct {
        users: ?[]struct {
            arn: ?[]const u8 = null,
            directory_user_id: ?[]const u8 = null,
            hierarchy_group_id: ?[]const u8 = null,
            id: ?[]const u8 = null,
            identity_info: ?struct {
                first_name: ?[]const u8 = null,
                last_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .first_name = "FirstName",
                        .last_name = "LastName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            phone_config: ?UserPhoneConfig = null,
            routing_profile_id: ?[]const u8 = null,
            security_profile_ids: ?[][]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            username: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .directory_user_id = "DirectoryUserId",
                    .hierarchy_group_id = "HierarchyGroupId",
                    .id = "Id",
                    .identity_info = "IdentityInfo",
                    .phone_config = "PhoneConfig",
                    .routing_profile_id = "RoutingProfileId",
                    .security_profile_ids = "SecurityProfileIds",
                    .tags = "Tags",
                    .username = "Username",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,
        approximate_total_count: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .next_token = "NextToken",
                .approximate_total_count = "ApproximateTotalCount",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_vocabularies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/vocabulary-summary/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchVocabularies",
    Request: type = struct {
        instance_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        state: ?[]const u8 = null,
        name_starts_with: ?[]const u8 = null,
        language_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .state = "State",
                .name_starts_with = "NameStartsWith",
                .language_code = "LanguageCode",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_vocabularies) } {
            return .{ .service_metadata = service_metadata, .action = search_vocabularies };
        }
    },
    Response: type = struct {
        vocabulary_summary_list: ?[]struct {
            name: []const u8,
            id: []const u8,
            arn: []const u8,
            language_code: []const u8,
            state: []const u8,
            last_modified_time: i64,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .arn = "Arn",
                    .language_code = "LanguageCode",
                    .state = "State",
                    .last_modified_time = "LastModifiedTime",
                    .failure_reason = "FailureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vocabulary_summary_list = "VocabularySummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        Throttling,
    },
} = .{};
pub const send_chat_integration_event: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/chat-integration-event",
        .success_code = 200,
    };

    action_name: []const u8 = "SendChatIntegrationEvent",
    Request: type = struct {
        source_id: []const u8,
        destination_id: []const u8,
        subtype: ?[]const u8 = null,
        event: struct {
            type: []const u8,
            content_type: ?[]const u8 = null,
            content: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .content_type = "ContentType",
                    .content = "Content",
                };
                return @field(mappings, field_name);
            }
        },
        new_session_details: ?struct {
            supported_messaging_content_types: ?[][]const u8 = null,
            participant_details: ?ParticipantDetails = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            streaming_configuration: ?ChatStreamingConfiguration = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .supported_messaging_content_types = "SupportedMessagingContentTypes",
                    .participant_details = "ParticipantDetails",
                    .attributes = "Attributes",
                    .streaming_configuration = "StreamingConfiguration",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_id = "SourceId",
                .destination_id = "DestinationId",
                .subtype = "Subtype",
                .event = "Event",
                .new_session_details = "NewSessionDetails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_chat_integration_event) } {
            return .{ .service_metadata = service_metadata, .action = send_chat_integration_event };
        }
    },
    Response: type = struct {
        initial_contact_id: ?[]const u8 = null,
        new_chat_created: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .initial_contact_id = "InitialContactId",
                .new_chat_created = "NewChatCreated",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const start_chat_contact: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact/chat",
        .success_code = 200,
    };

    action_name: []const u8 = "StartChatContact",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_id: []const u8,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        participant_details: ParticipantDetails,
        initial_message: ?struct {
            content_type: []const u8,
            content: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .content_type = "ContentType",
                    .content = "Content",
                };
                return @field(mappings, field_name);
            }
        } = null,
        client_token: ?[]const u8 = null,
        chat_duration_in_minutes: ?i64 = null,
        supported_messaging_content_types: ?[][]const u8 = null,
        persistent_chat: ?struct {
            rehydration_type: ?[]const u8 = null,
            source_contact_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rehydration_type = "RehydrationType",
                    .source_contact_id = "SourceContactId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        related_contact_id: ?[]const u8 = null,
        segment_attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                value_string: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .value_string = "ValueString",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
                .attributes = "Attributes",
                .participant_details = "ParticipantDetails",
                .initial_message = "InitialMessage",
                .client_token = "ClientToken",
                .chat_duration_in_minutes = "ChatDurationInMinutes",
                .supported_messaging_content_types = "SupportedMessagingContentTypes",
                .persistent_chat = "PersistentChat",
                .related_contact_id = "RelatedContactId",
                .segment_attributes = "SegmentAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            if (std.mem.eql(u8, "segment_attributes", field_name))
                return try serializeMap(self.segment_attributes, self.fieldNameFor("segment_attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_chat_contact) } {
            return .{ .service_metadata = service_metadata, .action = start_chat_contact };
        }
    },
    Response: type = struct {
        contact_id: ?[]const u8 = null,
        participant_id: ?[]const u8 = null,
        participant_token: ?[]const u8 = null,
        continued_from_contact_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .participant_id = "ParticipantId",
                .participant_token = "ParticipantToken",
                .continued_from_contact_id = "ContinuedFromContactId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const start_contact_evaluation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact-evaluations/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "StartContactEvaluation",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        evaluation_form_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .evaluation_form_id = "EvaluationFormId",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_contact_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = start_contact_evaluation };
        }
    },
    Response: type = struct {
        evaluation_id: []const u8,
        evaluation_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
                .evaluation_arn = "EvaluationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const start_contact_recording: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/start-recording",
        .success_code = 200,
    };

    action_name: []const u8 = "StartContactRecording",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        initial_contact_id: []const u8,
        voice_recording_configuration: struct {
            voice_recording_track: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .voice_recording_track = "VoiceRecordingTrack",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .initial_contact_id = "InitialContactId",
                .voice_recording_configuration = "VoiceRecordingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_contact_recording) } {
            return .{ .service_metadata = service_metadata, .action = start_contact_recording };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const start_contact_streaming: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/start-streaming",
        .success_code = 200,
    };

    action_name: []const u8 = "StartContactStreaming",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        chat_streaming_configuration: ChatStreamingConfiguration,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .chat_streaming_configuration = "ChatStreamingConfiguration",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_contact_streaming) } {
            return .{ .service_metadata = service_metadata, .action = start_contact_streaming };
        }
    },
    Response: type = struct {
        streaming_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_id = "StreamingId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const start_outbound_voice_contact: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact/outbound-voice",
        .success_code = 200,
    };

    action_name: []const u8 = "StartOutboundVoiceContact",
    Request: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        references: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Reference = null,
        } = null,
        related_contact_id: ?[]const u8 = null,
        destination_phone_number: []const u8,
        contact_flow_id: []const u8,
        instance_id: []const u8,
        client_token: ?[]const u8 = null,
        source_phone_number: ?[]const u8 = null,
        queue_id: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        answer_machine_detection_config: ?struct {
            enable_answer_machine_detection: ?bool = null,
            await_answer_machine_prompt: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enable_answer_machine_detection = "EnableAnswerMachineDetection",
                    .await_answer_machine_prompt = "AwaitAnswerMachinePrompt",
                };
                return @field(mappings, field_name);
            }
        } = null,
        campaign_id: ?[]const u8 = null,
        traffic_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .references = "References",
                .related_contact_id = "RelatedContactId",
                .destination_phone_number = "DestinationPhoneNumber",
                .contact_flow_id = "ContactFlowId",
                .instance_id = "InstanceId",
                .client_token = "ClientToken",
                .source_phone_number = "SourcePhoneNumber",
                .queue_id = "QueueId",
                .attributes = "Attributes",
                .answer_machine_detection_config = "AnswerMachineDetectionConfig",
                .campaign_id = "CampaignId",
                .traffic_type = "TrafficType",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "references", field_name))
                return try serializeMap(self.references, self.fieldNameFor("references"), options, out_stream);
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_outbound_voice_contact) } {
            return .{ .service_metadata = service_metadata, .action = start_outbound_voice_contact };
        }
    },
    Response: type = struct {
        contact_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DestinationNotAllowed,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        OutboundContactNotPermitted,
        ResourceNotFound,
    },
} = .{};
pub const start_task_contact: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact/task",
        .success_code = 200,
    };

    action_name: []const u8 = "StartTaskContact",
    Request: type = struct {
        instance_id: []const u8,
        previous_contact_id: ?[]const u8 = null,
        contact_flow_id: ?[]const u8 = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        name: []const u8,
        references: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Reference = null,
        } = null,
        description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        scheduled_time: ?i64 = null,
        task_template_id: ?[]const u8 = null,
        quick_connect_id: ?[]const u8 = null,
        related_contact_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .previous_contact_id = "PreviousContactId",
                .contact_flow_id = "ContactFlowId",
                .attributes = "Attributes",
                .name = "Name",
                .references = "References",
                .description = "Description",
                .client_token = "ClientToken",
                .scheduled_time = "ScheduledTime",
                .task_template_id = "TaskTemplateId",
                .quick_connect_id = "QuickConnectId",
                .related_contact_id = "RelatedContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            if (std.mem.eql(u8, "references", field_name))
                return try serializeMap(self.references, self.fieldNameFor("references"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_task_contact) } {
            return .{ .service_metadata = service_metadata, .action = start_task_contact };
        }
    },
    Response: type = struct {
        contact_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const start_web_rtc_contact: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact/webrtc",
        .success_code = 200,
    };

    action_name: []const u8 = "StartWebRTCContact",
    Request: type = struct {
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: ?[]const u8 = null,
        contact_flow_id: []const u8,
        instance_id: []const u8,
        allowed_capabilities: ?struct {
            customer: ?ParticipantCapabilities = null,
            agent: ?ParticipantCapabilities = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .customer = "Customer",
                    .agent = "Agent",
                };
                return @field(mappings, field_name);
            }
        } = null,
        participant_details: ParticipantDetails,
        related_contact_id: ?[]const u8 = null,
        references: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Reference = null,
        } = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .attributes = "Attributes",
                .client_token = "ClientToken",
                .contact_flow_id = "ContactFlowId",
                .instance_id = "InstanceId",
                .allowed_capabilities = "AllowedCapabilities",
                .participant_details = "ParticipantDetails",
                .related_contact_id = "RelatedContactId",
                .references = "References",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            if (std.mem.eql(u8, "references", field_name))
                return try serializeMap(self.references, self.fieldNameFor("references"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_web_rtc_contact) } {
            return .{ .service_metadata = service_metadata, .action = start_web_rtc_contact };
        }
    },
    Response: type = struct {
        connection_data: ?struct {
            attendee: ?struct {
                attendee_id: ?[]const u8 = null,
                join_token: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attendee_id = "AttendeeId",
                        .join_token = "JoinToken",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            meeting: ?struct {
                media_region: ?[]const u8 = null,
                media_placement: ?struct {
                    audio_host_url: ?[]const u8 = null,
                    audio_fallback_url: ?[]const u8 = null,
                    signaling_url: ?[]const u8 = null,
                    turn_control_url: ?[]const u8 = null,
                    event_ingestion_url: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .audio_host_url = "AudioHostUrl",
                            .audio_fallback_url = "AudioFallbackUrl",
                            .signaling_url = "SignalingUrl",
                            .turn_control_url = "TurnControlUrl",
                            .event_ingestion_url = "EventIngestionUrl",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                meeting_features: ?struct {
                    audio: ?struct {
                        echo_reduction: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .echo_reduction = "EchoReduction",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .audio = "Audio",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                meeting_id: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .media_region = "MediaRegion",
                        .media_placement = "MediaPlacement",
                        .meeting_features = "MeetingFeatures",
                        .meeting_id = "MeetingId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attendee = "Attendee",
                    .meeting = "Meeting",
                };
                return @field(mappings, field_name);
            }
        } = null,
        contact_id: ?[]const u8 = null,
        participant_id: ?[]const u8 = null,
        participant_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_data = "ConnectionData",
                .contact_id = "ContactId",
                .participant_id = "ParticipantId",
                .participant_token = "ParticipantToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const stop_contact: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopContact",
    Request: type = struct {
        contact_id: []const u8,
        instance_id: []const u8,
        disconnect_reason: ?struct {
            code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code = "Code",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .instance_id = "InstanceId",
                .disconnect_reason = "DisconnectReason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_contact) } {
            return .{ .service_metadata = service_metadata, .action = stop_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ContactNotFound,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const stop_contact_recording: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/stop-recording",
        .success_code = 200,
    };

    action_name: []const u8 = "StopContactRecording",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        initial_contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .initial_contact_id = "InitialContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_contact_recording) } {
            return .{ .service_metadata = service_metadata, .action = stop_contact_recording };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const stop_contact_streaming: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/stop-streaming",
        .success_code = 200,
    };

    action_name: []const u8 = "StopContactStreaming",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        streaming_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .streaming_id = "StreamingId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_contact_streaming) } {
            return .{ .service_metadata = service_metadata, .action = stop_contact_streaming };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const submit_contact_evaluation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact-evaluations/{InstanceId}/{EvaluationId}/submit",
        .success_code = 200,
    };

    action_name: []const u8 = "SubmitContactEvaluation",
    Request: type = struct {
        instance_id: []const u8,
        evaluation_id: []const u8,
        answers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?EvaluationAnswerInput = null,
        } = null,
        notes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?EvaluationNote = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .evaluation_id = "EvaluationId",
                .answers = "Answers",
                .notes = "Notes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "answers", field_name))
                return try serializeMap(self.answers, self.fieldNameFor("answers"), options, out_stream);
            if (std.mem.eql(u8, "notes", field_name))
                return try serializeMap(self.notes, self.fieldNameFor("notes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(submit_contact_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = submit_contact_evaluation };
        }
    },
    Response: type = struct {
        evaluation_id: []const u8,
        evaluation_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
                .evaluation_arn = "EvaluationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const suspend_contact_recording: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/suspend-recording",
        .success_code = 200,
    };

    action_name: []const u8 = "SuspendContactRecording",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        initial_contact_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .initial_contact_id = "InitialContactId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(suspend_contact_recording) } {
            return .{ .service_metadata = service_metadata, .action = suspend_contact_recording };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const tag_contact: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagContact",
    Request: type = struct {
        contact_id: []const u8,
        instance_id: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .instance_id = "InstanceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_contact) } {
            return .{ .service_metadata = service_metadata, .action = tag_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const transfer_contact: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/transfer",
        .success_code = 200,
    };

    action_name: []const u8 = "TransferContact",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        queue_id: ?[]const u8 = null,
        user_id: ?[]const u8 = null,
        contact_flow_id: []const u8,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .queue_id = "QueueId",
                .user_id = "UserId",
                .contact_flow_id = "ContactFlowId",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(transfer_contact) } {
            return .{ .service_metadata = service_metadata, .action = transfer_contact };
        }
    },
    Response: type = struct {
        contact_id: ?[]const u8 = null,
        contact_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .contact_arn = "ContactArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Idempotency,
        InternalService,
        InvalidRequest,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const untag_contact: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/contact/tags/{InstanceId}/{ContactId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagContact",
    Request: type = struct {
        contact_id: []const u8,
        instance_id: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "TagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .contact_id = "ContactId",
                .instance_id = "InstanceId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_contact) } {
            return .{ .service_metadata = service_metadata, .action = untag_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_agent_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/agent-status/{InstanceId}/{AgentStatusId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAgentStatus",
    Request: type = struct {
        instance_id: []const u8,
        agent_status_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        state: ?[]const u8 = null,
        display_order: ?i64 = null,
        reset_order_number: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .agent_status_id = "AgentStatusId",
                .name = "Name",
                .description = "Description",
                .state = "State",
                .display_order = "DisplayOrder",
                .reset_order_number = "ResetOrderNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_agent_status) } {
            return .{ .service_metadata = service_metadata, .action = update_agent_status };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contacts/{InstanceId}/{ContactId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContact",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        references: ?[]struct {
            key: ?[]const u8 = null,
            value: ?Reference = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .name = "Name",
                .description = "Description",
                .references = "References",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "references", field_name))
                return try serializeMap(self.references, self.fieldNameFor("references"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact) } {
            return .{ .service_metadata = service_metadata, .action = update_contact };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact_attributes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/attributes",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactAttributes",
    Request: type = struct {
        initial_contact_id: []const u8,
        instance_id: []const u8,
        attributes: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .initial_contact_id = "InitialContactId",
                .instance_id = "InstanceId",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_attributes) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_attributes };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_contact_evaluation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact-evaluations/{InstanceId}/{EvaluationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactEvaluation",
    Request: type = struct {
        instance_id: []const u8,
        evaluation_id: []const u8,
        answers: ?[]struct {
            key: ?[]const u8 = null,
            value: ?EvaluationAnswerInput = null,
        } = null,
        notes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?EvaluationNote = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .evaluation_id = "EvaluationId",
                .answers = "Answers",
                .notes = "Notes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "answers", field_name))
                return try serializeMap(self.answers, self.fieldNameFor("answers"), options, out_stream);
            if (std.mem.eql(u8, "notes", field_name))
                return try serializeMap(self.notes, self.fieldNameFor("notes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_evaluation) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_evaluation };
        }
    },
    Response: type = struct {
        evaluation_id: []const u8,
        evaluation_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_id = "EvaluationId",
                .evaluation_arn = "EvaluationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact_flow_content: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact-flows/{InstanceId}/{ContactFlowId}/content",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactFlowContent",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_id: []const u8,
        content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
                .content = "Content",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_flow_content) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_flow_content };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidContactFlow,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact_flow_metadata: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact-flows/{InstanceId}/{ContactFlowId}/metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactFlowMetadata",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        contact_flow_state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
                .name = "Name",
                .description = "Description",
                .contact_flow_state = "ContactFlowState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_flow_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_flow_metadata };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact_flow_module_content: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact-flow-modules/{InstanceId}/{ContactFlowModuleId}/content",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactFlowModuleContent",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_module_id: []const u8,
        content: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_module_id = "ContactFlowModuleId",
                .content = "Content",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_flow_module_content) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_flow_module_content };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidContactFlowModule,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact_flow_module_metadata: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact-flow-modules/{InstanceId}/{ContactFlowModuleId}/metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactFlowModuleMetadata",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_module_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_module_id = "ContactFlowModuleId",
                .name = "Name",
                .description = "Description",
                .state = "State",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_flow_module_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_flow_module_metadata };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact_flow_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact-flows/{InstanceId}/{ContactFlowId}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactFlowName",
    Request: type = struct {
        instance_id: []const u8,
        contact_flow_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_flow_id = "ContactFlowId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_flow_name) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_flow_name };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact_routing_data: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contacts/{InstanceId}/{ContactId}/routing-data",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactRoutingData",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        queue_time_adjustment_seconds: ?i64 = null,
        queue_priority: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .queue_time_adjustment_seconds = "QueueTimeAdjustmentSeconds",
                .queue_priority = "QueuePriority",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_routing_data) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_routing_data };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_contact_schedule: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/contact/schedule",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateContactSchedule",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        scheduled_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .scheduled_time = "ScheduledTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_contact_schedule) } {
            return .{ .service_metadata = service_metadata, .action = update_contact_schedule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_evaluation_form: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/evaluation-forms/{InstanceId}/{EvaluationFormId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEvaluationForm",
    Request: type = struct {
        instance_id: []const u8,
        evaluation_form_id: []const u8,
        evaluation_form_version: i64,
        create_new_version: ?bool = null,
        title: []const u8,
        description: ?[]const u8 = null,
        items: []EvaluationFormItem,
        scoring_strategy: ?EvaluationFormScoringStrategy = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .evaluation_form_id = "EvaluationFormId",
                .evaluation_form_version = "EvaluationFormVersion",
                .create_new_version = "CreateNewVersion",
                .title = "Title",
                .description = "Description",
                .items = "Items",
                .scoring_strategy = "ScoringStrategy",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_evaluation_form) } {
            return .{ .service_metadata = service_metadata, .action = update_evaluation_form };
        }
    },
    Response: type = struct {
        evaluation_form_id: []const u8,
        evaluation_form_arn: []const u8,
        evaluation_form_version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .evaluation_form_id = "EvaluationFormId",
                .evaluation_form_arn = "EvaluationFormArn",
                .evaluation_form_version = "EvaluationFormVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        ResourceConflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const update_hours_of_operation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/hours-of-operations/{InstanceId}/{HoursOfOperationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateHoursOfOperation",
    Request: type = struct {
        instance_id: []const u8,
        hours_of_operation_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        time_zone: ?[]const u8 = null,
        config: ?[]HoursOfOperationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .hours_of_operation_id = "HoursOfOperationId",
                .name = "Name",
                .description = "Description",
                .time_zone = "TimeZone",
                .config = "Config",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_hours_of_operation) } {
            return .{ .service_metadata = service_metadata, .action = update_hours_of_operation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_instance_attribute: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/instance/{InstanceId}/attribute/{AttributeType}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInstanceAttribute",
    Request: type = struct {
        instance_id: []const u8,
        attribute_type: []const u8,
        value: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .attribute_type = "AttributeType",
                .value = "Value",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_instance_attribute) } {
            return .{ .service_metadata = service_metadata, .action = update_instance_attribute };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_instance_storage_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/instance/{InstanceId}/storage-config/{AssociationId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInstanceStorageConfig",
    Request: type = struct {
        instance_id: []const u8,
        association_id: []const u8,
        resource_type: []const u8,
        storage_config: InstanceStorageConfig,

        pub const http_query = .{
            .resource_type = "resourceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .association_id = "AssociationId",
                .resource_type = "ResourceType",
                .storage_config = "StorageConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_instance_storage_config) } {
            return .{ .service_metadata = service_metadata, .action = update_instance_storage_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_participant_role_config: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/contact/participant-role-config/{InstanceId}/{ContactId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateParticipantRoleConfig",
    Request: type = struct {
        instance_id: []const u8,
        contact_id: []const u8,
        channel_configuration: union {
            chat: ?struct {
                participant_timer_config_list: []struct {
                    participant_role: []const u8,
                    timer_type: []const u8,
                    timer_value: union {
                        participant_timer_action: ?[]const u8,
                        participant_timer_duration_in_minutes: ?i64,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .participant_timer_action = "ParticipantTimerAction",
                                .participant_timer_duration_in_minutes = "ParticipantTimerDurationInMinutes",
                            };
                            return @field(mappings, field_name);
                        }
                    },

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .participant_role = "ParticipantRole",
                            .timer_type = "TimerType",
                            .timer_value = "TimerValue",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .participant_timer_config_list = "ParticipantTimerConfigList",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .chat = "Chat",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .contact_id = "ContactId",
                .channel_configuration = "ChannelConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_participant_role_config) } {
            return .{ .service_metadata = service_metadata, .action = update_participant_role_config };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_phone_number: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/phone-number/{PhoneNumberId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePhoneNumber",
    Request: type = struct {
        phone_number_id: []const u8,
        target_arn: ?[]const u8 = null,
        instance_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .target_arn = "TargetArn",
                .instance_id = "InstanceId",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_phone_number) } {
            return .{ .service_metadata = service_metadata, .action = update_phone_number };
        }
    },
    Response: type = struct {
        phone_number_id: ?[]const u8 = null,
        phone_number_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .phone_number_arn = "PhoneNumberArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Idempotency,
        InternalService,
        InvalidParameter,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_phone_number_metadata: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/phone-number/{PhoneNumberId}/metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePhoneNumberMetadata",
    Request: type = struct {
        phone_number_id: []const u8,
        phone_number_description: ?[]const u8 = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_number_id = "PhoneNumberId",
                .phone_number_description = "PhoneNumberDescription",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_phone_number_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_phone_number_metadata };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Idempotency,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_predefined_attribute: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/predefined-attributes/{InstanceId}/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePredefinedAttribute",
    Request: type = struct {
        instance_id: []const u8,
        name: []const u8,
        values: ?PredefinedAttributeValues = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .name = "Name",
                .values = "Values",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_predefined_attribute) } {
            return .{ .service_metadata = service_metadata, .action = update_predefined_attribute };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_prompt: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/prompts/{InstanceId}/{PromptId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdatePrompt",
    Request: type = struct {
        instance_id: []const u8,
        prompt_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        s3_uri: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .prompt_id = "PromptId",
                .name = "Name",
                .description = "Description",
                .s3_uri = "S3Uri",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_prompt) } {
            return .{ .service_metadata = service_metadata, .action = update_prompt };
        }
    },
    Response: type = struct {
        prompt_arn: ?[]const u8 = null,
        prompt_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prompt_arn = "PromptARN",
                .prompt_id = "PromptId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_queue_hours_of_operation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/hours-of-operation",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueueHoursOfOperation",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        hours_of_operation_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .hours_of_operation_id = "HoursOfOperationId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue_hours_of_operation) } {
            return .{ .service_metadata = service_metadata, .action = update_queue_hours_of_operation };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_queue_max_contacts: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/max-contacts",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueueMaxContacts",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        max_contacts: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .max_contacts = "MaxContacts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue_max_contacts) } {
            return .{ .service_metadata = service_metadata, .action = update_queue_max_contacts };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_queue_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueueName",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue_name) } {
            return .{ .service_metadata = service_metadata, .action = update_queue_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_queue_outbound_caller_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/outbound-caller-config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueueOutboundCallerConfig",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        outbound_caller_config: OutboundCallerConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .outbound_caller_config = "OutboundCallerConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue_outbound_caller_config) } {
            return .{ .service_metadata = service_metadata, .action = update_queue_outbound_caller_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_queue_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/queues/{InstanceId}/{QueueId}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQueueStatus",
    Request: type = struct {
        instance_id: []const u8,
        queue_id: []const u8,
        status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .queue_id = "QueueId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_queue_status) } {
            return .{ .service_metadata = service_metadata, .action = update_queue_status };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_quick_connect_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/quick-connects/{InstanceId}/{QuickConnectId}/config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQuickConnectConfig",
    Request: type = struct {
        instance_id: []const u8,
        quick_connect_id: []const u8,
        quick_connect_config: QuickConnectConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .quick_connect_id = "QuickConnectId",
                .quick_connect_config = "QuickConnectConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_quick_connect_config) } {
            return .{ .service_metadata = service_metadata, .action = update_quick_connect_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_quick_connect_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/quick-connects/{InstanceId}/{QuickConnectId}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateQuickConnectName",
    Request: type = struct {
        instance_id: []const u8,
        quick_connect_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .quick_connect_id = "QuickConnectId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_quick_connect_name) } {
            return .{ .service_metadata = service_metadata, .action = update_quick_connect_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_routing_profile_agent_availability_timer: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/agent-availability-timer",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoutingProfileAgentAvailabilityTimer",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        agent_availability_timer: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .agent_availability_timer = "AgentAvailabilityTimer",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_profile_agent_availability_timer) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_profile_agent_availability_timer };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_routing_profile_concurrency: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/concurrency",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoutingProfileConcurrency",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        media_concurrencies: []MediaConcurrency,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .media_concurrencies = "MediaConcurrencies",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_profile_concurrency) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_profile_concurrency };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_routing_profile_default_outbound_queue: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/default-outbound-queue",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoutingProfileDefaultOutboundQueue",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        default_outbound_queue_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .default_outbound_queue_id = "DefaultOutboundQueueId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_profile_default_outbound_queue) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_profile_default_outbound_queue };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_routing_profile_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoutingProfileName",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_profile_name) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_profile_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_routing_profile_queues: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/routing-profiles/{InstanceId}/{RoutingProfileId}/queues",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRoutingProfileQueues",
    Request: type = struct {
        instance_id: []const u8,
        routing_profile_id: []const u8,
        queue_configs: []RoutingProfileQueueConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .routing_profile_id = "RoutingProfileId",
                .queue_configs = "QueueConfigs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_routing_profile_queues) } {
            return .{ .service_metadata = service_metadata, .action = update_routing_profile_queues };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_rule: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/rules/{InstanceId}/{RuleId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateRule",
    Request: type = struct {
        rule_id: []const u8,
        instance_id: []const u8,
        name: []const u8,
        function: []const u8,
        actions: []RuleAction,
        publish_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_id = "RuleId",
                .instance_id = "InstanceId",
                .name = "Name",
                .function = "Function",
                .actions = "Actions",
                .publish_status = "PublishStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rule) } {
            return .{ .service_metadata = service_metadata, .action = update_rule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_security_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/security-profiles/{InstanceId}/{SecurityProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSecurityProfile",
    Request: type = struct {
        description: ?[]const u8 = null,
        permissions: ?[][]const u8 = null,
        security_profile_id: []const u8,
        instance_id: []const u8,
        allowed_access_control_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tag_restricted_resources: ?[][]const u8 = null,
        applications: ?[]Application = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .permissions = "Permissions",
                .security_profile_id = "SecurityProfileId",
                .instance_id = "InstanceId",
                .allowed_access_control_tags = "AllowedAccessControlTags",
                .tag_restricted_resources = "TagRestrictedResources",
                .applications = "Applications",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "allowed_access_control_tags", field_name))
                return try serializeMap(self.allowed_access_control_tags, self.fieldNameFor("allowed_access_control_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_security_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_security_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_task_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/instance/{InstanceId}/task/template/{TaskTemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTaskTemplate",
    Request: type = struct {
        task_template_id: []const u8,
        instance_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        contact_flow_id: ?[]const u8 = null,
        constraints: ?TaskTemplateConstraints = null,
        defaults: ?TaskTemplateDefaults = null,
        status: ?[]const u8 = null,
        fields: ?[]TaskTemplateField = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_template_id = "TaskTemplateId",
                .instance_id = "InstanceId",
                .name = "Name",
                .description = "Description",
                .contact_flow_id = "ContactFlowId",
                .constraints = "Constraints",
                .defaults = "Defaults",
                .status = "Status",
                .fields = "Fields",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_task_template) } {
            return .{ .service_metadata = service_metadata, .action = update_task_template };
        }
    },
    Response: type = struct {
        instance_id: ?[]const u8 = null,
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        contact_flow_id: ?[]const u8 = null,
        constraints: ?TaskTemplateConstraints = null,
        defaults: ?TaskTemplateDefaults = null,
        fields: ?[]TaskTemplateField = null,
        status: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        created_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .id = "Id",
                .arn = "Arn",
                .name = "Name",
                .description = "Description",
                .contact_flow_id = "ContactFlowId",
                .constraints = "Constraints",
                .defaults = "Defaults",
                .fields = "Fields",
                .status = "Status",
                .last_modified_time = "LastModifiedTime",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        PropertyValidation,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const update_traffic_distribution: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/traffic-distribution/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTrafficDistribution",
    Request: type = struct {
        id: []const u8,
        telephony_config: ?TelephonyConfig = null,
        sign_in_config: ?SignInConfig = null,
        agent_config: ?AgentConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .telephony_config = "TelephonyConfig",
                .sign_in_config = "SignInConfig",
                .agent_config = "AgentConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_traffic_distribution) } {
            return .{ .service_metadata = service_metadata, .action = update_traffic_distribution };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidRequest,
        ResourceConflict,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_hierarchy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/hierarchy",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserHierarchy",
    Request: type = struct {
        hierarchy_group_id: ?[]const u8 = null,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_group_id = "HierarchyGroupId",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_hierarchy) } {
            return .{ .service_metadata = service_metadata, .action = update_user_hierarchy };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_hierarchy_group_name: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user-hierarchy-groups/{InstanceId}/{HierarchyGroupId}/name",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserHierarchyGroupName",
    Request: type = struct {
        name: []const u8,
        hierarchy_group_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .hierarchy_group_id = "HierarchyGroupId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_hierarchy_group_name) } {
            return .{ .service_metadata = service_metadata, .action = update_user_hierarchy_group_name };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_hierarchy_structure: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/user-hierarchy-structure/{InstanceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserHierarchyStructure",
    Request: type = struct {
        hierarchy_structure: struct {
            level_one: ?HierarchyLevelUpdate = null,
            level_two: ?HierarchyLevelUpdate = null,
            level_three: ?HierarchyLevelUpdate = null,
            level_four: ?HierarchyLevelUpdate = null,
            level_five: ?HierarchyLevelUpdate = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .level_one = "LevelOne",
                    .level_two = "LevelTwo",
                    .level_three = "LevelThree",
                    .level_four = "LevelFour",
                    .level_five = "LevelFive",
                };
                return @field(mappings, field_name);
            }
        },
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hierarchy_structure = "HierarchyStructure",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_hierarchy_structure) } {
            return .{ .service_metadata = service_metadata, .action = update_user_hierarchy_structure };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_identity_info: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/identity-info",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserIdentityInfo",
    Request: type = struct {
        identity_info: UserIdentityInfo,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_info = "IdentityInfo",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_identity_info) } {
            return .{ .service_metadata = service_metadata, .action = update_user_identity_info };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_phone_config: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/phone-config",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserPhoneConfig",
    Request: type = struct {
        phone_config: UserPhoneConfig,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .phone_config = "PhoneConfig",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_phone_config) } {
            return .{ .service_metadata = service_metadata, .action = update_user_phone_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_proficiencies: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/proficiencies",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserProficiencies",
    Request: type = struct {
        instance_id: []const u8,
        user_id: []const u8,
        user_proficiencies: []UserProficiency,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .user_id = "UserId",
                .user_proficiencies = "UserProficiencies",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_proficiencies) } {
            return .{ .service_metadata = service_metadata, .action = update_user_proficiencies };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_routing_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/routing-profile",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserRoutingProfile",
    Request: type = struct {
        routing_profile_id: []const u8,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .routing_profile_id = "RoutingProfileId",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_routing_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_user_routing_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_user_security_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/users/{InstanceId}/{UserId}/security-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUserSecurityProfiles",
    Request: type = struct {
        security_profile_ids: [][]const u8,
        user_id: []const u8,
        instance_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_profile_ids = "SecurityProfileIds",
                .user_id = "UserId",
                .instance_id = "InstanceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_security_profiles) } {
            return .{ .service_metadata = service_metadata, .action = update_user_security_profiles };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_view_content: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/views/{InstanceId}/{ViewId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateViewContent",
    Request: type = struct {
        instance_id: []const u8,
        view_id: []const u8,
        status: []const u8,
        content: ViewInputContent,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .view_id = "ViewId",
                .status = "Status",
                .content = "Content",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_view_content) } {
            return .{ .service_metadata = service_metadata, .action = update_view_content };
        }
    },
    Response: type = struct {
        view: ?View = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .view = "View",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};
pub const update_view_metadata: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/views/{InstanceId}/{ViewId}/metadata",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateViewMetadata",
    Request: type = struct {
        instance_id: []const u8,
        view_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_id = "InstanceId",
                .view_id = "ViewId",
                .name = "Name",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_view_metadata) } {
            return .{ .service_metadata = service_metadata, .action = update_view_metadata };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DuplicateResource,
        InternalService,
        InvalidParameter,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        TooManyRequests,
    },
} = .{};

pub const View = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    type: ?[]const u8 = null,
    description: ?[]const u8 = null,
    version: ?i64 = null,
    version_description: ?[]const u8 = null,
    content: ?ViewContent = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    created_time: ?i64 = null,
    last_modified_time: ?i64 = null,
    view_content_sha256: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
            .status = "Status",
            .type = "Type",
            .description = "Description",
            .version = "Version",
            .version_description = "VersionDescription",
            .content = "Content",
            .tags = "Tags",
            .created_time = "CreatedTime",
            .last_modified_time = "LastModifiedTime",
            .view_content_sha256 = "ViewContentSha256",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ViewContent = struct {
    input_schema: ?[]const u8 = null,
    template: ?[]const u8 = null,
    actions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_schema = "InputSchema",
            .template = "Template",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const ViewInputContent = struct {
    template: ?[]const u8 = null,
    actions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .template = "Template",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const UserProficiency = struct {
    attribute_name: []const u8,
    attribute_value: []const u8,
    level: f32,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .attribute_value = "AttributeValue",
            .level = "Level",
        };
        return @field(mappings, field_name);
    }
};

pub const UserPhoneConfig = struct {
    phone_type: []const u8,
    auto_accept: ?bool = null,
    after_contact_work_time_limit: ?i64 = null,
    desk_phone_number: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_type = "PhoneType",
            .auto_accept = "AutoAccept",
            .after_contact_work_time_limit = "AfterContactWorkTimeLimit",
            .desk_phone_number = "DeskPhoneNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const UserIdentityInfo = struct {
    first_name: ?[]const u8 = null,
    last_name: ?[]const u8 = null,
    email: ?[]const u8 = null,
    secondary_email: ?[]const u8 = null,
    mobile: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .first_name = "FirstName",
            .last_name = "LastName",
            .email = "Email",
            .secondary_email = "SecondaryEmail",
            .mobile = "Mobile",
        };
        return @field(mappings, field_name);
    }
};

pub const HierarchyLevelUpdate = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const AgentConfig = struct {
    distributions: []Distribution,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .distributions = "Distributions",
        };
        return @field(mappings, field_name);
    }
};

pub const Distribution = struct {
    region: []const u8,
    percentage: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "Region",
            .percentage = "Percentage",
        };
        return @field(mappings, field_name);
    }
};

pub const SignInConfig = struct {
    distributions: []SignInDistribution,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .distributions = "Distributions",
        };
        return @field(mappings, field_name);
    }
};

pub const SignInDistribution = struct {
    region: []const u8,
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "Region",
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const TelephonyConfig = struct {
    distributions: []Distribution,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .distributions = "Distributions",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskTemplateField = struct {
    id: TaskTemplateFieldIdentifier,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    single_select_options: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .description = "Description",
            .type = "Type",
            .single_select_options = "SingleSelectOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskTemplateFieldIdentifier = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskTemplateDefaults = struct {
    default_field_values: ?[]TaskTemplateDefaultFieldValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_field_values = "DefaultFieldValues",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskTemplateDefaultFieldValue = struct {
    id: ?TaskTemplateFieldIdentifier = null,
    default_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .default_value = "DefaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskTemplateConstraints = struct {
    required_fields: ?[]RequiredFieldInfo = null,
    read_only_fields: ?[]ReadOnlyFieldInfo = null,
    invisible_fields: ?[]InvisibleFieldInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .required_fields = "RequiredFields",
            .read_only_fields = "ReadOnlyFields",
            .invisible_fields = "InvisibleFields",
        };
        return @field(mappings, field_name);
    }
};

pub const InvisibleFieldInfo = struct {
    id: ?TaskTemplateFieldIdentifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};

pub const ReadOnlyFieldInfo = struct {
    id: ?TaskTemplateFieldIdentifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};

pub const RequiredFieldInfo = struct {
    id: ?TaskTemplateFieldIdentifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
        };
        return @field(mappings, field_name);
    }
};

pub const Application = struct {
    namespace: ?[]const u8 = null,
    application_permissions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "Namespace",
            .application_permissions = "ApplicationPermissions",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleAction = struct {
    action_type: []const u8,
    task_action: ?TaskActionDefinition = null,
    event_bridge_action: ?EventBridgeActionDefinition = null,
    assign_contact_category_action: ?AssignContactCategoryActionDefinition = null,
    send_notification_action: ?SendNotificationActionDefinition = null,
    create_case_action: ?CreateCaseActionDefinition = null,
    update_case_action: ?UpdateCaseActionDefinition = null,
    end_associated_tasks_action: ?EndAssociatedTasksActionDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_type = "ActionType",
            .task_action = "TaskAction",
            .event_bridge_action = "EventBridgeAction",
            .assign_contact_category_action = "AssignContactCategoryAction",
            .send_notification_action = "SendNotificationAction",
            .create_case_action = "CreateCaseAction",
            .update_case_action = "UpdateCaseAction",
            .end_associated_tasks_action = "EndAssociatedTasksAction",
        };
        return @field(mappings, field_name);
    }
};

pub const EndAssociatedTasksActionDefinition = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const UpdateCaseActionDefinition = struct {
    fields: []FieldValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fields = "Fields",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldValue = struct {
    id: []const u8,
    value: FieldValueUnion,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldValueUnion = struct {
    boolean_value: ?bool = null,
    double_value: ?f64 = null,
    empty_value: ?EmptyFieldValue = null,
    string_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .boolean_value = "BooleanValue",
            .double_value = "DoubleValue",
            .empty_value = "EmptyValue",
            .string_value = "StringValue",
        };
        return @field(mappings, field_name);
    }
};

pub const EmptyFieldValue = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const CreateCaseActionDefinition = struct {
    fields: []FieldValue,
    template_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .fields = "Fields",
            .template_id = "TemplateId",
        };
        return @field(mappings, field_name);
    }
};

pub const SendNotificationActionDefinition = struct {
    delivery_method: []const u8,
    subject: ?[]const u8 = null,
    content: []const u8,
    content_type: []const u8,
    recipient: NotificationRecipientType,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_method = "DeliveryMethod",
            .subject = "Subject",
            .content = "Content",
            .content_type = "ContentType",
            .recipient = "Recipient",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationRecipientType = struct {
    user_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    user_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_tags = "UserTags",
            .user_ids = "UserIds",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "user_tags", field_name))
            return try serializeMap(self.user_tags, self.fieldNameFor("user_tags"), options, out_stream);
        return false;
    }
};

pub const AssignContactCategoryActionDefinition = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const EventBridgeActionDefinition = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskActionDefinition = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    contact_flow_id: []const u8,
    references: ?[]struct {
        key: ?[]const u8 = null,
        value: ?Reference = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .contact_flow_id = "ContactFlowId",
            .references = "References",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "references", field_name))
            return try serializeMap(self.references, self.fieldNameFor("references"), options, out_stream);
        return false;
    }
};

pub const Reference = struct {
    value: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const RoutingProfileQueueConfig = struct {
    queue_reference: RoutingProfileQueueReference,
    priority: i64,
    delay: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queue_reference = "QueueReference",
            .priority = "Priority",
            .delay = "Delay",
        };
        return @field(mappings, field_name);
    }
};

pub const RoutingProfileQueueReference = struct {
    queue_id: []const u8,
    channel: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queue_id = "QueueId",
            .channel = "Channel",
        };
        return @field(mappings, field_name);
    }
};

pub const MediaConcurrency = struct {
    channel: []const u8,
    concurrency: i64,
    cross_channel_behavior: ?CrossChannelBehavior = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel = "Channel",
            .concurrency = "Concurrency",
            .cross_channel_behavior = "CrossChannelBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const CrossChannelBehavior = struct {
    behavior_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .behavior_type = "BehaviorType",
        };
        return @field(mappings, field_name);
    }
};

pub const QuickConnectConfig = struct {
    quick_connect_type: []const u8,
    user_config: ?UserQuickConnectConfig = null,
    queue_config: ?QueueQuickConnectConfig = null,
    phone_config: ?PhoneNumberQuickConnectConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quick_connect_type = "QuickConnectType",
            .user_config = "UserConfig",
            .queue_config = "QueueConfig",
            .phone_config = "PhoneConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const PhoneNumberQuickConnectConfig = struct {
    phone_number: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .phone_number = "PhoneNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const QueueQuickConnectConfig = struct {
    queue_id: []const u8,
    contact_flow_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queue_id = "QueueId",
            .contact_flow_id = "ContactFlowId",
        };
        return @field(mappings, field_name);
    }
};

pub const UserQuickConnectConfig = struct {
    user_id: []const u8,
    contact_flow_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_id = "UserId",
            .contact_flow_id = "ContactFlowId",
        };
        return @field(mappings, field_name);
    }
};

pub const OutboundCallerConfig = struct {
    outbound_caller_id_name: ?[]const u8 = null,
    outbound_caller_id_number_id: ?[]const u8 = null,
    outbound_flow_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .outbound_caller_id_name = "OutboundCallerIdName",
            .outbound_caller_id_number_id = "OutboundCallerIdNumberId",
            .outbound_flow_id = "OutboundFlowId",
        };
        return @field(mappings, field_name);
    }
};

pub const PredefinedAttributeValues = union {
    string_list: ?[][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_list = "StringList",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceStorageConfig = struct {
    association_id: ?[]const u8 = null,
    storage_type: []const u8,
    s3_config: ?S3Config = null,
    kinesis_video_stream_config: ?KinesisVideoStreamConfig = null,
    kinesis_stream_config: ?KinesisStreamConfig = null,
    kinesis_firehose_config: ?KinesisFirehoseConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .association_id = "AssociationId",
            .storage_type = "StorageType",
            .s3_config = "S3Config",
            .kinesis_video_stream_config = "KinesisVideoStreamConfig",
            .kinesis_stream_config = "KinesisStreamConfig",
            .kinesis_firehose_config = "KinesisFirehoseConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisFirehoseConfig = struct {
    firehose_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .firehose_arn = "FirehoseArn",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisStreamConfig = struct {
    stream_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_arn = "StreamArn",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisVideoStreamConfig = struct {
    prefix: []const u8,
    retention_period_hours: i64,
    encryption_config: EncryptionConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .retention_period_hours = "RetentionPeriodHours",
            .encryption_config = "EncryptionConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfig = struct {
    encryption_type: []const u8,
    key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_type = "EncryptionType",
            .key_id = "KeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Config = struct {
    bucket_name: []const u8,
    bucket_prefix: []const u8,
    encryption_config: ?EncryptionConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "BucketName",
            .bucket_prefix = "BucketPrefix",
            .encryption_config = "EncryptionConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const HoursOfOperationConfig = struct {
    day: []const u8,
    start_time: HoursOfOperationTimeSlice,
    end_time: HoursOfOperationTimeSlice,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .day = "Day",
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const HoursOfOperationTimeSlice = struct {
    hours: i64,
    minutes: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hours = "Hours",
            .minutes = "Minutes",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormScoringStrategy = struct {
    mode: []const u8,
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormItem = union {
    section: ?EvaluationFormSection,
    question: ?EvaluationFormQuestion,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .section = "Section",
            .question = "Question",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormQuestion = struct {
    title: []const u8,
    instructions: ?[]const u8 = null,
    ref_id: []const u8,
    not_applicable_enabled: ?bool = null,
    question_type: []const u8,
    question_type_properties: ?EvaluationFormQuestionTypeProperties = null,
    weight: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title = "Title",
            .instructions = "Instructions",
            .ref_id = "RefId",
            .not_applicable_enabled = "NotApplicableEnabled",
            .question_type = "QuestionType",
            .question_type_properties = "QuestionTypeProperties",
            .weight = "Weight",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormQuestionTypeProperties = union {
    numeric: ?EvaluationFormNumericQuestionProperties,
    single_select: ?EvaluationFormSingleSelectQuestionProperties,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .numeric = "Numeric",
            .single_select = "SingleSelect",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormSingleSelectQuestionProperties = struct {
    options: []EvaluationFormSingleSelectQuestionOption,
    display_as: ?[]const u8 = null,
    automation: ?EvaluationFormSingleSelectQuestionAutomation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .display_as = "DisplayAs",
            .automation = "Automation",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormSingleSelectQuestionAutomation = struct {
    options: []EvaluationFormSingleSelectQuestionAutomationOption,
    default_option_ref_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .options = "Options",
            .default_option_ref_id = "DefaultOptionRefId",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormSingleSelectQuestionAutomationOption = union {
    rule_category: ?SingleSelectQuestionRuleCategoryAutomation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_category = "RuleCategory",
        };
        return @field(mappings, field_name);
    }
};

pub const SingleSelectQuestionRuleCategoryAutomation = struct {
    category: []const u8,
    condition: []const u8,
    option_ref_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .category = "Category",
            .condition = "Condition",
            .option_ref_id = "OptionRefId",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormSingleSelectQuestionOption = struct {
    ref_id: []const u8,
    text: []const u8,
    score: ?i64 = null,
    automatic_fail: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ref_id = "RefId",
            .text = "Text",
            .score = "Score",
            .automatic_fail = "AutomaticFail",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormNumericQuestionProperties = struct {
    min_value: i64,
    max_value: i64,
    options: ?[]EvaluationFormNumericQuestionOption = null,
    automation: ?EvaluationFormNumericQuestionAutomation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_value = "MinValue",
            .max_value = "MaxValue",
            .options = "Options",
            .automation = "Automation",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormNumericQuestionAutomation = union {
    property_value: ?NumericQuestionPropertyValueAutomation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .property_value = "PropertyValue",
        };
        return @field(mappings, field_name);
    }
};

pub const NumericQuestionPropertyValueAutomation = struct {
    label: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .label = "Label",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormNumericQuestionOption = struct {
    min_value: i64,
    max_value: i64,
    score: ?i64 = null,
    automatic_fail: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_value = "MinValue",
            .max_value = "MaxValue",
            .score = "Score",
            .automatic_fail = "AutomaticFail",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationFormSection = struct {
    title: []const u8,
    ref_id: []const u8,
    instructions: ?[]const u8 = null,
    items: []EvaluationFormItem,
    weight: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title = "Title",
            .ref_id = "RefId",
            .instructions = "Instructions",
            .items = "Items",
            .weight = "Weight",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationNote = struct {
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationAnswerInput = struct {
    value: ?EvaluationAnswerData = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationAnswerData = union {
    string_value: ?[]const u8,
    numeric_value: ?f64,
    not_applicable: ?bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "StringValue",
            .numeric_value = "NumericValue",
            .not_applicable = "NotApplicable",
        };
        return @field(mappings, field_name);
    }
};

pub const ParticipantDetails = struct {
    display_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .display_name = "DisplayName",
        };
        return @field(mappings, field_name);
    }
};

pub const ParticipantCapabilities = struct {
    video: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .video = "Video",
        };
        return @field(mappings, field_name);
    }
};

pub const ChatStreamingConfiguration = struct {
    streaming_endpoint_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .streaming_endpoint_arn = "StreamingEndpointArn",
        };
        return @field(mappings, field_name);
    }
};

pub const UserSearchCriteria = struct {
    or_conditions: ?[]UserSearchCriteria = null,
    and_conditions: ?[]UserSearchCriteria = null,
    string_condition: ?StringCondition = null,
    hierarchy_group_condition: ?struct {
        value: ?[]const u8 = null,
        hierarchy_group_match_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .value = "Value",
                .hierarchy_group_match_type = "HierarchyGroupMatchType",
            };
            return @field(mappings, field_name);
        }
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .or_conditions = "OrConditions",
            .and_conditions = "AndConditions",
            .string_condition = "StringCondition",
            .hierarchy_group_condition = "HierarchyGroupCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const StringCondition = struct {
    field_name: ?[]const u8 = null,
    value: ?[]const u8 = null,
    comparison_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_name = "FieldName",
            .value = "Value",
            .comparison_type = "ComparisonType",
        };
        return @field(mappings, field_name);
    }
};

pub const ControlPlaneTagFilter = struct {
    or_conditions: ?[][]TagCondition = null,
    and_conditions: ?[]TagCondition = null,
    tag_condition: ?TagCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .or_conditions = "OrConditions",
            .and_conditions = "AndConditions",
            .tag_condition = "TagCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const TagCondition = struct {
    tag_key: ?[]const u8 = null,
    tag_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_key = "TagKey",
            .tag_value = "TagValue",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityProfileSearchCriteria = struct {
    or_conditions: ?[]SecurityProfileSearchCriteria = null,
    and_conditions: ?[]SecurityProfileSearchCriteria = null,
    string_condition: ?StringCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .or_conditions = "OrConditions",
            .and_conditions = "AndConditions",
            .string_condition = "StringCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const RoutingProfile = struct {
    instance_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    routing_profile_arn: ?[]const u8 = null,
    routing_profile_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    media_concurrencies: ?[]MediaConcurrency = null,
    default_outbound_queue_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    number_of_associated_queues: ?i64 = null,
    number_of_associated_users: ?i64 = null,
    agent_availability_timer: ?[]const u8 = null,
    last_modified_time: ?i64 = null,
    last_modified_region: ?[]const u8 = null,
    is_default: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "InstanceId",
            .name = "Name",
            .routing_profile_arn = "RoutingProfileArn",
            .routing_profile_id = "RoutingProfileId",
            .description = "Description",
            .media_concurrencies = "MediaConcurrencies",
            .default_outbound_queue_id = "DefaultOutboundQueueId",
            .tags = "Tags",
            .number_of_associated_queues = "NumberOfAssociatedQueues",
            .number_of_associated_users = "NumberOfAssociatedUsers",
            .agent_availability_timer = "AgentAvailabilityTimer",
            .last_modified_time = "LastModifiedTime",
            .last_modified_region = "LastModifiedRegion",
            .is_default = "IsDefault",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const RoutingProfileSearchCriteria = struct {
    or_conditions: ?[]RoutingProfileSearchCriteria = null,
    and_conditions: ?[]RoutingProfileSearchCriteria = null,
    string_condition: ?StringCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .or_conditions = "OrConditions",
            .and_conditions = "AndConditions",
            .string_condition = "StringCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const QuickConnect = struct {
    quick_connect_arn: ?[]const u8 = null,
    quick_connect_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    quick_connect_config: ?QuickConnectConfig = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    last_modified_time: ?i64 = null,
    last_modified_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .quick_connect_arn = "QuickConnectARN",
            .quick_connect_id = "QuickConnectId",
            .name = "Name",
            .description = "Description",
            .quick_connect_config = "QuickConnectConfig",
            .tags = "Tags",
            .last_modified_time = "LastModifiedTime",
            .last_modified_region = "LastModifiedRegion",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const QuickConnectSearchCriteria = struct {
    or_conditions: ?[]QuickConnectSearchCriteria = null,
    and_conditions: ?[]QuickConnectSearchCriteria = null,
    string_condition: ?StringCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .or_conditions = "OrConditions",
            .and_conditions = "AndConditions",
            .string_condition = "StringCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const Queue = struct {
    name: ?[]const u8 = null,
    queue_arn: ?[]const u8 = null,
    queue_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    outbound_caller_config: ?OutboundCallerConfig = null,
    hours_of_operation_id: ?[]const u8 = null,
    max_contacts: ?i64 = null,
    status: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    last_modified_time: ?i64 = null,
    last_modified_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .queue_arn = "QueueArn",
            .queue_id = "QueueId",
            .description = "Description",
            .outbound_caller_config = "OutboundCallerConfig",
            .hours_of_operation_id = "HoursOfOperationId",
            .max_contacts = "MaxContacts",
            .status = "Status",
            .tags = "Tags",
            .last_modified_time = "LastModifiedTime",
            .last_modified_region = "LastModifiedRegion",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const QueueSearchCriteria = struct {
    or_conditions: ?[]QueueSearchCriteria = null,
    and_conditions: ?[]QueueSearchCriteria = null,
    string_condition: ?StringCondition = null,
    queue_type_condition: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .or_conditions = "OrConditions",
            .and_conditions = "AndConditions",
            .string_condition = "StringCondition",
            .queue_type_condition = "QueueTypeCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const Prompt = struct {
    prompt_arn: ?[]const u8 = null,
    prompt_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    last_modified_time: ?i64 = null,
    last_modified_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prompt_arn = "PromptARN",
            .prompt_id = "PromptId",
            .name = "Name",
            .description = "Description",
            .tags = "Tags",
            .last_modified_time = "LastModifiedTime",
            .last_modified_region = "LastModifiedRegion",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const PromptSearchCriteria = struct {
    or_conditions: ?[]PromptSearchCriteria = null,
    and_conditions: ?[]PromptSearchCriteria = null,
    string_condition: ?StringCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .or_conditions = "OrConditions",
            .and_conditions = "AndConditions",
            .string_condition = "StringCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const PredefinedAttribute = struct {
    name: ?[]const u8 = null,
    values: ?PredefinedAttributeValues = null,
    last_modified_time: ?i64 = null,
    last_modified_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
            .last_modified_time = "LastModifiedTime",
            .last_modified_region = "LastModifiedRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const PredefinedAttributeSearchCriteria = struct {
    or_conditions: ?[]PredefinedAttributeSearchCriteria = null,
    and_conditions: ?[]PredefinedAttributeSearchCriteria = null,
    string_condition: ?StringCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .or_conditions = "OrConditions",
            .and_conditions = "AndConditions",
            .string_condition = "StringCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const HoursOfOperation = struct {
    hours_of_operation_id: ?[]const u8 = null,
    hours_of_operation_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    time_zone: ?[]const u8 = null,
    config: ?[]HoursOfOperationConfig = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    last_modified_time: ?i64 = null,
    last_modified_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hours_of_operation_id = "HoursOfOperationId",
            .hours_of_operation_arn = "HoursOfOperationArn",
            .name = "Name",
            .description = "Description",
            .time_zone = "TimeZone",
            .config = "Config",
            .tags = "Tags",
            .last_modified_time = "LastModifiedTime",
            .last_modified_region = "LastModifiedRegion",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const HoursOfOperationSearchCriteria = struct {
    or_conditions: ?[]HoursOfOperationSearchCriteria = null,
    and_conditions: ?[]HoursOfOperationSearchCriteria = null,
    string_condition: ?StringCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .or_conditions = "OrConditions",
            .and_conditions = "AndConditions",
            .string_condition = "StringCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const HierarchyGroupSummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    last_modified_time: ?i64 = null,
    last_modified_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
            .last_modified_time = "LastModifiedTime",
            .last_modified_region = "LastModifiedRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const RealTimeContactAnalysisTimeData = union {
    absolute_time: ?i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .absolute_time = "AbsoluteTime",
        };
        return @field(mappings, field_name);
    }
};

pub const RealTimeContactAnalysisCharacterInterval = struct {
    begin_offset_char: i64,
    end_offset_char: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .begin_offset_char = "BeginOffsetChar",
            .end_offset_char = "EndOffsetChar",
        };
        return @field(mappings, field_name);
    }
};

pub const QuickConnectSummary = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    quick_connect_type: ?[]const u8 = null,
    last_modified_time: ?i64 = null,
    last_modified_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
            .quick_connect_type = "QuickConnectType",
            .last_modified_time = "LastModifiedTime",
            .last_modified_region = "LastModifiedRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const LexBot = struct {
    name: []const u8,
    lex_region: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .lex_region = "LexRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const Attribute = struct {
    attribute_type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_type = "AttributeType",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const FlowAssociationSummary = struct {
    resource_id: ?[]const u8 = null,
    flow_id: ?[]const u8 = null,
    resource_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_id = "ResourceId",
            .flow_id = "FlowId",
            .resource_type = "ResourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationScore = struct {
    percentage: ?f64 = null,
    not_applicable: ?bool = null,
    automatic_fail: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .percentage = "Percentage",
            .not_applicable = "NotApplicable",
            .automatic_fail = "AutomaticFail",
        };
        return @field(mappings, field_name);
    }
};

pub const LexV2Bot = struct {
    alias_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alias_arn = "AliasArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalyticsDataAssociationResult = struct {
    data_set_id: ?[]const u8 = null,
    target_account_id: ?[]const u8 = null,
    resource_share_id: ?[]const u8 = null,
    resource_share_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_id = "DataSetId",
            .target_account_id = "TargetAccountId",
            .resource_share_id = "ResourceShareId",
            .resource_share_arn = "ResourceShareArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricV2 = struct {
    name: ?[]const u8 = null,
    threshold: ?[]ThresholdV2 = null,
    metric_filters: ?[]MetricFilterV2 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .threshold = "Threshold",
            .metric_filters = "MetricFilters",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricFilterV2 = struct {
    metric_filter_key: ?[]const u8 = null,
    metric_filter_values: ?[][]const u8 = null,
    negate: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_filter_key = "MetricFilterKey",
            .metric_filter_values = "MetricFilterValues",
            .negate = "Negate",
        };
        return @field(mappings, field_name);
    }
};

pub const ThresholdV2 = struct {
    comparison: ?[]const u8 = null,
    threshold_value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "Comparison",
            .threshold_value = "ThresholdValue",
        };
        return @field(mappings, field_name);
    }
};

pub const HistoricalMetric = struct {
    name: ?[]const u8 = null,
    threshold: ?Threshold = null,
    statistic: ?[]const u8 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .threshold = "Threshold",
            .statistic = "Statistic",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const Threshold = struct {
    comparison: ?[]const u8 = null,
    threshold_value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .comparison = "Comparison",
            .threshold_value = "ThresholdValue",
        };
        return @field(mappings, field_name);
    }
};

pub const Dimensions = struct {
    queue: ?QueueReference = null,
    channel: ?[]const u8 = null,
    routing_profile: ?RoutingProfileReference = null,
    routing_step_expression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queue = "Queue",
            .channel = "Channel",
            .routing_profile = "RoutingProfile",
            .routing_step_expression = "RoutingStepExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const RoutingProfileReference = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const QueueReference = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const Filters = struct {
    queues: ?[][]const u8 = null,
    channels: ?[][]const u8 = null,
    routing_profiles: ?[][]const u8 = null,
    routing_step_expressions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .queues = "Queues",
            .channels = "Channels",
            .routing_profiles = "RoutingProfiles",
            .routing_step_expressions = "RoutingStepExpressions",
        };
        return @field(mappings, field_name);
    }
};

pub const HierarchyGroupSummaryReference = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const CurrentMetric = struct {
    name: ?[]const u8 = null,
    unit: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .unit = "Unit",
        };
        return @field(mappings, field_name);
    }
};

pub const HierarchyLevel = struct {
    id: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    last_modified_time: ?i64 = null,
    last_modified_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .arn = "Arn",
            .name = "Name",
            .last_modified_time = "LastModifiedTime",
            .last_modified_region = "LastModifiedRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleTriggerEventSource = struct {
    event_source_name: []const u8,
    integration_association_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .event_source_name = "EventSourceName",
            .integration_association_id = "IntegrationAssociationId",
        };
        return @field(mappings, field_name);
    }
};

pub const Endpoint = struct {
    type: ?[]const u8 = null,
    address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .address = "Address",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorResult = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};
