const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-01-01";
pub const sdk_id: []const u8 = "Database Migration Service";
pub const arn_namespace: ?[]const u8 = "dms";
pub const endpoint_prefix: []const u8 = "dms";
pub const sigv4_name: []const u8 = "dms";
pub const name: []const u8 = "AmazonDMSv20160101";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-01-01",
    sdk_id: []const u8 = "Database Migration Service",
    arn_namespace: ?[]const u8 = "dms",
    endpoint_prefix: []const u8 = "dms",
    sigv4_name: []const u8 = "dms",
    name: []const u8 = "AmazonDMSv20160101",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_tags_to_resource: struct {
    action_name: []const u8 = "AddTagsToResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const apply_pending_maintenance_action: struct {
    action_name: []const u8 = "ApplyPendingMaintenanceAction",
    Request: type = struct {
        replication_instance_arn: []const u8,
        apply_action: []const u8,
        opt_in_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .apply_action = "ApplyAction",
                .opt_in_type = "OptInType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(apply_pending_maintenance_action) } {
            return .{ .service_metadata = service_metadata, .action = apply_pending_maintenance_action };
        }
    },
    Response: type = struct {
        resource_pending_maintenance_actions: ?ResourcePendingMaintenanceActions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_pending_maintenance_actions = "ResourcePendingMaintenanceActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const batch_start_recommendations: struct {
    action_name: []const u8 = "BatchStartRecommendations",
    Request: type = struct {
        data: ?[]struct {
            database_id: []const u8,
            settings: RecommendationSettings,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database_id = "DatabaseId",
                    .settings = "Settings",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data = "Data",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_start_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = batch_start_recommendations };
        }
    },
    Response: type = struct {
        error_entries: ?[]struct {
            database_id: ?[]const u8 = null,
            message: ?[]const u8 = null,
            code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database_id = "DatabaseId",
                    .message = "Message",
                    .code = "Code",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .error_entries = "ErrorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const cancel_replication_task_assessment_run: struct {
    action_name: []const u8 = "CancelReplicationTaskAssessmentRun",
    Request: type = struct {
        replication_task_assessment_run_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_assessment_run_arn = "ReplicationTaskAssessmentRunArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_replication_task_assessment_run) } {
            return .{ .service_metadata = service_metadata, .action = cancel_replication_task_assessment_run };
        }
    },
    Response: type = struct {
        replication_task_assessment_run: ?ReplicationTaskAssessmentRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_assessment_run = "ReplicationTaskAssessmentRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const create_data_provider: struct {
    action_name: []const u8 = "CreateDataProvider",
    Request: type = struct {
        data_provider_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        engine: []const u8,
        settings: DataProviderSettings,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_provider_name = "DataProviderName",
                .description = "Description",
                .engine = "Engine",
                .settings = "Settings",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_provider) } {
            return .{ .service_metadata = service_metadata, .action = create_data_provider };
        }
    },
    Response: type = struct {
        data_provider: ?DataProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_provider = "DataProvider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceAlreadyExists,
        ResourceQuotaExceeded,
    },
} = .{};
pub const create_endpoint: struct {
    action_name: []const u8 = "CreateEndpoint",
    Request: type = struct {
        endpoint_identifier: []const u8,
        endpoint_type: []const u8,
        engine_name: []const u8,
        username: ?[]const u8 = null,
        password: ?[]const u8 = null,
        server_name: ?[]const u8 = null,
        port: ?i64 = null,
        database_name: ?[]const u8 = null,
        extra_connection_attributes: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        certificate_arn: ?[]const u8 = null,
        ssl_mode: ?[]const u8 = null,
        service_access_role_arn: ?[]const u8 = null,
        external_table_definition: ?[]const u8 = null,
        dynamo_db_settings: ?DynamoDbSettings = null,
        s3_settings: ?S3Settings = null,
        dms_transfer_settings: ?DmsTransferSettings = null,
        mongo_db_settings: ?MongoDbSettings = null,
        kinesis_settings: ?KinesisSettings = null,
        kafka_settings: ?KafkaSettings = null,
        elasticsearch_settings: ?ElasticsearchSettings = null,
        neptune_settings: ?NeptuneSettings = null,
        redshift_settings: ?RedshiftSettings = null,
        postgre_sql_settings: ?PostgreSQLSettings = null,
        my_sql_settings: ?MySQLSettings = null,
        oracle_settings: ?OracleSettings = null,
        sybase_settings: ?SybaseSettings = null,
        microsoft_sql_server_settings: ?MicrosoftSQLServerSettings = null,
        ibm_db2_settings: ?IBMDb2Settings = null,
        resource_identifier: ?[]const u8 = null,
        doc_db_settings: ?DocDbSettings = null,
        redis_settings: ?RedisSettings = null,
        gcp_my_sql_settings: ?GcpMySQLSettings = null,
        timestream_settings: ?TimestreamSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_identifier = "EndpointIdentifier",
                .endpoint_type = "EndpointType",
                .engine_name = "EngineName",
                .username = "Username",
                .password = "Password",
                .server_name = "ServerName",
                .port = "Port",
                .database_name = "DatabaseName",
                .extra_connection_attributes = "ExtraConnectionAttributes",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
                .certificate_arn = "CertificateArn",
                .ssl_mode = "SslMode",
                .service_access_role_arn = "ServiceAccessRoleArn",
                .external_table_definition = "ExternalTableDefinition",
                .dynamo_db_settings = "DynamoDbSettings",
                .s3_settings = "S3Settings",
                .dms_transfer_settings = "DmsTransferSettings",
                .mongo_db_settings = "MongoDbSettings",
                .kinesis_settings = "KinesisSettings",
                .kafka_settings = "KafkaSettings",
                .elasticsearch_settings = "ElasticsearchSettings",
                .neptune_settings = "NeptuneSettings",
                .redshift_settings = "RedshiftSettings",
                .postgre_sql_settings = "PostgreSQLSettings",
                .my_sql_settings = "MySQLSettings",
                .oracle_settings = "OracleSettings",
                .sybase_settings = "SybaseSettings",
                .microsoft_sql_server_settings = "MicrosoftSQLServerSettings",
                .ibm_db2_settings = "IBMDb2Settings",
                .resource_identifier = "ResourceIdentifier",
                .doc_db_settings = "DocDbSettings",
                .redis_settings = "RedisSettings",
                .gcp_my_sql_settings = "GcpMySQLSettings",
                .timestream_settings = "TimestreamSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?Endpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "Endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        S3AccessDenied,
    },
} = .{};
pub const create_event_subscription: struct {
    action_name: []const u8 = "CreateEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        sns_topic_arn: []const u8,
        source_type: ?[]const u8 = null,
        event_categories: ?[][]const u8 = null,
        source_ids: ?[][]const u8 = null,
        enabled: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .sns_topic_arn = "SnsTopicArn",
                .source_type = "SourceType",
                .event_categories = "EventCategories",
                .source_ids = "SourceIds",
                .enabled = "Enabled",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        KMSThrottling,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        SNSInvalidTopic,
        SNSNoAuthorization,
    },
} = .{};
pub const create_fleet_advisor_collector: struct {
    action_name: []const u8 = "CreateFleetAdvisorCollector",
    Request: type = struct {
        collector_name: []const u8,
        description: ?[]const u8 = null,
        service_access_role_arn: []const u8,
        s3_bucket_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collector_name = "CollectorName",
                .description = "Description",
                .service_access_role_arn = "ServiceAccessRoleArn",
                .s3_bucket_name = "S3BucketName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_fleet_advisor_collector) } {
            return .{ .service_metadata = service_metadata, .action = create_fleet_advisor_collector };
        }
    },
    Response: type = struct {
        collector_referenced_id: ?[]const u8 = null,
        collector_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        service_access_role_arn: ?[]const u8 = null,
        s3_bucket_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collector_referenced_id = "CollectorReferencedId",
                .collector_name = "CollectorName",
                .description = "Description",
                .service_access_role_arn = "ServiceAccessRoleArn",
                .s3_bucket_name = "S3BucketName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceQuotaExceeded,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const create_instance_profile: struct {
    action_name: []const u8 = "CreateInstanceProfile",
    Request: type = struct {
        availability_zone: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        publicly_accessible: ?bool = null,
        tags: ?[]Tag = null,
        network_type: ?[]const u8 = null,
        instance_profile_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        subnet_group_identifier: ?[]const u8 = null,
        vpc_security_groups: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .availability_zone = "AvailabilityZone",
                .kms_key_arn = "KmsKeyArn",
                .publicly_accessible = "PubliclyAccessible",
                .tags = "Tags",
                .network_type = "NetworkType",
                .instance_profile_name = "InstanceProfileName",
                .description = "Description",
                .subnet_group_identifier = "SubnetGroupIdentifier",
                .vpc_security_groups = "VpcSecurityGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_instance_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_instance_profile };
        }
    },
    Response: type = struct {
        instance_profile: ?InstanceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_profile = "InstanceProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const create_migration_project: struct {
    action_name: []const u8 = "CreateMigrationProject",
    Request: type = struct {
        migration_project_name: ?[]const u8 = null,
        source_data_provider_descriptors: []DataProviderDescriptorDefinition,
        target_data_provider_descriptors: []DataProviderDescriptorDefinition,
        instance_profile_identifier: []const u8,
        transformation_rules: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,
        schema_conversion_application_attributes: ?SCApplicationAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_name = "MigrationProjectName",
                .source_data_provider_descriptors = "SourceDataProviderDescriptors",
                .target_data_provider_descriptors = "TargetDataProviderDescriptors",
                .instance_profile_identifier = "InstanceProfileIdentifier",
                .transformation_rules = "TransformationRules",
                .description = "Description",
                .tags = "Tags",
                .schema_conversion_application_attributes = "SchemaConversionApplicationAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_migration_project) } {
            return .{ .service_metadata = service_metadata, .action = create_migration_project };
        }
    },
    Response: type = struct {
        migration_project: ?MigrationProject = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project = "MigrationProject",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const create_replication_config: struct {
    action_name: []const u8 = "CreateReplicationConfig",
    Request: type = struct {
        replication_config_identifier: []const u8,
        source_endpoint_arn: []const u8,
        target_endpoint_arn: []const u8,
        compute_config: ComputeConfig,
        replication_type: []const u8,
        table_mappings: []const u8,
        replication_settings: ?[]const u8 = null,
        supplemental_settings: ?[]const u8 = null,
        resource_identifier: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config_identifier = "ReplicationConfigIdentifier",
                .source_endpoint_arn = "SourceEndpointArn",
                .target_endpoint_arn = "TargetEndpointArn",
                .compute_config = "ComputeConfig",
                .replication_type = "ReplicationType",
                .table_mappings = "TableMappings",
                .replication_settings = "ReplicationSettings",
                .supplemental_settings = "SupplementalSettings",
                .resource_identifier = "ResourceIdentifier",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_config) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_config };
        }
    },
    Response: type = struct {
        replication_config: ?ReplicationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config = "ReplicationConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        InvalidSubnet,
        KMSKeyNotAccessible,
        ReplicationSubnetGroupDoesNotCoverEnoughAZs,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
    },
} = .{};
pub const create_replication_instance: struct {
    action_name: []const u8 = "CreateReplicationInstance",
    Request: type = struct {
        replication_instance_identifier: []const u8,
        allocated_storage: ?i64 = null,
        replication_instance_class: []const u8,
        vpc_security_group_ids: ?[][]const u8 = null,
        availability_zone: ?[]const u8 = null,
        replication_subnet_group_identifier: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        multi_az: ?bool = null,
        engine_version: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        publicly_accessible: ?bool = null,
        dns_name_servers: ?[]const u8 = null,
        resource_identifier: ?[]const u8 = null,
        network_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_identifier = "ReplicationInstanceIdentifier",
                .allocated_storage = "AllocatedStorage",
                .replication_instance_class = "ReplicationInstanceClass",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .availability_zone = "AvailabilityZone",
                .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .multi_az = "MultiAZ",
                .engine_version = "EngineVersion",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .publicly_accessible = "PubliclyAccessible",
                .dns_name_servers = "DnsNameServers",
                .resource_identifier = "ResourceIdentifier",
                .network_type = "NetworkType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_instance };
        }
    },
    Response: type = struct {
        replication_instance: ?ReplicationInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance = "ReplicationInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InsufficientResourceCapacity,
        InvalidResourceState,
        InvalidSubnet,
        KMSKeyNotAccessible,
        ReplicationSubnetGroupDoesNotCoverEnoughAZs,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        StorageQuotaExceeded,
    },
} = .{};
pub const create_replication_subnet_group: struct {
    action_name: []const u8 = "CreateReplicationSubnetGroup",
    Request: type = struct {
        replication_subnet_group_identifier: []const u8,
        replication_subnet_group_description: []const u8,
        subnet_ids: [][]const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
                .replication_subnet_group_description = "ReplicationSubnetGroupDescription",
                .subnet_ids = "SubnetIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_subnet_group };
        }
    },
    Response: type = struct {
        replication_subnet_group: ?ReplicationSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_subnet_group = "ReplicationSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidSubnet,
        ReplicationSubnetGroupDoesNotCoverEnoughAZs,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
    },
} = .{};
pub const create_replication_task: struct {
    action_name: []const u8 = "CreateReplicationTask",
    Request: type = struct {
        replication_task_identifier: []const u8,
        source_endpoint_arn: []const u8,
        target_endpoint_arn: []const u8,
        replication_instance_arn: []const u8,
        migration_type: []const u8,
        table_mappings: []const u8,
        replication_task_settings: ?[]const u8 = null,
        cdc_start_time: ?i64 = null,
        cdc_start_position: ?[]const u8 = null,
        cdc_stop_position: ?[]const u8 = null,
        tags: ?[]Tag = null,
        task_data: ?[]const u8 = null,
        resource_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_identifier = "ReplicationTaskIdentifier",
                .source_endpoint_arn = "SourceEndpointArn",
                .target_endpoint_arn = "TargetEndpointArn",
                .replication_instance_arn = "ReplicationInstanceArn",
                .migration_type = "MigrationType",
                .table_mappings = "TableMappings",
                .replication_task_settings = "ReplicationTaskSettings",
                .cdc_start_time = "CdcStartTime",
                .cdc_start_position = "CdcStartPosition",
                .cdc_stop_position = "CdcStopPosition",
                .tags = "Tags",
                .task_data = "TaskData",
                .resource_identifier = "ResourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
    },
} = .{};
pub const delete_certificate: struct {
    action_name: []const u8 = "DeleteCertificate",
    Request: type = struct {
        certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_certificate) } {
            return .{ .service_metadata = service_metadata, .action = delete_certificate };
        }
    },
    Response: type = struct {
        certificate: ?Certificate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_connection: struct {
    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        endpoint_arn: []const u8,
        replication_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
                .replication_instance_arn = "ReplicationInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_data_provider: struct {
    action_name: []const u8 = "DeleteDataProvider",
    Request: type = struct {
        data_provider_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_provider_identifier = "DataProviderIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_provider) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_provider };
        }
    },
    Response: type = struct {
        data_provider: ?DataProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_provider = "DataProvider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_endpoint: struct {
    action_name: []const u8 = "DeleteEndpoint",
    Request: type = struct {
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?Endpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "Endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_event_subscription: struct {
    action_name: []const u8 = "DeleteEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_fleet_advisor_collector: struct {
    action_name: []const u8 = "DeleteFleetAdvisorCollector",
    Request: type = struct {
        collector_referenced_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collector_referenced_id = "CollectorReferencedId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fleet_advisor_collector) } {
            return .{ .service_metadata = service_metadata, .action = delete_fleet_advisor_collector };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        CollectorNotFound,
        InvalidResourceState,
    },
} = .{};
pub const delete_fleet_advisor_databases: struct {
    action_name: []const u8 = "DeleteFleetAdvisorDatabases",
    Request: type = struct {
        database_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_ids = "DatabaseIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_fleet_advisor_databases) } {
            return .{ .service_metadata = service_metadata, .action = delete_fleet_advisor_databases };
        }
    },
    Response: type = struct {
        database_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_ids = "DatabaseIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidOperation,
        ResourceNotFound,
    },
} = .{};
pub const delete_instance_profile: struct {
    action_name: []const u8 = "DeleteInstanceProfile",
    Request: type = struct {
        instance_profile_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_profile_identifier = "InstanceProfileIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_instance_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_instance_profile };
        }
    },
    Response: type = struct {
        instance_profile: ?InstanceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_profile = "InstanceProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_migration_project: struct {
    action_name: []const u8 = "DeleteMigrationProject",
    Request: type = struct {
        migration_project_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_migration_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_migration_project };
        }
    },
    Response: type = struct {
        migration_project: ?MigrationProject = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project = "MigrationProject",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_replication_config: struct {
    action_name: []const u8 = "DeleteReplicationConfig",
    Request: type = struct {
        replication_config_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config_arn = "ReplicationConfigArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_config };
        }
    },
    Response: type = struct {
        replication_config: ?ReplicationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config = "ReplicationConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_replication_instance: struct {
    action_name: []const u8 = "DeleteReplicationInstance",
    Request: type = struct {
        replication_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_instance };
        }
    },
    Response: type = struct {
        replication_instance: ?ReplicationInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance = "ReplicationInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_replication_subnet_group: struct {
    action_name: []const u8 = "DeleteReplicationSubnetGroup",
    Request: type = struct {
        replication_subnet_group_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_subnet_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_replication_task: struct {
    action_name: []const u8 = "DeleteReplicationTask",
    Request: type = struct {
        replication_task_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_replication_task_assessment_run: struct {
    action_name: []const u8 = "DeleteReplicationTaskAssessmentRun",
    Request: type = struct {
        replication_task_assessment_run_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_assessment_run_arn = "ReplicationTaskAssessmentRunArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_task_assessment_run) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_task_assessment_run };
        }
    },
    Response: type = struct {
        replication_task_assessment_run: ?ReplicationTaskAssessmentRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_assessment_run = "ReplicationTaskAssessmentRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_account_attributes: struct {
    action_name: []const u8 = "DescribeAccountAttributes",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_attributes };
        }
    },
    Response: type = struct {
        account_quotas: ?[]struct {
            account_quota_name: ?[]const u8 = null,
            used: ?i64 = null,
            max: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_quota_name = "AccountQuotaName",
                    .used = "Used",
                    .max = "Max",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unique_account_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_quotas = "AccountQuotas",
                .unique_account_identifier = "UniqueAccountIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_applicable_individual_assessments: struct {
    action_name: []const u8 = "DescribeApplicableIndividualAssessments",
    Request: type = struct {
        replication_task_arn: ?[]const u8 = null,
        replication_instance_arn: ?[]const u8 = null,
        source_engine_name: ?[]const u8 = null,
        target_engine_name: ?[]const u8 = null,
        migration_type: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .replication_instance_arn = "ReplicationInstanceArn",
                .source_engine_name = "SourceEngineName",
                .target_engine_name = "TargetEngineName",
                .migration_type = "MigrationType",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_applicable_individual_assessments) } {
            return .{ .service_metadata = service_metadata, .action = describe_applicable_individual_assessments };
        }
    },
    Response: type = struct {
        individual_assessment_names: ?[][]const u8 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .individual_assessment_names = "IndividualAssessmentNames",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_certificates: struct {
    action_name: []const u8 = "DescribeCertificates",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificates) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificates };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        certificates: ?[]Certificate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .certificates = "Certificates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_connections: struct {
    action_name: []const u8 = "DescribeConnections",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_connections };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        connections: ?[]Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .connections = "Connections",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_conversion_configuration: struct {
    action_name: []const u8 = "DescribeConversionConfiguration",
    Request: type = struct {
        migration_project_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_conversion_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_conversion_configuration };
        }
    },
    Response: type = struct {
        migration_project_identifier: ?[]const u8 = null,
        conversion_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .conversion_configuration = "ConversionConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_data_providers: struct {
    action_name: []const u8 = "DescribeDataProviders",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_providers) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_providers };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        data_providers: ?[]DataProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .data_providers = "DataProviders",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
    },
} = .{};
pub const describe_endpoints: struct {
    action_name: []const u8 = "DescribeEndpoints",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoints };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        endpoints: ?[]Endpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .endpoints = "Endpoints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_endpoint_settings: struct {
    action_name: []const u8 = "DescribeEndpointSettings",
    Request: type = struct {
        engine_name: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_name = "EngineName",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoint_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoint_settings };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        endpoint_settings: ?[]struct {
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            enum_values: ?[][]const u8 = null,
            sensitive: ?bool = null,
            units: ?[]const u8 = null,
            applicability: ?[]const u8 = null,
            int_value_min: ?i64 = null,
            int_value_max: ?i64 = null,
            default_value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .type = "Type",
                    .enum_values = "EnumValues",
                    .sensitive = "Sensitive",
                    .units = "Units",
                    .applicability = "Applicability",
                    .int_value_min = "IntValueMin",
                    .int_value_max = "IntValueMax",
                    .default_value = "DefaultValue",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .endpoint_settings = "EndpointSettings",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_endpoint_types: struct {
    action_name: []const u8 = "DescribeEndpointTypes",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoint_types) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoint_types };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        supported_endpoint_types: ?[]struct {
            engine_name: ?[]const u8 = null,
            supports_cdc: ?bool = null,
            endpoint_type: ?[]const u8 = null,
            replication_instance_engine_minimum_version: ?[]const u8 = null,
            engine_display_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine_name = "EngineName",
                    .supports_cdc = "SupportsCDC",
                    .endpoint_type = "EndpointType",
                    .replication_instance_engine_minimum_version = "ReplicationInstanceEngineMinimumVersion",
                    .engine_display_name = "EngineDisplayName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .supported_endpoint_types = "SupportedEndpointTypes",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_engine_versions: struct {
    action_name: []const u8 = "DescribeEngineVersions",
    Request: type = struct {
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_engine_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_engine_versions };
        }
    },
    Response: type = struct {
        engine_versions: ?[]struct {
            version: ?[]const u8 = null,
            lifecycle: ?[]const u8 = null,
            release_status: ?[]const u8 = null,
            launch_date: ?i64 = null,
            auto_upgrade_date: ?i64 = null,
            deprecation_date: ?i64 = null,
            force_upgrade_date: ?i64 = null,
            available_upgrades: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version = "Version",
                    .lifecycle = "Lifecycle",
                    .release_status = "ReleaseStatus",
                    .launch_date = "LaunchDate",
                    .auto_upgrade_date = "AutoUpgradeDate",
                    .deprecation_date = "DeprecationDate",
                    .force_upgrade_date = "ForceUpgradeDate",
                    .available_upgrades = "AvailableUpgrades",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_versions = "EngineVersions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_event_categories: struct {
    action_name: []const u8 = "DescribeEventCategories",
    Request: type = struct {
        source_type: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_type = "SourceType",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_categories) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_categories };
        }
    },
    Response: type = struct {
        event_category_group_list: ?[]struct {
            source_type: ?[]const u8 = null,
            event_categories: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_type = "SourceType",
                    .event_categories = "EventCategories",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_category_group_list = "EventCategoryGroupList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        source_identifier: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        duration: ?i64 = null,
        event_categories: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_identifier = "SourceIdentifier",
                .source_type = "SourceType",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .duration = "Duration",
                .event_categories = "EventCategories",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        events: ?[]struct {
            source_identifier: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            message: ?[]const u8 = null,
            event_categories: ?[][]const u8 = null,
            date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_identifier = "SourceIdentifier",
                    .source_type = "SourceType",
                    .message = "Message",
                    .event_categories = "EventCategories",
                    .date = "Date",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .events = "Events",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_event_subscriptions: struct {
    action_name: []const u8 = "DescribeEventSubscriptions",
    Request: type = struct {
        subscription_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_subscriptions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        event_subscriptions_list: ?[]EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .event_subscriptions_list = "EventSubscriptionsList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_extension_pack_associations: struct {
    action_name: []const u8 = "DescribeExtensionPackAssociations",
    Request: type = struct {
        migration_project_identifier: []const u8,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_extension_pack_associations) } {
            return .{ .service_metadata = service_metadata, .action = describe_extension_pack_associations };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        requests: ?[]SchemaConversionRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .requests = "Requests",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_fleet_advisor_collectors: struct {
    action_name: []const u8 = "DescribeFleetAdvisorCollectors",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_advisor_collectors) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_advisor_collectors };
        }
    },
    Response: type = struct {
        collectors: ?[]struct {
            collector_referenced_id: ?[]const u8 = null,
            collector_name: ?[]const u8 = null,
            collector_version: ?[]const u8 = null,
            version_status: ?[]const u8 = null,
            description: ?[]const u8 = null,
            s3_bucket_name: ?[]const u8 = null,
            service_access_role_arn: ?[]const u8 = null,
            collector_health_check: ?struct {
                collector_status: ?[]const u8 = null,
                local_collector_s3_access: ?bool = null,
                web_collector_s3_access: ?bool = null,
                web_collector_granted_role_based_access: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .collector_status = "CollectorStatus",
                        .local_collector_s3_access = "LocalCollectorS3Access",
                        .web_collector_s3_access = "WebCollectorS3Access",
                        .web_collector_granted_role_based_access = "WebCollectorGrantedRoleBasedAccess",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_data_received: ?[]const u8 = null,
            registered_date: ?[]const u8 = null,
            created_date: ?[]const u8 = null,
            modified_date: ?[]const u8 = null,
            inventory_data: ?struct {
                number_of_databases: ?i64 = null,
                number_of_schemas: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .number_of_databases = "NumberOfDatabases",
                        .number_of_schemas = "NumberOfSchemas",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .collector_referenced_id = "CollectorReferencedId",
                    .collector_name = "CollectorName",
                    .collector_version = "CollectorVersion",
                    .version_status = "VersionStatus",
                    .description = "Description",
                    .s3_bucket_name = "S3BucketName",
                    .service_access_role_arn = "ServiceAccessRoleArn",
                    .collector_health_check = "CollectorHealthCheck",
                    .last_data_received = "LastDataReceived",
                    .registered_date = "RegisteredDate",
                    .created_date = "CreatedDate",
                    .modified_date = "ModifiedDate",
                    .inventory_data = "InventoryData",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collectors = "Collectors",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
    },
} = .{};
pub const describe_fleet_advisor_databases: struct {
    action_name: []const u8 = "DescribeFleetAdvisorDatabases",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_advisor_databases) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_advisor_databases };
        }
    },
    Response: type = struct {
        databases: ?[]struct {
            database_id: ?[]const u8 = null,
            database_name: ?[]const u8 = null,
            ip_address: ?[]const u8 = null,
            number_of_schemas: ?i64 = null,
            server: ?ServerShortInfoResponse = null,
            software_details: ?struct {
                engine: ?[]const u8 = null,
                engine_version: ?[]const u8 = null,
                engine_edition: ?[]const u8 = null,
                service_pack: ?[]const u8 = null,
                support_level: ?[]const u8 = null,
                os_architecture: ?i64 = null,
                tooltip: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .engine = "Engine",
                        .engine_version = "EngineVersion",
                        .engine_edition = "EngineEdition",
                        .service_pack = "ServicePack",
                        .support_level = "SupportLevel",
                        .os_architecture = "OsArchitecture",
                        .tooltip = "Tooltip",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            collectors: ?[]struct {
                collector_referenced_id: ?[]const u8 = null,
                collector_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .collector_referenced_id = "CollectorReferencedId",
                        .collector_name = "CollectorName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database_id = "DatabaseId",
                    .database_name = "DatabaseName",
                    .ip_address = "IpAddress",
                    .number_of_schemas = "NumberOfSchemas",
                    .server = "Server",
                    .software_details = "SoftwareDetails",
                    .collectors = "Collectors",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .databases = "Databases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
    },
} = .{};
pub const describe_fleet_advisor_lsa_analysis: struct {
    action_name: []const u8 = "DescribeFleetAdvisorLsaAnalysis",
    Request: type = struct {
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_advisor_lsa_analysis) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_advisor_lsa_analysis };
        }
    },
    Response: type = struct {
        analysis: ?[]struct {
            lsa_analysis_id: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lsa_analysis_id = "LsaAnalysisId",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis = "Analysis",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
    },
} = .{};
pub const describe_fleet_advisor_schema_object_summary: struct {
    action_name: []const u8 = "DescribeFleetAdvisorSchemaObjectSummary",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_advisor_schema_object_summary) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_advisor_schema_object_summary };
        }
    },
    Response: type = struct {
        fleet_advisor_schema_objects: ?[]struct {
            schema_id: ?[]const u8 = null,
            object_type: ?[]const u8 = null,
            number_of_objects: ?i64 = null,
            code_line_count: ?i64 = null,
            code_size: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .schema_id = "SchemaId",
                    .object_type = "ObjectType",
                    .number_of_objects = "NumberOfObjects",
                    .code_line_count = "CodeLineCount",
                    .code_size = "CodeSize",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_advisor_schema_objects = "FleetAdvisorSchemaObjects",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
    },
} = .{};
pub const describe_fleet_advisor_schemas: struct {
    action_name: []const u8 = "DescribeFleetAdvisorSchemas",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_fleet_advisor_schemas) } {
            return .{ .service_metadata = service_metadata, .action = describe_fleet_advisor_schemas };
        }
    },
    Response: type = struct {
        fleet_advisor_schemas: ?[]struct {
            code_line_count: ?i64 = null,
            code_size: ?i64 = null,
            complexity: ?[]const u8 = null,
            server: ?ServerShortInfoResponse = null,
            database_instance: ?struct {
                database_id: ?[]const u8 = null,
                database_name: ?[]const u8 = null,
                database_ip_address: ?[]const u8 = null,
                database_engine: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .database_id = "DatabaseId",
                        .database_name = "DatabaseName",
                        .database_ip_address = "DatabaseIpAddress",
                        .database_engine = "DatabaseEngine",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            schema_id: ?[]const u8 = null,
            schema_name: ?[]const u8 = null,
            original_schema: ?struct {
                schema_id: ?[]const u8 = null,
                schema_name: ?[]const u8 = null,
                database_id: ?[]const u8 = null,
                database_name: ?[]const u8 = null,
                database_ip_address: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .schema_id = "SchemaId",
                        .schema_name = "SchemaName",
                        .database_id = "DatabaseId",
                        .database_name = "DatabaseName",
                        .database_ip_address = "DatabaseIpAddress",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            similarity: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code_line_count = "CodeLineCount",
                    .code_size = "CodeSize",
                    .complexity = "Complexity",
                    .server = "Server",
                    .database_instance = "DatabaseInstance",
                    .schema_id = "SchemaId",
                    .schema_name = "SchemaName",
                    .original_schema = "OriginalSchema",
                    .similarity = "Similarity",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .fleet_advisor_schemas = "FleetAdvisorSchemas",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
    },
} = .{};
pub const describe_instance_profiles: struct {
    action_name: []const u8 = "DescribeInstanceProfiles",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_instance_profiles) } {
            return .{ .service_metadata = service_metadata, .action = describe_instance_profiles };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        instance_profiles: ?[]InstanceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .instance_profiles = "InstanceProfiles",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
    },
} = .{};
pub const describe_metadata_model_assessments: struct {
    action_name: []const u8 = "DescribeMetadataModelAssessments",
    Request: type = struct {
        migration_project_identifier: []const u8,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_metadata_model_assessments) } {
            return .{ .service_metadata = service_metadata, .action = describe_metadata_model_assessments };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        requests: ?[]SchemaConversionRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .requests = "Requests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_metadata_model_conversions: struct {
    action_name: []const u8 = "DescribeMetadataModelConversions",
    Request: type = struct {
        migration_project_identifier: []const u8,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_metadata_model_conversions) } {
            return .{ .service_metadata = service_metadata, .action = describe_metadata_model_conversions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        requests: ?[]SchemaConversionRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .requests = "Requests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_metadata_model_exports_as_script: struct {
    action_name: []const u8 = "DescribeMetadataModelExportsAsScript",
    Request: type = struct {
        migration_project_identifier: []const u8,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_metadata_model_exports_as_script) } {
            return .{ .service_metadata = service_metadata, .action = describe_metadata_model_exports_as_script };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        requests: ?[]SchemaConversionRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .requests = "Requests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_metadata_model_exports_to_target: struct {
    action_name: []const u8 = "DescribeMetadataModelExportsToTarget",
    Request: type = struct {
        migration_project_identifier: []const u8,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_metadata_model_exports_to_target) } {
            return .{ .service_metadata = service_metadata, .action = describe_metadata_model_exports_to_target };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        requests: ?[]SchemaConversionRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .requests = "Requests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_metadata_model_imports: struct {
    action_name: []const u8 = "DescribeMetadataModelImports",
    Request: type = struct {
        migration_project_identifier: []const u8,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_metadata_model_imports) } {
            return .{ .service_metadata = service_metadata, .action = describe_metadata_model_imports };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        requests: ?[]SchemaConversionRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .requests = "Requests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_migration_projects: struct {
    action_name: []const u8 = "DescribeMigrationProjects",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_migration_projects) } {
            return .{ .service_metadata = service_metadata, .action = describe_migration_projects };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        migration_projects: ?[]MigrationProject = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .migration_projects = "MigrationProjects",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
    },
} = .{};
pub const describe_orderable_replication_instances: struct {
    action_name: []const u8 = "DescribeOrderableReplicationInstances",
    Request: type = struct {
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_orderable_replication_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_orderable_replication_instances };
        }
    },
    Response: type = struct {
        orderable_replication_instances: ?[]struct {
            engine_version: ?[]const u8 = null,
            replication_instance_class: ?[]const u8 = null,
            storage_type: ?[]const u8 = null,
            min_allocated_storage: ?i64 = null,
            max_allocated_storage: ?i64 = null,
            default_allocated_storage: ?i64 = null,
            included_allocated_storage: ?i64 = null,
            availability_zones: ?[][]const u8 = null,
            release_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine_version = "EngineVersion",
                    .replication_instance_class = "ReplicationInstanceClass",
                    .storage_type = "StorageType",
                    .min_allocated_storage = "MinAllocatedStorage",
                    .max_allocated_storage = "MaxAllocatedStorage",
                    .default_allocated_storage = "DefaultAllocatedStorage",
                    .included_allocated_storage = "IncludedAllocatedStorage",
                    .availability_zones = "AvailabilityZones",
                    .release_status = "ReleaseStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .orderable_replication_instances = "OrderableReplicationInstances",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_pending_maintenance_actions: struct {
    action_name: []const u8 = "DescribePendingMaintenanceActions",
    Request: type = struct {
        replication_instance_arn: ?[]const u8 = null,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pending_maintenance_actions) } {
            return .{ .service_metadata = service_metadata, .action = describe_pending_maintenance_actions };
        }
    },
    Response: type = struct {
        pending_maintenance_actions: ?[]ResourcePendingMaintenanceActions = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pending_maintenance_actions = "PendingMaintenanceActions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_recommendation_limitations: struct {
    action_name: []const u8 = "DescribeRecommendationLimitations",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_recommendation_limitations) } {
            return .{ .service_metadata = service_metadata, .action = describe_recommendation_limitations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        limitations: ?[]struct {
            database_id: ?[]const u8 = null,
            engine_name: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            impact: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database_id = "DatabaseId",
                    .engine_name = "EngineName",
                    .name = "Name",
                    .description = "Description",
                    .impact = "Impact",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .limitations = "Limitations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
    },
} = .{};
pub const describe_recommendations: struct {
    action_name: []const u8 = "DescribeRecommendations",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = describe_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recommendations: ?[]struct {
            database_id: ?[]const u8 = null,
            engine_name: ?[]const u8 = null,
            created_date: ?[]const u8 = null,
            status: ?[]const u8 = null,
            preferred: ?bool = null,
            settings: ?RecommendationSettings = null,
            data: ?struct {
                rds_engine: ?struct {
                    requirements_to_target: ?struct {
                        engine_edition: ?[]const u8 = null,
                        instance_vcpu: ?f64 = null,
                        instance_memory: ?f64 = null,
                        storage_size: ?i64 = null,
                        storage_iops: ?i64 = null,
                        deployment_option: ?[]const u8 = null,
                        engine_version: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .engine_edition = "EngineEdition",
                                .instance_vcpu = "InstanceVcpu",
                                .instance_memory = "InstanceMemory",
                                .storage_size = "StorageSize",
                                .storage_iops = "StorageIops",
                                .deployment_option = "DeploymentOption",
                                .engine_version = "EngineVersion",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    target_configuration: ?struct {
                        engine_edition: ?[]const u8 = null,
                        instance_type: ?[]const u8 = null,
                        instance_vcpu: ?f64 = null,
                        instance_memory: ?f64 = null,
                        storage_type: ?[]const u8 = null,
                        storage_size: ?i64 = null,
                        storage_iops: ?i64 = null,
                        deployment_option: ?[]const u8 = null,
                        engine_version: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .engine_edition = "EngineEdition",
                                .instance_type = "InstanceType",
                                .instance_vcpu = "InstanceVcpu",
                                .instance_memory = "InstanceMemory",
                                .storage_type = "StorageType",
                                .storage_size = "StorageSize",
                                .storage_iops = "StorageIops",
                                .deployment_option = "DeploymentOption",
                                .engine_version = "EngineVersion",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .requirements_to_target = "RequirementsToTarget",
                            .target_configuration = "TargetConfiguration",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .rds_engine = "RdsEngine",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .database_id = "DatabaseId",
                    .engine_name = "EngineName",
                    .created_date = "CreatedDate",
                    .status = "Status",
                    .preferred = "Preferred",
                    .settings = "Settings",
                    .data = "Data",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .recommendations = "Recommendations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
    },
} = .{};
pub const describe_refresh_schemas_status: struct {
    action_name: []const u8 = "DescribeRefreshSchemasStatus",
    Request: type = struct {
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_refresh_schemas_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_refresh_schemas_status };
        }
    },
    Response: type = struct {
        refresh_schemas_status: ?RefreshSchemasStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .refresh_schemas_status = "RefreshSchemasStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_configs: struct {
    action_name: []const u8 = "DescribeReplicationConfigs",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_configs) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_configs };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_configs: ?[]ReplicationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_configs = "ReplicationConfigs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_instances: struct {
    action_name: []const u8 = "DescribeReplicationInstances",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_instances };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_instances: ?[]ReplicationInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_instances = "ReplicationInstances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_instance_task_logs: struct {
    action_name: []const u8 = "DescribeReplicationInstanceTaskLogs",
    Request: type = struct {
        replication_instance_arn: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_instance_task_logs) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_instance_task_logs };
        }
    },
    Response: type = struct {
        replication_instance_arn: ?[]const u8 = null,
        replication_instance_task_logs: ?[]struct {
            replication_task_name: ?[]const u8 = null,
            replication_task_arn: ?[]const u8 = null,
            replication_instance_task_log_size: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replication_task_name = "ReplicationTaskName",
                    .replication_task_arn = "ReplicationTaskArn",
                    .replication_instance_task_log_size = "ReplicationInstanceTaskLogSize",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .replication_instance_task_logs = "ReplicationInstanceTaskLogs",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_replications: struct {
    action_name: []const u8 = "DescribeReplications",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replications) } {
            return .{ .service_metadata = service_metadata, .action = describe_replications };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replications: ?[]Replication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replications = "Replications",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_subnet_groups: struct {
    action_name: []const u8 = "DescribeReplicationSubnetGroups",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_subnet_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_subnet_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_subnet_groups: ?[]ReplicationSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_subnet_groups = "ReplicationSubnetGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_table_statistics: struct {
    action_name: []const u8 = "DescribeReplicationTableStatistics",
    Request: type = struct {
        replication_config_arn: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config_arn = "ReplicationConfigArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_table_statistics) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_table_statistics };
        }
    },
    Response: type = struct {
        replication_config_arn: ?[]const u8 = null,
        marker: ?[]const u8 = null,
        replication_table_statistics: ?[]TableStatistics = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config_arn = "ReplicationConfigArn",
                .marker = "Marker",
                .replication_table_statistics = "ReplicationTableStatistics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_task_assessment_results: struct {
    action_name: []const u8 = "DescribeReplicationTaskAssessmentResults",
    Request: type = struct {
        replication_task_arn: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_task_assessment_results) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_task_assessment_results };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        bucket_name: ?[]const u8 = null,
        replication_task_assessment_results: ?[]struct {
            replication_task_identifier: ?[]const u8 = null,
            replication_task_arn: ?[]const u8 = null,
            replication_task_last_assessment_date: ?i64 = null,
            assessment_status: ?[]const u8 = null,
            assessment_results_file: ?[]const u8 = null,
            assessment_results: ?[]const u8 = null,
            s3_object_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replication_task_identifier = "ReplicationTaskIdentifier",
                    .replication_task_arn = "ReplicationTaskArn",
                    .replication_task_last_assessment_date = "ReplicationTaskLastAssessmentDate",
                    .assessment_status = "AssessmentStatus",
                    .assessment_results_file = "AssessmentResultsFile",
                    .assessment_results = "AssessmentResults",
                    .s3_object_url = "S3ObjectUrl",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .bucket_name = "BucketName",
                .replication_task_assessment_results = "ReplicationTaskAssessmentResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_task_assessment_runs: struct {
    action_name: []const u8 = "DescribeReplicationTaskAssessmentRuns",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_task_assessment_runs) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_task_assessment_runs };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_task_assessment_runs: ?[]ReplicationTaskAssessmentRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_task_assessment_runs = "ReplicationTaskAssessmentRuns",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_task_individual_assessments: struct {
    action_name: []const u8 = "DescribeReplicationTaskIndividualAssessments",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_task_individual_assessments) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_task_individual_assessments };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_task_individual_assessments: ?[]struct {
            replication_task_individual_assessment_arn: ?[]const u8 = null,
            replication_task_assessment_run_arn: ?[]const u8 = null,
            individual_assessment_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            replication_task_individual_assessment_start_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replication_task_individual_assessment_arn = "ReplicationTaskIndividualAssessmentArn",
                    .replication_task_assessment_run_arn = "ReplicationTaskAssessmentRunArn",
                    .individual_assessment_name = "IndividualAssessmentName",
                    .status = "Status",
                    .replication_task_individual_assessment_start_date = "ReplicationTaskIndividualAssessmentStartDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_task_individual_assessments = "ReplicationTaskIndividualAssessments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_tasks: struct {
    action_name: []const u8 = "DescribeReplicationTasks",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        without_settings: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .without_settings = "WithoutSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_tasks };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_tasks: ?[]ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_tasks = "ReplicationTasks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_schemas: struct {
    action_name: []const u8 = "DescribeSchemas",
    Request: type = struct {
        endpoint_arn: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_schemas) } {
            return .{ .service_metadata = service_metadata, .action = describe_schemas };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        schemas: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .schemas = "Schemas",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_table_statistics: struct {
    action_name: []const u8 = "DescribeTableStatistics",
    Request: type = struct {
        replication_task_arn: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_table_statistics) } {
            return .{ .service_metadata = service_metadata, .action = describe_table_statistics };
        }
    },
    Response: type = struct {
        replication_task_arn: ?[]const u8 = null,
        table_statistics: ?[]TableStatistics = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .table_statistics = "TableStatistics",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const export_metadata_model_assessment: struct {
    action_name: []const u8 = "ExportMetadataModelAssessment",
    Request: type = struct {
        migration_project_identifier: []const u8,
        selection_rules: []const u8,
        file_name: ?[]const u8 = null,
        assessment_report_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .selection_rules = "SelectionRules",
                .file_name = "FileName",
                .assessment_report_types = "AssessmentReportTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_metadata_model_assessment) } {
            return .{ .service_metadata = service_metadata, .action = export_metadata_model_assessment };
        }
    },
    Response: type = struct {
        pdf_report: ?ExportMetadataModelAssessmentResultEntry = null,
        csv_report: ?ExportMetadataModelAssessmentResultEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pdf_report = "PdfReport",
                .csv_report = "CsvReport",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const import_certificate: struct {
    action_name: []const u8 = "ImportCertificate",
    Request: type = struct {
        certificate_identifier: []const u8,
        certificate_pem: ?[]const u8 = null,
        certificate_wallet: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_identifier = "CertificateIdentifier",
                .certificate_pem = "CertificatePem",
                .certificate_wallet = "CertificateWallet",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_certificate) } {
            return .{ .service_metadata = service_metadata, .action = import_certificate };
        }
    },
    Response: type = struct {
        certificate: ?Certificate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidCertificate,
        ResourceAlreadyExists,
        ResourceQuotaExceeded,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: ?[]const u8 = null,
        resource_arn_list: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .resource_arn_list = "ResourceArnList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const modify_conversion_configuration: struct {
    action_name: []const u8 = "ModifyConversionConfiguration",
    Request: type = struct {
        migration_project_identifier: []const u8,
        conversion_configuration: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .conversion_configuration = "ConversionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_conversion_configuration) } {
            return .{ .service_metadata = service_metadata, .action = modify_conversion_configuration };
        }
    },
    Response: type = struct {
        migration_project_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const modify_data_provider: struct {
    action_name: []const u8 = "ModifyDataProvider",
    Request: type = struct {
        data_provider_identifier: []const u8,
        data_provider_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        engine: ?[]const u8 = null,
        exact_settings: ?bool = null,
        settings: ?DataProviderSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_provider_identifier = "DataProviderIdentifier",
                .data_provider_name = "DataProviderName",
                .description = "Description",
                .engine = "Engine",
                .exact_settings = "ExactSettings",
                .settings = "Settings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_data_provider) } {
            return .{ .service_metadata = service_metadata, .action = modify_data_provider };
        }
    },
    Response: type = struct {
        data_provider: ?DataProvider = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_provider = "DataProvider",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const modify_endpoint: struct {
    action_name: []const u8 = "ModifyEndpoint",
    Request: type = struct {
        endpoint_arn: []const u8,
        endpoint_identifier: ?[]const u8 = null,
        endpoint_type: ?[]const u8 = null,
        engine_name: ?[]const u8 = null,
        username: ?[]const u8 = null,
        password: ?[]const u8 = null,
        server_name: ?[]const u8 = null,
        port: ?i64 = null,
        database_name: ?[]const u8 = null,
        extra_connection_attributes: ?[]const u8 = null,
        certificate_arn: ?[]const u8 = null,
        ssl_mode: ?[]const u8 = null,
        service_access_role_arn: ?[]const u8 = null,
        external_table_definition: ?[]const u8 = null,
        dynamo_db_settings: ?DynamoDbSettings = null,
        s3_settings: ?S3Settings = null,
        dms_transfer_settings: ?DmsTransferSettings = null,
        mongo_db_settings: ?MongoDbSettings = null,
        kinesis_settings: ?KinesisSettings = null,
        kafka_settings: ?KafkaSettings = null,
        elasticsearch_settings: ?ElasticsearchSettings = null,
        neptune_settings: ?NeptuneSettings = null,
        redshift_settings: ?RedshiftSettings = null,
        postgre_sql_settings: ?PostgreSQLSettings = null,
        my_sql_settings: ?MySQLSettings = null,
        oracle_settings: ?OracleSettings = null,
        sybase_settings: ?SybaseSettings = null,
        microsoft_sql_server_settings: ?MicrosoftSQLServerSettings = null,
        ibm_db2_settings: ?IBMDb2Settings = null,
        doc_db_settings: ?DocDbSettings = null,
        redis_settings: ?RedisSettings = null,
        exact_settings: ?bool = null,
        gcp_my_sql_settings: ?GcpMySQLSettings = null,
        timestream_settings: ?TimestreamSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
                .endpoint_identifier = "EndpointIdentifier",
                .endpoint_type = "EndpointType",
                .engine_name = "EngineName",
                .username = "Username",
                .password = "Password",
                .server_name = "ServerName",
                .port = "Port",
                .database_name = "DatabaseName",
                .extra_connection_attributes = "ExtraConnectionAttributes",
                .certificate_arn = "CertificateArn",
                .ssl_mode = "SslMode",
                .service_access_role_arn = "ServiceAccessRoleArn",
                .external_table_definition = "ExternalTableDefinition",
                .dynamo_db_settings = "DynamoDbSettings",
                .s3_settings = "S3Settings",
                .dms_transfer_settings = "DmsTransferSettings",
                .mongo_db_settings = "MongoDbSettings",
                .kinesis_settings = "KinesisSettings",
                .kafka_settings = "KafkaSettings",
                .elasticsearch_settings = "ElasticsearchSettings",
                .neptune_settings = "NeptuneSettings",
                .redshift_settings = "RedshiftSettings",
                .postgre_sql_settings = "PostgreSQLSettings",
                .my_sql_settings = "MySQLSettings",
                .oracle_settings = "OracleSettings",
                .sybase_settings = "SybaseSettings",
                .microsoft_sql_server_settings = "MicrosoftSQLServerSettings",
                .ibm_db2_settings = "IBMDb2Settings",
                .doc_db_settings = "DocDbSettings",
                .redis_settings = "RedisSettings",
                .exact_settings = "ExactSettings",
                .gcp_my_sql_settings = "GcpMySQLSettings",
                .timestream_settings = "TimestreamSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = modify_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?Endpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "Endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const modify_event_subscription: struct {
    action_name: []const u8 = "ModifyEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        sns_topic_arn: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        event_categories: ?[][]const u8 = null,
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .sns_topic_arn = "SnsTopicArn",
                .source_type = "SourceType",
                .event_categories = "EventCategories",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = modify_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        KMSThrottling,
        ResourceNotFound,
        ResourceQuotaExceeded,
        SNSInvalidTopic,
        SNSNoAuthorization,
    },
} = .{};
pub const modify_instance_profile: struct {
    action_name: []const u8 = "ModifyInstanceProfile",
    Request: type = struct {
        instance_profile_identifier: []const u8,
        availability_zone: ?[]const u8 = null,
        kms_key_arn: ?[]const u8 = null,
        publicly_accessible: ?bool = null,
        network_type: ?[]const u8 = null,
        instance_profile_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        subnet_group_identifier: ?[]const u8 = null,
        vpc_security_groups: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_profile_identifier = "InstanceProfileIdentifier",
                .availability_zone = "AvailabilityZone",
                .kms_key_arn = "KmsKeyArn",
                .publicly_accessible = "PubliclyAccessible",
                .network_type = "NetworkType",
                .instance_profile_name = "InstanceProfileName",
                .description = "Description",
                .subnet_group_identifier = "SubnetGroupIdentifier",
                .vpc_security_groups = "VpcSecurityGroups",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_instance_profile) } {
            return .{ .service_metadata = service_metadata, .action = modify_instance_profile };
        }
    },
    Response: type = struct {
        instance_profile: ?InstanceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_profile = "InstanceProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceNotFound,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const modify_migration_project: struct {
    action_name: []const u8 = "ModifyMigrationProject",
    Request: type = struct {
        migration_project_identifier: []const u8,
        migration_project_name: ?[]const u8 = null,
        source_data_provider_descriptors: ?[]DataProviderDescriptorDefinition = null,
        target_data_provider_descriptors: ?[]DataProviderDescriptorDefinition = null,
        instance_profile_identifier: ?[]const u8 = null,
        transformation_rules: ?[]const u8 = null,
        description: ?[]const u8 = null,
        schema_conversion_application_attributes: ?SCApplicationAttributes = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .migration_project_name = "MigrationProjectName",
                .source_data_provider_descriptors = "SourceDataProviderDescriptors",
                .target_data_provider_descriptors = "TargetDataProviderDescriptors",
                .instance_profile_identifier = "InstanceProfileIdentifier",
                .transformation_rules = "TransformationRules",
                .description = "Description",
                .schema_conversion_application_attributes = "SchemaConversionApplicationAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_migration_project) } {
            return .{ .service_metadata = service_metadata, .action = modify_migration_project };
        }
    },
    Response: type = struct {
        migration_project: ?MigrationProject = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project = "MigrationProject",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const modify_replication_config: struct {
    action_name: []const u8 = "ModifyReplicationConfig",
    Request: type = struct {
        replication_config_arn: []const u8,
        replication_config_identifier: ?[]const u8 = null,
        replication_type: ?[]const u8 = null,
        table_mappings: ?[]const u8 = null,
        replication_settings: ?[]const u8 = null,
        supplemental_settings: ?[]const u8 = null,
        compute_config: ?ComputeConfig = null,
        source_endpoint_arn: ?[]const u8 = null,
        target_endpoint_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config_arn = "ReplicationConfigArn",
                .replication_config_identifier = "ReplicationConfigIdentifier",
                .replication_type = "ReplicationType",
                .table_mappings = "TableMappings",
                .replication_settings = "ReplicationSettings",
                .supplemental_settings = "SupplementalSettings",
                .compute_config = "ComputeConfig",
                .source_endpoint_arn = "SourceEndpointArn",
                .target_endpoint_arn = "TargetEndpointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_replication_config) } {
            return .{ .service_metadata = service_metadata, .action = modify_replication_config };
        }
    },
    Response: type = struct {
        replication_config: ?ReplicationConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config = "ReplicationConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        InvalidSubnet,
        KMSKeyNotAccessible,
        ReplicationSubnetGroupDoesNotCoverEnoughAZs,
        ResourceNotFound,
    },
} = .{};
pub const modify_replication_instance: struct {
    action_name: []const u8 = "ModifyReplicationInstance",
    Request: type = struct {
        replication_instance_arn: []const u8,
        allocated_storage: ?i64 = null,
        apply_immediately: ?bool = null,
        replication_instance_class: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        multi_az: ?bool = null,
        engine_version: ?[]const u8 = null,
        allow_major_version_upgrade: ?bool = null,
        auto_minor_version_upgrade: ?bool = null,
        replication_instance_identifier: ?[]const u8 = null,
        network_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .allocated_storage = "AllocatedStorage",
                .apply_immediately = "ApplyImmediately",
                .replication_instance_class = "ReplicationInstanceClass",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .multi_az = "MultiAZ",
                .engine_version = "EngineVersion",
                .allow_major_version_upgrade = "AllowMajorVersionUpgrade",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .replication_instance_identifier = "ReplicationInstanceIdentifier",
                .network_type = "NetworkType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_replication_instance) } {
            return .{ .service_metadata = service_metadata, .action = modify_replication_instance };
        }
    },
    Response: type = struct {
        replication_instance: ?ReplicationInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance = "ReplicationInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InsufficientResourceCapacity,
        InvalidResourceState,
        ResourceAlreadyExists,
        ResourceNotFound,
        StorageQuotaExceeded,
        UpgradeDependencyFailure,
    },
} = .{};
pub const modify_replication_subnet_group: struct {
    action_name: []const u8 = "ModifyReplicationSubnetGroup",
    Request: type = struct {
        replication_subnet_group_identifier: []const u8,
        replication_subnet_group_description: ?[]const u8 = null,
        subnet_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
                .replication_subnet_group_description = "ReplicationSubnetGroupDescription",
                .subnet_ids = "SubnetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_replication_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_replication_subnet_group };
        }
    },
    Response: type = struct {
        replication_subnet_group: ?ReplicationSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_subnet_group = "ReplicationSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidSubnet,
        ReplicationSubnetGroupDoesNotCoverEnoughAZs,
        ResourceNotFound,
        ResourceQuotaExceeded,
        SubnetAlreadyInUse,
    },
} = .{};
pub const modify_replication_task: struct {
    action_name: []const u8 = "ModifyReplicationTask",
    Request: type = struct {
        replication_task_arn: []const u8,
        replication_task_identifier: ?[]const u8 = null,
        migration_type: ?[]const u8 = null,
        table_mappings: ?[]const u8 = null,
        replication_task_settings: ?[]const u8 = null,
        cdc_start_time: ?i64 = null,
        cdc_start_position: ?[]const u8 = null,
        cdc_stop_position: ?[]const u8 = null,
        task_data: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .replication_task_identifier = "ReplicationTaskIdentifier",
                .migration_type = "MigrationType",
                .table_mappings = "TableMappings",
                .replication_task_settings = "ReplicationTaskSettings",
                .cdc_start_time = "CdcStartTime",
                .cdc_start_position = "CdcStartPosition",
                .cdc_stop_position = "CdcStopPosition",
                .task_data = "TaskData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = modify_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const move_replication_task: struct {
    action_name: []const u8 = "MoveReplicationTask",
    Request: type = struct {
        replication_task_arn: []const u8,
        target_replication_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .target_replication_instance_arn = "TargetReplicationInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(move_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = move_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceNotFound,
        ResourceQuotaExceeded,
    },
} = .{};
pub const reboot_replication_instance: struct {
    action_name: []const u8 = "RebootReplicationInstance",
    Request: type = struct {
        replication_instance_arn: []const u8,
        force_failover: ?bool = null,
        force_planned_failover: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .force_failover = "ForceFailover",
                .force_planned_failover = "ForcePlannedFailover",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_replication_instance) } {
            return .{ .service_metadata = service_metadata, .action = reboot_replication_instance };
        }
    },
    Response: type = struct {
        replication_instance: ?ReplicationInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance = "ReplicationInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const refresh_schemas: struct {
    action_name: []const u8 = "RefreshSchemas",
    Request: type = struct {
        endpoint_arn: []const u8,
        replication_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
                .replication_instance_arn = "ReplicationInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(refresh_schemas) } {
            return .{ .service_metadata = service_metadata, .action = refresh_schemas };
        }
    },
    Response: type = struct {
        refresh_schemas_status: ?RefreshSchemasStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .refresh_schemas_status = "RefreshSchemasStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceNotFound,
        ResourceQuotaExceeded,
    },
} = .{};
pub const reload_replication_tables: struct {
    action_name: []const u8 = "ReloadReplicationTables",
    Request: type = struct {
        replication_config_arn: []const u8,
        tables_to_reload: []TableToReload,
        reload_option: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config_arn = "ReplicationConfigArn",
                .tables_to_reload = "TablesToReload",
                .reload_option = "ReloadOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reload_replication_tables) } {
            return .{ .service_metadata = service_metadata, .action = reload_replication_tables };
        }
    },
    Response: type = struct {
        replication_config_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config_arn = "ReplicationConfigArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const reload_tables: struct {
    action_name: []const u8 = "ReloadTables",
    Request: type = struct {
        replication_task_arn: []const u8,
        tables_to_reload: []TableToReload,
        reload_option: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .tables_to_reload = "TablesToReload",
                .reload_option = "ReloadOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reload_tables) } {
            return .{ .service_metadata = service_metadata, .action = reload_tables };
        }
    },
    Response: type = struct {
        replication_task_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const remove_tags_from_resource: struct {
    action_name: []const u8 = "RemoveTagsFromResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const run_fleet_advisor_lsa_analysis: struct {
    action_name: []const u8 = "RunFleetAdvisorLsaAnalysis",
    Request: type = struct {
        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(run_fleet_advisor_lsa_analysis) } {
            return .{ .service_metadata = service_metadata, .action = run_fleet_advisor_lsa_analysis };
        }
    },
    Response: type = struct {
        lsa_analysis_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lsa_analysis_id = "LsaAnalysisId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const start_extension_pack_association: struct {
    action_name: []const u8 = "StartExtensionPackAssociation",
    Request: type = struct {
        migration_project_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_extension_pack_association) } {
            return .{ .service_metadata = service_metadata, .action = start_extension_pack_association };
        }
    },
    Response: type = struct {
        request_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_identifier = "RequestIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const start_metadata_model_assessment: struct {
    action_name: []const u8 = "StartMetadataModelAssessment",
    Request: type = struct {
        migration_project_identifier: []const u8,
        selection_rules: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .selection_rules = "SelectionRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_metadata_model_assessment) } {
            return .{ .service_metadata = service_metadata, .action = start_metadata_model_assessment };
        }
    },
    Response: type = struct {
        request_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_identifier = "RequestIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const start_metadata_model_conversion: struct {
    action_name: []const u8 = "StartMetadataModelConversion",
    Request: type = struct {
        migration_project_identifier: []const u8,
        selection_rules: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .selection_rules = "SelectionRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_metadata_model_conversion) } {
            return .{ .service_metadata = service_metadata, .action = start_metadata_model_conversion };
        }
    },
    Response: type = struct {
        request_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_identifier = "RequestIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const start_metadata_model_export_as_script: struct {
    action_name: []const u8 = "StartMetadataModelExportAsScript",
    Request: type = struct {
        migration_project_identifier: []const u8,
        selection_rules: []const u8,
        origin: []const u8,
        file_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .selection_rules = "SelectionRules",
                .origin = "Origin",
                .file_name = "FileName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_metadata_model_export_as_script) } {
            return .{ .service_metadata = service_metadata, .action = start_metadata_model_export_as_script };
        }
    },
    Response: type = struct {
        request_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_identifier = "RequestIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const start_metadata_model_export_to_target: struct {
    action_name: []const u8 = "StartMetadataModelExportToTarget",
    Request: type = struct {
        migration_project_identifier: []const u8,
        selection_rules: []const u8,
        overwrite_extension_pack: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .selection_rules = "SelectionRules",
                .overwrite_extension_pack = "OverwriteExtensionPack",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_metadata_model_export_to_target) } {
            return .{ .service_metadata = service_metadata, .action = start_metadata_model_export_to_target };
        }
    },
    Response: type = struct {
        request_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_identifier = "RequestIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const start_metadata_model_import: struct {
    action_name: []const u8 = "StartMetadataModelImport",
    Request: type = struct {
        migration_project_identifier: []const u8,
        selection_rules: []const u8,
        origin: []const u8,
        refresh: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .migration_project_identifier = "MigrationProjectIdentifier",
                .selection_rules = "SelectionRules",
                .origin = "Origin",
                .refresh = "Refresh",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_metadata_model_import) } {
            return .{ .service_metadata = service_metadata, .action = start_metadata_model_import };
        }
    },
    Response: type = struct {
        request_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_identifier = "RequestIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const start_recommendations: struct {
    action_name: []const u8 = "StartRecommendations",
    Request: type = struct {
        database_id: []const u8,
        settings: RecommendationSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_id = "DatabaseId",
                .settings = "Settings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = start_recommendations };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const start_replication: struct {
    action_name: []const u8 = "StartReplication",
    Request: type = struct {
        replication_config_arn: []const u8,
        start_replication_type: []const u8,
        cdc_start_time: ?i64 = null,
        cdc_start_position: ?[]const u8 = null,
        cdc_stop_position: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config_arn = "ReplicationConfigArn",
                .start_replication_type = "StartReplicationType",
                .cdc_start_time = "CdcStartTime",
                .cdc_start_position = "CdcStartPosition",
                .cdc_stop_position = "CdcStopPosition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_replication) } {
            return .{ .service_metadata = service_metadata, .action = start_replication };
        }
    },
    Response: type = struct {
        replication: ?Replication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication = "Replication",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const start_replication_task: struct {
    action_name: []const u8 = "StartReplicationTask",
    Request: type = struct {
        replication_task_arn: []const u8,
        start_replication_task_type: []const u8,
        cdc_start_time: ?i64 = null,
        cdc_start_position: ?[]const u8 = null,
        cdc_stop_position: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .start_replication_task_type = "StartReplicationTaskType",
                .cdc_start_time = "CdcStartTime",
                .cdc_start_position = "CdcStartPosition",
                .cdc_stop_position = "CdcStopPosition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = start_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const start_replication_task_assessment: struct {
    action_name: []const u8 = "StartReplicationTaskAssessment",
    Request: type = struct {
        replication_task_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_replication_task_assessment) } {
            return .{ .service_metadata = service_metadata, .action = start_replication_task_assessment };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const start_replication_task_assessment_run: struct {
    action_name: []const u8 = "StartReplicationTaskAssessmentRun",
    Request: type = struct {
        replication_task_arn: []const u8,
        service_access_role_arn: []const u8,
        result_location_bucket: []const u8,
        result_location_folder: ?[]const u8 = null,
        result_encryption_mode: ?[]const u8 = null,
        result_kms_key_arn: ?[]const u8 = null,
        assessment_run_name: []const u8,
        include_only: ?[][]const u8 = null,
        exclude: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .service_access_role_arn = "ServiceAccessRoleArn",
                .result_location_bucket = "ResultLocationBucket",
                .result_location_folder = "ResultLocationFolder",
                .result_encryption_mode = "ResultEncryptionMode",
                .result_kms_key_arn = "ResultKmsKeyArn",
                .assessment_run_name = "AssessmentRunName",
                .include_only = "IncludeOnly",
                .exclude = "Exclude",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_replication_task_assessment_run) } {
            return .{ .service_metadata = service_metadata, .action = start_replication_task_assessment_run };
        }
    },
    Response: type = struct {
        replication_task_assessment_run: ?ReplicationTaskAssessmentRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_assessment_run = "ReplicationTaskAssessmentRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSAccessDenied,
        KMSDisabled,
        KMS,
        KMSInvalidState,
        KMSKeyNotAccessible,
        KMSNotFound,
        ResourceAlreadyExists,
        ResourceNotFound,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const stop_replication: struct {
    action_name: []const u8 = "StopReplication",
    Request: type = struct {
        replication_config_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_config_arn = "ReplicationConfigArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_replication) } {
            return .{ .service_metadata = service_metadata, .action = stop_replication };
        }
    },
    Response: type = struct {
        replication: ?Replication = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication = "Replication",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const stop_replication_task: struct {
    action_name: []const u8 = "StopReplicationTask",
    Request: type = struct {
        replication_task_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = stop_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const test_connection: struct {
    action_name: []const u8 = "TestConnection",
    Request: type = struct {
        replication_instance_arn: []const u8,
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_connection) } {
            return .{ .service_metadata = service_metadata, .action = test_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceNotFound,
        ResourceQuotaExceeded,
    },
} = .{};
pub const update_subscriptions_to_event_bridge: struct {
    action_name: []const u8 = "UpdateSubscriptionsToEventBridge",
    Request: type = struct {
        force_move: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .force_move = "ForceMove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_subscriptions_to_event_bridge) } {
            return .{ .service_metadata = service_metadata, .action = update_subscriptions_to_event_bridge };
        }
    },
    Response: type = struct {
        result: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "Result",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
    },
} = .{};

pub const Connection = struct {
    replication_instance_arn: ?[]const u8 = null,
    endpoint_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    last_failure_message: ?[]const u8 = null,
    endpoint_identifier: ?[]const u8 = null,
    replication_instance_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_instance_arn = "ReplicationInstanceArn",
            .endpoint_arn = "EndpointArn",
            .status = "Status",
            .last_failure_message = "LastFailureMessage",
            .endpoint_identifier = "EndpointIdentifier",
            .replication_instance_identifier = "ReplicationInstanceIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTask = struct {
    replication_task_identifier: ?[]const u8 = null,
    source_endpoint_arn: ?[]const u8 = null,
    target_endpoint_arn: ?[]const u8 = null,
    replication_instance_arn: ?[]const u8 = null,
    migration_type: ?[]const u8 = null,
    table_mappings: ?[]const u8 = null,
    replication_task_settings: ?[]const u8 = null,
    status: ?[]const u8 = null,
    last_failure_message: ?[]const u8 = null,
    stop_reason: ?[]const u8 = null,
    replication_task_creation_date: ?i64 = null,
    replication_task_start_date: ?i64 = null,
    cdc_start_position: ?[]const u8 = null,
    cdc_stop_position: ?[]const u8 = null,
    recovery_checkpoint: ?[]const u8 = null,
    replication_task_arn: ?[]const u8 = null,
    replication_task_stats: ?ReplicationTaskStats = null,
    task_data: ?[]const u8 = null,
    target_replication_instance_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_task_identifier = "ReplicationTaskIdentifier",
            .source_endpoint_arn = "SourceEndpointArn",
            .target_endpoint_arn = "TargetEndpointArn",
            .replication_instance_arn = "ReplicationInstanceArn",
            .migration_type = "MigrationType",
            .table_mappings = "TableMappings",
            .replication_task_settings = "ReplicationTaskSettings",
            .status = "Status",
            .last_failure_message = "LastFailureMessage",
            .stop_reason = "StopReason",
            .replication_task_creation_date = "ReplicationTaskCreationDate",
            .replication_task_start_date = "ReplicationTaskStartDate",
            .cdc_start_position = "CdcStartPosition",
            .cdc_stop_position = "CdcStopPosition",
            .recovery_checkpoint = "RecoveryCheckpoint",
            .replication_task_arn = "ReplicationTaskArn",
            .replication_task_stats = "ReplicationTaskStats",
            .task_data = "TaskData",
            .target_replication_instance_arn = "TargetReplicationInstanceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTaskStats = struct {
    full_load_progress_percent: ?i64 = null,
    elapsed_time_millis: ?i64 = null,
    tables_loaded: ?i64 = null,
    tables_loading: ?i64 = null,
    tables_queued: ?i64 = null,
    tables_errored: ?i64 = null,
    fresh_start_date: ?i64 = null,
    start_date: ?i64 = null,
    stop_date: ?i64 = null,
    full_load_start_date: ?i64 = null,
    full_load_finish_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .full_load_progress_percent = "FullLoadProgressPercent",
            .elapsed_time_millis = "ElapsedTimeMillis",
            .tables_loaded = "TablesLoaded",
            .tables_loading = "TablesLoading",
            .tables_queued = "TablesQueued",
            .tables_errored = "TablesErrored",
            .fresh_start_date = "FreshStartDate",
            .start_date = "StartDate",
            .stop_date = "StopDate",
            .full_load_start_date = "FullLoadStartDate",
            .full_load_finish_date = "FullLoadFinishDate",
        };
        return @field(mappings, field_name);
    }
};

pub const Replication = struct {
    replication_config_identifier: ?[]const u8 = null,
    replication_config_arn: ?[]const u8 = null,
    source_endpoint_arn: ?[]const u8 = null,
    target_endpoint_arn: ?[]const u8 = null,
    replication_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    provision_data: ?ProvisionData = null,
    stop_reason: ?[]const u8 = null,
    failure_messages: ?[][]const u8 = null,
    replication_stats: ?ReplicationStats = null,
    start_replication_type: ?[]const u8 = null,
    cdc_start_time: ?i64 = null,
    cdc_start_position: ?[]const u8 = null,
    cdc_stop_position: ?[]const u8 = null,
    recovery_checkpoint: ?[]const u8 = null,
    replication_create_time: ?i64 = null,
    replication_update_time: ?i64 = null,
    replication_last_stop_time: ?i64 = null,
    replication_deprovision_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_config_identifier = "ReplicationConfigIdentifier",
            .replication_config_arn = "ReplicationConfigArn",
            .source_endpoint_arn = "SourceEndpointArn",
            .target_endpoint_arn = "TargetEndpointArn",
            .replication_type = "ReplicationType",
            .status = "Status",
            .provision_data = "ProvisionData",
            .stop_reason = "StopReason",
            .failure_messages = "FailureMessages",
            .replication_stats = "ReplicationStats",
            .start_replication_type = "StartReplicationType",
            .cdc_start_time = "CdcStartTime",
            .cdc_start_position = "CdcStartPosition",
            .cdc_stop_position = "CdcStopPosition",
            .recovery_checkpoint = "RecoveryCheckpoint",
            .replication_create_time = "ReplicationCreateTime",
            .replication_update_time = "ReplicationUpdateTime",
            .replication_last_stop_time = "ReplicationLastStopTime",
            .replication_deprovision_time = "ReplicationDeprovisionTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationStats = struct {
    full_load_progress_percent: ?i64 = null,
    elapsed_time_millis: ?i64 = null,
    tables_loaded: ?i64 = null,
    tables_loading: ?i64 = null,
    tables_queued: ?i64 = null,
    tables_errored: ?i64 = null,
    fresh_start_date: ?i64 = null,
    start_date: ?i64 = null,
    stop_date: ?i64 = null,
    full_load_start_date: ?i64 = null,
    full_load_finish_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .full_load_progress_percent = "FullLoadProgressPercent",
            .elapsed_time_millis = "ElapsedTimeMillis",
            .tables_loaded = "TablesLoaded",
            .tables_loading = "TablesLoading",
            .tables_queued = "TablesQueued",
            .tables_errored = "TablesErrored",
            .fresh_start_date = "FreshStartDate",
            .start_date = "StartDate",
            .stop_date = "StopDate",
            .full_load_start_date = "FullLoadStartDate",
            .full_load_finish_date = "FullLoadFinishDate",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisionData = struct {
    provision_state: ?[]const u8 = null,
    provisioned_capacity_units: ?i64 = null,
    date_provisioned: ?i64 = null,
    is_new_provisioning_available: ?bool = null,
    date_new_provisioning_data_available: ?i64 = null,
    reason_for_new_provisioning_data: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .provision_state = "ProvisionState",
            .provisioned_capacity_units = "ProvisionedCapacityUnits",
            .date_provisioned = "DateProvisioned",
            .is_new_provisioning_available = "IsNewProvisioningAvailable",
            .date_new_provisioning_data_available = "DateNewProvisioningDataAvailable",
            .reason_for_new_provisioning_data = "ReasonForNewProvisioningData",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTaskAssessmentRun = struct {
    replication_task_assessment_run_arn: ?[]const u8 = null,
    replication_task_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    replication_task_assessment_run_creation_date: ?i64 = null,
    assessment_progress: ?ReplicationTaskAssessmentRunProgress = null,
    last_failure_message: ?[]const u8 = null,
    service_access_role_arn: ?[]const u8 = null,
    result_location_bucket: ?[]const u8 = null,
    result_location_folder: ?[]const u8 = null,
    result_encryption_mode: ?[]const u8 = null,
    result_kms_key_arn: ?[]const u8 = null,
    assessment_run_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_task_assessment_run_arn = "ReplicationTaskAssessmentRunArn",
            .replication_task_arn = "ReplicationTaskArn",
            .status = "Status",
            .replication_task_assessment_run_creation_date = "ReplicationTaskAssessmentRunCreationDate",
            .assessment_progress = "AssessmentProgress",
            .last_failure_message = "LastFailureMessage",
            .service_access_role_arn = "ServiceAccessRoleArn",
            .result_location_bucket = "ResultLocationBucket",
            .result_location_folder = "ResultLocationFolder",
            .result_encryption_mode = "ResultEncryptionMode",
            .result_kms_key_arn = "ResultKmsKeyArn",
            .assessment_run_name = "AssessmentRunName",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTaskAssessmentRunProgress = struct {
    individual_assessment_count: ?i64 = null,
    individual_assessment_completed_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .individual_assessment_count = "IndividualAssessmentCount",
            .individual_assessment_completed_count = "IndividualAssessmentCompletedCount",
        };
        return @field(mappings, field_name);
    }
};

pub const RecommendationSettings = struct {
    instance_sizing_type: []const u8,
    workload_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_sizing_type = "InstanceSizingType",
            .workload_type = "WorkloadType",
        };
        return @field(mappings, field_name);
    }
};

pub const TableToReload = struct {
    schema_name: []const u8,
    table_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_name = "SchemaName",
            .table_name = "TableName",
        };
        return @field(mappings, field_name);
    }
};

pub const RefreshSchemasStatus = struct {
    endpoint_arn: ?[]const u8 = null,
    replication_instance_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    last_refresh_date: ?i64 = null,
    last_failure_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_arn = "EndpointArn",
            .replication_instance_arn = "ReplicationInstanceArn",
            .status = "Status",
            .last_refresh_date = "LastRefreshDate",
            .last_failure_message = "LastFailureMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationInstance = struct {
    replication_instance_identifier: ?[]const u8 = null,
    replication_instance_class: ?[]const u8 = null,
    replication_instance_status: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    instance_create_time: ?i64 = null,
    vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
    availability_zone: ?[]const u8 = null,
    replication_subnet_group: ?ReplicationSubnetGroup = null,
    preferred_maintenance_window: ?[]const u8 = null,
    pending_modified_values: ?ReplicationPendingModifiedValues = null,
    multi_az: ?bool = null,
    engine_version: ?[]const u8 = null,
    auto_minor_version_upgrade: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    replication_instance_arn: ?[]const u8 = null,
    replication_instance_public_ip_address: ?[]const u8 = null,
    replication_instance_private_ip_address: ?[]const u8 = null,
    replication_instance_public_ip_addresses: ?[][]const u8 = null,
    replication_instance_private_ip_addresses: ?[][]const u8 = null,
    replication_instance_ipv6_addresses: ?[][]const u8 = null,
    publicly_accessible: ?bool = null,
    secondary_availability_zone: ?[]const u8 = null,
    free_until: ?i64 = null,
    dns_name_servers: ?[]const u8 = null,
    network_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_instance_identifier = "ReplicationInstanceIdentifier",
            .replication_instance_class = "ReplicationInstanceClass",
            .replication_instance_status = "ReplicationInstanceStatus",
            .allocated_storage = "AllocatedStorage",
            .instance_create_time = "InstanceCreateTime",
            .vpc_security_groups = "VpcSecurityGroups",
            .availability_zone = "AvailabilityZone",
            .replication_subnet_group = "ReplicationSubnetGroup",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .pending_modified_values = "PendingModifiedValues",
            .multi_az = "MultiAZ",
            .engine_version = "EngineVersion",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .kms_key_id = "KmsKeyId",
            .replication_instance_arn = "ReplicationInstanceArn",
            .replication_instance_public_ip_address = "ReplicationInstancePublicIpAddress",
            .replication_instance_private_ip_address = "ReplicationInstancePrivateIpAddress",
            .replication_instance_public_ip_addresses = "ReplicationInstancePublicIpAddresses",
            .replication_instance_private_ip_addresses = "ReplicationInstancePrivateIpAddresses",
            .replication_instance_ipv6_addresses = "ReplicationInstanceIpv6Addresses",
            .publicly_accessible = "PubliclyAccessible",
            .secondary_availability_zone = "SecondaryAvailabilityZone",
            .free_until = "FreeUntil",
            .dns_name_servers = "DnsNameServers",
            .network_type = "NetworkType",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationPendingModifiedValues = struct {
    replication_instance_class: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    multi_az: ?bool = null,
    engine_version: ?[]const u8 = null,
    network_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_instance_class = "ReplicationInstanceClass",
            .allocated_storage = "AllocatedStorage",
            .multi_az = "MultiAZ",
            .engine_version = "EngineVersion",
            .network_type = "NetworkType",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationSubnetGroup = struct {
    replication_subnet_group_identifier: ?[]const u8 = null,
    replication_subnet_group_description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_group_status: ?[]const u8 = null,
    subnets: ?[]Subnet = null,
    supported_network_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
            .replication_subnet_group_description = "ReplicationSubnetGroupDescription",
            .vpc_id = "VpcId",
            .subnet_group_status = "SubnetGroupStatus",
            .subnets = "Subnets",
            .supported_network_types = "SupportedNetworkTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const Subnet = struct {
    subnet_identifier: ?[]const u8 = null,
    subnet_availability_zone: ?AvailabilityZone = null,
    subnet_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_identifier = "SubnetIdentifier",
            .subnet_availability_zone = "SubnetAvailabilityZone",
            .subnet_status = "SubnetStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailabilityZone = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcSecurityGroupMembership = struct {
    vpc_security_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_security_group_id = "VpcSecurityGroupId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationConfig = struct {
    replication_config_identifier: ?[]const u8 = null,
    replication_config_arn: ?[]const u8 = null,
    source_endpoint_arn: ?[]const u8 = null,
    target_endpoint_arn: ?[]const u8 = null,
    replication_type: ?[]const u8 = null,
    compute_config: ?ComputeConfig = null,
    replication_settings: ?[]const u8 = null,
    supplemental_settings: ?[]const u8 = null,
    table_mappings: ?[]const u8 = null,
    replication_config_create_time: ?i64 = null,
    replication_config_update_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_config_identifier = "ReplicationConfigIdentifier",
            .replication_config_arn = "ReplicationConfigArn",
            .source_endpoint_arn = "SourceEndpointArn",
            .target_endpoint_arn = "TargetEndpointArn",
            .replication_type = "ReplicationType",
            .compute_config = "ComputeConfig",
            .replication_settings = "ReplicationSettings",
            .supplemental_settings = "SupplementalSettings",
            .table_mappings = "TableMappings",
            .replication_config_create_time = "ReplicationConfigCreateTime",
            .replication_config_update_time = "ReplicationConfigUpdateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeConfig = struct {
    availability_zone: ?[]const u8 = null,
    dns_name_servers: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    max_capacity_units: ?i64 = null,
    min_capacity_units: ?i64 = null,
    multi_az: ?bool = null,
    preferred_maintenance_window: ?[]const u8 = null,
    replication_subnet_group_id: ?[]const u8 = null,
    vpc_security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_zone = "AvailabilityZone",
            .dns_name_servers = "DnsNameServers",
            .kms_key_id = "KmsKeyId",
            .max_capacity_units = "MaxCapacityUnits",
            .min_capacity_units = "MinCapacityUnits",
            .multi_az = "MultiAZ",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .replication_subnet_group_id = "ReplicationSubnetGroupId",
            .vpc_security_group_ids = "VpcSecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const MigrationProject = struct {
    migration_project_name: ?[]const u8 = null,
    migration_project_arn: ?[]const u8 = null,
    migration_project_creation_time: ?i64 = null,
    source_data_provider_descriptors: ?[]DataProviderDescriptor = null,
    target_data_provider_descriptors: ?[]DataProviderDescriptor = null,
    instance_profile_arn: ?[]const u8 = null,
    instance_profile_name: ?[]const u8 = null,
    transformation_rules: ?[]const u8 = null,
    description: ?[]const u8 = null,
    schema_conversion_application_attributes: ?SCApplicationAttributes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .migration_project_name = "MigrationProjectName",
            .migration_project_arn = "MigrationProjectArn",
            .migration_project_creation_time = "MigrationProjectCreationTime",
            .source_data_provider_descriptors = "SourceDataProviderDescriptors",
            .target_data_provider_descriptors = "TargetDataProviderDescriptors",
            .instance_profile_arn = "InstanceProfileArn",
            .instance_profile_name = "InstanceProfileName",
            .transformation_rules = "TransformationRules",
            .description = "Description",
            .schema_conversion_application_attributes = "SchemaConversionApplicationAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const SCApplicationAttributes = struct {
    s3_bucket_path: ?[]const u8 = null,
    s3_bucket_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_path = "S3BucketPath",
            .s3_bucket_role_arn = "S3BucketRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DataProviderDescriptor = struct {
    secrets_manager_secret_id: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    data_provider_name: ?[]const u8 = null,
    data_provider_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .data_provider_name = "DataProviderName",
            .data_provider_arn = "DataProviderArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DataProviderDescriptorDefinition = struct {
    data_provider_identifier: []const u8,
    secrets_manager_secret_id: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_provider_identifier = "DataProviderIdentifier",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const InstanceProfile = struct {
    instance_profile_arn: ?[]const u8 = null,
    availability_zone: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,
    publicly_accessible: ?bool = null,
    network_type: ?[]const u8 = null,
    instance_profile_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    instance_profile_creation_time: ?i64 = null,
    subnet_group_identifier: ?[]const u8 = null,
    vpc_security_groups: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_profile_arn = "InstanceProfileArn",
            .availability_zone = "AvailabilityZone",
            .kms_key_arn = "KmsKeyArn",
            .publicly_accessible = "PubliclyAccessible",
            .network_type = "NetworkType",
            .instance_profile_name = "InstanceProfileName",
            .description = "Description",
            .instance_profile_creation_time = "InstanceProfileCreationTime",
            .subnet_group_identifier = "SubnetGroupIdentifier",
            .vpc_security_groups = "VpcSecurityGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const EventSubscription = struct {
    customer_aws_id: ?[]const u8 = null,
    cust_subscription_id: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    subscription_creation_time: ?[]const u8 = null,
    source_type: ?[]const u8 = null,
    source_ids_list: ?[][]const u8 = null,
    event_categories_list: ?[][]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_aws_id = "CustomerAwsId",
            .cust_subscription_id = "CustSubscriptionId",
            .sns_topic_arn = "SnsTopicArn",
            .status = "Status",
            .subscription_creation_time = "SubscriptionCreationTime",
            .source_type = "SourceType",
            .source_ids_list = "SourceIdsList",
            .event_categories_list = "EventCategoriesList",
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Endpoint = struct {
    endpoint_identifier: ?[]const u8 = null,
    endpoint_type: ?[]const u8 = null,
    engine_name: ?[]const u8 = null,
    engine_display_name: ?[]const u8 = null,
    username: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    extra_connection_attributes: ?[]const u8 = null,
    status: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    endpoint_arn: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    ssl_mode: ?[]const u8 = null,
    service_access_role_arn: ?[]const u8 = null,
    external_table_definition: ?[]const u8 = null,
    external_id: ?[]const u8 = null,
    dynamo_db_settings: ?DynamoDbSettings = null,
    s3_settings: ?S3Settings = null,
    dms_transfer_settings: ?DmsTransferSettings = null,
    mongo_db_settings: ?MongoDbSettings = null,
    kinesis_settings: ?KinesisSettings = null,
    kafka_settings: ?KafkaSettings = null,
    elasticsearch_settings: ?ElasticsearchSettings = null,
    neptune_settings: ?NeptuneSettings = null,
    redshift_settings: ?RedshiftSettings = null,
    postgre_sql_settings: ?PostgreSQLSettings = null,
    my_sql_settings: ?MySQLSettings = null,
    oracle_settings: ?OracleSettings = null,
    sybase_settings: ?SybaseSettings = null,
    microsoft_sql_server_settings: ?MicrosoftSQLServerSettings = null,
    ibm_db2_settings: ?IBMDb2Settings = null,
    doc_db_settings: ?DocDbSettings = null,
    redis_settings: ?RedisSettings = null,
    gcp_my_sql_settings: ?GcpMySQLSettings = null,
    timestream_settings: ?TimestreamSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_identifier = "EndpointIdentifier",
            .endpoint_type = "EndpointType",
            .engine_name = "EngineName",
            .engine_display_name = "EngineDisplayName",
            .username = "Username",
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .extra_connection_attributes = "ExtraConnectionAttributes",
            .status = "Status",
            .kms_key_id = "KmsKeyId",
            .endpoint_arn = "EndpointArn",
            .certificate_arn = "CertificateArn",
            .ssl_mode = "SslMode",
            .service_access_role_arn = "ServiceAccessRoleArn",
            .external_table_definition = "ExternalTableDefinition",
            .external_id = "ExternalId",
            .dynamo_db_settings = "DynamoDbSettings",
            .s3_settings = "S3Settings",
            .dms_transfer_settings = "DmsTransferSettings",
            .mongo_db_settings = "MongoDbSettings",
            .kinesis_settings = "KinesisSettings",
            .kafka_settings = "KafkaSettings",
            .elasticsearch_settings = "ElasticsearchSettings",
            .neptune_settings = "NeptuneSettings",
            .redshift_settings = "RedshiftSettings",
            .postgre_sql_settings = "PostgreSQLSettings",
            .my_sql_settings = "MySQLSettings",
            .oracle_settings = "OracleSettings",
            .sybase_settings = "SybaseSettings",
            .microsoft_sql_server_settings = "MicrosoftSQLServerSettings",
            .ibm_db2_settings = "IBMDb2Settings",
            .doc_db_settings = "DocDbSettings",
            .redis_settings = "RedisSettings",
            .gcp_my_sql_settings = "GcpMySQLSettings",
            .timestream_settings = "TimestreamSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const TimestreamSettings = struct {
    database_name: []const u8,
    memory_duration: i64,
    magnetic_duration: i64,
    cdc_inserts_and_updates: ?bool = null,
    enable_magnetic_store_writes: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .memory_duration = "MemoryDuration",
            .magnetic_duration = "MagneticDuration",
            .cdc_inserts_and_updates = "CdcInsertsAndUpdates",
            .enable_magnetic_store_writes = "EnableMagneticStoreWrites",
        };
        return @field(mappings, field_name);
    }
};

pub const GcpMySQLSettings = struct {
    after_connect_script: ?[]const u8 = null,
    clean_source_metadata_on_mismatch: ?bool = null,
    database_name: ?[]const u8 = null,
    events_poll_interval: ?i64 = null,
    target_db_type: ?[]const u8 = null,
    max_file_size: ?i64 = null,
    parallel_load_threads: ?i64 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    server_name: ?[]const u8 = null,
    server_timezone: ?[]const u8 = null,
    username: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .after_connect_script = "AfterConnectScript",
            .clean_source_metadata_on_mismatch = "CleanSourceMetadataOnMismatch",
            .database_name = "DatabaseName",
            .events_poll_interval = "EventsPollInterval",
            .target_db_type = "TargetDbType",
            .max_file_size = "MaxFileSize",
            .parallel_load_threads = "ParallelLoadThreads",
            .password = "Password",
            .port = "Port",
            .server_name = "ServerName",
            .server_timezone = "ServerTimezone",
            .username = "Username",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const RedisSettings = struct {
    server_name: []const u8,
    port: i64,
    ssl_security_protocol: ?[]const u8 = null,
    auth_type: ?[]const u8 = null,
    auth_user_name: ?[]const u8 = null,
    auth_password: ?[]const u8 = null,
    ssl_ca_certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name = "ServerName",
            .port = "Port",
            .ssl_security_protocol = "SslSecurityProtocol",
            .auth_type = "AuthType",
            .auth_user_name = "AuthUserName",
            .auth_password = "AuthPassword",
            .ssl_ca_certificate_arn = "SslCaCertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DocDbSettings = struct {
    username: ?[]const u8 = null,
    password: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    nesting_level: ?[]const u8 = null,
    extract_doc_id: ?bool = null,
    docs_to_investigate: ?i64 = null,
    kms_key_id: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,
    use_update_look_up: ?bool = null,
    replicate_shard_collections: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .password = "Password",
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .nesting_level = "NestingLevel",
            .extract_doc_id = "ExtractDocId",
            .docs_to_investigate = "DocsToInvestigate",
            .kms_key_id = "KmsKeyId",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .use_update_look_up = "UseUpdateLookUp",
            .replicate_shard_collections = "ReplicateShardCollections",
        };
        return @field(mappings, field_name);
    }
};

pub const IBMDb2Settings = struct {
    database_name: ?[]const u8 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    server_name: ?[]const u8 = null,
    set_data_capture_changes: ?bool = null,
    current_lsn: ?[]const u8 = null,
    max_k_bytes_per_read: ?i64 = null,
    username: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,
    load_timeout: ?i64 = null,
    write_buffer_size: ?i64 = null,
    max_file_size: ?i64 = null,
    keep_csv_files: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .password = "Password",
            .port = "Port",
            .server_name = "ServerName",
            .set_data_capture_changes = "SetDataCaptureChanges",
            .current_lsn = "CurrentLsn",
            .max_k_bytes_per_read = "MaxKBytesPerRead",
            .username = "Username",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .load_timeout = "LoadTimeout",
            .write_buffer_size = "WriteBufferSize",
            .max_file_size = "MaxFileSize",
            .keep_csv_files = "KeepCsvFiles",
        };
        return @field(mappings, field_name);
    }
};

pub const MicrosoftSQLServerSettings = struct {
    port: ?i64 = null,
    bcp_packet_size: ?i64 = null,
    database_name: ?[]const u8 = null,
    control_tables_file_group: ?[]const u8 = null,
    password: ?[]const u8 = null,
    query_single_always_on_node: ?bool = null,
    read_backup_only: ?bool = null,
    safeguard_policy: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    username: ?[]const u8 = null,
    use_bcp_full_load: ?bool = null,
    use_third_party_backup_device: ?bool = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,
    trim_space_in_char: ?bool = null,
    tlog_access_mode: ?[]const u8 = null,
    force_lob_lookup: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port = "Port",
            .bcp_packet_size = "BcpPacketSize",
            .database_name = "DatabaseName",
            .control_tables_file_group = "ControlTablesFileGroup",
            .password = "Password",
            .query_single_always_on_node = "QuerySingleAlwaysOnNode",
            .read_backup_only = "ReadBackupOnly",
            .safeguard_policy = "SafeguardPolicy",
            .server_name = "ServerName",
            .username = "Username",
            .use_bcp_full_load = "UseBcpFullLoad",
            .use_third_party_backup_device = "UseThirdPartyBackupDevice",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .trim_space_in_char = "TrimSpaceInChar",
            .tlog_access_mode = "TlogAccessMode",
            .force_lob_lookup = "ForceLobLookup",
        };
        return @field(mappings, field_name);
    }
};

pub const SybaseSettings = struct {
    database_name: ?[]const u8 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    server_name: ?[]const u8 = null,
    username: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .password = "Password",
            .port = "Port",
            .server_name = "ServerName",
            .username = "Username",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const OracleSettings = struct {
    add_supplemental_logging: ?bool = null,
    archived_log_dest_id: ?i64 = null,
    additional_archived_log_dest_id: ?i64 = null,
    extra_archived_log_dest_ids: ?[]i64 = null,
    allow_select_nested_tables: ?bool = null,
    parallel_asm_read_threads: ?i64 = null,
    read_ahead_blocks: ?i64 = null,
    access_alternate_directly: ?bool = null,
    use_alternate_folder_for_online: ?bool = null,
    oracle_path_prefix: ?[]const u8 = null,
    use_path_prefix: ?[]const u8 = null,
    replace_path_prefix: ?bool = null,
    enable_homogenous_tablespace: ?bool = null,
    direct_path_no_log: ?bool = null,
    archived_logs_only: ?bool = null,
    asm_password: ?[]const u8 = null,
    asm_server: ?[]const u8 = null,
    asm_user: ?[]const u8 = null,
    char_length_semantics: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    direct_path_parallel_load: ?bool = null,
    fail_tasks_on_lob_truncation: ?bool = null,
    number_datatype_scale: ?i64 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    read_table_space_name: ?bool = null,
    retry_interval: ?i64 = null,
    security_db_encryption: ?[]const u8 = null,
    security_db_encryption_name: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    spatial_data_option_to_geo_json_function_name: ?[]const u8 = null,
    standby_delay_time: ?i64 = null,
    username: ?[]const u8 = null,
    use_b_file: ?bool = null,
    use_direct_path_full_load: ?bool = null,
    use_logminer_reader: ?bool = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,
    secrets_manager_oracle_asm_access_role_arn: ?[]const u8 = null,
    secrets_manager_oracle_asm_secret_id: ?[]const u8 = null,
    trim_space_in_char: ?bool = null,
    convert_timestamp_with_zone_to_utc: ?bool = null,
    open_transaction_window: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .add_supplemental_logging = "AddSupplementalLogging",
            .archived_log_dest_id = "ArchivedLogDestId",
            .additional_archived_log_dest_id = "AdditionalArchivedLogDestId",
            .extra_archived_log_dest_ids = "ExtraArchivedLogDestIds",
            .allow_select_nested_tables = "AllowSelectNestedTables",
            .parallel_asm_read_threads = "ParallelAsmReadThreads",
            .read_ahead_blocks = "ReadAheadBlocks",
            .access_alternate_directly = "AccessAlternateDirectly",
            .use_alternate_folder_for_online = "UseAlternateFolderForOnline",
            .oracle_path_prefix = "OraclePathPrefix",
            .use_path_prefix = "UsePathPrefix",
            .replace_path_prefix = "ReplacePathPrefix",
            .enable_homogenous_tablespace = "EnableHomogenousTablespace",
            .direct_path_no_log = "DirectPathNoLog",
            .archived_logs_only = "ArchivedLogsOnly",
            .asm_password = "AsmPassword",
            .asm_server = "AsmServer",
            .asm_user = "AsmUser",
            .char_length_semantics = "CharLengthSemantics",
            .database_name = "DatabaseName",
            .direct_path_parallel_load = "DirectPathParallelLoad",
            .fail_tasks_on_lob_truncation = "FailTasksOnLobTruncation",
            .number_datatype_scale = "NumberDatatypeScale",
            .password = "Password",
            .port = "Port",
            .read_table_space_name = "ReadTableSpaceName",
            .retry_interval = "RetryInterval",
            .security_db_encryption = "SecurityDbEncryption",
            .security_db_encryption_name = "SecurityDbEncryptionName",
            .server_name = "ServerName",
            .spatial_data_option_to_geo_json_function_name = "SpatialDataOptionToGeoJsonFunctionName",
            .standby_delay_time = "StandbyDelayTime",
            .username = "Username",
            .use_b_file = "UseBFile",
            .use_direct_path_full_load = "UseDirectPathFullLoad",
            .use_logminer_reader = "UseLogminerReader",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .secrets_manager_oracle_asm_access_role_arn = "SecretsManagerOracleAsmAccessRoleArn",
            .secrets_manager_oracle_asm_secret_id = "SecretsManagerOracleAsmSecretId",
            .trim_space_in_char = "TrimSpaceInChar",
            .convert_timestamp_with_zone_to_utc = "ConvertTimestampWithZoneToUTC",
            .open_transaction_window = "OpenTransactionWindow",
        };
        return @field(mappings, field_name);
    }
};

pub const MySQLSettings = struct {
    after_connect_script: ?[]const u8 = null,
    clean_source_metadata_on_mismatch: ?bool = null,
    database_name: ?[]const u8 = null,
    events_poll_interval: ?i64 = null,
    target_db_type: ?[]const u8 = null,
    max_file_size: ?i64 = null,
    parallel_load_threads: ?i64 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    server_name: ?[]const u8 = null,
    server_timezone: ?[]const u8 = null,
    username: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,
    execute_timeout: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .after_connect_script = "AfterConnectScript",
            .clean_source_metadata_on_mismatch = "CleanSourceMetadataOnMismatch",
            .database_name = "DatabaseName",
            .events_poll_interval = "EventsPollInterval",
            .target_db_type = "TargetDbType",
            .max_file_size = "MaxFileSize",
            .parallel_load_threads = "ParallelLoadThreads",
            .password = "Password",
            .port = "Port",
            .server_name = "ServerName",
            .server_timezone = "ServerTimezone",
            .username = "Username",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .execute_timeout = "ExecuteTimeout",
        };
        return @field(mappings, field_name);
    }
};

pub const PostgreSQLSettings = struct {
    after_connect_script: ?[]const u8 = null,
    capture_ddls: ?bool = null,
    max_file_size: ?i64 = null,
    database_name: ?[]const u8 = null,
    ddl_artifacts_schema: ?[]const u8 = null,
    execute_timeout: ?i64 = null,
    fail_tasks_on_lob_truncation: ?bool = null,
    heartbeat_enable: ?bool = null,
    heartbeat_schema: ?[]const u8 = null,
    heartbeat_frequency: ?i64 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    server_name: ?[]const u8 = null,
    username: ?[]const u8 = null,
    slot_name: ?[]const u8 = null,
    plugin_name: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,
    trim_space_in_char: ?bool = null,
    map_boolean_as_boolean: ?bool = null,
    map_jsonb_as_clob: ?bool = null,
    map_long_varchar_as: ?[]const u8 = null,
    database_mode: ?[]const u8 = null,
    babelfish_database_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .after_connect_script = "AfterConnectScript",
            .capture_ddls = "CaptureDdls",
            .max_file_size = "MaxFileSize",
            .database_name = "DatabaseName",
            .ddl_artifacts_schema = "DdlArtifactsSchema",
            .execute_timeout = "ExecuteTimeout",
            .fail_tasks_on_lob_truncation = "FailTasksOnLobTruncation",
            .heartbeat_enable = "HeartbeatEnable",
            .heartbeat_schema = "HeartbeatSchema",
            .heartbeat_frequency = "HeartbeatFrequency",
            .password = "Password",
            .port = "Port",
            .server_name = "ServerName",
            .username = "Username",
            .slot_name = "SlotName",
            .plugin_name = "PluginName",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .trim_space_in_char = "TrimSpaceInChar",
            .map_boolean_as_boolean = "MapBooleanAsBoolean",
            .map_jsonb_as_clob = "MapJsonbAsClob",
            .map_long_varchar_as = "MapLongVarcharAs",
            .database_mode = "DatabaseMode",
            .babelfish_database_name = "BabelfishDatabaseName",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftSettings = struct {
    accept_any_date: ?bool = null,
    after_connect_script: ?[]const u8 = null,
    bucket_folder: ?[]const u8 = null,
    bucket_name: ?[]const u8 = null,
    case_sensitive_names: ?bool = null,
    comp_update: ?bool = null,
    connection_timeout: ?i64 = null,
    database_name: ?[]const u8 = null,
    date_format: ?[]const u8 = null,
    empty_as_null: ?bool = null,
    encryption_mode: ?[]const u8 = null,
    explicit_ids: ?bool = null,
    file_transfer_upload_streams: ?i64 = null,
    load_timeout: ?i64 = null,
    max_file_size: ?i64 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    remove_quotes: ?bool = null,
    replace_invalid_chars: ?[]const u8 = null,
    replace_chars: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    service_access_role_arn: ?[]const u8 = null,
    server_side_encryption_kms_key_id: ?[]const u8 = null,
    time_format: ?[]const u8 = null,
    trim_blanks: ?bool = null,
    truncate_columns: ?bool = null,
    username: ?[]const u8 = null,
    write_buffer_size: ?i64 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,
    map_boolean_as_boolean: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accept_any_date = "AcceptAnyDate",
            .after_connect_script = "AfterConnectScript",
            .bucket_folder = "BucketFolder",
            .bucket_name = "BucketName",
            .case_sensitive_names = "CaseSensitiveNames",
            .comp_update = "CompUpdate",
            .connection_timeout = "ConnectionTimeout",
            .database_name = "DatabaseName",
            .date_format = "DateFormat",
            .empty_as_null = "EmptyAsNull",
            .encryption_mode = "EncryptionMode",
            .explicit_ids = "ExplicitIds",
            .file_transfer_upload_streams = "FileTransferUploadStreams",
            .load_timeout = "LoadTimeout",
            .max_file_size = "MaxFileSize",
            .password = "Password",
            .port = "Port",
            .remove_quotes = "RemoveQuotes",
            .replace_invalid_chars = "ReplaceInvalidChars",
            .replace_chars = "ReplaceChars",
            .server_name = "ServerName",
            .service_access_role_arn = "ServiceAccessRoleArn",
            .server_side_encryption_kms_key_id = "ServerSideEncryptionKmsKeyId",
            .time_format = "TimeFormat",
            .trim_blanks = "TrimBlanks",
            .truncate_columns = "TruncateColumns",
            .username = "Username",
            .write_buffer_size = "WriteBufferSize",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .map_boolean_as_boolean = "MapBooleanAsBoolean",
        };
        return @field(mappings, field_name);
    }
};

pub const NeptuneSettings = struct {
    service_access_role_arn: ?[]const u8 = null,
    s3_bucket_name: []const u8,
    s3_bucket_folder: []const u8,
    error_retry_duration: ?i64 = null,
    max_file_size: ?i64 = null,
    max_retry_count: ?i64 = null,
    iam_auth_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_access_role_arn = "ServiceAccessRoleArn",
            .s3_bucket_name = "S3BucketName",
            .s3_bucket_folder = "S3BucketFolder",
            .error_retry_duration = "ErrorRetryDuration",
            .max_file_size = "MaxFileSize",
            .max_retry_count = "MaxRetryCount",
            .iam_auth_enabled = "IamAuthEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticsearchSettings = struct {
    service_access_role_arn: []const u8,
    endpoint_uri: []const u8,
    full_load_error_percentage: ?i64 = null,
    error_retry_duration: ?i64 = null,
    use_new_mapping_type: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_access_role_arn = "ServiceAccessRoleArn",
            .endpoint_uri = "EndpointUri",
            .full_load_error_percentage = "FullLoadErrorPercentage",
            .error_retry_duration = "ErrorRetryDuration",
            .use_new_mapping_type = "UseNewMappingType",
        };
        return @field(mappings, field_name);
    }
};

pub const KafkaSettings = struct {
    broker: ?[]const u8 = null,
    topic: ?[]const u8 = null,
    message_format: ?[]const u8 = null,
    include_transaction_details: ?bool = null,
    include_partition_value: ?bool = null,
    partition_include_schema_table: ?bool = null,
    include_table_alter_operations: ?bool = null,
    include_control_details: ?bool = null,
    message_max_bytes: ?i64 = null,
    include_null_and_empty: ?bool = null,
    security_protocol: ?[]const u8 = null,
    ssl_client_certificate_arn: ?[]const u8 = null,
    ssl_client_key_arn: ?[]const u8 = null,
    ssl_client_key_password: ?[]const u8 = null,
    ssl_ca_certificate_arn: ?[]const u8 = null,
    sasl_username: ?[]const u8 = null,
    sasl_password: ?[]const u8 = null,
    no_hex_prefix: ?bool = null,
    sasl_mechanism: ?[]const u8 = null,
    ssl_endpoint_identification_algorithm: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .broker = "Broker",
            .topic = "Topic",
            .message_format = "MessageFormat",
            .include_transaction_details = "IncludeTransactionDetails",
            .include_partition_value = "IncludePartitionValue",
            .partition_include_schema_table = "PartitionIncludeSchemaTable",
            .include_table_alter_operations = "IncludeTableAlterOperations",
            .include_control_details = "IncludeControlDetails",
            .message_max_bytes = "MessageMaxBytes",
            .include_null_and_empty = "IncludeNullAndEmpty",
            .security_protocol = "SecurityProtocol",
            .ssl_client_certificate_arn = "SslClientCertificateArn",
            .ssl_client_key_arn = "SslClientKeyArn",
            .ssl_client_key_password = "SslClientKeyPassword",
            .ssl_ca_certificate_arn = "SslCaCertificateArn",
            .sasl_username = "SaslUsername",
            .sasl_password = "SaslPassword",
            .no_hex_prefix = "NoHexPrefix",
            .sasl_mechanism = "SaslMechanism",
            .ssl_endpoint_identification_algorithm = "SslEndpointIdentificationAlgorithm",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisSettings = struct {
    stream_arn: ?[]const u8 = null,
    message_format: ?[]const u8 = null,
    service_access_role_arn: ?[]const u8 = null,
    include_transaction_details: ?bool = null,
    include_partition_value: ?bool = null,
    partition_include_schema_table: ?bool = null,
    include_table_alter_operations: ?bool = null,
    include_control_details: ?bool = null,
    include_null_and_empty: ?bool = null,
    no_hex_prefix: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_arn = "StreamArn",
            .message_format = "MessageFormat",
            .service_access_role_arn = "ServiceAccessRoleArn",
            .include_transaction_details = "IncludeTransactionDetails",
            .include_partition_value = "IncludePartitionValue",
            .partition_include_schema_table = "PartitionIncludeSchemaTable",
            .include_table_alter_operations = "IncludeTableAlterOperations",
            .include_control_details = "IncludeControlDetails",
            .include_null_and_empty = "IncludeNullAndEmpty",
            .no_hex_prefix = "NoHexPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const MongoDbSettings = struct {
    username: ?[]const u8 = null,
    password: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    auth_type: ?[]const u8 = null,
    auth_mechanism: ?[]const u8 = null,
    nesting_level: ?[]const u8 = null,
    extract_doc_id: ?[]const u8 = null,
    docs_to_investigate: ?[]const u8 = null,
    auth_source: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,
    use_update_look_up: ?bool = null,
    replicate_shard_collections: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .password = "Password",
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .auth_type = "AuthType",
            .auth_mechanism = "AuthMechanism",
            .nesting_level = "NestingLevel",
            .extract_doc_id = "ExtractDocId",
            .docs_to_investigate = "DocsToInvestigate",
            .auth_source = "AuthSource",
            .kms_key_id = "KmsKeyId",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .use_update_look_up = "UseUpdateLookUp",
            .replicate_shard_collections = "ReplicateShardCollections",
        };
        return @field(mappings, field_name);
    }
};

pub const DmsTransferSettings = struct {
    service_access_role_arn: ?[]const u8 = null,
    bucket_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_access_role_arn = "ServiceAccessRoleArn",
            .bucket_name = "BucketName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Settings = struct {
    service_access_role_arn: ?[]const u8 = null,
    external_table_definition: ?[]const u8 = null,
    csv_row_delimiter: ?[]const u8 = null,
    csv_delimiter: ?[]const u8 = null,
    bucket_folder: ?[]const u8 = null,
    bucket_name: ?[]const u8 = null,
    compression_type: ?[]const u8 = null,
    encryption_mode: ?[]const u8 = null,
    server_side_encryption_kms_key_id: ?[]const u8 = null,
    data_format: ?[]const u8 = null,
    encoding_type: ?[]const u8 = null,
    dict_page_size_limit: ?i64 = null,
    row_group_length: ?i64 = null,
    data_page_size: ?i64 = null,
    parquet_version: ?[]const u8 = null,
    enable_statistics: ?bool = null,
    include_op_for_full_load: ?bool = null,
    cdc_inserts_only: ?bool = null,
    timestamp_column_name: ?[]const u8 = null,
    parquet_timestamp_in_millisecond: ?bool = null,
    cdc_inserts_and_updates: ?bool = null,
    date_partition_enabled: ?bool = null,
    date_partition_sequence: ?[]const u8 = null,
    date_partition_delimiter: ?[]const u8 = null,
    use_csv_no_sup_value: ?bool = null,
    csv_no_sup_value: ?[]const u8 = null,
    preserve_transactions: ?bool = null,
    cdc_path: ?[]const u8 = null,
    use_task_start_time_for_full_load_timestamp: ?bool = null,
    canned_acl_for_objects: ?[]const u8 = null,
    add_column_name: ?bool = null,
    cdc_max_batch_interval: ?i64 = null,
    cdc_min_file_size: ?i64 = null,
    csv_null_value: ?[]const u8 = null,
    ignore_header_rows: ?i64 = null,
    max_file_size: ?i64 = null,
    rfc4180: ?bool = null,
    date_partition_timezone: ?[]const u8 = null,
    add_trailing_padding_character: ?bool = null,
    expected_bucket_owner: ?[]const u8 = null,
    glue_catalog_generation: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_access_role_arn = "ServiceAccessRoleArn",
            .external_table_definition = "ExternalTableDefinition",
            .csv_row_delimiter = "CsvRowDelimiter",
            .csv_delimiter = "CsvDelimiter",
            .bucket_folder = "BucketFolder",
            .bucket_name = "BucketName",
            .compression_type = "CompressionType",
            .encryption_mode = "EncryptionMode",
            .server_side_encryption_kms_key_id = "ServerSideEncryptionKmsKeyId",
            .data_format = "DataFormat",
            .encoding_type = "EncodingType",
            .dict_page_size_limit = "DictPageSizeLimit",
            .row_group_length = "RowGroupLength",
            .data_page_size = "DataPageSize",
            .parquet_version = "ParquetVersion",
            .enable_statistics = "EnableStatistics",
            .include_op_for_full_load = "IncludeOpForFullLoad",
            .cdc_inserts_only = "CdcInsertsOnly",
            .timestamp_column_name = "TimestampColumnName",
            .parquet_timestamp_in_millisecond = "ParquetTimestampInMillisecond",
            .cdc_inserts_and_updates = "CdcInsertsAndUpdates",
            .date_partition_enabled = "DatePartitionEnabled",
            .date_partition_sequence = "DatePartitionSequence",
            .date_partition_delimiter = "DatePartitionDelimiter",
            .use_csv_no_sup_value = "UseCsvNoSupValue",
            .csv_no_sup_value = "CsvNoSupValue",
            .preserve_transactions = "PreserveTransactions",
            .cdc_path = "CdcPath",
            .use_task_start_time_for_full_load_timestamp = "UseTaskStartTimeForFullLoadTimestamp",
            .canned_acl_for_objects = "CannedAclForObjects",
            .add_column_name = "AddColumnName",
            .cdc_max_batch_interval = "CdcMaxBatchInterval",
            .cdc_min_file_size = "CdcMinFileSize",
            .csv_null_value = "CsvNullValue",
            .ignore_header_rows = "IgnoreHeaderRows",
            .max_file_size = "MaxFileSize",
            .rfc4180 = "Rfc4180",
            .date_partition_timezone = "DatePartitionTimezone",
            .add_trailing_padding_character = "AddTrailingPaddingCharacter",
            .expected_bucket_owner = "ExpectedBucketOwner",
            .glue_catalog_generation = "GlueCatalogGeneration",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamoDbSettings = struct {
    service_access_role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_access_role_arn = "ServiceAccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DataProvider = struct {
    data_provider_name: ?[]const u8 = null,
    data_provider_arn: ?[]const u8 = null,
    data_provider_creation_time: ?i64 = null,
    description: ?[]const u8 = null,
    engine: ?[]const u8 = null,
    settings: ?DataProviderSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_provider_name = "DataProviderName",
            .data_provider_arn = "DataProviderArn",
            .data_provider_creation_time = "DataProviderCreationTime",
            .description = "Description",
            .engine = "Engine",
            .settings = "Settings",
        };
        return @field(mappings, field_name);
    }
};

pub const DataProviderSettings = union {
    redshift_settings: ?RedshiftDataProviderSettings,
    postgre_sql_settings: ?PostgreSqlDataProviderSettings,
    my_sql_settings: ?MySqlDataProviderSettings,
    oracle_settings: ?OracleDataProviderSettings,
    microsoft_sql_server_settings: ?MicrosoftSqlServerDataProviderSettings,
    doc_db_settings: ?DocDbDataProviderSettings,
    maria_db_settings: ?MariaDbDataProviderSettings,
    mongo_db_settings: ?MongoDbDataProviderSettings,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .redshift_settings = "RedshiftSettings",
            .postgre_sql_settings = "PostgreSqlSettings",
            .my_sql_settings = "MySqlSettings",
            .oracle_settings = "OracleSettings",
            .microsoft_sql_server_settings = "MicrosoftSqlServerSettings",
            .doc_db_settings = "DocDbSettings",
            .maria_db_settings = "MariaDbSettings",
            .mongo_db_settings = "MongoDbSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const MongoDbDataProviderSettings = struct {
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    ssl_mode: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    auth_type: ?[]const u8 = null,
    auth_source: ?[]const u8 = null,
    auth_mechanism: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .ssl_mode = "SslMode",
            .certificate_arn = "CertificateArn",
            .auth_type = "AuthType",
            .auth_source = "AuthSource",
            .auth_mechanism = "AuthMechanism",
        };
        return @field(mappings, field_name);
    }
};

pub const MariaDbDataProviderSettings = struct {
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    ssl_mode: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name = "ServerName",
            .port = "Port",
            .ssl_mode = "SslMode",
            .certificate_arn = "CertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DocDbDataProviderSettings = struct {
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    ssl_mode: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .ssl_mode = "SslMode",
            .certificate_arn = "CertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MicrosoftSqlServerDataProviderSettings = struct {
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    ssl_mode: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .ssl_mode = "SslMode",
            .certificate_arn = "CertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const OracleDataProviderSettings = struct {
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    ssl_mode: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    asm_server: ?[]const u8 = null,
    secrets_manager_oracle_asm_secret_id: ?[]const u8 = null,
    secrets_manager_oracle_asm_access_role_arn: ?[]const u8 = null,
    secrets_manager_security_db_encryption_secret_id: ?[]const u8 = null,
    secrets_manager_security_db_encryption_access_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .ssl_mode = "SslMode",
            .certificate_arn = "CertificateArn",
            .asm_server = "AsmServer",
            .secrets_manager_oracle_asm_secret_id = "SecretsManagerOracleAsmSecretId",
            .secrets_manager_oracle_asm_access_role_arn = "SecretsManagerOracleAsmAccessRoleArn",
            .secrets_manager_security_db_encryption_secret_id = "SecretsManagerSecurityDbEncryptionSecretId",
            .secrets_manager_security_db_encryption_access_role_arn = "SecretsManagerSecurityDbEncryptionAccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MySqlDataProviderSettings = struct {
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    ssl_mode: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name = "ServerName",
            .port = "Port",
            .ssl_mode = "SslMode",
            .certificate_arn = "CertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PostgreSqlDataProviderSettings = struct {
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    ssl_mode: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .ssl_mode = "SslMode",
            .certificate_arn = "CertificateArn",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftDataProviderSettings = struct {
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
            .resource_arn = "ResourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Certificate = struct {
    certificate_identifier: ?[]const u8 = null,
    certificate_creation_date: ?i64 = null,
    certificate_pem: ?[]const u8 = null,
    certificate_wallet: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    certificate_owner: ?[]const u8 = null,
    valid_from_date: ?i64 = null,
    valid_to_date: ?i64 = null,
    signing_algorithm: ?[]const u8 = null,
    key_length: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_identifier = "CertificateIdentifier",
            .certificate_creation_date = "CertificateCreationDate",
            .certificate_pem = "CertificatePem",
            .certificate_wallet = "CertificateWallet",
            .certificate_arn = "CertificateArn",
            .certificate_owner = "CertificateOwner",
            .valid_from_date = "ValidFromDate",
            .valid_to_date = "ValidToDate",
            .signing_algorithm = "SigningAlgorithm",
            .key_length = "KeyLength",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportMetadataModelAssessmentResultEntry = struct {
    s3_object_key: ?[]const u8 = null,
    object_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object_key = "S3ObjectKey",
            .object_url = "ObjectURL",
        };
        return @field(mappings, field_name);
    }
};

pub const TableStatistics = struct {
    schema_name: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    inserts: ?i64 = null,
    deletes: ?i64 = null,
    updates: ?i64 = null,
    ddls: ?i64 = null,
    applied_inserts: ?i64 = null,
    applied_deletes: ?i64 = null,
    applied_updates: ?i64 = null,
    applied_ddls: ?i64 = null,
    full_load_rows: ?i64 = null,
    full_load_condtnl_chk_failed_rows: ?i64 = null,
    full_load_error_rows: ?i64 = null,
    full_load_start_time: ?i64 = null,
    full_load_end_time: ?i64 = null,
    full_load_reloaded: ?bool = null,
    last_update_time: ?i64 = null,
    table_state: ?[]const u8 = null,
    validation_pending_records: ?i64 = null,
    validation_failed_records: ?i64 = null,
    validation_suspended_records: ?i64 = null,
    validation_state: ?[]const u8 = null,
    validation_state_details: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_name = "SchemaName",
            .table_name = "TableName",
            .inserts = "Inserts",
            .deletes = "Deletes",
            .updates = "Updates",
            .ddls = "Ddls",
            .applied_inserts = "AppliedInserts",
            .applied_deletes = "AppliedDeletes",
            .applied_updates = "AppliedUpdates",
            .applied_ddls = "AppliedDdls",
            .full_load_rows = "FullLoadRows",
            .full_load_condtnl_chk_failed_rows = "FullLoadCondtnlChkFailedRows",
            .full_load_error_rows = "FullLoadErrorRows",
            .full_load_start_time = "FullLoadStartTime",
            .full_load_end_time = "FullLoadEndTime",
            .full_load_reloaded = "FullLoadReloaded",
            .last_update_time = "LastUpdateTime",
            .table_state = "TableState",
            .validation_pending_records = "ValidationPendingRecords",
            .validation_failed_records = "ValidationFailedRecords",
            .validation_suspended_records = "ValidationSuspendedRecords",
            .validation_state = "ValidationState",
            .validation_state_details = "ValidationStateDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePendingMaintenanceActions = struct {
    resource_identifier: ?[]const u8 = null,
    pending_maintenance_action_details: ?[]PendingMaintenanceAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_identifier = "ResourceIdentifier",
            .pending_maintenance_action_details = "PendingMaintenanceActionDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingMaintenanceAction = struct {
    action: ?[]const u8 = null,
    auto_applied_after_date: ?i64 = null,
    forced_apply_date: ?i64 = null,
    opt_in_status: ?[]const u8 = null,
    current_apply_date: ?i64 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .auto_applied_after_date = "AutoAppliedAfterDate",
            .forced_apply_date = "ForcedApplyDate",
            .opt_in_status = "OptInStatus",
            .current_apply_date = "CurrentApplyDate",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaConversionRequest = struct {
    status: ?[]const u8 = null,
    request_identifier: ?[]const u8 = null,
    migration_project_arn: ?[]const u8 = null,
    @"error": ?ErrorDetails = null,
    export_sql_details: ?ExportSqlDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .request_identifier = "RequestIdentifier",
            .migration_project_arn = "MigrationProjectArn",
            .@"error" = "Error",
            .export_sql_details = "ExportSqlDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportSqlDetails = struct {
    s3_object_key: ?[]const u8 = null,
    object_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object_key = "S3ObjectKey",
            .object_url = "ObjectURL",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetails = union {
    default_error_details: ?DefaultErrorDetails,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_error_details = "defaultErrorDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultErrorDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const ServerShortInfoResponse = struct {
    server_id: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,
    server_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .server_id = "ServerId",
            .ip_address = "IpAddress",
            .server_name = "ServerName",
        };
        return @field(mappings, field_name);
    }
};
